// swad_text_action.c: texts of actions, in several languages

/*
    SWAD (Shared Workspace At a Distance),
    is a web platform developed at the University of Granada (Spain),
    and used to support university teaching.

    This file is part of SWAD core.
    Copyright (C) 1999-2024 Antonio Caas Vargas

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/*****************************************************************************/
/*********************************** Headers *********************************/
/*****************************************************************************/

#include "swad_action_list.h"

/*****************************************************************************/
/************************* Private global variables **************************/
/*****************************************************************************/

#ifndef L
#define L 3	// English
#endif

const char *Txt_Actions[ActLst_NUM_ACTIONS] =
	{
	[ActAll] =
#if   L==1	// ca
	"Qualsevol acci&oacute;"
#elif L==2	// de
	"Irgendeine Aktion"
#elif L==3	// en
	"Any action"
#elif L==4	// es
	"Cualquier acci&oacute;n"
#elif L==5	// fr
	"N'importe quelle action"
#elif L==6	// gn
	"Oimera&etilde;va tembiapo"
#elif L==7	// it
	"Qualsiasi azione"
#elif L==8	// pl
	"Wszelkie dzia&lstrok;ania"
#elif L==9	// pt
	"Qualquer a&ccedil;&atilde;o"
#elif L==10	// tr
	"Herhangi bir eylem"
#endif
	,
	[ActUnk] =
#if   L==1	// ca
	"Acci&oacute; desconeguda"
#elif L==2	// de
	"Unbekannte Aktion"
#elif L==3	// en
	"Unknown action"
#elif L==4	// es
	"Acci&oacute;n desconocida"
#elif L==5	// fr
	"Action inconnue"
#elif L==6	// gn
	"Tembiapo ndojekua&aacute;iva"
#elif L==7	// it
	"Azione sconosciuta"
#elif L==8	// pl
	"Nieznane dzia&lstrok;anie"
#elif L==9	// pt
	"A&ccedil;&atilde;o desconhecida"
#elif L==10	// tr
	"Bilinmeyen eylem"
#endif
	,
	[ActMnu] =
#if   L==1	// ca
	"Mostra men&uacute;"
#elif L==2	// de
	"Zeige das Men&uuml;"
#elif L==3	// en
	"Show menu"
#elif L==4	// es
	"Mostrar men&uacute;"
#elif L==5	// fr
	"Afficher le menu"
#elif L==6	// gn
	"Ohechauka men&uacute;"
#elif L==7	// it
	"Mostra menu"
#elif L==8	// pl
	"Poka&zdot; menu"
#elif L==9	// pt
	"Mostrar menu"
#elif L==10	// tr
	"Men&uuml;y&uuml; g&ouml;ster"
#endif
	,
	[ActRefCon] =
#if   L==1	// ca
	"Refrescar notificacions i connectats"
#elif L==2	// de
	"Aktualisieren Benachrichtigungen und verbundenen"
#elif L==3	// en
	"Refresh notifications and connected"
#elif L==4	// es
	"Refrescar notificaciones y conectados"
#elif L==5	// fr
	"Actualiser les notifications et connect&eacute;s"
#elif L==6	// gn
	"Ombopyahu momarandu ha o&ntilde;embojoaj&uacute;va"
#elif L==7	// it
	"Aggiornare le notifiche e gli connessi"
#elif L==8	// pl
	"Od&sacute;wie&zdot;y&cacute; powiadomienia i po&lstrok;&aogon;czy&cacute;"
#elif L==9	// pt
	"Atualizar notifica&ccedil;&otilde;es e conectados"
#elif L==10	// tr
	"Bildirimleri yenile ve ba&gbreve;lan"
#endif
	,
	[ActWebSvc] =
#if   L==1	// ca
	"Servei web (funci&oacute; API)"
#elif L==2	// de
	"Webservice (API-Funktion)"
#elif L==3	// en
	"Web service (API function)"
#elif L==4	// es
	"Servicio web (funci&oacute;n API)"
#elif L==5	// fr
	"Service Web (fonction API)"
#elif L==6	// gn
	"Servicio web (API rembiapor&atilde;)"
#elif L==7	// it
	"Servizio Web (funzione API)"
#elif L==8	// pl
	"Serwis internetowy (funkcja API)"
#elif L==9	// pt
	"Servi&ccedil;o da Web (fun&ccedil;&atilde;o de API)"
#elif L==10	// tr
	"Web hizmeti (API i&scedil;levi)"
#endif
	,
	[ActFrmLogIn] =
#if   L==1	// ca
	"P&agrave;gina d'inici"
#elif L==2	// de
	"Landingpage"
#elif L==3	// en
	"Landing page"
#elif L==4	// es
	"P&aacute;gina de inicio"
#elif L==5	// fr
	"Page initiale"
#elif L==6	// gn
	"P&aacute;gina principal"
#elif L==7	// it
	"Landing page"
#elif L==8	// pl
	"Landing page"
#elif L==9	// pt
	"Landing page"
#elif L==10	// tr
	"Anasayfa"
#endif
	,
	[ActLogIn] =
#if   L==1	// ca
	"Autenticar usuari"
#elif L==2	// de
	"Benutzer authentifizieren"
#elif L==3	// en
	"Authenticate user"
#elif L==4	// es
	"Autenticar usuario"
#elif L==5	// fr
	"Authentifier l'utilisateur"
#elif L==6	// gn
	"Omoa&ntilde;ete puruh&aacute;ra"
#elif L==7	// it
	"Autenticare l'utente"
#elif L==8	// pl
	"Uwierzytelnij u&zdot;ytkownika"
#elif L==9	// pt
	"Autenticar usu&aacute;rio"
#elif L==10	// tr
	"Kullan&inodot;c&inodot;y&inodot; do&gbreve;rula"
#endif
	,
	[ActLogInNew] =
#if   L==1	// ca
	"Autenticar usuari en compte buit"
#elif L==2	// de
	"Benutzer in leerem Konto authentifizieren"
#elif L==3	// en
	"Authenticate user in empty account"
#elif L==4	// es
	"Autenticar usuario en cuenta vac&iacute;a"
#elif L==5	// fr
	"Authentifier l'utilisateur dans un compte vide"
#elif L==6	// gn
	"Omoa&ntilde;ete puruh&aacute;ra cuenta nandi-pe"
#elif L==7	// it
	"Autenticare l'utente in un account vuoto"
#elif L==8	// pl
	"Uwierzytelnij u&zdot;ytkownika na pustym koncie"
#elif L==9	// pt
	"Autenticar usu&aacute;rio em conta vazia"
#elif L==10	// tr
	"Kullan&inodot;c&inodot;n&inodot;n kimli&gbreve;ini bo&scedil; hesapta do&gbreve;rulay&inodot;n"
#endif
	,
	[ActLogInLan] =
#if   L==1	// ca
	"Canviar idioma despr&eacute;s d'autenticar"
#elif L==2	// de
	"Sprache nach Authentifizierung &auml;ndern"
#elif L==3	// en
	"Change language after authentication"
#elif L==4	// es
	"Cambiar idioma tras autenticar"
#elif L==5	// fr
	"Changer de langue apr&egrave;s authentification"
#elif L==6	// gn
	"Emoambue &ntilde;e'&etilde; emoa&ntilde;ete rire"
#elif L==7	// it
	"Cambia lingua dopo l'autenticazione"
#elif L==8	// pl
	"Zmie&nacute; j&eogon;zyk po uwierzytelnieniu"
#elif L==9	// pt
	"Alterar idioma ap&oacute;s autentica&ccedil;&atilde;o"
#elif L==10	// tr
	"Kimlik do&gbreve;rulamas&inodot;ndan sonra dili de&gbreve;i&scedil;tir"
#endif
	,
	[ActAnnSee] =
#if   L==1	// ca
	"Marcar anunci com a vist"
#elif L==2	// de
	"Ank&uuml;ndigung als gesehen markieren"
#elif L==3	// en
	"Mark announcement as seen"
#elif L==4	// es
	"Marcar anuncio como visto"
#elif L==5	// fr
	"Marquer l'annonce comme vue"
#elif L==6	// gn
	"Marca anuncio ojehechah&aacute;icha"
#elif L==7	// it
	"Segna l'annuncio come visto"
#elif L==8	// pl
	"Oznacz og&lstrok;oszenie tak, jak wida&cacute;"
#elif L==9	// pt
	"Marcar an&uacute;ncio como visto"
#elif L==10	// tr
	"Duyuruyu g&ouml;r&uuml;ld&uuml;&gbreve;&uuml; gibi i&scedil;aretle"
#endif
	,
	[ActReqSndNewPwd] =
#if   L==1	// ca
	"Sol&middot;licitar enviament de nova contrasenya"
#elif L==2	// de
	"Fordern Sie das Senden eines neuen Passworts an"
#elif L==3	// en
	"Request to send a new password"
#elif L==4	// es
	"Solicitar env&iacute;o de nueva contrase&ntilde;a"
#elif L==5	// fr
	"Demander l'envoi d'un nouveau mot de passe"
#elif L==6	// gn
	"Ejerure emondo hag&gbreve;ua pete&itilde; &ntilde;e'&etilde;&ntilde;emi pyahu"
#elif L==7	// it
	"Richiedi l'invio di una nuova password"
#elif L==8	// pl
	"Pro&sacute;ba o przes&lstrok;anie nowego has&lstrok;a"
#elif L==9	// pt
	"Solicitar o envio de uma nova senha"
#elif L==10	// tr
	"Yeni bir &scedil;ifre g&ouml;nderme iste&gbreve;i"
#endif
	,
	[ActSndNewPwd] =
#if   L==1	// ca
	"Enviar nova contrasenya"
#elif L==2	// de
	"Neues Passwort senden"
#elif L==3	// en
	"Send new password"
#elif L==4	// es
	"Enviar nueva contrase&ntilde;a"
#elif L==5	// fr
	"Envoyer un nouveau mot de passe"
#elif L==6	// gn
	"Emondo &ntilde;e'&etilde;&ntilde;emi pyahu"
#elif L==7	// it
	"Invia nuova password"
#elif L==8	// pl
	"Wy&sacute;lij nowe has&lstrok;o"
#elif L==9	// pt
	"Enviar nova senha"
#elif L==10	// tr
	"Yeni &scedil;ifre g&ouml;nder"
#endif
	,
	[ActLogOut] =
#if   L==1	// ca
	"Tancar sessi&oacute;"
#elif L==2	// de
	"Abmelden"
#elif L==3	// en
	"Log out"
#elif L==4	// es
	"Cerrar sesi&oacute;n"
#elif L==5	// fr
	"Fermer session"
#elif L==6	// gn
	"S&#7869;"
#elif L==7	// it
	"Chiudi sessione"
#elif L==8	// pl
	"Wyloguj si&eogon;"
#elif L==9	// pt
	"Fechar sess&atilde;o"
#elif L==10	// tr
	"&Ccedil;&inodot;k&inodot;&scedil; yap"
#endif
	,
	[ActReqSch] =
#if   L==1	// ca
	"Sollicitar la recerca"
#elif L==2	// de
	"Suche anfordern"
#elif L==3	// en
	"Request search"
#elif L==4	// es
	"Solicitar b&uacute;squeda"
#elif L==5	// fr
	"Demander une recherche"
#elif L==6	// gn
	"Mba'ejerure jeheka"
#elif L==7	// it
	"Richiedere la ricerca"
#elif L==8	// pl
	"Popro&sacute; o wyszukiwanie"
#elif L==9	// pt
	"Solicitar pesquisa"
#elif L==10	// tr
	"Arama iste"
#endif
	,
	[ActSch] =
#if   L==1	// ca
	"Cercar"
#elif L==2	// de
	"Suche"
#elif L==3	// en
	"Search"
#elif L==4	// es
	"Buscar"
#elif L==5	// fr
	"Chercher"
#elif L==6	// gn
	"Heka"
#elif L==7	// it
	"Cercare"
#elif L==8	// pl
	"Szuka&cacute;"
#elif L==9	// pt
	"Procurar"
#elif L==10	// tr
	"Aramak"
#endif
	,
	[ActSeeGblTL] =
#if   L==1	// ca
	"Mostrar timeline global"
#elif L==2	// de
	"Globale Timeline anzeigen"
#elif L==3	// en
	"Show global timeline"
#elif L==4	// es
	"Mostrar timeline global"
#elif L==5	// fr
	"Afficher chronologie globale"
#elif L==6	// gn
	"Ohechauka l&iacute;nea de tiempo global"
#elif L==7	// it
	"Mostra timeline globale"
#elif L==8	// pl
	"Poka&zdot; globaln&aogon; timeline"
#elif L==9	// pt
	"Mostrar timeline global"
#elif L==10	// tr
	"K&uuml;resel zaman &ccedil;izelgesini g&ouml;ster"
#endif
	,
	[ActRefNewPubGblTL] =
#if   L==1	// ca
	"Actualitzar timeline global (noves publicacions)"
#elif L==2	// de
	"Globale Zeitleiste aktualisieren (Neuver&ouml;ffentlichungen)"
#elif L==3	// en
	"Refresh global timeline (new publications)"
#elif L==4	// es
	"Actualizar timeline global (nuevas publicaciones)"
#elif L==5	// fr
	"Actualiser la chronologie globale (nouvelles publications)"
#elif L==6	// gn
	"Ombopyahu l&iacute;nea de tiempo global (post pyahu)"
#elif L==7	// it
	"Aggiorna la sequenza temporale globale (nuove pubblicazioni)"
#elif L==8	// pl
	"Od&sacute;wie&zdot; globaln&aogon; o&sacute; czasu (nowe publikacje)"
#elif L==9	// pt
	"Atualizar linha do tempo global (novas publica&ccedil;&otilde;es)"
#elif L==10	// tr
	"K&uuml;resel zaman &ccedil;izelgesini yenile (yeni yay&inodot;nlar)"
#endif
	,
	[ActRefOldPubGblTL] =
#if   L==1	// ca
	"Mostrar publicacions anteriors a timeline global"
#elif L==2	// de
	"Fr&uuml;here Ver&ouml;ffentlichungen in der globalen Zeitleiste anzeigen"
#elif L==3	// en
	"Show previous publications in global timeline"
#elif L==4	// es
	"Mostrar publicaciones anteriores en timeline global"
#elif L==5	// fr
	"Afficher les publications pr&eacute;c&eacute;dentes dans la chronologie globale"
#elif L==6	// gn
	"Ehechauka umi kuatia&ntilde;e'&etilde; yma guare l&iacute;nea de tiempo global-pe"
#elif L==7	// it
	"Mostra le pubblicazioni precedenti nella sequenza temporale globale"
#elif L==8	// pl
	"Poka&zdot; poprzednie publikacje na globalnej osi czasu"
#elif L==9	// pt
	"Mostrar publica&ccedil;&otilde;es anteriores na linha do tempo global"
#elif L==10	// tr
	"&Ouml;nceki yay&inodot;nlar&inodot; k&uuml;resel zaman &ccedil;izelgesinde g&ouml;ster"
#endif
	,
	[ActRcvPstGblTL] =
#if   L==1	// ca
	"Create post in global timeline"	// Necessita traducci
#elif L==2	// de
	"Create post in global timeline"	// Need bersetzung
#elif L==3	// en
	"Create post in global timeline"
#elif L==4	// es
	"Crear post en timeline global"
#elif L==5	// fr
	"Create post in global timeline"	// Besoin de traduction
#elif L==6	// gn
	"Crear post en timeline global"		// Okoteve traduccin
#elif L==7	// it
	"Create post in global timeline"	// Bisogno di traduzione
#elif L==8	// pl
	"Create post in global timeline"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create post in global timeline"	// Precisa de traduo
#elif L==10	// tr
	"Create post in global timeline"	// eviri lazim!
#endif
	,
	[ActRcvComGblTL] =
#if   L==1	// ca
	"Create comment in global timeline"	// Necessita traducci
#elif L==2	// de
	"Create comment in global timeline"	// Need bersetzung
#elif L==3	// en
	"Create comment in global timeline"
#elif L==4	// es
	"Crear comentario en timeline global"
#elif L==5	// fr
	"Create comment in global timeline"	// Besoin de traduction
#elif L==6	// gn
	"Crear comentario en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Create comment in global timeline"	// Bisogno di traduzione
#elif L==8	// pl
	"Create comment in global timeline"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create comment in global timeline"	// Precisa de traduo
#elif L==10	// tr
	"Create comment in global timeline"	// eviri lazim!
#endif
	,
	[ActShoHidComGblTL] =
#if   L==1	// ca
	"Show hidden comments in global timeline"		// Necessita traducci
#elif L==2	// de
	"Show hidden comments in global timeline"		// Need bersetzung
#elif L==3	// en
	"Show hidden comments in global timeline"
#elif L==4	// es
	"Mostrar comentarios ocultos en timeline global"
#elif L==5	// fr
	"Show hidden comments in global timeline"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar comentarios ocultos en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Show hidden comments in global timeline"		// Bisogno di traduzione
#elif L==8	// pl
	"Show hidden comments in global timeline"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show hidden comments in global timeline"		// Precisa de traduo
#elif L==10	// tr
	"Show hidden comments in global timeline"		// eviri lazim!
#endif
	,
	[ActAllShaNotGblTL] =
#if   L==1	// ca
	"Show who shared a publication in global timeline"				// Necessita traducci
#elif L==2	// de
	"Show who shared a publication in global timeline"				// Need bersetzung
#elif L==3	// en
	"Show who shared a publication in global timeline"
#elif L==4	// es
	"Mostrar qui&eacute;nes compartieron una publicaci&oacute;n en timeline global"
#elif L==5	// fr
	"Show who shared a publication in global timeline"				// Besoin de traduction
#elif L==6	// gn
	"Mostrar qui&eacute;nes compartieron una publicaci&oacute;n en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Show who shared a publication in global timeline"				// Bisogno di traduzione
#elif L==8	// pl
	"Show who shared a publication in global timeline"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show who shared a publication in global timeline"				// Precisa de traduo
#elif L==10	// tr
	"Show who shared a publication in global timeline"				// eviri lazim!
#endif
	,
	[ActAllFavNotGblTL] =
#if   L==1	// ca
	"Show who favourited a publication in global timeline"						// Necessita traducci
#elif L==2	// de
	"Show who favourited a publication in global timeline"						// Need bersetzung
#elif L==3	// en
	"Show who favourited a publication in global timeline"
#elif L==4	// es
	"Mostrar qui&eacute;nes marcaron como favorita una publicaci&oacute;n en timeline global"
#elif L==5	// fr
	"Show who favourited a publication in global timeline"						// Besoin de traduction
#elif L==6	// gn
	"Mostrar qui&eacute;nes marcaron como favorita una publicaci&oacute;n en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Show who favourited a publication in global timeline"						// Bisogno di traduzione
#elif L==8	// pl
	"Show who favourited a publication in global timeline"						// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show who favourited a publication in global timeline"						// Precisa de traduo
#elif L==10	// tr
	"Show who favourited a publication in global timeline"						// eviri lazim!
#endif
	,
	[ActAllFavComGblTL] =
#if   L==1	// ca
	"Show who favourited a comment in global timeline"					// Necessita traducci
#elif L==2	// de
	"Show who favourited a comment in global timeline"					// Need bersetzung
#elif L==3	// en
	"Show who favourited a comment in global timeline"
#elif L==4	// es
	"Mostrar qui&eacute;nes marcaron como favorito un comentario en timeline global"
#elif L==5	// fr
	"Show who favourited a comment in global timeline"					// Besoin de traduction
#elif L==6	// gn
	"Mostrar qui&eacute;nes marcaron como favorito un comentario en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Show who favourited a comment in global timeline"					// Bisogno di traduzione
#elif L==8	// pl
	"Show who favourited a comment in global timeline"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show who favourited a comment in global timeline"					// Precisa de traduo
#elif L==10	// tr
	"Show who favourited a comment in global timeline"					// eviri lazim!
#endif
	,
	[ActShaNotGblTL] =
#if   L==1	// ca
	"Share a publication in global timeline"		// Necessita traducci
#elif L==2	// de
	"Share a publication in global timeline"		// Need bersetzung
#elif L==3	// en
	"Share a publication in global timeline"
#elif L==4	// es
	"Compartir una publicaci&oacute;n en timeline global"
#elif L==5	// fr
	"Share a publication in global timeline"		// Besoin de traduction
#elif L==6	// gn
	"Compartir una publicaci&oacute;n en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Share a publication in global timeline"		// Bisogno di traduzione
#elif L==8	// pl
	"Share a publication in global timeline"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Share a publication in global timeline"		// Precisa de traduo
#elif L==10	// tr
	"Share a publication in global timeline"		// eviri lazim!
#endif
	,
	[ActUnsNotGblTL] =
#if   L==1	// ca
	"Unshare a publication in global timeline"			// Necessita traducci
#elif L==2	// de
	"Unshare a publication in global timeline"			// Need bersetzung
#elif L==3	// en
	"Unshare a publication in global timeline"
#elif L==4	// es
	"Dejar de compartir una publicaci&oacute;n en timeline global"
#elif L==5	// fr
	"Unshare a publication in global timeline"			// Besoin de traduction
#elif L==6	// gn
	"Dejar de compartir una publicaci&oacute;n en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Unshare a publication in global timeline"			// Bisogno di traduzione
#elif L==8	// pl
	"Unshare a publication in global timeline"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unshare a publication in global timeline"			// Precisa de traduo
#elif L==10	// tr
	"Unshare a publication in global timeline"			// eviri lazim!
#endif
	,
	[ActFavNotGblTL] =
#if   L==1	// ca
	"Favourite a publication in global timeline"				// Necessita traducci
#elif L==2	// de
	"Favourite a publication in global timeline"				// Need bersetzung
#elif L==3	// en
	"Favourite a publication in global timeline"
#elif L==4	// es
	"Marcar como favorita una publicaci&oacute;n en timeline global"
#elif L==5	// fr
	"Favourite a publication in global timeline"				// Besoin de traduction
#elif L==6	// gn
	"Marcar como favorita una publicaci&oacute;n en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Favourite a publication in global timeline"				// Bisogno di traduzione
#elif L==8	// pl
	"Favourite a publication in global timeline"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Favourite a publication in global timeline"				// Precisa de traduo
#elif L==10	// tr
	"Favourite a publication in global timeline"				// eviri lazim!
#endif
	,
	[ActUnfNotGblTL] =
#if   L==1	// ca
	"Unfavourite a publication in global timeline"					// Necessita traducci
#elif L==2	// de
	"Unfavourite a publication in global timeline"					// Need bersetzung
#elif L==3	// en
	"Unfavourite a publication in global timeline"
#elif L==4	// es
	"Dejar de marcar como favorita una publicaci&oacute;n en timeline global"
#elif L==5	// fr
	"Unfavourite a publication in global timeline"					// Besoin de traduction
#elif L==6	// gn
	"Dejar de marcar como favorita una publicaci&oacute;n en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Unfavourite a publication in global timeline"					// Bisogno di traduzione
#elif L==8	// pl
	"Unfavourite a publication in global timeline"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unfavourite a publication in global timeline"					// Precisa de traduo
#elif L==10	// tr
	"Unfavourite a publication in global timeline"					// eviri lazim!
#endif
	,
	[ActFavComGblTL] =
#if   L==1	// ca
	"Favourite a comment in global timeline"		// Necessita traducci
#elif L==2	// de
	"Favourite a comment in global timeline"		// Need bersetzung
#elif L==3	// en
	"Favourite a comment in global timeline"
#elif L==4	// es
	"Marcar como favorito un comentario en timeline global"
#elif L==5	// fr
	"Favourite a comment in global timeline"		// Besoin de traduction
#elif L==6	// gn
	"Marcar como favorito un comentario en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Favourite a comment in global timeline"		// Bisogno di traduzione
#elif L==8	// pl
	"Favourite a comment in global timeline"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Favourite a comment in global timeline"		// Precisa de traduo
#elif L==10	// tr
	"Favourite a comment in global timeline"		// eviri lazim!
#endif
	,
	[ActUnfComGblTL] =
#if   L==1	// ca
	"Unfavourite a comment in global timeline"			// Necessita traducci
#elif L==2	// de
	"Unfavourite a comment in global timeline"			// Need bersetzung
#elif L==3	// en
	"Unfavourite a comment in global timeline"
#elif L==4	// es
	"Desmarcar como favorito un comentario en timeline global"
#elif L==5	// fr
	"Unfavourite a comment in global timeline"			// Besoin de traduction
#elif L==6	// gn
	"Desmarcar como favorito un comentario en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Unfavourite a comment in global timeline"			// Bisogno di traduzione
#elif L==8	// pl
	"Unfavourite a comment in global timeline"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unfavourite a comment in global timeline"			// Precisa de traduo
#elif L==10	// tr
	"Unfavourite a comment in global timeline"			// eviri lazim!
#endif
	,
	[ActReqRemPubGblTL] =
#if   L==1	// ca
	"Request deletion of a publication in global timeline"				// Necessita traducci
#elif L==2	// de
	"Request deletion of a publication in global timeline"				// Need bersetzung
#elif L==3	// en
	"Request deletion of a publication in global timeline"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de una publicaci&oacute;n en timeline global"
#elif L==5	// fr
	"Request deletion of a publication in global timeline"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de una publicaci&oacute;n en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Request deletion of a publication in global timeline"				// Bisogno di traduzione
#elif L==8	// pl
	"Request deletion of a publication in global timeline"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request deletion of a publication in global timeline"				// Precisa de traduo
#elif L==10	// tr
	"Request deletion of a publication in global timeline"				// eviri lazim!
#endif
	,
	[ActRemPubGblTL] =
#if   L==1	// ca
	"Delete publication in global timeline"			// Necessita traducci
#elif L==2	// de
	"Delete publication in global timeline"			// Need bersetzung
#elif L==3	// en
	"Delete publication in global timeline"
#elif L==4	// es
	"Eliminar publicaci&oacute;n en timeline global"
#elif L==5	// fr
	"Delete publication in global timeline"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar publicaci&oacute;n en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Delete publication in global timeline"			// Bisogno di traduzione
#elif L==8	// pl
	"Delete publication in global timeline"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Delete publication in global timeline"			// Precisa de traduo
#elif L==10	// tr
	"Delete publication in global timeline"			// eviri lazim!
#endif
	,
	[ActReqRemComGblTL] =
#if   L==1	// ca
	"Request deletion of a comment in global timeline"			// Necessita traducci
#elif L==2	// de
	"Request deletion of a comment in global timeline"			// Need bersetzung
#elif L==3	// en
	"Request deletion of a comment in global timeline"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de un comentario en timeline global"
#elif L==5	// fr
	"Request deletion of a comment in global timeline"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de un comentario en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Request deletion of a comment in global timeline"			// Bisogno di traduzione
#elif L==8	// pl
	"Request deletion of a comment in global timeline"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request deletion of a comment in global timeline"			// Precisa de traduo
#elif L==10	// tr
	"Request deletion of a comment in global timeline"			// eviri lazim!
#endif
	,
	[ActRemComGblTL] =
#if   L==1	// ca
	"Delete a comment in global timeline"		// Necessita traducci
#elif L==2	// de
	"Delete a comment in global timeline"		// Need bersetzung
#elif L==3	// en
	"Delete a comment in global timeline"
#elif L==4	// es
	"Eliminar comentario en timeline global"
#elif L==5	// fr
	"Delete a comment in global timeline"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar comentario en timeline global"	// Okoteve traduccin
#elif L==7	// it
	"Delete a comment in global timeline"		// Bisogno di traduzione
#elif L==8	// pl
	"Delete a comment in global timeline"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Delete a comment in global timeline"		// Precisa de traduo
#elif L==10	// tr
	"Delete a comment in global timeline"		// eviri lazim!
#endif
	,
	[ActSeeSocPrf] =
#if   L==1	// ca
	"Suggerir llista d'usuaris a seguir"
#elif L==2	// de
	"Schlagen Sie eine Liste von Benutzern vor, denen Sie folgen m&ouml;chten"
#elif L==3	// en
	"Suggest list of users to follow"
#elif L==4	// es
	"Sugerir lista de usuarios a seguir"
#elif L==5	// fr
	"Sugg&eacute;rer liste d'utilisateurs &agrave; suivre"
#elif L==6	// gn
	"Epropone lista de usuarios ojesegui ha&gtilde;ua"
#elif L==7	// it
	"Suggerisci elenco di utenti da seguire"
#elif L==8	// pl
	"Zasugeruj list&eogon; u&zdot;ytkownik&oacute;w do obserwowania"
#elif L==9	// pt
	"Sugerir lista de usu&aacute;rios a seguir"
#elif L==10	// tr
	"Takip edilecek kullan&inodot;c&inodot;lar&inodot;n listesini &ouml;ner"
#endif
	,
	[ActReqOthPubPrf] =
#if   L==1	// ca
	"Request to show public user profile"		// Necessita traducci
#elif L==2	// de
	"Request to show public user profile"		// Need bersetzung
#elif L==3	// en
	"Request to show public user profile"
#elif L==4	// es
	"Solicitar mostrar perfil de usuario"
#elif L==5	// fr
	"Request to show public user profile"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar mostrar perfil de usuario"		// Okoteve traduccin
#elif L==7	// it
	"Request to show public user profile"		// Bisogno di traduzione
#elif L==8	// pl
	"Request to show public user profile"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request to show public user profile"		// Precisa de traduo
#elif L==10	// tr
	"Request to show public user profile"		// eviri lazim!
#endif
	,
	[ActRefOldPubUsrTL] =
#if   L==1	// ca
	"Show previous publications in user timeline"			// Necessita traducci
#elif L==2	// de
	"Show previous publications in user timeline"			// Need bersetzung
#elif L==3	// en
	"Show previous publications in user timeline"
#elif L==4	// es
	"Mostrar publicaciones anteriores en timeline de usuario"
#elif L==5	// fr
	"Show previous publications in user timeline"			// Besoin de traduction
#elif L==6	// gn
	"Mostrar publicaciones anteriores en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Show previous publications in user timeline"			// Bisogno di traduzione
#elif L==8	// pl
	"Show previous publications in user timeline"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show previous publications in user timeline"			// Precisa de traduo
#elif L==10	// tr
	"Show previous publications in user timeline"			// eviri lazim!
#endif
	,
	[ActRcvPstUsrTL] =
#if   L==1	// ca
	"Create post in user timeline"			// Necessita traducci
#elif L==2	// de
	"Create post in user timeline"			// Need bersetzung
#elif L==3	// en
	"Create post in user timeline"
#elif L==4	// es
	"Crear post en timeline de usuario"
#elif L==5	// fr
	"Create post in user timeline"			// Besoin de traduction
#elif L==6	// gn
	"Crear post en timeline de usuario"		// Okoteve traduccin
#elif L==7	// it
	"Create post in user timeline"			// Bisogno di traduzione
#elif L==8	// pl
	"Create post in user timeline"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create post in user timeline"			// Precisa de traduo
#elif L==10	// tr
	"Create post in user timeline"			// eviri lazim!
#endif
	,
	[ActRcvComUsrTL] =
#if   L==1	// ca
	"Create comment in user timeline"		// Necessita traducci
#elif L==2	// de
	"Create comment in user timeline"		// Need bersetzung
#elif L==3	// en
	"Create comment in user timeline"
#elif L==4	// es
	"Crear comentario en timeline de usuario"
#elif L==5	// fr
	"Create comment in user timeline"		// Besoin de traduction
#elif L==6	// gn
	"Crear comentario en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Create comment in user timeline"		// Bisogno di traduzione
#elif L==8	// pl
	"Create comment in user timeline"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create comment in user timeline"		// Precisa de traduo
#elif L==10	// tr
	"Create comment in user timeline"		// eviri lazim!
#endif
	,
	[ActShoHidComUsrTL] =
#if   L==1	// ca
	"Show hidden comments in user timeline"			// Necessita traducci
#elif L==2	// de
	"Show hidden comments in user timeline"			// Need bersetzung
#elif L==3	// en
	"Show hidden comments in user timeline"
#elif L==4	// es
	"Mostrar comentarios ocultos en timeline de usuario"
#elif L==5	// fr
	"Show hidden comments in user timeline"			// Besoin de traduction
#elif L==6	// gn
	"Mostrar comentarios ocultos en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Show hidden comments in user timeline"			// Bisogno di traduzione
#elif L==8	// pl
	"Show hidden comments in user timeline"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show hidden comments in user timeline"			// Precisa de traduo
#elif L==10	// tr
	"Show hidden comments in user timeline"			// eviri lazim!
#endif
	,
	[ActAllShaNotUsrTL] =
#if   L==1	// ca
	"Show who shared a publication in user timeline"					// Necessita traducci
#elif L==2	// de
	"Show who shared a publication in user timeline"					// Need bersetzung
#elif L==3	// en
	"Show who shared a publication in user timeline"
#elif L==4	// es
	"Mostrar qui&eacute;nes compartieron una publicaci&oacute;n en timeline de usuario"
#elif L==5	// fr
	"Show who shared a publication in user timeline"					// Besoin de traduction
#elif L==6	// gn
	"Mostrar qui&eacute;nes compartieron una publicaci&oacute;n en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Show who shared a publication in user timeline"					// Bisogno di traduzione
#elif L==8	// pl
	"Show who shared a publication in user timeline"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show who shared a publication in user timeline"					// Precisa de traduo
#elif L==10	// tr
	"Show who shared a publication in user timeline"					// eviri lazim!
#endif
	,
	[ActAllFavNotUsrTL] =
#if   L==1	// ca
	"Show who favourited a publication in user timeline"						// Necessita traducci
#elif L==2	// de
	"Show who favourited a publication in user timeline"						// Need bersetzung
#elif L==3	// en
	"Show who favourited a publication in user timeline"
#elif L==4	// es
	"Mostrar qui&eacute;nes marcaron como favorita una publicaci&oacute;n en timeline de usuario"
#elif L==5	// fr
	"Show who favourited a publication in user timeline"						// Besoin de traduction
#elif L==6	// gn
	"Mostrar qui&eacute;nes marcaron como favorita una publicaci&oacute;n en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Show who favourited a publication in user timeline"						// Bisogno di traduzione
#elif L==8	// pl
	"Show who favourited a publication in user timeline"						// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show who favourited a publication in user timeline"						// Precisa de traduo
#elif L==10	// tr
	"Show who favourited a publication in user timeline"						// eviri lazim!
#endif
	,
	[ActAllFavComUsrTL] =
#if   L==1	// ca
	"Show who favourited a comment in user timeline"					// Necessita traducci
#elif L==2	// de
	"Show who favourited a comment in user timeline"					// Need bersetzung
#elif L==3	// en
	"Show who favourited a comment in user timeline"
#elif L==4	// es
	"Mostrar qui&eacute;nes marcaron como favorito un comentario en timeline de usuario"
#elif L==5	// fr
	"Show who favourited a comment in user timeline"					// Besoin de traduction
#elif L==6	// gn
	"Mostrar qui&eacute;nes marcaron como favorito un comentario en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Show who favourited a comment in user timeline"					// Bisogno di traduzione
#elif L==8	// pl
	"Show who favourited a comment in user timeline"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show who favourited a comment in user timeline"					// Precisa de traduo
#elif L==10	// tr
	"Show who favourited a comment in user timeline"					// eviri lazim!
#endif
	,
	[ActShaNotUsrTL] =
#if   L==1	// ca
	"Share a publication in user timeline"				// Necessita traducci
#elif L==2	// de
	"Share a publication in user timeline"				// Need bersetzung
#elif L==3	// en
	"Share a publication in user timeline"
#elif L==4	// es
	"Compartir una publicaci&oacute;n en timeline de usuario"
#elif L==5	// fr
	"Share a publication in user timeline"				// Besoin de traduction
#elif L==6	// gn
	"Compartir una publicaci&oacute;n en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Share a publication in user timeline"				// Bisogno di traduzione
#elif L==8	// pl
	"Share a publication in user timeline"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Share a publication in user timeline"				// Precisa de traduo
#elif L==10	// tr
	"Share a publication in user timeline"				// eviri lazim!
#endif
	,
	[ActUnsNotUsrTL] =
#if   L==1	// ca
	"Unshare a publication in user timeline"				// Necessita traducci
#elif L==2	// de
	"Unshare a publication in user timeline"				// Need bersetzung
#elif L==3	// en
	"Unshare a publication in user timeline"
#elif L==4	// es
	"Dejar de compartir una publicaci&oacute;n en timeline de usuario"
#elif L==5	// fr
	"Unshare a publication in user timeline"				// Besoin de traduction
#elif L==6	// gn
	"Dejar de compartir una publicaci&oacute;n en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Unshare a publication in user timeline"				// Bisogno di traduzione
#elif L==8	// pl
	"Unshare a publication in user timeline"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unshare a publication in user timeline"				// Precisa de traduo
#elif L==10	// tr
	"Unshare a publication in user timeline"				// eviri lazim!
#endif
	,
	[ActFavNotUsrTL] =
#if   L==1	// ca
	"Favourite a publication in user timeline"				// Necessita traducci
#elif L==2	// de
	"Favourite a publication in user timeline"				// Need bersetzung
#elif L==3	// en
	"Favourite a publication in user timeline"
#elif L==4	// es
	"Marcar como favorita una publicaci&oacute;n en timeline de usuario"
#elif L==5	// fr
	"Favourite a publication in user timeline"				// Besoin de traduction
#elif L==6	// gn
	"Marcar como favorita una publicaci&oacute;n en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Favourite a publication in user timeline"				// Bisogno di traduzione
#elif L==8	// pl
	"Favourite a publication in user timeline"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Favourite a publication in user timeline"				// Precisa de traduo
#elif L==10	// tr
	"Favourite a publication in user timeline"				// eviri lazim!
#endif
	,
	[ActUnfNotUsrTL] =
#if   L==1	// ca
	"Unfavourite a publication in user timeline"					// Necessita traducci
#elif L==2	// de
	"Unfavourite a publication in user timeline"					// Need bersetzung
#elif L==3	// en
	"Unfavourite a publication in user timeline"
#elif L==4	// es
	"Dejar de marcar como favorita una publicaci&oacute;n en timeline de usuario"
#elif L==5	// fr
	"Unfavourite a publication in user timeline"					// Besoin de traduction
#elif L==6	// gn
	"Dejar de marcar como favorita una publicaci&oacute;n en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Unfavourite a publication in user timeline"					// Bisogno di traduzione
#elif L==8	// pl
	"Unfavourite a publication in user timeline"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unfavourite a publication in user timeline"					// Precisa de traduo
#elif L==10	// tr
	"Unfavourite a publication in user timeline"					// eviri lazim!
#endif
	,
	[ActFavComUsrTL] =
#if   L==1	// ca
	"Favourite a comment in user timeline"				// Necessita traducci
#elif L==2	// de
	"Favourite a comment in user timeline"				// Need bersetzung
#elif L==3	// en
	"Favourite a comment in user timeline"
#elif L==4	// es
	"Marcar como favorito un comentario en timeline de usuario"
#elif L==5	// fr
	"Favourite a comment in user timeline"				// Besoin de traduction
#elif L==6	// gn
	"Marcar como favorito un comentario en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Favourite a comment in user timeline"				// Bisogno di traduzione
#elif L==8	// pl
	"Favourite a comment in user timeline"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Favourite a comment in user timeline"				// Precisa de traduo
#elif L==10	// tr
	"Favourite a comment in user timeline"				// eviri lazim!
#endif
	,
	[ActUnfComUsrTL] =
#if   L==1	// ca
	"Unfavourite a comment in user timeline"			// Necessita traducci
#elif L==2	// de
	"Unfavourite a comment in user timeline"			// Need bersetzung
#elif L==3	// en
	"Unfavourite a comment in user timeline"
#elif L==4	// es
	"Desmarcar como favorito un comentario en timeline de usuario"
#elif L==5	// fr
	"Unfavourite a comment in user timeline"			// Besoin de traduction
#elif L==6	// gn
	"Desmarcar como favorito un comentario en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Unfavourite a comment in user timeline"			// Bisogno di traduzione
#elif L==8	// pl
	"Unfavourite a comment in user timeline"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unfavourite a comment in user timeline"			// Precisa de traduo
#elif L==10	// tr
	"Unfavourite a comment in user timeline"			// eviri lazim!
#endif
	,
	[ActReqRemPubUsrTL] =
#if   L==1	// ca
	"Request deletion of a publication in user timeline"				// Necessita traducci
#elif L==2	// de
	"Request deletion of a publication in user timeline"				// Need bersetzung
#elif L==3	// en
	"Request deletion of a publication in user timeline"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de una publicaci&oacute;n en timeline de usuario"
#elif L==5	// fr
	"Request deletion of a publication in user timeline"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de una publicaci&oacute;n en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Request deletion of a publication in user timeline"				// Bisogno di traduzione
#elif L==8	// pl
	"Request deletion of a publication in user timeline"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request deletion of a publication in user timeline"				// Precisa de traduo
#elif L==10	// tr
	"Request deletion of a publication in user timeline"				// eviri lazim!
#endif
	,
	[ActRemPubUsrTL] =
#if   L==1	// ca
	"Delete publication in user timeline"			// Necessita traducci
#elif L==2	// de
	"Delete publication in user timeline"			// Need bersetzung
#elif L==3	// en
	"Delete publication in user timeline"
#elif L==4	// es
	"Eliminar publicaci&oacute;n en timeline de usuario"
#elif L==5	// fr
	"Delete publication in user timeline"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar publicaci&oacute;n en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Delete publication in user timeline"			// Bisogno di traduzione
#elif L==8	// pl
	"Delete publication in user timeline"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Delete publication in user timeline"			// Precisa de traduo
#elif L==10	// tr
	"Delete publication in user timeline"			// eviri lazim!
#endif
	,
	[ActReqRemComUsrTL] =
#if   L==1	// ca
	"Request deletion of a comment in user timeline"			// Necessita traducci
#elif L==2	// de
	"Request deletion of a comment in user timeline"			// Need bersetzung
#elif L==3	// en
	"Request deletion of a comment in user timeline"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de un comentario en timeline de usuario"
#elif L==5	// fr
	"Request deletion of a comment in user timeline"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de un comentario en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Request deletion of a comment in user timeline"			// Bisogno di traduzione
#elif L==8	// pl
	"Request deletion of a comment in user timeline"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request deletion of a comment in user timeline"			// Precisa de traduo
#elif L==10	// tr
	"Request deletion of a comment in user timeline"			// eviri lazim!
#endif
	,
	[ActRemComUsrTL] =
#if   L==1	// ca
	"Delete a comment in user timeline"		// Necessita traducci
#elif L==2	// de
	"Delete a comment in user timeline"		// Need bersetzung
#elif L==3	// en
	"Delete a comment in user timeline"
#elif L==4	// es
	"Eliminar comentario en timeline de usuario"
#elif L==5	// fr
	"Delete a comment in user timeline"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar comentario en timeline de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Delete a comment in user timeline"		// Bisogno di traduzione
#elif L==8	// pl
	"Delete a comment in user timeline"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Delete a comment in user timeline"		// Precisa de traduo
#elif L==10	// tr
	"Delete a comment in user timeline"		// eviri lazim!
#endif
	,
	[ActSeeOthPubPrf] =
#if   L==1	// ca
	"Show user profile"		// Necessita traducci
#elif L==2	// de
	"Show user profile"		// Need bersetzung
#elif L==3	// en
	"Show user profile"
#elif L==4	// es
	"Mostrar perfil de usuario"
#elif L==5	// fr
	"Show user profile"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar perfil de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Show user profile"		// Bisogno di traduzione
#elif L==8	// pl
	"Show user profile"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show user profile"		// Precisa de traduo
#elif L==10	// tr
	"Show user profile"		// eviri lazim!
#endif
	,
	[ActCalFig] =
#if   L==1	// ca
	"Calculate user figures"	// Necessita traducci
#elif L==2	// de
	"Calculate user figures"	// Need bersetzung
#elif L==3	// en
	"Calculate user figures"
#elif L==4	// es
	"Calcular cifras de usuario"
#elif L==5	// fr
	"Calculate user figures"	// Besoin de traduction
#elif L==6	// gn
	"Calcular cifras de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Calculate user figures"	// Bisogno di traduzione
#elif L==8	// pl
	"Calculate user figures"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Calculate user figures"	// Precisa de traduo
#elif L==10	// tr
	"Calculate user figures"	// eviri lazim!
#endif
	,
	[ActFolUsr] =
#if   L==1	// ca
	"Follow user"		// Necessita traducci
#elif L==2	// de
	"Follow user"		// Need bersetzung
#elif L==3	// en
	"Follow user"
#elif L==4	// es
	"Seguir usuario"
#elif L==5	// fr
	"Follow user"		// Besoin de traduction
#elif L==6	// gn
	"Seguir usuario"	// Okoteve traduccin
#elif L==7	// it
	"Follow user"		// Bisogno di traduzione
#elif L==8	// pl
	"Follow user"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Follow user"		// Precisa de traduo
#elif L==10	// tr
	"Follow user"		// eviri lazim!
#endif
	,
	[ActUnfUsr] =
#if   L==1	// ca
	"Unfollow user"			// Necessita traducci
#elif L==2	// de
	"Unfollow user"			// Need bersetzung
#elif L==3	// en
	"Unfollow user"
#elif L==4	// es
	"Dejar de seguir usuario"
#elif L==5	// fr
	"Unfollow user"			// Besoin de traduction
#elif L==6	// gn
	"Dejar de seguir usuario"	// Okoteve traduccin
#elif L==7	// it
	"Unfollow user"			// Bisogno di traduzione
#elif L==8	// pl
	"Unfollow user"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unfollow user"			// Precisa de traduo
#elif L==10	// tr
	"Unfollow user"			// eviri lazim!
#endif
	,
	[ActSeeFlg] =
#if   L==1	// ca
	"Show followed users"		// Necessita traducci
#elif L==2	// de
	"Show followed users"		// Need bersetzung
#elif L==3	// en
	"Show followed users"
#elif L==4	// es
	"Mostrar usuarios seguidos"
#elif L==5	// fr
	"Show followed users"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar usuarios seguidos"	// Okoteve traduccin
#elif L==7	// it
	"Show followed users"		// Bisogno di traduzione
#elif L==8	// pl
	"Show followed users"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show followed users"		// Precisa de traduo
#elif L==10	// tr
	"Show followed users"		// eviri lazim!
#endif
	,
	[ActSeeFlr] =
#if   L==1	// ca
	"Show followers"	// Necessita traducci
#elif L==2	// de
	"Show followers"	// Need bersetzung
#elif L==3	// en
	"Show followers"
#elif L==4	// es
	"Mostrar seguidores"
#elif L==5	// fr
	"Show followers"	// Besoin de traduction
#elif L==6	// gn
	"Mostrar seguidores"	// Okoteve traduccin
#elif L==7	// it
	"Show followers"	// Bisogno di traduzione
#elif L==8	// pl
	"Show followers"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show followers"	// Precisa de traduo
#elif L==10	// tr
	"Show followers"	// eviri lazim!
#endif
	,
	[ActSeeUsrAgd] =
#if   L==1	// ca
	"See a user's public agenda"			// Necessita traducci
#elif L==2	// de
	"See a user's public agenda"			// Need bersetzung
#elif L==3	// en
	"See a user's public agenda"
#elif L==4	// es
	"Ver la agenda p&uacute;blica de usuario"
#elif L==5	// fr
	"See a user's public agenda"			// Besoin de traduction
#elif L==6	// gn
	"Ver la agenda p&uacute;blica de usuario"	// Okoteve traduccin
#elif L==7	// it
	"See a user's public agenda"			// Bisogno di traduzione
#elif L==8	// pl
	"See a user's public agenda"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See a user's public agenda"			// Precisa de traduo
#elif L==10	// tr
	"See a user's public agenda"			// eviri lazim!
#endif
	,
	[ActSeeCal] =
#if   L==1	// ca
	"Mostrar calendari"
#elif L==2	// de
	"Kalender zeigen"
#elif L==3	// en
	"Show calendar"
#elif L==4	// es
	"Mostrar calendario"
#elif L==5	// fr
	"Afficher le calendrier"
#elif L==6	// gn
	"Ohechauka calendario"
#elif L==7	// it
	"Mostra il calendario"
#elif L==8	// pl
	"Poka&zdot; kalendarz"
#elif L==9	// pt
	"Mostrar calend&aacute;rio"
#elif L==10	// tr
	"Takvimi g&ouml;ster"
#endif
	,
	[ActPrnCal] =
#if   L==1	// ca
	"Print calendar"	// Necessita traducci
#elif L==2	// de
	"Print calendar"	// Need bersetzung
#elif L==3	// en
	"Print calendar"
#elif L==4	// es
	"Imprimir calendario"
#elif L==5	// fr
	"Print calendar"	// Besoin de traduction
#elif L==6	// gn
	"Imprimir calendario"	// Okoteve traduccin
#elif L==7	// it
	"Print calendar"	// Bisogno di traduzione
#elif L==8	// pl
	"Print calendar"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Print calendar"	// Precisa de traduo
#elif L==10	// tr
	"Print calendar"	// eviri lazim!
#endif
	,
	[ActChgCal1stDay] =
#if   L==1	// ca
	"Change first day of the week in calendar"		// Necessita traducci
#elif L==2	// de
	"Change first day of the week in calendar"		// Need bersetzung
#elif L==3	// en
	"Change first day of the week in calendar"
#elif L==4	// es
	"Cambiar primer d&iacute;a de la semana en calendario"
#elif L==5	// fr
	"Change first day of the week in calendar"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar primer d&iacute;a de la semana en calendario"	// Okoteve traduccin
#elif L==7	// it
	"Change first day of the week in calendar"		// Bisogno di traduzione
#elif L==8	// pl
	"Change first day of the week in calendar"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change first day of the week in calendar"		// Precisa de traduo
#elif L==10	// tr
	"Change first day of the week in calendar"		// eviri lazim!
#endif
	,
	[ActSeeNtf] =
#if   L==1	// ca
	"Mostrar notificacions"
#elif L==2	// de
	"Benachrichtigungen zeigen"
#elif L==3	// en
	"Show notifications"
#elif L==4	// es
	"Mostrar notificaciones"
#elif L==5	// fr
	"Afficher les notifications"
#elif L==6	// gn
	"Ohechauka marandu"
#elif L==7	// it
	"Mostra notifiche"
#elif L==8	// pl
	"Poka&zdot; powiadomienia"
#elif L==9	// pt
	"Mostrar notifica&ccedil;&otilde;es"
#elif L==10	// tr
	"Bildirimleri g&ouml;ster"
#endif
	,
	[ActSeeNewNtf] =
#if   L==1	// ca
	"Show notifications"		// Necessita traducci
#elif L==2	// de
	"Show notifications"		// Need bersetzung
#elif L==3	// en
	"Show notifications"
#elif L==4	// es
	"Mostrar notificaciones"
#elif L==5	// fr
	"Show notifications"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar notificaciones"	// Okoteve traduccin
#elif L==7	// it
	"Show notifications"		// Bisogno di traduzione
#elif L==8	// pl
	"Show notifications"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show notifications"		// Precisa de traduo
#elif L==10	// tr
	"Show notifications"		// eviri lazim!
#endif
	,
	[ActMrkNtfSee] =
#if   L==1	// ca
	"Mark notifications as seen"		// Necessita traducci
#elif L==2	// de
	"Mark notifications as seen"		// Need bersetzung
#elif L==3	// en
	"Mark notifications as seen"
#elif L==4	// es
	"Marcar notificaciones como vistas"
#elif L==5	// fr
	"Mark notifications as seen"		// Besoin de traduction
#elif L==6	// gn
	"Marcar notificaciones como vistas"	// Okoteve traduccin
#elif L==7	// it
	"Mark notifications as seen"		// Bisogno di traduzione
#elif L==8	// pl
	"Mark notifications as seen"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Mark notifications as seen"		// Precisa de traduo
#elif L==10	// tr
	"Mark notifications as seen"		// eviri lazim!
#endif
	,
	[ActSeeMai] =
#if   L==1	// ca
	"Show mail domains"		// Necessita traducci
#elif L==2	// de
	"Show mail domains"		// Need bersetzung
#elif L==3	// en
	"Show mail domains"
#elif L==4	// es
	"Mostrar dominios de correo"
#elif L==5	// fr
	"Show mail domains"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar dominios de correo"	// Okoteve traduccin
#elif L==7	// it
	"Show mail domains"		// Bisogno di traduzione
#elif L==8	// pl
	"Show mail domains"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show mail domains"		// Precisa de traduo
#elif L==10	// tr
	"Show mail domains"		// eviri lazim!
#endif
	,
	[ActEdiMai] =
#if   L==1	// ca
	"Edit mail domains"		// Necessita traducci
#elif L==2	// de
	"Edit mail domains"		// Need bersetzung
#elif L==3	// en
	"Edit mail domains"
#elif L==4	// es
	"Editar dominios de correo"
#elif L==5	// fr
	"Edit mail domains"		// Besoin de traduction
#elif L==6	// gn
	"Editar dominios de correo"	// Okoteve traduccin
#elif L==7	// it
	"Edit mail domains"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit mail domains"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit mail domains"		// Precisa de traduo
#elif L==10	// tr
	"Edit mail domains"		// eviri lazim!
#endif
	,
	[ActNewMai] =
#if   L==1	// ca
	"Crear domini de correu"
#elif L==2	// de
	"E-Mail-Dom&auml;ne anlegen"
#elif L==3	// en
	"Create email domain"
#elif L==4	// es
	"Crear dominio de correo"
#elif L==5	// fr
	"Cr&eacute;er domaine de messagerie"
#elif L==6	// gn
	"Crear dominio de correo"	// Okoteve traduccin
#elif L==7	// it
	"Crea campo mail"
#elif L==8	// pl
	"Utw&oacute;rz domeny mail"
#elif L==9	// pt
	"Criar dom&iacute;nio de email"
#elif L==10	// tr
	"Create email domain"		// eviri lazim!
#endif
	,
	[ActRemMai] =
#if   L==1	// ca
	"Remove email domain"		// Necessita traducci
#elif L==2	// de
	"Remove email domain"		// Need bersetzung
#elif L==3	// en
	"Remove email domain"
#elif L==4	// es
	"Eliminar dominio de correo"
#elif L==5	// fr
	"Remove email domain"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar dominio de correo"	// Okoteve traduccin
#elif L==7	// it
	"Remove email domain"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove email domain"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove email domain"		// Precisa de traduo
#elif L==10	// tr
	"Remove email domain"		// eviri lazim!
#endif
	,
	[ActRenMaiSho] =
#if   L==1	// ca
	"Change email domain"		// Necessita traducci
#elif L==2	// de
	"Change email domain"		// Need bersetzung
#elif L==3	// en
	"Change email domain"
#elif L==4	// es
	"Cambiar dominio de correo"
#elif L==5	// fr
	"Change email domain"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar dominio de correo"	// Okoteve traduccin
#elif L==7	// it
	"Change email domain"		// Bisogno di traduzione
#elif L==8	// pl
	"Change email domain"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change email domain"		// Precisa de traduo
#elif L==10	// tr
	"Change email domain"		// eviri lazim!
#endif
	,
	[ActRenMaiFul] =
#if   L==1	// ca
	"Change email domain information"			// Necessita traducci
#elif L==2	// de
	"Change email domain information"			// Need bersetzung
#elif L==3	// en
	"Change email domain information"
#elif L==4	// es
	"Cambiar informaci&oacute;n de dominio de correo"
#elif L==5	// fr
	"Change email domain information"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar informaci&oacute;n de dominio de correo"	// Okoteve traduccin
#elif L==7	// it
	"Change email domain information"			// Bisogno di traduzione
#elif L==8	// pl
	"Change email domain information"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change email domain information"			// Precisa de traduo
#elif L==10	// tr
	"Cambiar informaci&oacute;n de dominio de correo"	// eviri lazim!
#endif
	,
	[ActSeeSysInf] =
#if   L==1	// ca
	"Show information on the platform"			// Necessita traducci
#elif L==2	// de
	"Show information on the platform"			// Need bersetzung
#elif L==3	// en
	"Show information on the platform"
#elif L==4	// es
	"Mostrar informaci&oacute;n sobre la plataforma"
#elif L==5	// fr
	"Show information on the platform"			// Besoin de traduction
#elif L==6	// gn
	"Mostrar informaci&oacute;n sobre la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Show information on the platform"			// Bisogno di traduzione
#elif L==8	// pl
	"Show information on the platform"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show information on the platform"			// Precisa de traduo
#elif L==10	// tr
	"Show information on the platform"			// eviri lazim!
#endif
	,
	[ActPrnSysInf] =
#if   L==1	// ca
	"Print information on the platform"			// Necessita traducci
#elif L==2	// de
	"Print information on the platform"			// Need bersetzung
#elif L==3	// en
	"Print information on the platform"
#elif L==4	// es
	"Imprimir informaci&oacute;n sobre la plataforma"
#elif L==5	// fr
	"Print information on the platform"			// Besoin de traduction
#elif L==6	// gn
	"Imprimir informaci&oacute;n sobre la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Print information on the platform"			// Bisogno di traduzione
#elif L==8	// pl
	"Print information on the platform"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Print information on the platform"			// Precisa de traduo
#elif L==10	// tr
	"Print information on the platform"			// eviri lazim!
#endif
	,
	[ActSeeCty] =
#if   L==1	// ca
	"List countries"	// Necessita traducci
#elif L==2	// de
	"List countries"	// Need bersetzung
#elif L==3	// en
	"List countries"
#elif L==4	// es
	"Listar pa&iacute;ses"
#elif L==5	// fr
	"List countries"	// Besoin de traduction
#elif L==6	// gn
	"Listar pa&iacute;ses"	// Okoteve traduccin
#elif L==7	// it
	"List countries"	// Bisogno di traduzione
#elif L==8	// pl
	"List countries"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List countries"	// Precisa de traduo
#elif L==10	// tr
	"List countries"	// eviri lazim!
#endif
	,
	[ActEdiCty] =
#if   L==1	// ca
	"Edit countries"	// Necessita traducci
#elif L==2	// de
	"Edit countries"	// Need bersetzung
#elif L==3	// en
	"Edit countries"
#elif L==4	// es
	"Editar pa&iacute;ses"
#elif L==5	// fr
	"Edit countries"	// Besoin de traduction
#elif L==6	// gn
	"Editar pa&iacute;ses"	// Okoteve traduccin
#elif L==7	// it
	"Edit countries"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit countries"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit countries"	// Precisa de traduo
#elif L==10	// tr
	"Edit countries"	// eviri lazim!
#endif
	,
	[ActNewCty] =
#if   L==1	// ca
	"Crear pa&iacute;s"
#elif L==2	// de
	"Land eingeben"
#elif L==3	// en
	"Create country"
#elif L==4	// es
	"Crear pa&iacute;s"
#elif L==5	// fr
	"Cr&eacute;er pays"
#elif L==6	// gn
	"Crear pa&iacute;s"	// Okoteve traduccin
#elif L==7	// it
	"Creare paese"
#elif L==8	// pl
	"Utw&oacute;rz kraju"
#elif L==9	// pt
	"Criar pa&iacute;s"
#elif L==10	// tr
	"Create country"	// eviri lazim!
#endif
	,
	[ActRemCty] =
#if   L==1	// ca
	"Remove country"	// Necessita traducci
#elif L==2	// de
	"Remove country"	// Need bersetzung
#elif L==3	// en
	"Remove country"
#elif L==4	// es
	"Eliminar pa&iacute;s"
#elif L==5	// fr
	"Remove country"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar pa&iacute;s"	// Okoteve traduccin
#elif L==7	// it
	"Remove country"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove country"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove country"	// Precisa de traduo
#elif L==10	// tr
	"Remove country"	// eviri lazim!
#endif
	,
	[ActRenCty] =
#if   L==1	// ca
	"Change name of a country"		// Necessita traducci
#elif L==2	// de
	"Change name of a country"		// Need bersetzung
#elif L==3	// en
	"Change name of a country"
#elif L==4	// es
	"Cambiar nombre de un pa&iacute;s"
#elif L==5	// fr
	"Change name of a country"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre de un pa&iacute;s"	// Okoteve traduccin
#elif L==7	// it
	"Change name of a country"		// Bisogno di traduzione
#elif L==8	// pl
	"Change name of a country"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change name of a country"		// Precisa de traduo
#elif L==10	// tr
	"Change name of a country"		// eviri lazim!
#endif
	,
	[ActChgCtyWWW] =
#if   L==1	// ca
	"Change web of country"		// Necessita traducci
#elif L==2	// de
	"Change web of country"		// Need bersetzung
#elif L==3	// en
	"Change web of country"
#elif L==4	// es
	"Cambiar web de un pa&iacute;s"
#elif L==5	// fr
	"Change web of country"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar web de un pa&iacute;s"	// Okoteve traduccin
#elif L==7	// it
	"Change web of country"		// Bisogno di traduzione
#elif L==8	// pl
	"Change web of country"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change web of country"		// Precisa de traduo
#elif L==10	// tr
	"Change web of country"		// eviri lazim!
#endif
	,
	[ActSeePen] =
#if   L==1	// ca
	"Institutions, centers, titulacions i assignatures pendents d'activar"
#elif L==2	// de
	"Anh&auml;ngig Hochschulen, Lehrinstitute, Studiengang und Kursen"
#elif L==3	// en
	"Pending institutions, centers, degrees and courses"
#elif L==4	// es
	"Instituciones, centros, titulaciones y asignaturas pendientes de activar"
#elif L==5	// fr
	"&Eacute;tablissements, centers, &eacute;tudes et mati&egrave;res en attente"
#elif L==6	// gn
	"Instituciones, centros, titulaciones y asignaturas pendientes de activar"	// Okoteve traduccin
#elif L==7	// it
	"Istituzioni, centri, lauree e corsi in attesa di essere attivati"
#elif L==8	// pl
	"Instytucje, centra, stopnie i kurs&otilde;w oczekuj&aogon;cy"
#elif L==9	// pt
	"Institu&ccedil;&otilde;es, centros, graus e disciplinas pendentes"
#elif L==10	// tr
	"Pending institutions, centers, degrees and courses"				// eviri lazim!
#endif
	,
	[ActSeeLnk] =
#if   L==1	// ca
	"See institutional links"	// Necessita traducci
#elif L==2	// de
	"See institutional links"	// Need bersetzung
#elif L==3	// en
	"See institutional links"
#elif L==4	// es
	"Ver enlaces institucionales"
#elif L==5	// fr
	"See institutional links"	// Besoin de traduction
#elif L==6	// gn
	"Ver enlaces institucionales"	// Okoteve traduccin
#elif L==7	// it
	"See institutional links"	// Bisogno di traduzione
#elif L==8	// pl
	"See institutional links"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See institutional links"	// Precisa de traduo
#elif L==10	// tr
	"See institutional links"	// eviri lazim!
#endif
	,
	[ActEdiLnk] =
#if   L==1	// ca
	"Edit institutional links"		// Necessita traducci
#elif L==2	// de
	"Edit institutional links"		// Need bersetzung
#elif L==3	// en
	"Edit institutional links"
#elif L==4	// es
	"Editar enlaces institucionales"
#elif L==5	// fr
	"Edit institutional links"		// Besoin de traduction
#elif L==6	// gn
	"Editar enlaces institucionales"	// Okoteve traduccin
#elif L==7	// it
	"Edit institutional links"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit institutional links"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit institutional links"		// Precisa de traduo
#elif L==10	// tr
	"Edit institutional links"		// eviri lazim!
#endif
	,
	[ActNewLnk] =
#if   L==1	// ca
	"Crear enlla&ccedil;"
#elif L==2	// de
	"Link erstellen"
#elif L==3	// en
	"Create link"
#elif L==4	// es
	"Crear enlace"
#elif L==5	// fr
	"Cr&eacute;er lien"
#elif L==6	// gn
	"Crear enlace"	// Okoteve traduccin
#elif L==7	// it
	"Creare link"
#elif L==8	// pl
	"Utw&oacute;rz link"
#elif L==9	// pt
	"Criar liga&ccedil;&atilde;o"
#elif L==10	// tr
	"Create link"	// eviri lazim!
#endif
	,
	[ActRemLnk] =
#if   L==1	// ca
	"Request removal of institutional link"				// Necessita traducci
#elif L==2	// de
	"Request removal of institutional link"				// Need bersetzung
#elif L==3	// en
	"Request removal of institutional link"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de un enlace institucional"
#elif L==5	// fr
	"Request removal of institutional link"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de un enlace institucional"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of institutional link"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of institutional link"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of institutional link"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of institutional link"				// eviri lazim!
#endif
	,
	[ActRenLnkSho] =
#if   L==1	// ca
	"Request change of the short name of institutional link"		// Necessita traducci
#elif L==2	// de
	"Request change of the short name of institutional link"		// Need bersetzung
#elif L==3	// en
	"Request change of the short name of institutional link"
#elif L==4	// es
	"Solicitar el cambio del nombre breve de un enlace institucional"
#elif L==5	// fr
	"Request change of the short name of institutional link"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar el cambio del nombre breve de un enlace institucional"	// Okoteve traduccin
#elif L==7	// it
	"Request change of the short name of institutional link"		// Bisogno di traduzione
#elif L==8	// pl
	"Request change of the short name of institutional link"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request change of the short name of institutional link"		// Precisa de traduo
#elif L==10	// tr
	"Request change of the short name of institutional link"		// eviri lazim!
#endif
	,
	[ActRenLnkFul] =
#if   L==1	// ca
	"Request change of the full name of institutional link"			// Necessita traducci
#elif L==2	// de
	"Request change of the full name of institutional link"			// Need bersetzung
#elif L==3	// en
	"Request change of the full name of institutional link"
#elif L==4	// es
	"Solicitar el cambio del nombre completo de un enlace institucional"
#elif L==5	// fr
	"Request change of the full name of institutional link"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar el cambio del nombre completo de un enlace institucional"	// Okoteve traduccin
#elif L==7	// it
	"Request change of the full name of institutional link"			// Bisogno di traduzione
#elif L==8	// pl
	"Request change of the full name of institutional link"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request change of the full name of institutional link"			// Precisa de traduo
#elif L==10	// tr
	"Request change of the full name of institutional link"			// eviri lazim!
#endif
	,
	[ActChgLnkWWW] =
#if   L==1	// ca
	"Request change of the web of institutional link"		// Necessita traducci
#elif L==2	// de
	"Request change of the web of institutional link"		// Need bersetzung
#elif L==3	// en
	"Request change of the web of institutional link"
#elif L==4	// es
	"Solicitar el cambio de la web de un enlace institucional"
#elif L==5	// fr
	"Request change of the web of institutional link"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar el cambio de la web de un enlace institucional"	// Okoteve traduccin
#elif L==7	// it
	"Request change of the web of institutional link"		// Bisogno di traduzione
#elif L==8	// pl
	"Request change of the web of institutional link"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request change of the web of institutional link"		// Precisa de traduo
#elif L==10	// tr
	"Request change of the web of institutional link"		// eviri lazim!
#endif
	,
	[ActSeeBan] =
#if   L==1	// ca
	"See banners"		// Necessita traducci
#elif L==2	// de
	"See banners"		// Need bersetzung
#elif L==3	// en
	"See banners"
#elif L==4	// es
	"Ver banners"
#elif L==5	// fr
	"See banners"		// Besoin de traduction
#elif L==6	// gn
	"Ver banners"		// Okoteve traduccin
#elif L==7	// it
	"See banners"		// Bisogno di traduzione
#elif L==8	// pl
	"See banners"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See banners"		// Precisa de traduo
#elif L==10	// tr
	"See banners"		// eviri lazim!
#endif
	,
	[ActEdiBan] =
#if   L==1	// ca
	"Edit banners"		// Necessita traducci
#elif L==2	// de
	"Edit banners"		// Need bersetzung
#elif L==3	// en
	"Edit banners"
#elif L==4	// es
	"Editar banners"
#elif L==5	// fr
	"Edit banners"		// Besoin de traduction
#elif L==6	// gn
	"Editar banners"	// Okoteve traduccin
#elif L==7	// it
	"Edit banners"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit banners"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit banners"		// Precisa de traduo
#elif L==10	// tr
	"Edit banners"		// eviri lazim!
#endif
	,
	[ActNewBan] =
#if   L==1	// ca
	"Crear banner"
#elif L==2	// de
	"Werbebanner erstellen"
#elif L==3	// en
	"Create banner"
#elif L==4	// es
	"Crear banner"
#elif L==5	// fr
	"Cr&eacute;er banni&eacute;re"
#elif L==6	// gn
	"Omohe&ntilde;&oacute;i pancarta"
#elif L==7	// it
	"Creare banner"
#elif L==8	// pl
	"Utw&oacute;rz banner"
#elif L==9	// pt
	"Criar banner"
#elif L==10	// tr
	"Afi&scedil; olu&scedil;tur"
#endif
	,
	[ActRemBan] =
#if   L==1	// ca
	"Request removal of banner"			// Necessita traducci
#elif L==2	// de
	"Request removal of banner"			// Need bersetzung
#elif L==3	// en
	"Request removal of banner"
#elif L==4	// es
	"Solicitar eliminaci&ocute;n de banner"
#elif L==5	// fr
	"Request removal of banner"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&ocute;n de banner"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of banner"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of banner"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of banner"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of banner"			// eviri lazim!
#endif
	,
	[ActUnhBan] =
#if   L==1	// ca
	"Show a hidden banner"	// Necessita traducci
#elif L==2	// de
	"Show a hidden banner"	// Need bersetzung
#elif L==3	// en
	"Show a hidden banner"
#elif L==4	// es
	"Mostrar banner oculto"
#elif L==5	// fr
	"Show a hidden banner"	// Besoin de traduction
#elif L==6	// gn
	"Mostrar banner oculto"	// Okoteve traduccin
#elif L==7	// it
	"Show a hidden banner"	// Bisogno di traduzione
#elif L==8	// pl
	"Show a hidden banner"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show a hidden banner"	// Precisa de traduo
#elif L==10	// tr
	"Show a hidden banner"	// eviri lazim!
#endif
	,
	[ActHidBan] =
#if   L==1	// ca
	"Hide visible banner"		// Necessita traducci
#elif L==2	// de
	"Hide visible banner"		// Need bersetzung
#elif L==3	// en
	"Hide visible banner"
#elif L==4	// es
	"Ocultar un banner visible"
#elif L==5	// fr
	"Hide visible banner"		// Besoin de traduction
#elif L==6	// gn
	"Ocultar un banner visible"	// Okoteve traduccin
#elif L==7	// it
	"Hide visible banner"		// Bisogno di traduzione
#elif L==8	// pl
	"Hide visible banner"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide visible banner"		// Precisa de traduo
#elif L==10	// tr
	"Hide visible banner"		// eviri lazim!
#endif
	,
	[ActRenBanSho] =
#if   L==1	// ca
	"Request change of the short name of a banner"		// Necessita traducci
#elif L==2	// de
	"Request change of the short name of a banner"		// Need bersetzung
#elif L==3	// en
	"Request change of the short name of a banner"
#elif L==4	// es
	"Solicitar el cambio del nombre breve de un banner"
#elif L==5	// fr
	"Request change of the short name of a banner"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar el cambio del nombre breve de un banner"	// Okoteve traduccin
#elif L==7	// it
	"Request change of the short name of a banner"		// Bisogno di traduzione
#elif L==8	// pl
	"Request change of the short name of a banner"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request change of the short name of a banner"		// Precisa de traduo
#elif L==10	// tr
	"Request change of the short name of a banner"		// eviri lazim!
#endif
	,
	[ActRenBanFul] =
#if   L==1	// ca
	"Request change of the full name of a banner"		// Necessita traducci
#elif L==2	// de
	"Request change of the full name of a banner"		// Need bersetzung
#elif L==3	// en
	"Request change of the full name of a banner"
#elif L==4	// es
	"Solicitar el cambio del nombre completo de un banner"
#elif L==5	// fr
	"Request change of the full name of a banner"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar el cambio del nombre completo de un banner"	// Okoteve traduccin
#elif L==7	// it
	"Request change of the full name of a banner"		// Bisogno di traduzione
#elif L==8	// pl
	"Request change of the full name of a banner"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request change of the full name of a banner"		// Precisa de traduo
#elif L==10	// tr
	"Request change of the full name of a banner"		// eviri lazim!
#endif
	,
	[ActChgBanImg] =
#if   L==1	// ca
	"Request change of the image of a banner"	// Necessita traducci
#elif L==2	// de
	"Request change of the image of a banner"	// Need bersetzung
#elif L==3	// en
	"Request change of the image of a banner"
#elif L==4	// es
	"Solicitar el cambio de la imagen de un banner"
#elif L==5	// fr
	"Request change of the image of a banner"	// Besoin de traduction
#elif L==6	// gn
	"Solicitar el cambio de la imagen de un banner"	// Okoteve traduccin
#elif L==7	// it
	"Request change of the image of a banner"	// Bisogno di traduzione
#elif L==8	// pl
	"Request change of the image of a banner"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request change of the image of a banner"	// Precisa de traduo
#elif L==10	// tr
	"Request change of the image of a banner"	// eviri lazim!
#endif
	,
	[ActChgBanWWW] =
#if   L==1	// ca
	"Request change of the web of a banner"		// Necessita traducci
#elif L==2	// de
	"Request change of the web of a banner"		// Need bersetzung
#elif L==3	// en
	"Request change of the web of a banner"
#elif L==4	// es
	"Solicitar el cambio de la web de un banner"
#elif L==5	// fr
	"Request change of the web of a banner"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar el cambio de la web de un banner"	// Okoteve traduccin
#elif L==7	// it
	"Request change of the web of a banner"		// Bisogno di traduzione
#elif L==8	// pl
	"Request change of the web of a banner"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request change of the web of a banner"		// Precisa de traduo
#elif L==10	// tr
	"Request change of the web of a banner"		// eviri lazim!
#endif
	,
	[ActClkBan] =
#if   L==1	// ca
	"Go to a banner when clicked"	// Necessita traducci
#elif L==2	// de
	"Go to a banner when clicked"	// Need bersetzung
#elif L==3	// en
	"Go to a banner when clicked"
#elif L==4	// es
	"Ir a un banner al pulsar"
#elif L==5	// fr
	"Go to a banner when clicked"	// Besoin de traduction
#elif L==6	// gn
	"Ir a un banner al pulsar"	// Okoteve traduccin
#elif L==7	// it
	"Go to a banner when clicked"	// Bisogno di traduzione
#elif L==8	// pl
	"Go to a banner when clicked"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Go to a banner when clicked"	// Precisa de traduo
#elif L==10	// tr
	"Go to a banner when clicked"	// eviri lazim!
#endif
	,
	[ActSeePlg] =
#if   L==1	// ca
	"List plugins"		// Necessita traducci
#elif L==2	// de
	"List plugins"		// Need bersetzung
#elif L==3	// en
	"List plugins"
#elif L==4	// es
	"Listar complementos"
#elif L==5	// fr
	"List plugins"		// Besoin de traduction
#elif L==6	// gn
	"Listar complementos"	// Okoteve traduccin
#elif L==7	// it
	"List plugins"		// Bisogno di traduzione
#elif L==8	// pl
	"List plugins"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List plugins"		// Precisa de traduo
#elif L==10	// tr
	"List plugins"		// eviri lazim!
#endif
	,
	[ActEdiPlg] =
#if   L==1	// ca
	"Edit plugins"		// Necessita traducci
#elif L==2	// de
	"Edit plugins"		// Need bersetzung
#elif L==3	// en
	"Edit plugins"
#elif L==4	// es
	"Editar complementos"
#elif L==5	// fr
	"Edit plugins"		// Besoin de traduction
#elif L==6	// gn
	"Editar complementos"	// Okoteve traduccin
#elif L==7	// it
	"Edit plugins"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit plugins"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit plugins"		// Precisa de traduo
#elif L==10	// tr
	"Edit plugins"		// eviri lazim!
#endif
	,
	[ActNewPlg] =
#if   L==1	// ca
	"Crear complement"
#elif L==2	// de
	"Plugin erstellen"
#elif L==3	// en
	"Create plugin"
#elif L==4	// es
	"Crear complemento"
#elif L==5	// fr
	"Cr&eacute;er plugin"
#elif L==6	// gn
	"Crear complemento"	// Okoteve traduccin
#elif L==7	// it
	"Creare plugin"
#elif L==8	// pl
	"Utw&oacute;rz plugin"
#elif L==9	// pt
	"Criar plugin"
#elif L==10	// tr
	"Create plugin"		// eviri lazim!
#endif
	,
	[ActRemPlg] =
#if   L==1	// ca
	"Remove plugin"		// Necessita traducci
#elif L==2	// de
	"Remove plugin"		// Need bersetzung
#elif L==3	// en
	"Remove plugin"
#elif L==4	// es
	"Eliminar complemento"
#elif L==5	// fr
	"Remove plugin"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar complemento"	// Okoteve traduccin
#elif L==7	// it
	"Remove plugin"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove plugin"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove plugin"		// Precisa de traduo
#elif L==10	// tr
	"Remove plugin"		// eviri lazim!
#endif
	,
	[ActRenPlg] =
#if   L==1	// ca
	"Rename plugin"		// Necessita traducci
#elif L==2	// de
	"Rename plugin"		// Need bersetzung
#elif L==3	// en
	"Rename plugin"
#elif L==4	// es
	"Renombrar complemento"
#elif L==5	// fr
	"Rename plugin"		// Besoin de traduction
#elif L==6	// gn
	"Renombrar complemento"	// Okoteve traduccin
#elif L==7	// it
	"Rename plugin"		// Bisogno di traduzione
#elif L==8	// pl
	"Rename plugin"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename plugin"		// Precisa de traduo
#elif L==10	// tr
	"Rename plugin"		// eviri lazim!
#endif
	,
	[ActChgPlgDes] =
#if   L==1	// ca
	"Change description of a plugin"		// Necessita traducci
#elif L==2	// de
	"Change description of a plugin"		// Need bersetzung
#elif L==3	// en
	"Change description of a plugin"
#elif L==4	// es
	"Cambiar descripci&ocute;n de un complemento"
#elif L==5	// fr
	"Change description of a plugin"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar descripci&ocute;n de un complemento"	// Okoteve traduccin
#elif L==7	// it
	"Change description of a plugin"		// Bisogno di traduzione
#elif L==8	// pl
	"Change description of a plugin"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change description of a plugin"		// Precisa de traduo
#elif L==10	// tr
	"Change description of a plugin"		// eviri lazim!
#endif
	,
	[ActChgPlgLog] =
#if   L==1	// ca
	"Change logo of a plugin"		// Necessita traducci
#elif L==2	// de
	"Change logo of a plugin"		// Need bersetzung
#elif L==3	// en
	"Change logo of a plugin"
#elif L==4	// es
	"Cambiar logo de un complemento"
#elif L==5	// fr
	"Change logo of a plugin"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar logo de un complemento"	// Okoteve traduccin
#elif L==7	// it
	"Change logo of a plugin"		// Bisogno di traduzione
#elif L==8	// pl
	"Change logo of a plugin"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change logo of a plugin"		// Precisa de traduo
#elif L==10	// tr
	"Change logo of a plugin"		// eviri lazim!
#endif
	,
	[ActChgPlgAppKey] =
#if   L==1	// ca
	"Change application key of a plugin"			// Necessita traducci
#elif L==2	// de
	"Change application key of a plugin"			// Need bersetzung
#elif L==3	// en
	"Change application key of a plugin"
#elif L==4	// es
	"Cambiar clave de aplicaci&oacute;n de un complemento"
#elif L==5	// fr
	"Change application key of a plugin"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar clave de aplicaci&oacute;n de un complemento"	// Okoteve traduccin
#elif L==7	// it
	"Change application key of a plugin"			// Bisogno di traduzione
#elif L==8	// pl
	"Change application key of a plugin"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change application key of a plugin"			// Precisa de traduo
#elif L==10	// tr
	"Change application key of a plugin"			// eviri lazim!
#endif
	,
	[ActChgPlgURL] =
#if   L==1	// ca
	"Change URL of a plugin"	// Necessita traducci
#elif L==2	// de
	"Change URL of a plugin"	// Need bersetzung
#elif L==3	// en
	"Change URL of a plugin"
#elif L==4	// es
	"Cambiar URL de un complemento"
#elif L==5	// fr
	"Change URL of a plugin"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar URL de un complemento"	// Okoteve traduccin
#elif L==7	// it
	"Change URL of a plugin"	// Bisogno di traduzione
#elif L==8	// pl
	"Change URL of a plugin"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change URL of a plugin"	// Precisa de traduo
#elif L==10	// tr
	"Change URL of a plugin"	// eviri lazim!
#endif
	,
	[ActChgPlgIP] =
#if   L==1	// ca
	"Change IP address of a plugin"			// Necessita traducci
#elif L==2	// de
	"Change IP address of a plugin"			// Need bersetzung
#elif L==3	// en
	"Change IP address of a plugin"
#elif L==4	// es
	"Cambiar direcci&oacute;n IP de un complemento"
#elif L==5	// fr
	"Change IP address of a plugin"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar direcci&oacute;n IP de un complemento"	// Okoteve traduccin
#elif L==7	// it
	"Change IP address of a plugin"			// Bisogno di traduzione
#elif L==8	// pl
	"Change IP address of a plugin"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change IP address of a plugin"			// Precisa de traduo
#elif L==10	// tr
	"Change IP address of a plugin"			// eviri lazim!
#endif
	,
	[ActMtn] =
#if   L==1	// ca
	"Manteniment"
#elif L==2	// de
	"Erhaltung"
#elif L==3	// en
	"Maintenance"
#elif L==4	// es
	"Mantenimiento"
#elif L==5	// fr
	"Entretien"
#elif L==6	// gn
	"&Ntilde;emyatyr&otilde;"
#elif L==7	// it
	"Manutenzione"
#elif L==8	// pl
	"Utrzymanie"
#elif L==9	// pt
	"Manuten&ccedil;&atilde;o"
#elif L==10	// tr
	"Maintenance"	// eviri lazim!
#endif
	,
	[ActSetUp] =
#if   L==1	// ca
	"Instal lar"
#elif L==2	// de
	"Einrichten"
#elif L==3	// en
	"Set up"
#elif L==4	// es
	"Instalar"
#elif L==5	// fr
	"Installer"
#elif L==6	// gn
	"Instalar"	// Okoteve traduccin
#elif L==7	// it
	"Setup"
#elif L==8	// pl
	"Set up"
#elif L==9	// pt
	"Instalar"
#elif L==10	// tr
	"Set up"	// eviri lazim!
#endif
	,
	[ActReqRemOldCrs] =
#if   L==1	// ca
	"Request total removal of old courses"			// Necessita traducci
#elif L==2	// de
	"Request total removal of old courses"			// Need bersetzung
#elif L==3	// en
	"Request total removal of old courses"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de asignaturas antiguas"
#elif L==5	// fr
	"Request total removal of old courses"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de asignaturas antiguas"	// Okoteve traduccin
#elif L==7	// it
	"Request total removal of old courses"			// Bisogno di traduzione
#elif L==8	// pl
	"Request total removal of old courses"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request total removal of old courses"			// Precisa de traduo
#elif L==10	// tr
	"Request total removal of old courses"			// eviri lazim!
#endif
	,
	[ActRemOldCrs] =
#if   L==1	// ca
	"Remove completely old courses"			// Necessita traducci
#elif L==2	// de
	"Remove completely old courses"			// Need bersetzung
#elif L==3	// en
	"Remove completely old courses"
#elif L==4	// es
	"Eliminar completamente asignaturas antiguas"
#elif L==5	// fr
	"Remove completely old courses"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar completamente asignaturas antiguas"	// Okoteve traduccin
#elif L==7	// it
	"Remove completely old courses"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove completely old courses"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove completely old courses"			// Precisa de traduo
#elif L==10	// tr
	"Remove completely old courses"			// eviri lazim!
#endif
	,
	[ActSeeCtyInf] =
#if   L==1	// ca
	"Show information on the country"			// Necessita traducci
#elif L==2	// de
	"Show information on the country"			// Need bersetzung
#elif L==3	// en
	"Show information on the country"
#elif L==4	// es
	"Mostrar informaci&oacute;n sobre el pa&iacute;s"
#elif L==5	// fr
	"Show information on the country"			// Besoin de traduction
#elif L==6	// gn
	"Mostrar informaci&oacute;n sobre el pa&iacute;s"	// Okoteve traduccin
#elif L==7	// it
	"Show information on the country"			// Bisogno di traduzione
#elif L==8	// pl
	"Show information on the country"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show information on the country"			// Precisa de traduo
#elif L==10	// tr
	"Show information on the country"			// eviri lazim!
#endif
	,
	[ActPrnCtyInf] =
#if   L==1	// ca
	"Print information on the country"			// Necessita traducci
#elif L==2	// de
	"Print information on the country"			// Need bersetzung
#elif L==3	// en
	"Print information on the country"
#elif L==4	// es
	"Imprimir informaci&oacute;n sobre el pa&iacute;s"
#elif L==5	// fr
	"Print information on the country"			// Besoin de traduction
#elif L==6	// gn
	"Imprimir informaci&oacute;n sobre el pa&iacute;s"	// Okoteve traduccin
#elif L==7	// it
	"Print information on the country"			// Bisogno di traduzione
#elif L==8	// pl
	"Print information on the country"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Print information on the country"			// Precisa de traduo
#elif L==10	// tr
	"Print information on the country"			// eviri lazim!
#endif
	,
	[ActChgCtyMapAtt] =
#if   L==1	// ca
	"Change map attribution of a country"			// Necessita traducci
#elif L==2	// de
	"Change map attribution of a country"			// Need bersetzung
#elif L==3	// en
	"Change map attribution of a country"
#elif L==4	// es
	"Cambiar atribuci&oacute;n del mapa de un pa&iacute;s"
#elif L==5	// fr
	"Change map attribution of a country"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar atribuci&oacute;n del mapa de un pa&iacute;s"	// Okoteve traduccin
#elif L==7	// it
	"Change map attribution of a country"			// Bisogno di traduzione
#elif L==8	// pl
	"Change map attribution of a country"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change map attribution of a country"			// Precisa de traduo
#elif L==10	// tr
	"Change map attribution of a country"			// eviri lazim!
#endif
	,
	[ActSeeIns] =
#if   L==1	// ca
	"List institutions"	// Necessita traducci
#elif L==2	// de
	"List institutions"	// Need bersetzung
#elif L==3	// en
	"List institutions"
#elif L==4	// es
	"Listar instituciones"
#elif L==5	// fr
	"List institutions"	// Besoin de traduction
#elif L==6	// gn
	"Listar instituciones"	// Okoteve traduccin
#elif L==7	// it
	"List institutions"	// Bisogno di traduzione
#elif L==8	// pl
	"List institutions"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List institutions"	// Precisa de traduo
#elif L==10	// tr
	"List institutions"	// eviri lazim!
#endif
	,
	[ActEdiIns] =
#if   L==1	// ca
	"Edit institutions"	// Necessita traducci
#elif L==2	// de
	"Edit institutions"	// Need bersetzung
#elif L==3	// en
	"Edit institutions"
#elif L==4	// es
	"Editar instituciones"
#elif L==5	// fr
	"Edit institutions"	// Besoin de traduction
#elif L==6	// gn
	"Editar instituciones"	// Okoteve traduccin
#elif L==7	// it
	"Edit institutions"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit institutions"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit institutions"	// Precisa de traduo
#elif L==10	// tr
	"Edit institutions"	// eviri lazim!
#endif
	,
	[ActReqIns] =
#if   L==1	// ca
	"Request creation of institution"			// Necessita traducci
#elif L==2	// de
	"Request creation of institution"			// Need bersetzung
#elif L==3	// en
	"Request creation of institution"
#elif L==4	// es
	"Solicitar creaci&oacute;n de instituci&oacute;n"
#elif L==5	// fr
	"Request creation of institution"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar creaci&oacute;n de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request creation of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Request creation of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request creation of institution"			// Precisa de traduo
#elif L==10	// tr
	"Request creation of institution"			// eviri lazim!
#endif
	,
	[ActNewIns] =
#if   L==1	// ca
	"Crear instituci&oacute;"
#elif L==2	// de
	"Hochschule eingeben"
#elif L==3	// en
	"Create institution"
#elif L==4	// es
	"Crear instituci&oacute;n"
#elif L==5	// fr
	"Cr&eacute;er &eacute;tablissement"
#elif L==6	// gn
	"Crear instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Creare istituzione"
#elif L==8	// pl
	"Utw&oacute;rz instytucji"
#elif L==9	// pt
	"Criar institu&ccedil;&atilde;o"
#elif L==10	// tr
	"Create institution"		// eviri lazim!
#endif
	,
	[ActRemIns] =
#if   L==1	// ca
	"Remove institution"		// Necessita traducci
#elif L==2	// de
	"Remove institution"		// Need bersetzung
#elif L==3	// en
	"Remove institution"
#elif L==4	// es
	"Eliminar instituci&oacute;n"
#elif L==5	// fr
	"Remove institution"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove institution"		// Precisa de traduo
#elif L==10	// tr
	"Remove institution"		// eviri lazim!
#endif
	,
	[ActRenInsSho] =
#if   L==1	// ca
	"Change short name of institution"		// Necessita traducci
#elif L==2	// de
	"Change short name of institution"		// Need bersetzung
#elif L==3	// en
	"Change short name of institution"
#elif L==4	// es
	"Cambiar nombre breve de instituci&oacute;n"
#elif L==5	// fr
	"Change short name of institution"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre breve de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change short name of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Change short name of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change short name of institution"		// Precisa de traduo
#elif L==10	// tr
	"Change short name of institution"		// eviri lazim!
#endif
	,
	[ActRenInsFul] =
#if   L==1	// ca
	"Change full name of institution"		// Necessita traducci
#elif L==2	// de
	"Change full name of institution"		// Need bersetzung
#elif L==3	// en
	"Change full name of institution"
#elif L==4	// es
	"Cambiar nombre completo de instituci&oacute;n"
#elif L==5	// fr
	"Change full name of institution"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre completo de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change full name of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Change full name of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change full name of institution"		// Precisa de traduo
#elif L==10	// tr
	"Change full name of institution"		// eviri lazim!
#endif
	,
	[ActChgInsWWW] =
#if   L==1	// ca
	"Change web of institution"		// Necessita traducci
#elif L==2	// de
	"Change web of institution"		// Need bersetzung
#elif L==3	// en
	"Change web of institution"
#elif L==4	// es
	"Cambiar web de instituci&oacute;n"
#elif L==5	// fr
	"Change web of institution"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar web de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change web of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Change web of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change web of institution"		// Precisa de traduo
#elif L==10	// tr
	"Change web of institution"		// eviri lazim!
#endif
	,
	[ActChgInsSta] =
#if   L==1	// ca
	"Change status of institution"		// Necessita traducci
#elif L==2	// de
	"Change status of institution"		// Need bersetzung
#elif L==3	// en
	"Change status of institution"
#elif L==4	// es
	"Cambiar estado de instituci&oacute;n"
#elif L==5	// fr
	"Change status of institution"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar estado de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change status of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Change status of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change status of institution"		// Precisa de traduo
#elif L==10	// tr
	"Change status of institution"		// eviri lazim!
#endif
	,
	[ActSeeInsInf] =
#if   L==1	// ca
	"Show information on the institution"			// Necessita traducci
#elif L==2	// de
	"Show information on the institution"			// Need bersetzung
#elif L==3	// en
	"Show information on the institution"
#elif L==4	// es
	"Mostrar informaci&oacute;n sobre la instituci&oacute;n"
#elif L==5	// fr
	"Show information on the institution"			// Besoin de traduction
#elif L==6	// gn
	"Show information on the institution"			// Okoteve traduccin
#elif L==7	// it
	"Show information on the institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Show information on the institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show information on the institution"			// Precisa de traduo
#elif L==10	// tr
	"Show information on the institution"			// eviri lazim!
#endif
	,
	[ActPrnInsInf] =
#if   L==1	// ca
	"Print information on the institution"				// Necessita traducci
#elif L==2	// de
	"Print information on the institution"				// Need bersetzung
#elif L==3	// en
	"Print information on the institution"
#elif L==4	// es
	"Imprimir informaci&oacute;n sobre la instituci&oacute;n"
#elif L==5	// fr
	"Print information on the institution"				// Besoin de traduction
#elif L==6	// gn
	"Imprimir informaci&oacute;n sobre la instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Print information on the institution"				// Bisogno di traduzione
#elif L==8	// pl
	"Print information on the institution"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Print information on the institution"				// Precisa de traduo
#elif L==10	// tr
	"Print information on the institution"				// eviri lazim!
#endif
	,
	[ActChgInsCtyCfg] =
#if   L==1	// ca
	"Change country of institution in its configuration"			// Necessita traducci
#elif L==2	// de
	"Change country of institution in its configuration"			// Need bersetzung
#elif L==3	// en
	"Change country of institution in its configuration"
#elif L==4	// es
	"Cambiar pa&iacute;s de instituci&oacute;n en su configuraci&oacute;n"
#elif L==5	// fr
	"Change country of institution in its configuration"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar pa&iacute;s de instituci&oacute;n en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change country of institution in its configuration"			// Bisogno di traduzione
#elif L==8	// pl
	"Change country of institution in its configuration"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change country of institution in its configuration"			// Precisa de traduo
#elif L==10	// tr
	"Change country of institution in its configuration"			// eviri lazim!
#endif
	,
	[ActRenInsShoCfg] =
#if   L==1	// ca
	"Change short name of institution in its configuration"			// Necessita traducci
#elif L==2	// de
	"Change short name of institution in its configuration"			// Need bersetzung
#elif L==3	// en
	"Change short name of institution in its configuration"
#elif L==4	// es
	"Cambiar nombre breve de instituci&oacute;n en su configuraci&oacute;n"
#elif L==5	// fr
	"Change short name of institution in its configuration"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre breve de instituci&oacute;n en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change short name of institution in its configuration"			// Bisogno di traduzione
#elif L==8	// pl
	"Change short name of institution in its configuration"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change short name of institution in its configuration"			// Precisa de traduo
#elif L==10	// tr
	"Change short name of institution in its configuration"			// eviri lazim!
#endif
	,
	[ActRenInsFulCfg] =
#if   L==1	// ca
	"Change full name of institution in its configuration"				// Necessita traducci
#elif L==2	// de
	"Change full name of institution in its configuration"				// Need bersetzung
#elif L==3	// en
	"Change full name of institution in its configuration"
#elif L==4	// es
	"Cambiar nombre completo de instituci&oacute;n en su configuraci&oacute;n"
#elif L==5	// fr
	"Change full name of institution in its configuration"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre completo de instituci&oacute;n en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change full name of institution in its configuration"				// Bisogno di traduzione
#elif L==8	// pl
	"Change full name of institution in its configuration"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change full name of institution in its configuration"				// Precisa de traduo
#elif L==10	// tr
	"Change full name of institution in its configuration"				// eviri lazim!
#endif
	,
	[ActChgInsWWWCfg] =
#if   L==1	// ca
	"Change web of institution in its configuration"		// Necessita traducci
#elif L==2	// de
	"Change web of institution in its configuration"		// Need bersetzung
#elif L==3	// en
	"Change web of institution in its configuration"
#elif L==4	// es
	"Cambiar web de instituci&oacute;n en su configuraci&oacute;n"
#elif L==5	// fr
	"Change web of institution in its configuration"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar web de instituci&oacute;n en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change web of institution in its configuration"		// Bisogno di traduzione
#elif L==8	// pl
	"Change web of institution in its configuration"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change web of institution in its configuration"		// Precisa de traduo
#elif L==10	// tr
	"Change web of institution in its configuration"		// eviri lazim!
#endif
	,
	[ActReqInsLog] =
#if   L==1	// ca
	"Request logo of the current institution"		// Necessita traducci
#elif L==2	// de
	"Request logo of the current institution"		// Need bersetzung
#elif L==3	// en
	"Request logo of the current institution"
#elif L==4	// es
	"Solicitar el logo de instituci&oacute;n actual"
#elif L==5	// fr
	"Request logo of the current institution"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar el logo de instituci&oacute;n actual"	// Okoteve traduccin
#elif L==7	// it
	"Request logo of the current institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Request logo of the current institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request logo of the current institution"		// Precisa de traduo
#elif L==10	// tr
	"Request logo of the current institution"		// eviri lazim!
#endif
	,
	[ActRecInsLog] =
#if   L==1	// ca
	"Change logo of the current institution"	// Necessita traducci
#elif L==2	// de
	"Change logo of the current institution"	// Need bersetzung
#elif L==3	// en
	"Change logo of the current institution"
#elif L==4	// es
	"Cambiar logo de instituci&oacute;n actual"
#elif L==5	// fr
	"Change logo of the current institution"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar logo de instituci&oacute;n actual"	// Okoteve traduccin
#elif L==7	// it
	"Change logo of the current institution"	// Bisogno di traduzione
#elif L==8	// pl
	"Change logo of the current institution"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change logo of the current institution"	// Precisa de traduo
#elif L==10	// tr
	"Change logo of the current institution"	// eviri lazim!
#endif
	,
	[ActRemInsLog] =
#if   L==1	// ca
	"Remove the logo of the current institution"	// Necessita traducci
#elif L==2	// de
	"Remove the logo of the current institution"	// Need bersetzung
#elif L==3	// en
	"Remove the logo of the current institution"
#elif L==4	// es
	"Eliminar logo de instituci&oacute;n actual"
#elif L==5	// fr
	"Remove the logo of the current institution"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar logo de instituci&oacute;n actual"	// Okoteve traduccin
#elif L==7	// it
	"Remove the logo of the current institution"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove the logo of the current institution"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove the logo of the current institution"	// Precisa de traduo
#elif L==10	// tr
	"Remove the logo of the current institution"	// eviri lazim!
#endif
	,
	[ActSeeCtr] =
#if   L==1	// ca
	"List centers"		// Necessita traducci
#elif L==2	// de
	"List centers"		// Need bersetzung
#elif L==3	// en
	"List centers"
#elif L==4	// es
	"Listar centros"
#elif L==5	// fr
	"List centers"		// Besoin de traduction
#elif L==6	// gn
	"Listar centros"	// Okoteve traduccin
#elif L==7	// it
	"List centers"		// Bisogno di traduzione
#elif L==8	// pl
	"List centers"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List centers"		// Precisa de traduo
#elif L==10	// tr
	"List centers"		// eviri lazim!
#endif
	,
	[ActEdiCtr] =
#if   L==1	// ca
	"Edit centers"		// Necessita traducci
#elif L==2	// de
	"Edit centers"		// Need bersetzung
#elif L==3	// en
	"Edit centers"
#elif L==4	// es
	"Editar centros"
#elif L==5	// fr
	"Edit centers"		// Besoin de traduction
#elif L==6	// gn
	"Editar centros"	// Okoteve traduccin
#elif L==7	// it
	"Edit centers"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit centers"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit centers"		// Precisa de traduo
#elif L==10	// tr
	"Edit centers"		// eviri lazim!
#endif
	,
	[ActReqCtr] =
#if   L==1	// ca
	"Request creation of center"		// Necessita traducci
#elif L==2	// de
	"Request creation of center"		// Need bersetzung
#elif L==3	// en
	"Request creation of center"
#elif L==4	// es
	"Solicitar creaci&oacute;n de centro"
#elif L==5	// fr
	"Request creation of center"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar creaci&oacute;n de centro"	// Okoteve traduccin
#elif L==7	// it
	"Request creation of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Request creation of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request creation of center"		// Precisa de traduo
#elif L==10	// tr
	"Request creation of center"		// eviri lazim!
#endif
	,
	[ActNewCtr] =
#if   L==1	// ca
	"Crear center"
#elif L==2	// de
	"Lehrinstitut eingeben"
#elif L==3	// en
	"Create center"
#elif L==4	// es
	"Crear centro"
#elif L==5	// fr
	"Cr&eacute;er center"
#elif L==6	// gn
	"Crear centro"		// Okoteve traduccin
#elif L==7	// it
	"Creare centro"
#elif L==8	// pl
	"Utw&oacute;rz centrum"
#elif L==9	// pt
	"Criar centro"
#elif L==10	// tr
	"Create center"		// eviri lazim!
#endif
	,
	[ActRemCtr] =
#if   L==1	// ca
	"Remove center"		// Necessita traducci
#elif L==2	// de
	"Remove center"		// Need bersetzung
#elif L==3	// en
	"Remove center"
#elif L==4	// es
	"Eliminar centro"
#elif L==5	// fr
	"Remove center"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar centro"	// Okoteve traduccin
#elif L==7	// it
	"Remove center"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove center"		// Precisa de traduo
#elif L==10	// tr
	"Remove center"		// eviri lazim!
#endif
	,
	[ActChgCtrPlc] =
#if   L==1	// ca
	"Change place of center"	// Necessita traducci
#elif L==2	// de
	"Change place of center"	// Need bersetzung
#elif L==3	// en
	"Change place of center"
#elif L==4	// es
	"Cambiar lugar de centro"
#elif L==5	// fr
	"Change place of center"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar lugar de centro"	// Okoteve traduccin
#elif L==7	// it
	"Change place of center"	// Bisogno di traduzione
#elif L==8	// pl
	"Change place of center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change place of center"	// Precisa de traduo
#elif L==10	// tr
	"Change place of center"	// eviri lazim!
#endif
	,
	[ActRenCtrSho] =
#if   L==1	// ca
	"Change short name of center"		// Necessita traducci
#elif L==2	// de
	"Change short name of center"		// Need bersetzung
#elif L==3	// en
	"Change short name of center"
#elif L==4	// es
	"Cambiar nombre breve de centro"
#elif L==5	// fr
	"Change short name of center"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre breve de centro"	// Okoteve traduccin
#elif L==7	// it
	"Change short name of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Change short name of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change short name of center"		// Precisa de traduo
#elif L==10	// tr
	"Change short name of center"		// eviri lazim!
#endif
	,
	[ActRenCtrFul] =
#if   L==1	// ca
	"Change full name of center"		// Necessita traducci
#elif L==2	// de
	"Change full name of center"		// Need bersetzung
#elif L==3	// en
	"Change full name of center"
#elif L==4	// es
	"Cambiar nombre completo de centro"
#elif L==5	// fr
	"Change full name of center"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre completo de centro"	// Okoteve traduccin
#elif L==7	// it
	"Change full name of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Change full name of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change full name of center"		// Precisa de traduo
#elif L==10	// tr
	"Change full name of center"		// eviri lazim!
#endif
	,
	[ActChgCtrWWW] =
#if   L==1	// ca
	"Change web of center"	// Necessita traducci
#elif L==2	// de
	"Change web of center"	// Need bersetzung
#elif L==3	// en
	"Change web of center"
#elif L==4	// es
	"Cambiar web de centro"
#elif L==5	// fr
	"Change web of center"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar web de centro"	// Okoteve traduccin
#elif L==7	// it
	"Change web of center"	// Bisogno di traduzione
#elif L==8	// pl
	"Change web of center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change web of center"	// Precisa de traduo
#elif L==10	// tr
	"Change web of center"	// eviri lazim!
#endif
	,
	[ActChgCtrSta] =
#if   L==1	// ca
	"Change status of center"	// Necessita traducci
#elif L==2	// de
	"Change status of center"	// Need bersetzung
#elif L==3	// en
	"Change status of center"
#elif L==4	// es
	"Cambiar estado de centro"
#elif L==5	// fr
	"Change status of center"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar estado de centro"	// Okoteve traduccin
#elif L==7	// it
	"Change status of center"	// Bisogno di traduzione
#elif L==8	// pl
	"Change status of center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change status of center"	// Precisa de traduo
#elif L==10	// tr
	"Change status of center"	// eviri lazim!
#endif
	,
	[ActSeePlc] =
#if   L==1	// ca
	"List places"		// Necessita traducci
#elif L==2	// de
	"List places"		// Need bersetzung
#elif L==3	// en
	"List places"
#elif L==4	// es
	"Listar lugares"
#elif L==5	// fr
	"List places"		// Besoin de traduction
#elif L==6	// gn
	"Listar lugares"	// Okoteve traduccin
#elif L==7	// it
	"List places"		// Bisogno di traduzione
#elif L==8	// pl
	"List places"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List places"		// Precisa de traduo
#elif L==10	// tr
	"List places"		// eviri lazim!
#endif
	,
	[ActEdiPlc] =
#if   L==1	// ca
	"Edit places"		// Necessita traducci
#elif L==2	// de
	"Edit places"		// Need bersetzung
#elif L==3	// en
	"Edit places"
#elif L==4	// es
	"Editar lugares"
#elif L==5	// fr
	"Edit places"		// Besoin de traduction
#elif L==6	// gn
	"Editar lugares"	// Okoteve traduccin
#elif L==7	// it
	"Edit places"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit places"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit places"		// Precisa de traduo
#elif L==10	// tr
	"Edit places"		// eviri lazim!
#endif
	,
	[ActNewPlc] =
#if   L==1	// ca
	"Crear lloc"
#elif L==2	// de
	"Standort eingeben"
#elif L==3	// en
	"Create place"
#elif L==4	// es
	"Crear lugar"
#elif L==5	// fr
	"Cr&eacute;er emplacement"
#elif L==6	// gn
	"Crear lugar"	// Okoteve traduccin
#elif L==7	// it
	"Creare localit&grave;"
#elif L==8	// pl
	"Utw&oacute;rz miejsce"
#elif L==9	// pt
	"Criar localiza&ccedil;&atilde;o"
#elif L==10	// tr
	"Create place"	// eviri lazim!
#endif
	,
	[ActRemPlc] =
#if   L==1	// ca
	"Remove place"		// Necessita traducci
#elif L==2	// de
	"Remove place"		// Need bersetzung
#elif L==3	// en
	"Remove place"
#elif L==4	// es
	"Eliminar lugar"
#elif L==5	// fr
	"Remove place"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar lugar"	// Okoteve traduccin
#elif L==7	// it
	"Remove place"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove place"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove place"		// Precisa de traduo
#elif L==10	// tr
	"Remove place"		// eviri lazim!
#endif
	,
	[ActRenPlcSho] =
#if   L==1	// ca
	"Change short name of a place"		// Necessita traducci
#elif L==2	// de
	"Change short name of a place"		// Need bersetzung
#elif L==3	// en
	"Change short name of a place"
#elif L==4	// es
	"Cambiar nombre breve de un lugar"
#elif L==5	// fr
	"Change short name of a place"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre breve de un lugar"	// Okoteve traduccin
#elif L==7	// it
	"Change short name of a place"		// Bisogno di traduzione
#elif L==8	// pl
	"Change short name of a place"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change short name of a place"		// Precisa de traduo
#elif L==10	// tr
	"Change short name of a place"		// eviri lazim!
#endif
	,
	[ActRenPlcFul] =
#if   L==1	// ca
	"Change full name of a place"		// Necessita traducci
#elif L==2	// de
	"Change full name of a place"		// Need bersetzung
#elif L==3	// en
	"Change full name of a place"
#elif L==4	// es
	"Cambiar nombre completo de un lugar"
#elif L==5	// fr
	"Change full name of a place"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre completo de un lugar"	// Okoteve traduccin
#elif L==7	// it
	"Change full name of a place"		// Bisogno di traduzione
#elif L==8	// pl
	"Change full name of a place"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change full name of a place"		// Precisa de traduo
#elif L==10	// tr
	"Change full name of a place"		// eviri lazim!
#endif
	,
	[ActSeeDpt] =
#if   L==1	// ca
	"List departments"	// Necessita traducci
#elif L==2	// de
	"List departments"	// Need bersetzung
#elif L==3	// en
	"List departments"
#elif L==4	// es
	"Listar departamentos"
#elif L==5	// fr
	"List departments"	// Besoin de traduction
#elif L==6	// gn
	"Listar departamentos"	// Okoteve traduccin
#elif L==7	// it
	"List departments"	// Bisogno di traduzione
#elif L==8	// pl
	"List departments"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List departments"	// Precisa de traduo
#elif L==10	// tr
	"List departments"	// eviri lazim!
#endif
	,
	[ActEdiDpt] =
#if   L==1	// ca
	"Edit departments"	// Necessita traducci
#elif L==2	// de
	"Edit departments"	// Need bersetzung
#elif L==3	// en
	"Edit departments"
#elif L==4	// es
	"Editar departamentos"
#elif L==5	// fr
	"Edit departments"	// Besoin de traduction
#elif L==6	// gn
	"Editar departamentos"	// Okoteve traduccin
#elif L==7	// it
	"Edit departments"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit departments"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit departments"	// Precisa de traduo
#elif L==10	// tr
	"Edit departments"	// eviri lazim!
#endif
	,
	[ActNewDpt] =
#if   L==1	// ca
	"Crear departament"
#elif L==2	// de
	"Abteilung eingeben"
#elif L==3	// en
	"Create department"
#elif L==4	// es
	"Crear departamento"
#elif L==5	// fr
	"Cr&eacute;er d&eacute;partement"
#elif L==6	// gn
	"Crear departamento"	// Okoteve traduccin
#elif L==7	// it
	"Creare dipartimento"
#elif L==8	// pl
	"Utw&oacute;rz dzia&lstrok;u"
#elif L==9	// pt
	"Criar departamento"
#elif L==10	// tr
	"Create department"	// eviri lazim!
#endif
	,
	[ActRemDpt] =
#if   L==1	// ca
	"Remove department"	// Necessita traducci
#elif L==2	// de
	"Remove department"	// Need bersetzung
#elif L==3	// en
	"Remove department"
#elif L==4	// es
	"Eliminar departamento"
#elif L==5	// fr
	"Remove department"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar departamento"	// Okoteve traduccin
#elif L==7	// it
	"Remove department"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove department"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove department"	// Precisa de traduo
#elif L==10	// tr
	"Remove department"	// eviri lazim!
#endif
	,
	[ActChgDptIns] =
#if   L==1	// ca
	"Change institution of a department"		// Necessita traducci
#elif L==2	// de
	"Change institution of a department"		// Need bersetzung
#elif L==3	// en
	"Change institution of a department"
#elif L==4	// es
	"Cambiar instituci&oacute;n de un departamento"
#elif L==5	// fr
	"Change institution of a department"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar instituci&oacute;n de un departamento"	// Okoteve traduccin
#elif L==7	// it
	"Change institution of a department"		// Bisogno di traduzione
#elif L==8	// pl
	"Change institution of a department"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change institution of a department"		// Precisa de traduo
#elif L==10	// tr
	"Change institution of a department"		// eviri lazim!
#endif
	,
	[ActRenDptSho] =
#if   L==1	// ca
	"Change short name of a department"		// Necessita traducci
#elif L==2	// de
	"Change short name of a department"		// Need bersetzung
#elif L==3	// en
	"Change short name of a department"
#elif L==4	// es
	"Cambiar nombre breve de un departamento"
#elif L==5	// fr
	"Change short name of a department"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre breve de un departamento"	// Okoteve traduccin
#elif L==7	// it
	"Change short name of a department"		// Bisogno di traduzione
#elif L==8	// pl
	"Change short name of a department"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change short name of a department"		// Precisa de traduo
#elif L==10	// tr
	"Change short name of a department"		// eviri lazim!
#endif
	,
	[ActRenDptFul] =
#if   L==1	// ca
	"Change full name of a department"		// Necessita traducci
#elif L==2	// de
	"Change full name of a department"		// Need bersetzung
#elif L==3	// en
	"Change full name of a department"
#elif L==4	// es
	"Cambiar nombre completo de un departamento"
#elif L==4	// es
	"Change full name of a department"
#elif L==5	// fr
	"Change full name of a department"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre completo de un departamento"	// Okoteve traduccin
#elif L==7	// it
	"Change full name of a department"		// Bisogno di traduzione
#elif L==8	// pl
	"Change full name of a department"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change full name of a department"		// Precisa de traduo
#elif L==10	// tr
	"Change full name of a department"		// eviri lazim!
#endif
	,
	[ActChgDptWWW] =
#if   L==1	// ca
	"Change web of a department"		// Necessita traducci
#elif L==2	// de
	"Change web of a department"		// Need bersetzung
#elif L==3	// en
	"Change web of a department"
#elif L==4	// es
	"Cambiar web de un departamento"
#elif L==5	// fr
	"Change web of a department"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar web de un departamento"	// Okoteve traduccin
#elif L==7	// it
	"Change web of a department"		// Bisogno di traduzione
#elif L==8	// pl
	"Change web of a department"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change web of a department"		// Precisa de traduo
#elif L==10	// tr
	"Change web of a department"		// eviri lazim!
#endif
	,
	[ActSeeHld] =
#if   L==1	// ca
	"List holidays"		// Necessita traducci
#elif L==2	// de
	"List holidays"		// Need bersetzung
#elif L==3	// en
	"List holidays"
#elif L==4	// es
	"Listar festivos"
#elif L==5	// fr
	"List holidays"		// Besoin de traduction
#elif L==6	// gn
	"Listar festivos"	// Okoteve traduccin
#elif L==7	// it
	"List holidays"		// Bisogno di traduzione
#elif L==8	// pl
	"List holidays"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List holidays"		// Precisa de traduo
#elif L==10	// tr
	"List holidays"		// eviri lazim!
#endif
	,
	[ActEdiHld] =
#if   L==1	// ca
	"Edit holidays"		// Necessita traducci
#elif L==2	// de
	"Edit holidays"		// Need bersetzung
#elif L==3	// en
	"Edit holidays"
#elif L==4	// es
	"Editar festivos"
#elif L==5	// fr
	"Edit holidays"		// Besoin de traduction
#elif L==6	// gn
	"Editar festivos"	// Okoteve traduccin
#elif L==7	// it
	"Edit holidays"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit holidays"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit holidays"		// Precisa de traduo
#elif L==10	// tr
	"Edit holidays"		// eviri lazim!
#endif
	,
	[ActNewHld] =
#if   L==1	// ca
	"Crear festivitat"
#elif L==2	// de
	"Feiertag eingeben"
#elif L==3	// en
	"Create holiday"
#elif L==4	// es
	"Crear festividad"
#elif L==5	// fr
	"Cr&eacute;er f&ecirc;te"
#elif L==6	// gn
	"Omohe&ntilde;&oacute;i arete"
#elif L==7	// it
	"Creare festivit&agrave;"
#elif L==8	// pl
	"Utw&oacute;rz wakacje"
#elif L==9	// pt
	"Criar f&eacute;ria"
#elif L==10	// tr
	"Tatil olu&scedil;tur"
#endif
	,
	[ActRemHld] =
#if   L==1	// ca
	"Remove holiday"	// Necessita traducci
#elif L==2	// de
	"Remove holiday"	// Need bersetzung
#elif L==3	// en
	"Remove holiday"
#elif L==4	// es
	"Eliminar festivo"
#elif L==5	// fr
	"Remove holiday"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar festivo"	// Okoteve traduccin
#elif L==7	// it
	"Remove holiday"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove holiday"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove holiday"	// Precisa de traduo
#elif L==10	// tr
	"Remove holiday"	// eviri lazim!
#endif
	,
	[ActChgHldPlc] =
#if   L==1	// ca
	"Change place of a holiday"	// Necessita traducci
#elif L==2	// de
	"Change place of a holiday"	// Need bersetzung
#elif L==3	// en
	"Change place of a holiday"
#elif L==4	// es
	"Cambiar lugar de un festivo"
#elif L==5	// fr
	"Change place of a holiday"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar lugar de un festivo"	// Okoteve traduccin
#elif L==7	// it
	"Change place of a holiday"	// Bisogno di traduzione
#elif L==8	// pl
	"Change place of a holiday"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change place of a holiday"	// Precisa de traduo
#elif L==10	// tr
	"Change place of a holiday"	// eviri lazim!
#endif
	,
	[ActChgHldTyp] =
#if   L==1	// ca
	"Change type of a holiday"	// Necessita traducci
#elif L==2	// de
	"Change type of a holiday"	// Need bersetzung
#elif L==3	// en
	"Change type of a holiday"
#elif L==4	// es
	"Cambiar tipo de un festivo"
#elif L==5	// fr
	"Change type of a holiday"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar tipo de un festivo"	// Okoteve traduccin
#elif L==7	// it
	"Change type of a holiday"	// Bisogno di traduzione
#elif L==8	// pl
	"Change type of a holiday"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change type of a holiday"	// Precisa de traduo
#elif L==10	// tr
	"Change type of a holiday"	// eviri lazim!
#endif
	,
	[ActChgHldStrDat] =
#if   L==1	// ca
	"Change start date of a holiday"	// Necessita traducci
#elif L==2	// de
	"Change start date of a holiday"	// Need bersetzung
#elif L==3	// en
	"Change start date of a holiday"
#elif L==4	// es
	"Cambiar fecha inicial de un festivo"
#elif L==5	// fr
	"Change start date of a holiday"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar fecha inicial de un festivo"	// Okoteve traduccin
#elif L==7	// it
	"Change start date of a holiday"	// Bisogno di traduzione
#elif L==8	// pl
	"Change start date of a holiday"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change start date of a holiday"	// Precisa de traduo
#elif L==10	// tr
	"Change start date of a holiday"	// eviri lazim!
#endif
	,
	[ActChgHldEndDat] =
#if   L==1	// ca
	"Change end date of a holiday"		// Necessita traducci
#elif L==2	// de
	"Change end date of a holiday"		// Need bersetzung
#elif L==3	// en
	"Change end date of a holiday"
#elif L==4	// es
	"Cambiar fecha final de un festivo"
#elif L==5	// fr
	"Change end date of a holiday"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar fecha final de un festivo"	// Okoteve traduccin
#elif L==7	// it
	"Change end date of a holiday"		// Bisogno di traduzione
#elif L==8	// pl
	"Change end date of a holiday"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change end date of a holiday"		// Precisa de traduo
#elif L==10	// tr
	"Change end date of a holiday"		// eviri lazim!
#endif
	,
	[ActRenHld] =
#if   L==1	// ca
	"Change name of a holiday"	// Necessita traducci
#elif L==2	// de
	"Change name of a holiday"	// Need bersetzung
#elif L==3	// en
	"Change name of a holiday"
#elif L==4	// es
	"Cambiar nombre de un festivo"
#elif L==5	// fr
	"Change name of a holiday"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre de un festivo"	// Okoteve traduccin
#elif L==7	// it
	"Change name of a holiday"	// Bisogno di traduzione
#elif L==8	// pl
	"Change name of a holiday"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change name of a holiday"	// Precisa de traduo
#elif L==10	// tr
	"Change name of a holiday"	// eviri lazim!
#endif
	,
	[ActSeeCtrInf] =
#if   L==1	// ca
	"Show information on the center"		// Necessita traducci
#elif L==2	// de
	"Show information on the center"		// Need bersetzung
#elif L==3	// en
	"Show information on the center"
#elif L==4	// es
	"Mostrar informaci&oacute;n sobre el centro"
#elif L==5	// fr
	"Show information on the center"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar informaci&oacute;n sobre el centro"	// Okoteve traduccin
#elif L==7	// it
	"Show information on the center"		// Bisogno di traduzione
#elif L==8	// pl
	"Show information on the center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show information on the center"		// Precisa de traduo
#elif L==10	// tr
	"Show information on the center"		// eviri lazim!
#endif
	,
	[ActPrnCtrInf] =
#if   L==1	// ca
	"Print information on the center"		// Necessita traducci
#elif L==2	// de
	"Print information on the center"		// Need bersetzung
#elif L==3	// en
	"Print information on the center"
#elif L==4	// es
	"Imprimir informaci&oacute;n sobre el centro"
#elif L==5	// fr
	"Print information on the center"		// Besoin de traduction
#elif L==6	// gn
	"Imprimir informaci&oacute;n sobre el centro"	// Okoteve traduccin
#elif L==7	// it
	"Print information on the center"		// Bisogno di traduzione
#elif L==8	// pl
	"Print information on the center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Print information on the center"		// Precisa de traduo
#elif L==10	// tr
	"Print information on the center"		// eviri lazim!
#endif
	,
	[ActChgCtrInsCfg] =
#if   L==1	// ca
	"Change institution of center in its configuration"			// Necessita traducci
#elif L==2	// de
	"Change institution of center in its configuration"			// Need bersetzung
#elif L==3	// en
	"Change institution of center in its configuration"
#elif L==4	// es
	"Cambiar instituci&oacute;n de centro en su configuraci&oacute;n"
#elif L==5	// fr
	"Change institution of center in its configuration"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar instituci&oacute;n de centro en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change institution of center in its configuration"			// Bisogno di traduzione
#elif L==8	// pl
	"Change institution of center in its configuration"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change institution of center in its configuration"			// Precisa de traduo
#elif L==10	// tr
	"Change institution of center in its configuration"			// eviri lazim!
#endif
	,
	[ActRenCtrShoCfg] =
#if   L==1	// ca
	"Change short name center in its configuration"			// Necessita traducci
#elif L==2	// de
	"Change short name center in its configuration"			// Need bersetzung
#elif L==3	// en
	"Change short name center in its configuration"
#elif L==4	// es
	"Cambiar nombre breve de centro en su configuraci&oacute;n"
#elif L==5	// fr
	"Change short name center in its configuration"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre breve de centro en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change short name center in its configuration"			// Bisogno di traduzione
#elif L==8	// pl
	"Change short name center in its configuration"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change short name center in its configuration"			// Precisa de traduo
#elif L==10	// tr
	"Change short name center in its configuration"			// eviri lazim!
#endif
	,
	[ActRenCtrFulCfg] =
#if   L==1	// ca
	"Change full name center in its configuratio"			// Necessita traducci
#elif L==2	// de
	"Change full name center in its configuratio"			// Need bersetzung
#elif L==3	// en
	"Change full name center in its configuration"
#elif L==4	// es
	"Cambiar nombre completo de centro en su configuraci&oacute;n"
#elif L==5	// fr
	"Change full name center in its configuratio"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre completo de centro en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change full name center in its configuratio"			// Bisogno di traduzione
#elif L==8	// pl
	"Change full name center in its configuratio"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change full name center in its configuratio"			// Precisa de traduo
#elif L==10	// tr
	"Change full name center in its configuration"			// eviri lazim!
#endif
	,
	[ActChgCtrPlcCfg] =
#if   L==1	// ca
	"Change place of center in its configuration"		// Necessita traducci
#elif L==2	// de
	"Change place of center in its configuration"		// Need bersetzung
#elif L==3	// en
	"Change place of center in its configuration"
#elif L==4	// es
	"Cambiar lugar de centro en su configuraci&oacute;n"
#elif L==5	// fr
	"Change place of center in its configuration"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar lugar de centro en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change place of center in its configuration"		// Bisogno di traduzione
#elif L==8	// pl
	"Change place of center in its configuration"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change place of center in its configuration"		// Precisa de traduo
#elif L==10	// tr
	"Change place of center in its configuration"		// eviri lazim!
#endif
	,
	[ActChgCtrLatCfg] =
#if   L==1	// ca
	"Change latitude of center in its configuration"	// Necessita traducci
#elif L==2	// de
	"Change latitude of center in its configuration"	// Need bersetzung
#elif L==3	// en
	"Change latitude of center in its configuration"
#elif L==4	// es
	"Cambiar latitud de centro en su configuraci&oacute;n"
#elif L==5	// fr
	"Change latitude of center in its configuration"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar latitud de centro en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change latitude of center in its configuration"	// Bisogno di traduzione
#elif L==8	// pl
	"Change latitude of center in its configuration"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change latitude of center in its configuration"	// Precisa de traduo
#elif L==10	// tr
	"Change latitude of center in its configuration"	// eviri lazim!
#endif
	,
	[ActChgCtrLgtCfg] =
#if   L==1	// ca
	"Change longitude of center in its configuration"	// Necessita traducci
#elif L==2	// de
	"Change longitude of center in its configuration"	// Need bersetzung
#elif L==3	// en
	"Change longitude of center in its configuration"
#elif L==4	// es
	"Cambiar longitud de centro en su configuraci&oacute;n"
#elif L==5	// fr
	"Change longitude of center in its configuration"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar longitud de centro en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change longitude of center in its configuration"	// Bisogno di traduzione
#elif L==8	// pl
	"Change longitude of center in its configuration"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change longitude of center in its configuration"	// Precisa de traduo
#elif L==10	// tr
	"Change longitude of center in its configuration"	// eviri lazim!
#endif
	,
	[ActChgCtrAltCfg] =
#if   L==1	// ca
	"Change altitude of center in its configuration"	// Necessita traducci
#elif L==2	// de
	"Change altitude of center in its configuration"	// Need bersetzung
#elif L==3	// en
	"Change altitude of center in its configuration"
#elif L==4	// es
	"Cambiar altitud de centro en su configuraci&oacute;n"
#elif L==5	// fr
	"Change altitude of center in its configuration"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar altitud de centro en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change altitude of center in its configuration"	// Bisogno di traduzione
#elif L==8	// pl
	"Change altitude of center in its configuration"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change altitude of center in its configuration"	// Precisa de traduo
#elif L==10	// tr
	"Change altitude of center in its configuration"	// eviri lazim!
#endif
	,
	[ActChgCtrWWWCfg] =
#if   L==1	// ca
	"Change web of center in its configuration"		// Necessita traducci
#elif L==2	// de
	"Change web of center in its configuration"		// Need bersetzung
#elif L==3	// en
	"Change web of center in its configuration"
#elif L==4	// es
	"Cambiar web de centro en su configuraci&oacute;n"
#elif L==5	// fr
	"Change web of center in its configuration"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar web de centro en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change web of center in its configuration"		// Bisogno di traduzione
#elif L==8	// pl
	"Change web of center in its configuration"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change web of center in its configuration"		// Precisa de traduo
#elif L==10	// tr
	"Change web of center in its configuration"		// eviri lazim!
#endif
	,
	[ActReqCtrLog] =
#if   L==1	// ca
	"Request change of the logo of the current center"	// Necessita traducci
#elif L==2	// de
	"Request change of the logo of the current center"	// Need bersetzung
#elif L==3	// en
	"Request change of the logo of the current center"
#elif L==4	// es
	"Solicitar el cambio de logo de centro actual"
#elif L==5	// fr
	"Request change of the logo of the current center"	// Besoin de traduction
#elif L==6	// gn
	"Solicitar el cambio de logo de centro actual"		// Okoteve traduccin
#elif L==7	// it
	"Request change of the logo of the current center"	// Bisogno di traduzione
#elif L==8	// pl
	"Request change of the logo of the current center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request change of the logo of the current center"	// Precisa de traduo
#elif L==10	// tr
	"Request change of the logo of the current center"	// eviri lazim!
#endif
	,
	[ActRecCtrLog] =
#if   L==1	// ca
	"Change logo of the current center"	// Necessita traducci
#elif L==2	// de
	"Change logo of the current center"	// Need bersetzung
#elif L==3	// en
	"Change logo of the current center"
#elif L==4	// es
	"Cambiar logo de centro actual"
#elif L==5	// fr
	"Change logo of the current center"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar logo de centro actual"		// Okoteve traduccin
#elif L==7	// it
	"Change logo of the current center"	// Bisogno di traduzione
#elif L==8	// pl
	"Change logo of the current center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change logo of the current center"	// Precisa de traduo
#elif L==10	// tr
	"Change logo of the current center"	// eviri lazim!
#endif
	,
	[ActRemCtrLog] =
#if   L==1	// ca
	"Remove the logo of the current center"	// Necessita traducci
#elif L==2	// de
	"Remove the logo of the current center"	// Need bersetzung
#elif L==3	// en
	"Remove the logo of the current center"
#elif L==4	// es
	"Eliminar logo de centro actual"
#elif L==5	// fr
	"Remove the logo of the current center"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar logo de centro actual"	// Okoteve traduccin
#elif L==7	// it
	"Remove the logo of the current center"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove the logo of the current center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove the logo of the current center"	// Precisa de traduo
#elif L==10	// tr
	"Remove the logo of the current center"	// eviri lazim!
#endif
	,
	[ActReqCtrPho] =
#if   L==1	// ca
	"Request change of the photo of the current center"	// Necessita traducci
#elif L==2	// de
	"Request change of the photo of the current center"	// Need bersetzung
#elif L==3	// en
	"Request change of the photo of the current center"
#elif L==4	// es
	"Solicitar el cambio de foto de centro actual"
#elif L==5	// fr
	"Request change of the photo of the current center"	// Besoin de traduction
#elif L==6	// gn
	"Solicitar el cambio de foto de centro actual"		// Okoteve traduccin
#elif L==7	// it
	"Request change of the photo of the current center"	// Bisogno di traduzione
#elif L==8	// pl
	"Request change of the photo of the current center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request change of the photo of the current center"	// Precisa de traduo
#elif L==10	// tr
	"Request change of the photo of the current center"	// eviri lazim!
#endif
	,
	[ActRecCtrPho] =
#if   L==1	// ca
	"Change photo of the current center"	// Necessita traducci
#elif L==2	// de
	"Change photo of the current center"	// Need bersetzung
#elif L==3	// en
	"Change photo of the current center"
#elif L==4	// es
	"Cambiar foto de centro actual"
#elif L==5	// fr
	"Change photo of the current center"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar foto de centro actual"		// Okoteve traduccin
#elif L==7	// it
	"Change photo of the current center"	// Bisogno di traduzione
#elif L==8	// pl
	"Change photo of the current center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change photo of the current center"	// Precisa de traduo
#elif L==10	// tr
	"Change photo of the current center"	// eviri lazim!
#endif
	,
	[ActChgCtrPhoAtt] =
#if   L==1	// ca
	"Change attribution of center photo"		// Necessita traducci
#elif L==2	// de
	"Change attribution of center photo"		// Need bersetzung
#elif L==3	// en
	"Change attribution of center photo"
#elif L==4	// es
	"Cambiar atribuci&oacute;n de foto de centro"
#elif L==5	// fr
	"Change attribution of center photo"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar atribuci&oacute;n de foto de centro"	// Okoteve traduccin
#elif L==7	// it
	"Change attribution of center photo"		// Bisogno di traduzione
#elif L==8	// pl
	"Change attribution of center photo"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change attribution of center photo"		// Precisa de traduo
#elif L==10	// tr
	"Change attribution of center photo"		// eviri lazim!
#endif
	,
	[ActSeeDeg] =
#if   L==1	// ca
	"List degrees in a center"	// Necessita traducci
#elif L==2	// de
	"List degrees in a center"	// Need bersetzung
#elif L==3	// en
	"List degrees in a center"
#elif L==4	// es
	"Listar titulaciones de centro"
#elif L==5	// fr
	"List degrees in a center"	// Besoin de traduction
#elif L==6	// gn
	"Listar titulaciones de centro"	// Okoteve traduccin
#elif L==7	// it
	"List degrees in a center"	// Bisogno di traduzione
#elif L==8	// pl
	"List degrees in a center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List degrees in a center"	// Precisa de traduo
#elif L==10	// tr
	"List degrees in a center"	// eviri lazim!
#endif
	,
	[ActEdiDeg] =
#if   L==1	// ca
	"Edit degrees"		// Necessita traducci
#elif L==2	// de
	"Edit degrees"		// Need bersetzung
#elif L==3	// en
	"Edit degrees"
#elif L==4	// es
	"Editar titulaciones"
#elif L==5	// fr
	"Edit degrees"		// Besoin de traduction
#elif L==6	// gn
	"Editar titulaciones"	// Okoteve traduccin
#elif L==7	// it
	"Edit degrees"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit degrees"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit degrees"		// Precisa de traduo
#elif L==10	// tr
	"Edit degrees"		// eviri lazim!
#endif
	,
	[ActReqDeg] =
#if   L==1	// ca
	"Request creation of degree"				// Necessita traducci
#elif L==2	// de
	"Request creation of degree"				// Need bersetzung
#elif L==3	// en
	"Request creation of degree"
#elif L==4	// es
	"Solicitar creaci&oacute;n de titulaci&oacute;n"
#elif L==5	// fr
	"Request creation of degree"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar creaci&oacute;n de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request creation of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Request creation of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request creation of degree"				// Precisa de traduo
#elif L==10	// tr
	"Request creation of degree"				// eviri lazim!
#endif
	,
	[ActNewDeg] =
#if   L==1	// ca
	"Crear titulaci&oacute;"
#elif L==2	// de
	"Studiengang eingeben"
#elif L==3	// en
	"Create degree"
#elif L==4	// es
	"Crear titulaci&oacute;n"
#elif L==5	// fr
	"Cr&eacute;er &eacute;tude"
#elif L==6	// gn
	"Crear titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Creare laurea"
#elif L==8	// pl
	"Utw&oacute;rz stopnia"
#elif L==9	// pt
	"Criar grau"
#elif L==10	// tr
	"Create degree"			// eviri lazim!
#endif
	,
	[ActRemDeg] =
#if   L==1	// ca
	"Remove degree"			// Necessita traducci
#elif L==2	// de
	"Remove degree"			// Need bersetzung
#elif L==3	// en
	"Remove degree"
#elif L==4	// es
	"Eliminar titulaci&oacute;n"
#elif L==5	// fr
	"Remove degree"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove degree"			// Precisa de traduo
#elif L==10	// tr
	"Remove degree"			// eviri lazim!
#endif
	,
	[ActRenDegSho] =
#if   L==1	// ca
	"Change short name of degree"			// Necessita traducci
#elif L==2	// de
	"Change short name of degree"			// Need bersetzung
#elif L==3	// en
	"Change short name of degree"
#elif L==4	// es
	"Cambiar nombre breve de titulaci&oacute;n"
#elif L==5	// fr
	"Change short name of degree"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre breve de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change short name of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Change short name of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change short name of degree"			// Precisa de traduo
#elif L==10	// tr
	"Change short name of degree"			// eviri lazim!
#endif
	,
	[ActRenDegFul] =
#if   L==1	// ca
	"Change full name of degree"			// Necessita traducci
#elif L==2	// de
	"Change full name of degree"			// Need bersetzung
#elif L==3	// en
	"Change full name of degree"
#elif L==4	// es
	"Cambiar nombre completo de titulaci&oacute;n"
#elif L==5	// fr
	"Change full name of degree"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre completo de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change full name of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Change full name of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change full name of degree"			// Precisa de traduo
#elif L==10	// tr
	"Change full name of degree"			// eviri lazim!
#endif
	,
	[ActChgDegTyp] =
#if   L==1	// ca
	"Change type of degree"			// Necessita traducci
#elif L==2	// de
	"Change type of degree"			// Need bersetzung
#elif L==3	// en
	"Change type of degree"
#elif L==4	// es
	"Cambiar tipo de titulaci&oacute;n"
#elif L==5	// fr
	"Change type of degree"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar tipo de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change type of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Change type of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change type of degree"			// Precisa de traduo
#elif L==10	// tr
	"Change type of degree"			// eviri lazim!
#endif
	,
	[ActChgDegWWW] =
#if   L==1	// ca
	"Change web of degree"			// Necessita traducci
#elif L==2	// de
	"Change web of degree"			// Need bersetzung
#elif L==3	// en
	"Change web of degree"
#elif L==4	// es
	"Cambiar web de titulaci&oacute;n"
#elif L==5	// fr
	"Change web of degree"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar web de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change web of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Change web of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change web of degree"			// Precisa de traduo
#elif L==10	// tr
	"Change web of degree"			// eviri lazim!
#endif
	,
	[ActChgDegSta] =
#if   L==1	// ca
	"Change status of degree"		// Necessita traducci
#elif L==2	// de
	"Change status of degree"		// Need bersetzung
#elif L==3	// en
	"Change status of degree"
#elif L==4	// es
	"Cambiar estado de titulaci&oacute;n"
#elif L==5	// fr
	"Change status of degree"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar estado de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change status of degree"		// Bisogno di traduzione
#elif L==8	// pl
	"Change status of degree"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change status of degree"		// Precisa de traduo
#elif L==10	// tr
	"Change status of degree"		// eviri lazim!
#endif
	,
	[ActSeeDegTyp] =
#if   L==1	// ca
	"List types of degrees"			// Necessita traducci
#elif L==2	// de
	"List types of degrees"			// Need bersetzung
#elif L==3	// en
	"List types of degrees"
#elif L==4	// es
	"Listar tipos de titulaci&oacute;n"
#elif L==5	// fr
	"List types of degrees"			// Besoin de traduction
#elif L==6	// gn
	"Listar tipos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"List types of degrees"			// Bisogno di traduzione
#elif L==8	// pl
	"List types of degrees"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List types of degrees"			// Precisa de traduo
#elif L==10	// tr
	"List types of degrees"			// eviri lazim!
#endif
	,
	[ActEdiDegTyp] =
#if   L==1	// ca
	"Request edition of types of degrees"				// Necessita traducci
#elif L==2	// de
	"Request edition of types of degrees"				// Need bersetzung
#elif L==3	// en
	"Request edition of types of degrees"
#elif L==4	// es
	"Solicitar edici&oacute;n de tipos de titulaci&oacute;n"
#elif L==5	// fr
	"Request edition of types of degrees"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar edici&oacute;n de tipos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request edition of types of degrees"				// Bisogno di traduzione
#elif L==8	// pl
	"Request edition of types of degrees"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request edition of types of degrees"				// Precisa de traduo
#elif L==10	// tr
	"Request edition of types of degrees"				// eviri lazim!
#endif
	,
	[ActNewDegTyp] =
#if   L==1	// ca
	"Crear tipus de titulaci&oacute;"
#elif L==2	// de
	"Abschlussart definieren"
#elif L==3	// en
	"Create type of degree"
#elif L==4	// es
	"Crear tipo de titulaci&oacute;n"
#elif L==5	// fr
	"Cr&eacute;er type d'&eacute;tude"
#elif L==6	// gn
	"Crear tipo de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Creare tipo di laurea"
#elif L==8	// pl
	"Utw&oacute;rz typu stopnia"
#elif L==9	// pt
	"Criar tipo de grau"
#elif L==10	// tr
	"Create type of degree"			// eviri lazim!
#endif
	,
	[ActRemDegTyp] =
#if   L==1	// ca
	"Remove type of degree"			// Necessita traducci
#elif L==2	// de
	"Remove type of degree"			// Need bersetzung
#elif L==3	// en
	"Remove type of degree"
#elif L==4	// es
	"Eliminar tipo de titulaci&oacute;n"
#elif L==5	// fr
	"Remove type of degree"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar tipo de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove type of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove type of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove type of degree"			// Precisa de traduo
#elif L==10	// tr
	"Remove type of degree"			// eviri lazim!
#endif
	,
	[ActRenDegTyp] =
#if   L==1	// ca
	"Rename type of degree"			// Necessita traducci
#elif L==2	// de
	"Rename type of degree"			// Need bersetzung
#elif L==3	// en
	"Rename type of degree"
#elif L==4	// es
	"Renombrar tipo de titulaci&oacute;n"
#elif L==5	// fr
	"Rename type of degree"			// Besoin de traduction
#elif L==6	// gn
	"Renombrar tipo de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Rename type of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Rename type of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename type of degree"			// Precisa de traduo
#elif L==10	// tr
	"Rename type of degree"			// eviri lazim!
#endif
	,
	[ActSeeBld] =
#if   L==1	// ca
	"List buildings in a center"	// Necessita traducci
#elif L==2	// de
	"List buildings in a center"	// Need bersetzung
#elif L==3	// en
	"List buildings in a center"
#elif L==4	// es
	"Listar edificios de centro"
#elif L==5	// fr
	"List buildings in a center"	// Besoin de traduction
#elif L==6	// gn
	"Listar edificios de centro"	// Okoteve traduccin
#elif L==7	// it
	"List buildings in a center"	// Bisogno di traduzione
#elif L==8	// pl
	"List buildings in a center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List buildings in a center"	// Precisa de traduo
#elif L==10	// tr
	"List buildings in a center"	// eviri lazim!
#endif
	,
	[ActEdiBld] =
#if   L==1	// ca
	"Edit buildings"	// Necessita traducci
#elif L==2	// de
	"Edit buildings"	// Need bersetzung
#elif L==3	// en
	"Edit buildings"
#elif L==4	// es
	"Editar edificios"
#elif L==5	// fr
	"Edit buildings"	// Besoin de traduction
#elif L==6	// gn
	"Editar edificios"	// Okoteve traduccin
#elif L==7	// it
	"Edit buildings"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit buildings"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit buildings"	// Precisa de traduo
#elif L==10	// tr
	"Edit buildings"	// eviri lazim!
#endif
	,
	[ActNewBld] =
#if   L==1	// ca
	"Crear edifici"
#elif L==2	// de
	"Geb&auml;ude eingeben"
#elif L==3	// en
	"Create building"
#elif L==4	// es
	"Crear edificio"
#elif L==5	// fr
	"Cr&eacute;er b&acirc;timent"
#elif L==6	// gn
	"Crear edificio"	// Okoteve traduccin
#elif L==7	// it
	"Creare edificio"
#elif L==8	// pl
	"Utw&oacute;rz budynek"
#elif L==9	// pt
	"Criar edif&iacute;cio"
#elif L==10	// tr
	"Create building"	// eviri lazim!
#endif
	,
	[ActRemBld] =
#if   L==1	// ca
	"Remove building"	// Necessita traducci
#elif L==2	// de
	"Remove building"	// Need bersetzung
#elif L==3	// en
	"Remove building"
#elif L==4	// es
	"Eliminar edificio"
#elif L==5	// fr
	"Remove building"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar edificio"	// Okoteve traduccin
#elif L==7	// it
	"Remove building"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove building"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove building"	// Precisa de traduo
#elif L==10	// tr
	"Remove building"	// eviri lazim!
#endif
	,
	[ActRenBldSho] =
#if   L==1	// ca
	"Change short name of building"		// Necessita traducci
#elif L==2	// de
	"Change short name of building"		// Need bersetzung
#elif L==3	// en
	"Change short name of building"
#elif L==4	// es
	"Cambiar nombre breve de edificio"
#elif L==5	// fr
	"Change short name of building"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre breve de edificio"	// Okoteve traduccin
#elif L==7	// it
	"Change short name of building"		// Bisogno di traduzione
#elif L==8	// pl
	"Change short name of building"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change short name of building"		// Precisa de traduo
#elif L==10	// tr
	"Change short name of building"		// eviri lazim!
#endif
	,
	[ActRenBldFul] =
#if   L==1	// ca
	"Change full name of building"		// Necessita traducci
#elif L==2	// de
	"Change full name of building"		// Need bersetzung
#elif L==3	// en
	"Change full name of building"
#elif L==4	// es
	"Cambiar nombre completo de edificio"
#elif L==5	// fr
	"Change full name of building"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre completo de edificio"	// Okoteve traduccin
#elif L==7	// it
	"Change full name of building"		// Bisogno di traduzione
#elif L==8	// pl
	"Change full name of building"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change full name of building"		// Precisa de traduo
#elif L==10	// tr
	"Change full name of building"		// eviri lazim!
#endif
	,
	[ActRenBldLoc] =
#if   L==1	// ca
	"Change location of building"		// Necessita traducci
#elif L==2	// de
	"Change location of building"		// Need bersetzung
#elif L==3	// en
	"Change location of building"
#elif L==4	// es
	"Cambiar ubicaci&oacute;n de edificio"
#elif L==5	// fr
	"Change location of building"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar ubicaci&oacute;n de edificio"	// Okoteve traduccin
#elif L==7	// it
	"Change location of building"		// Bisogno di traduzione
#elif L==8	// pl
	"Change location of building"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change location of building"		// Precisa de traduo
#elif L==10	// tr
	"Change location of building"		// eviri lazim!
#endif
	,
	[ActSeeRoo] =
#if   L==1	// ca
	"List rooms in a center"	// Necessita traducci
#elif L==2	// de
	"List rooms in a center"	// Need bersetzung
#elif L==3	// en
	"List rooms in a center"
#elif L==4	// es
	"Listar salas de centro"
#elif L==5	// fr
	"List rooms in a center"	// Besoin de traduction
#elif L==6	// gn
	"Listar salas de centro"	// Okoteve traduccin
#elif L==7	// it
	"List rooms in a center"	// Bisogno di traduzione
#elif L==8	// pl
	"List rooms in a center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List rooms in a center"	// Precisa de traduo
#elif L==10	// tr
	"List rooms in a center"	// eviri lazim!
#endif
	,
	[ActEdiRoo] =
#if   L==1	// ca
	"Edit rooms"	// Necessita traducci
#elif L==2	// de
	"Edit rooms"	// Need bersetzung
#elif L==3	// en
	"Edit rooms"
#elif L==4	// es
	"Editar salas"
#elif L==5	// fr
	"Edit rooms"	// Besoin de traduction
#elif L==6	// gn
	"Editar salas"	// Okoteve traduccin
#elif L==7	// it
	"Edit rooms"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit rooms"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit rooms"	// Precisa de traduo
#elif L==10	// tr
	"Edit rooms"	// eviri lazim!
#endif
	,
	[ActNewRoo] =
#if   L==1	// ca
	"Crear sala"
#elif L==2	// de
	"Raum eingeben"
#elif L==3	// en
	"Create room"
#elif L==4	// es
	"Crear sala"
#elif L==5	// fr
	"Cr&eacute;er salle"
#elif L==6	// gn
	"Crear sala"	// Okoteve traduccin
#elif L==7	// it
	"Creare aula"
#elif L==8	// pl
	"Utw&oacute;rz klasa"
#elif L==9	// pt
	"Criar sala"
#elif L==10	// tr
	"Create room"	// eviri lazim!
#endif
	,
	[ActRemRoo] =
#if   L==1	// ca
	"Remove room"		// Necessita traducci
#elif L==2	// de
	"Remove room"		// Need bersetzung
#elif L==3	// en
	"Remove room"
#elif L==4	// es
	"Eliminar sala"
#elif L==5	// fr
	"Remove room"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar sala"		// Okoteve traduccin
#elif L==7	// it
	"Remove room"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove room"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove room"		// Precisa de traduo
#elif L==10	// tr
	"Remove room"		// eviri lazim!
#endif
	,
	[ActChgRooBld] =
#if   L==1	// ca
	"Change building of room"	// Necessita traducci
#elif L==2	// de
	"Change building of room"	// Need bersetzung
#elif L==3	// en
	"Change building of room"
#elif L==4	// es
	"Cambiar edificio de sala"
#elif L==5	// fr
	"Change building of room"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar edificio de sala"	// Okoteve traduccin
#elif L==7	// it
	"Change building of room"	// Bisogno di traduzione
#elif L==8	// pl
	"Change building of room"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change building of room"	// Precisa de traduo
#elif L==10	// tr
	"Change building of room"	// eviri lazim!
#endif
	,
	[ActChgRooMaxUsr] =
#if   L==1	// ca
	"Change number of users of room"		// Necessita traducci
#elif L==2	// de
	"Change number of users of room"		// Need bersetzung
#elif L==3	// en
	"Change number of users of room"
#elif L==4	// es
	"Cambiar n&uacute;mero de usuarios de sala"
#elif L==5	// fr
	"Change number of users of room"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar n&uacute;mero de usuarios de sala"	// Okoteve traduccin
#elif L==7	// it
	"Change number of users of room"		// Bisogno di traduzione
#elif L==8	// pl
	"Change number of users of room"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change number of users of room"		// Precisa de traduo
#elif L==10	// tr
	"Change number of users of room"		// eviri lazim!
#endif
	,
	[ActChgRooMAC] =
#if   L==1	// ca
	"Change MAC of room"		// Necessita traducci
#elif L==2	// de
	"Change MAC of room"		// Need bersetzung
#elif L==3	// en
	"Change MAC of room"
#elif L==4	// es
	"Cambiar MAC de sala"
#elif L==5	// fr
	"Change MAC of room"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar MAC de sala"	// Okoteve traduccin
#elif L==7	// it
	"Change MAC of room"		// Bisogno di traduzione
#elif L==8	// pl
	"Change MAC of room"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change MAC of room"		// Precisa de traduo
#elif L==10	// tr
	"Change MAC of room"		// eviri lazim!
#endif
	,
	[ActRenRooSho] =
#if   L==1	// ca
	"Change short name of room"	// Necessita traducci
#elif L==2	// de
	"Change short name of room"	// Need bersetzung
#elif L==3	// en
	"Change short name of room"
#elif L==4	// es
	"Cambiar nombre breve de sala"
#elif L==5	// fr
	"Change short name of room"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre breve de sala"	// Okoteve traduccin
#elif L==7	// it
	"Change short name of room"	// Bisogno di traduzione
#elif L==8	// pl
	"Change short name of room"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change short name of room"	// Precisa de traduo
#elif L==10	// tr
	"Change short name of room"	// eviri lazim!
#endif
	,
	[ActRenRooFul] =
#if   L==1	// ca
	"Change full name of room"		// Necessita traducci
#elif L==2	// de
	"Change full name of room"		// Need bersetzung
#elif L==3	// en
	"Change full name of room"
#elif L==4	// es
	"Cambiar nombre completo de sala"
#elif L==5	// fr
	"Change full name of room"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre completo de sala"	// Okoteve traduccin
#elif L==7	// it
	"Change full name of room"		// Bisogno di traduzione
#elif L==8	// pl
	"Change full name of room"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change full name of room"		// Precisa de traduo
#elif L==10	// tr
	"Change full name of room"		// eviri lazim!
#endif
	,
	[ActChgRooFlo] =
#if   L==1	// ca
	"Change floor of room"		// Necessita traducci
#elif L==2	// de
	"Change floor of room"		// Need bersetzung
#elif L==3	// en
	"Change floor of room"
#elif L==4	// es
	"Cambiar planta de sala"
#elif L==5	// fr
	"Change floor of room"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar planta de sala"	// Okoteve traduccin
#elif L==7	// it
	"Change floor of room"		// Bisogno di traduzione
#elif L==8	// pl
	"Change floor of room"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change floor of room"		// Precisa de traduo
#elif L==10	// tr
	"Change floor of room"		// eviri lazim!
#endif
	,
	[ActChgRooTyp] =
#if   L==1	// ca
	"Change type of room"		// Necessita traducci
#elif L==2	// de
	"Change type of room"		// Need bersetzung
#elif L==3	// en
	"Change type of room"
#elif L==4	// es
	"Cambiar tipo de sala"
#elif L==5	// fr
	"Change type of room"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar tipo de sala"	// Okoteve traduccin
#elif L==7	// it
	"Change type of room"		// Bisogno di traduzione
#elif L==8	// pl
	"Change type of room"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change type of room"		// Precisa de traduo
#elif L==10	// tr
	"Change type of room"		// eviri lazim!
#endif
	,
	[ActSeeDegInf] =
#if   L==1	// ca
	"Show information on the degree"			// Necessita traducci
#elif L==2	// de
	"Show information on the degree"			// Need bersetzung
#elif L==3	// en
	"Show information on the degree"
#elif L==4	// es
	"Mostrar informaci&oacute;n sobre la titulaci&oacute;n"
#elif L==5	// fr
	"Show information on the degree"			// Besoin de traduction
#elif L==6	// gn
	"Mostrar informaci&oacute;n sobre la titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Show information on the degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Show information on the degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show information on the degree"			// Precisa de traduo
#elif L==10	// tr
	"Show information on the degree"			// eviri lazim!
#endif
	,
	[ActPrnDegInf] =
#if   L==1	// ca
	"Print information on the degree"				// Necessita traducci
#elif L==2	// de
	"Print information on the degree"				// Need bersetzung
#elif L==3	// en
	"Print information on the degree"
#elif L==4	// es
	"Imprimir informaci&oacute;n sobre la titulaci&oacute;n"
#elif L==5	// fr
	"Print information on the degree"				// Besoin de traduction
#elif L==6	// gn
	"Imprimir informaci&oacute;n sobre la titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Print information on the degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Print information on the degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Print information on the degree"				// Precisa de traduo
#elif L==10	// tr
	"Print information on the degree"				// eviri lazim!
#endif
	,
	[ActChgDegCtrCfg] =
#if   L==1	// ca
	"Change center of degree in its configuration"				// Necessita traducci
#elif L==2	// de
	"Change center of degree in its configuration"				// Need bersetzung
#elif L==3	// en
	"Change center of degree in its configuration"
#elif L==4	// es
	"Cambiar centro de titulaci&oacute;n en su configuraci&oacute;n"
#elif L==5	// fr
	"Change center of degree in its configuration"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar centro de titulaci&oacute;n en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change center of degree in its configuration"				// Bisogno di traduzione
#elif L==8	// pl
	"Change center of degree in its configuration"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change center of degree in its configuration"				// Precisa de traduo
#elif L==10	// tr
	"Change center of degree in its configuration"				// eviri lazim!
#endif
	,
	[ActRenDegShoCfg] =
#if   L==1	// ca
	"Change short name of degree in its configuration"			// Necessita traducci
#elif L==2	// de
	"Change short name of degree in its configuration"			// Need bersetzung
#elif L==3	// en
	"Change short name of degree in its configuration"
#elif L==4	// es
	"Cambiar nombre breve de titulaci&oacute;n en su configuraci&oacute;n"
#elif L==5	// fr
	"Change short name of degree in its configuration"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre breve de titulaci&oacute;n en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change short name of degree in its configuration"			// Bisogno di traduzione
#elif L==8	// pl
	"Change short name of degree in its configuration"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change short name of degree in its configuration"			// Precisa de traduo
#elif L==10	// tr
	"Change short name of degree in its configuration"			// eviri lazim!
#endif
	,
	[ActRenDegFulCfg] =
#if   L==1	// ca
	"Change full name of degree in its configuration"				// Necessita traducci
#elif L==2	// de
	"Change full name of degree in its configuration"				// Need bersetzung
#elif L==3	// en
	"Change full name of degree in its configuration"
#elif L==4	// es
	"Cambiar nombre completo de titulaci&oacute;n en su configuraci&oacute;n"
#elif L==5	// fr
	"Change full name of degree in its configuration"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre completo de titulaci&oacute;n en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change full name of degree in its configuration"				// Bisogno di traduzione
#elif L==8	// pl
	"Change full name of degree in its configuration"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change full name of degree in its configuration"				// Precisa de traduo
#elif L==10	// tr
	"Change full name of degree in its configuration"				// eviri lazim!
#endif
	,
	[ActChgDegWWWCfg] =
#if   L==1	// ca
	"Change web of degree in its configuration"			// Necessita traducci
#elif L==2	// de
	"Change web of degree in its configuration"			// Need bersetzung
#elif L==3	// en
	"Change web of degree in its configuration"
#elif L==4	// es
	"Cambiar web de titulaci&oacute;n en su configuraci&oacute;n"
#elif L==5	// fr
	"Change web of degree in its configuration"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar web de titulaci&oacute;n en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change web of degree in its configuration"			// Bisogno di traduzione
#elif L==8	// pl
	"Change web of degree in its configuration"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change web of degree in its configuration"			// Precisa de traduo
#elif L==10	// tr
	"Change web of degree in its configuration"			// eviri lazim!
#endif
	,
	[ActReqDegLog] =
#if   L==1	// ca
	"Request change of the logo of the current degree"		// Necessita traducci
#elif L==2	// de
	"Request change of the logo of the current degree"		// Need bersetzung
#elif L==3	// en
	"Request change of the logo of the current degree"
#elif L==4	// es
	"Solicitar el cambio del logo de la titulaci&oacute;n actual"
#elif L==5	// fr
	"Request change of the logo of the current degree"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar el cambio del logo de la titulaci&oacute;n actual"	// Okoteve traduccin
#elif L==7	// it
	"Request change of the logo of the current degree"		// Bisogno di traduzione
#elif L==8	// pl
	"Request change of the logo of the current degree"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request change of the logo of the current degree"		// Precisa de traduo
#elif L==10	// tr
	"Request change of the logo of the current degree"		// eviri lazim!
#endif
	,
	[ActRecDegLog] =
#if   L==1	// ca
	"Change logo of the current degree"		// Necessita traducci
#elif L==2	// de
	"Change logo of the current degree"		// Need bersetzung
#elif L==3	// en
	"Change logo of the current degree"
#elif L==4	// es
	"Cambiar logo de la titulaci&oacute;n actual"
#elif L==5	// fr
	"Change logo of the current degree"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar logo de la titulaci&oacute;n actual"	// Okoteve traduccin
#elif L==7	// it
	"Change logo of the current degree"		// Bisogno di traduzione
#elif L==8	// pl
	"Change logo of the current degree"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change logo of the current degree"		// Precisa de traduo
#elif L==10	// tr
	"Change logo of the current degree"		// eviri lazim!
#endif
	,
	[ActRemDegLog] =
#if   L==1	// ca
	"Remove the logo of the current degree"		// Necessita traducci
#elif L==2	// de
	"Remove the logo of the current degree"		// Need bersetzung
#elif L==3	// en
	"Remove the logo of the current degree"
#elif L==4	// es
	"Eliminar logo de la titulaci&oacute;n actual"
#elif L==5	// fr
	"Remove the logo of the current degree"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar logo de la titulaci&oacute;n actual"	// Okoteve traduccin
#elif L==7	// it
	"Remove the logo of the current degree"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove the logo of the current degree"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove the logo of the current degree"		// Precisa de traduo
#elif L==10	// tr
	"Remove the logo of the current degree"		// eviri lazim!
#endif
	,
	[ActSeeCrs] =
#if   L==1	// ca
	"List courses of degree"			// Necessita traducci
#elif L==2	// de
	"List courses of degree"			// Need bersetzung
#elif L==3	// en
	"List courses of degree"
#elif L==4	// es
	"Listar asignaturas de titulaci&oacute;n"
#elif L==5	// fr
	"List courses of degree"			// Besoin de traduction
#elif L==6	// gn
	"Listar asignaturas de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"List courses of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"List courses of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List courses of degree"			// Precisa de traduo
#elif L==10	// tr
	"List courses of degree"			// eviri lazim!
#endif
	,
	[ActEdiCrs] =
#if   L==1	// ca
	"Edit courses"		// Necessita traducci
#elif L==2	// de
	"Edit courses"		// Need bersetzung
#elif L==3	// en
	"Edit courses"
#elif L==4	// es
	"Editar asignaturas"
#elif L==5	// fr
	"Edit courses"		// Besoin de traduction
#elif L==6	// gn
	"Editar asignaturas"	// Okoteve traduccin
#elif L==7	// it
	"Edit courses"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit courses"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit courses"		// Precisa de traduo
#elif L==10	// tr
	"Edit courses"		// eviri lazim!
#endif
	,
	[ActReqCrs] =
#if   L==1	// ca
	"Request creation of course"			// Necessita traducci
#elif L==2	// de
	"Request creation of course"			// Need bersetzung
#elif L==3	// en
	"Request creation of course"
#elif L==4	// es
	"Solicitar creaci&oacute;n de asignatura"
#elif L==5	// fr
	"Request creation of course"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar creaci&oacute;n de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Request creation of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Request creation of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request creation of course"			// Precisa de traduo
#elif L==10	// tr
	"Request creation of course"			// eviri lazim!
#endif
	,
	[ActNewCrs] =
#if   L==1	// ca
	"Crear assignatura"
#elif L==2	// de
	"Kurs eingeben"
#elif L==3	// en
	"Create course"
#elif L==4	// es
	"Crear asignatura"
#elif L==5	// fr
	"Cr&eacute;er mati&egrave;re"
#elif L==6	// gn
	"Crear asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Creare corso"
#elif L==8	// pl
	"Utw&oacute;rz kursu"
#elif L==9	// pt
	"Criar disciplina"
#elif L==10	// tr
	"Create course"		// eviri lazim!
#endif
	,
	[ActRemCrs] =
#if   L==1	// ca
	"Remove course"		// Necessita traducci
#elif L==2	// de
	"Remove course"		// Need bersetzung
#elif L==3	// en
	"Remove course"
#elif L==4	// es
	"Eliminar asignatura"
#elif L==5	// fr
	"Remove course"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove course"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove course"		// Precisa de traduo
#elif L==10	// tr
	"Remove course"		// eviri lazim!
#endif
	,
	[ActChgInsCrsCod] =
#if   L==1	// ca
	"Change institutional code of course"			// Necessita traducci
#elif L==2	// de
	"Change institutional code of course"			// Need bersetzung
#elif L==3	// en
	"Change institutional code of course"
#elif L==4	// es
	"Cambiar c&oacute;digo institucional de asignatura"
#elif L==5	// fr
	"Change institutional code of course"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar c&oacute;digo institucional de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change institutional code of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Change institutional code of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change institutional code of course"			// Precisa de traduo
#elif L==10	// tr
	"Change institutional code of course"			// eviri lazim!
#endif
	,
	[ActChgCrsYea] =
#if   L==1	// ca
	"Change year/semester of course"		// Necessita traducci
#elif L==2	// de
	"Change year/semester of course"		// Need bersetzung
#elif L==3	// en
	"Change year/semester of course"
#elif L==4	// es
	"Cambiar a&ntilde;o/semestre de asignatura"
#elif L==5	// fr
	"Change year/semester of course"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar a&ntilde;o/semestre de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change year/semester of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Change year/semester of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change year/semester of course"		// Precisa de traduo
#elif L==10	// tr
	"Change year/semester of course"		// eviri lazim!
#endif
	,
	[ActRenCrsSho] =
#if   L==1	// ca
	"Change short name of course"		// Necessita traducci
#elif L==2	// de
	"Change short name of course"		// Need bersetzung
#elif L==3	// en
	"Change short name of course"
#elif L==4	// es
	"Cambiar nombre breve de asignatura"
#elif L==5	// fr
	"Change short name of course"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre breve de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change short name of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Change short name of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change short name of course"		// Precisa de traduo
#elif L==10	// tr
	"Change short name of course"		// eviri lazim!
#endif
	,
	[ActRenCrsFul] =
#if   L==1	// ca
	"Change full name of course"		// Necessita traducci
#elif L==2	// de
	"Change full name of course"		// Need bersetzung
#elif L==3	// en
	"Change full name of course"
#elif L==4	// es
	"Cambiar nombre completo de asignatura"
#elif L==5	// fr
	"Change full name of course"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre completo de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change full name of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Change full name of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change full name of course"		// Precisa de traduo
#elif L==10	// tr
	"Change full name of course"		// eviri lazim!
#endif
	,
	[ActChgCrsSta] =
#if   L==1	// ca
	"Change status of course"	// Necessita traducci
#elif L==2	// de
	"Change status of course"	// Need bersetzung
#elif L==3	// en
	"Change status of course"
#elif L==4	// es
	"Cambiar estado de asignatura"
#elif L==5	// fr
	"Change status of course"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar estado de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change status of course"	// Bisogno di traduzione
#elif L==8	// pl
	"Change status of course"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change status of course"	// Precisa de traduo
#elif L==10	// tr
	"Change status of course"	// eviri lazim!
#endif
	,
	[ActSeeCrsInf] =
#if   L==1	// ca
	"Show information on the course"			// Necessita traducci
#elif L==2	// de
	"Show information on the course"			// Need bersetzung
#elif L==3	// en
	"Show information on the course"
#elif L==4	// es
	"Mostrar informaci&oacute;n sobre la asignatura"
#elif L==5	// fr
	"Show information on the course"			// Besoin de traduction
#elif L==6	// gn
	"Mostrar informaci&oacute;n sobre la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Show information on the course"			// Bisogno di traduzione
#elif L==8	// pl
	"Show information on the course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show information on the course"			// Precisa de traduo
#elif L==10	// tr
	"Show information on the course"			// eviri lazim!
#endif
	,
	[ActPrnCrsInf] =
#if   L==1	// ca
	"Print information on the course"			// Necessita traducci
#elif L==2	// de
	"Print information on the course"			// Need bersetzung
#elif L==3	// en
	"Print information on the course"
#elif L==4	// es
	"Imprimir informaci&oacute;n sobre la asignatura"
#elif L==5	// fr
	"Print information on the course"			// Besoin de traduction
#elif L==6	// gn
	"Imprimir informaci&oacute;n sobre la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Print information on the course"			// Bisogno di traduzione
#elif L==8	// pl
	"Print information on the course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Print information on the course"			// Precisa de traduo
#elif L==10	// tr
	"Print information on the course"			// eviri lazim!
#endif
	,
	[ActChgCrsDegCfg] =
#if   L==1	// ca
	"Change degree of course in its configuration"				// Necessita traducci
#elif L==2	// de
	"Change degree of course in its configuration"				// Need bersetzung
#elif L==3	// en
	"Change degree of course in its configuration"
#elif L==4	// es
	"Cambiar titulaci&oacute;n de asignatura en su configuraci&oacute;n"
#elif L==5	// fr
	"Change degree of course in its configuration"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar titulaci&oacute;n de asignatura en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change degree of course in its configuration"				// Bisogno di traduzione
#elif L==8	// pl
	"Change degree of course in its configuration"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change degree of course in its configuration"				// Precisa de traduo
#elif L==10	// tr
	"Change degree of course in its configuration"				// eviri lazim!
#endif
	,
	[ActRenCrsShoCfg] =
#if   L==1	// ca
	"Change short name of course in its configuration"		// Necessita traducci
#elif L==2	// de
	"Change short name of course in its configuration"		// Need bersetzung
#elif L==3	// en
	"Change short name of course in its configuration"
#elif L==4	// es
	"Cambiar nombre breve de asignatura en su configuraci&oacute;n"
#elif L==5	// fr
	"Change short name of course in its configuration"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre breve de asignatura en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change short name of course in its configuration"		// Bisogno di traduzione
#elif L==8	// pl
	"Change short name of course in its configuration"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change short name of course in its configuration"		// Precisa de traduo
#elif L==10	// tr
	"Change short name of course in its configuration"		// eviri lazim!
#endif
	,
	[ActRenCrsFulCfg] =
#if   L==1	// ca
	"Change full name of course in its configuration"			// Necessita traducci
#elif L==2	// de
	"Change full name of course in its configuration"			// Need bersetzung
#elif L==3	// en
	"Change full name of course in its configuration"
#elif L==4	// es
	"Cambiar nombre completo de asignatura en su configuraci&oacute;n"
#elif L==5	// fr
	"Change full name of course in its configuration"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar nombre completo de asignatura en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change full name of course in its configuration"			// Bisogno di traduzione
#elif L==8	// pl
	"Change full name of course in its configuration"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change full name of course in its configuration"			// Precisa de traduo
#elif L==10	// tr
	"Change full name of course in its configuration"			// eviri lazim!
#endif
	,
	[ActChgInsCrsCodCfg] =
#if   L==1	// ca
	"Change institutional code of course in its configuration"			// Necessita traducci
#elif L==2	// de
	"Change institutional code of course in its configuration"			// Need bersetzung
#elif L==3	// en
	"Change institutional code of course in its configuration"
#elif L==4	// es
	"Cambiar c&oacute;digo institucional de asignatura en su configuraci&oacute;n"
#elif L==5	// fr
	"Change institutional code of course in its configuration"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar c&oacute;digo institucional de asignatura en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change institutional code of course in its configuration"			// Bisogno di traduzione
#elif L==8	// pl
	"Change institutional code of course in its configuration"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change institutional code of course in its configuration"			// Precisa de traduo
#elif L==10	// tr
	"Change institutional code of course in its configuration"			// eviri lazim!
#endif
	,
	[ActChgCrsYeaCfg] =
#if   L==1	// ca
	"Change year/semester of course in its configuration"			// Necessita traducci
#elif L==2	// de
	"Change year/semester of course in its configuration"			// Need bersetzung
#elif L==3	// en
	"Change year/semester of course in its configuration"
#elif L==4	// es
	"Cambiar a&ntilde;o/semestre de asignatura en su configuraci&oacute;n"
#elif L==5	// fr
	"Change year/semester of course in its configuration"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar a&ntilde;o/semestre de asignatura en su configuraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change year/semester of course in its configuration"			// Bisogno di traduzione
#elif L==8	// pl
	"Change year/semester of course in its configuration"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change year/semester of course in its configuration"			// Precisa de traduo
#elif L==10	// tr
	"Change year/semester of course in its configuration"			// eviri lazim!
#endif
	,
	[ActEdiCrsInf] =
#if   L==1	// ca
	"Edit information about the course"		// Necessita traducci
#elif L==2	// de
	"Edit information about the course"		// Need bersetzung
#elif L==3	// en
	"Edit information about the course"
#elif L==4	// es
	"Editar la informaci&oacute;n de la asignatura"
#elif L==5	// fr
	"Edit information about the course"		// Besoin de traduction
#elif L==6	// gn
	"Editar la informaci&oacute;n de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Edit information about the course"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit information about the course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit information about the course"		// Precisa de traduo
#elif L==10	// tr
	"Edit information about the course"		// eviri lazim!
#endif
	,
	[ActChgFrcReaCrsInf] =
#if   L==1	// ca
	"Change whether students are forced to read the course information"			// Necessita traducci
#elif L==2	// de
	"Change whether students are forced to read the course information"			// Need bersetzung
#elif L==3	// en
	"Change whether students are forced to read the course information"
#elif L==4	// es
	"Cambiar si se obliga a los estudiantes a leer la informaci&oacute;n de la asignatura"
#elif L==5	// fr
	"Change whether students are forced to read the course information"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar si se obliga a los estudiantes a leer la informaci&oacute;n de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change whether students are forced to read the course information"			// Bisogno di traduzione
#elif L==8	// pl
	"Change whether students are forced to read the course information"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change whether students are forced to read the course information"			// Precisa de traduo
#elif L==10	// tr
	"Change whether students are forced to read the course information"			// eviri lazim!
#endif
	,
	[ActChgHavReaCrsInf] =
#if   L==1	// ca
	"Change if I have read the course information"				// Necessita traducci
#elif L==2	// de
	"Change if I have read the course information"				// Need bersetzung
#elif L==3	// en
	"Change if I have read the course information"
#elif L==4	// es
	"Cambiar si he le&iacute;do la informaci&oacute;n de la asignatura"
#elif L==5	// fr
	"Change if I have read the course information"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar si he le&iacute;do la informaci&oacute;n de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change if I have read the course information"				// Bisogno di traduzione
#elif L==8	// pl
	"Change if I have read the course information"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change if I have read the course information"				// Precisa de traduo
#elif L==10	// tr
	"Change if I have read the course information"				// eviri lazim!
#endif
	,
	[ActSelInfSrcCrsInf] =
#if   L==1	// ca
	"Select the type of information shown in the course information"				// Necessita traducci
#elif L==2	// de
	"Select the type of information shown in the course information"				// Need bersetzung
#elif L==3	// en
	"Select the type of information shown in the course information"
#elif L==4	// es
	"Seleccionar el tipo de informaci&oacute;n mostrada en la informaci&oacute;n de la asignatura"
#elif L==5	// fr
	"Select the type of information shown in the course information"				// Besoin de traduction
#elif L==6	// gn
	"Seleccionar el tipo de informaci&oacute;n mostrada en la informaci&oacute;n de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Select the type of information shown in the course information"				// Bisogno di traduzione
#elif L==8	// pl
	"Select the type of information shown in the course information"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Select the type of information shown in the course information"				// Precisa de traduo
#elif L==10	// tr
	"Select the type of information shown in the course information"				// eviri lazim!
#endif
	,
	[ActRcvURLCrsInf] =
#if   L==1	// ca
	"Create URL in the course information"				// Necessita traducci
#elif L==2	// de
	"Create URL in the course information"				// Need bersetzung
#elif L==3	// en
	"Create URL in the course information"
#elif L==4	// es
	"Crear una URL en la informaci&oacute;n de la asignatura"
#elif L==5	// fr
	"Create URL in the course information"				// Besoin de traduction
#elif L==6	// gn
	"Crear una URL en la informaci&oacute;n de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create URL in the course information"				// Bisogno di traduzione
#elif L==8	// pl
	"Create URL in the course information"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create URL in the course information"				// Precisa de traduo
#elif L==10	// tr
	"Create URL in the course information"				// eviri lazim!
#endif
	,
	[ActRcvPagCrsInf] =
#if   L==1	// ca
	"Create web page in the course information"				// Necessita traducci
#elif L==2	// de
	"Create web page in the course information"				// Need bersetzung
#elif L==3	// en
	"Create web page in the course information"
#elif L==4	// es
	"Crear una p&aacute;gina web en la informaci&oacute;n de la asignatura"
#elif L==5	// fr
	"Create web page in the course information"				// Besoin de traduction
#elif L==6	// gn
	"Crear una p&aacute;gina web en la informaci&oacute;n de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create web page in the course information"				// Bisogno di traduzione
#elif L==8	// pl
	"Create web page in the course information"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create web page in the course information"				// Precisa de traduo
#elif L==10	// tr
	"Create web page in the course information"				// eviri lazim!
#endif
	,
	[ActEditorCrsInf] =
#if   L==1	// ca
	"Integrated editor of course information"			// Necessita traducci
#elif L==2	// de
	"Integrated editor of course information"			// Need bersetzung
#elif L==3	// en
	"Integrated editor of course information"
#elif L==4	// es
	"Editor integrado de la informaci&oacute;n de la asignatura"
#elif L==5	// fr
	"Integrated editor of course information"			// Besoin de traduction
#elif L==6	// gn
	"Editor integrado de la informaci&oacute;n de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Integrated editor of course information"			// Bisogno di traduzione
#elif L==8	// pl
	"Integrated editor of course information"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Integrated editor of course information"			// Precisa de traduo
#elif L==10	// tr
	"Integrated editor of course information"			// eviri lazim!
#endif
	,
	[ActPlaTxtEdiCrsInf] =
#if   L==1	// ca
	"Plain text editor of course information"				// Necessita traducci
#elif L==2	// de
	"Plain text editor of course information"				// Need bersetzung
#elif L==3	// en
	"Plain text editor of course information"
#elif L==4	// es
	"Editor de texto plano de la informaci&oacute;n de la asignatura"
#elif L==5	// fr
	"Plain text editor of course information"				// Besoin de traduction
#elif L==6	// gn
	"Editor de texto plano de la informaci&oacute;n de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Plain text editor of course information"				// Bisogno di traduzione
#elif L==8	// pl
	"Plain text editor of course information"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Plain text editor of course information"				// Precisa de traduo
#elif L==10	// tr
	"Plain text editor of course information"				// eviri lazim!
#endif
	,
	[ActRchTxtEdiCrsInf] =
#if   L==1	// ca
	"Rich text editor of course information"				// Necessita traducci
#elif L==2	// de
	"Rich text editor of course information"				// Need bersetzung
#elif L==3	// en
	"Rich text editor of course information"
#elif L==4	// es
	"Editor de texto enriquecido de la informaci&oacute;n de la asignatura"
#elif L==5	// fr
	"Rich text editor of course information"				// Besoin de traduction
#elif L==6	// gn
	"Editor de texto enriquecido de la informaci&oacute;n de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Rich text editor of course information"				// Bisogno di traduzione
#elif L==8	// pl
	"Rich text editor of course information"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rich text editor of course information"				// Precisa de traduo
#elif L==10	// tr
	"Rich text editor of course information"				// eviri lazim!
#endif
	,
	[ActRcvPlaTxtCrsInf] =
#if   L==1	// ca
	"Change plain text of course information"			// Necessita traducci
#elif L==2	// de
	"Change plain text of course information"			// Need bersetzung
#elif L==3	// en
	"Change plain text of course information"
#elif L==4	// es
	"Cambiar texto plano de la informaci&oacute;n de la asignatura"
#elif L==5	// fr
	"Change plain text of course information"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar texto plano de la informaci&oacute;n de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change plain text of course information"			// Bisogno di traduzione
#elif L==8	// pl
	"Change plain text of course information"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change plain text of course information"			// Precisa de traduo
#elif L==10	// tr
	"Change plain text of course information"			// eviri lazim!
#endif
	,
	[ActRcvRchTxtCrsInf] =
#if   L==1	// ca
	"Change rich text of course information"				// Necessita traducci
#elif L==2	// de
	"Change rich text of course information"				// Need bersetzung
#elif L==3	// en
	"Change rich text of course information"
#elif L==4	// es
	"Cambiar texto enriquecido de la informaci&oacute;n de la asignatura"
#elif L==5	// fr
	"Change rich text of course information"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar texto enriquecido de la informaci&oacute;n de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change rich text of course information"				// Bisogno di traduzione
#elif L==8	// pl
	"Change rich text of course information"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change rich text of course information"				// Precisa de traduo
#elif L==10	// tr
	"Change rich text of course information"				// eviri lazim!
#endif
	,
	[ActSeePrg] =
#if   L==1	// ca
	"Veure programaci&oacute; did&agrave;ctica de l'assignatura"
#elif L==2	// de
	"Siehe Ausbildungsplan des Kurses"
#elif L==3	// en
	"See educational schedule of the course"
#elif L==4	// es
	"Ver programaci&oacute;n did&aacute;ctica de la asignatura"
#elif L==5	// fr
	"Voir programme didactique de la mati&egrave;re"
#elif L==6	// gn
	"Ehecha programa did&aacute;ctico upe materia rehegua"
#elif L==7	// it
	"Vedi programma didattico della materia"
#elif L==8	// pl
	"Zobacz program edukacyjny kursu"
#elif L==9	// pt
	"Ver programa did&aacute;tico da disciplina"
#elif L==10	// tr
	"Konunun didaktik program&inodot;na bak&inodot;n"
#endif
	,
	[ActEdiPrg] =
#if   L==1	// ca
	"Edit educational schedule of course"				// Necessita traducci
#elif L==2	// de
	"Edit educational schedule of course"				// Need bersetzung
#elif L==3	// en
	"Edit educational schedule of course"
#elif L==4	// es
	"Editar programaci&oacute;n did&aacute;ctica de la asignatura"
#elif L==5	// fr
	"Edit educational schedule of course"				// Besoin de traduction
#elif L==6	// gn
	"Editar programaci&oacute;n did&aacute;ctica de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Edit educational schedule of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Edit educational schedule of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit educational schedule of course"				// Precisa de traduo
#elif L==10	// tr
	"Edit educational schedule of course"				// eviri lazim!
#endif
	,
	[ActSeePrgItm] =
#if   L==1	// ca
	"See program item"			// Necessita traducci
#elif L==2	// de
	"See program item"			// Need bersetzung
#elif L==3	// en
	"See program item"
#elif L==4	// es
	"Ver &iacute;tem del programa"
#elif L==5	// fr
	"See program item"			// Besoin de traduction
#elif L==6	// gn
	"Ver &iacute;tem del programa"	// Okoteve traduccin
#elif L==7	// it
	"See program item"			// Bisogno di traduzione
#elif L==8	// pl
	"See program item"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See program item"			// Precisa de traduo
#elif L==10	// tr
	"See program item"			// eviri lazim!
#endif
	,
	[ActFrmChgPrgItm] =
#if   L==1	// ca
	"Edit program item"			// Necessita traducci
#elif L==2	// de
	"Edit program item"			// Need bersetzung
#elif L==3	// en
	"Edit program item"
#elif L==4	// es
	"Editar &iacute;tem del programa"
#elif L==5	// fr
	"Edit program item"			// Besoin de traduction
#elif L==6	// gn
	"Editar &iacute;tem del programa"	// Okoteve traduccin
#elif L==7	// it
	"Edit program item"			// Bisogno di traduzione
#elif L==8	// pl
	"Edit program item"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit program item"			// Precisa de traduo
#elif L==10	// tr
	"Edit program item"			// eviri lazim!
#endif
	,
	[ActFrmNewPrgItm] =
#if   L==1	// ca
	"Request new program item"			// Necessita traducci
#elif L==2	// de
	"Request new program item"			// Need bersetzung
#elif L==3	// en
	"Request new program item"
#elif L==4	// es
	"Solicitar nuevo &iacute;tem del programa"
#elif L==5	// fr
	"Request new program item"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar nuevo &iacute;tem del programa"	// Okoteve traduccin
#elif L==7	// it
	"Request new program item"			// Bisogno di traduzione
#elif L==8	// pl
	"Request new program item"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request new program item"			// Precisa de traduo
#elif L==10	// tr
	"Request new program item"			// eviri lazim!
#endif
	,
	[ActChgPrgItm] =
#if   L==1	// ca
	"Canviar &iacute;tem del programa"
#elif L==2	// de
	"Programmpunkt &auml;ndern"
#elif L==3	// en
	"Change program item"
#elif L==4	// es
	"Cambiar &iacute;tem del programa"
#elif L==5	// fr
	"Changer &eacute;l&eacute;ment de programme"
#elif L==6	// gn
	"Emoambue elemento programa"
#elif L==7	// it
	"Cambiare articolo del programma"
#elif L==8	// pl
	"Zmie&nacute; pozycj&eogon; programu"
#elif L==9	// pt
	"Alterar item do programa"
#elif L==10	// tr
	"Program &ouml;&gbreve;esini de&gbreve;i&scedil;tir"
#endif
	,
	[ActNewPrgItm] =
#if   L==1	// ca
	"Crear &iacute;tem del programa"
#elif L==2	// de
	"Programmpunkt erstellen"
#elif L==3	// en
	"Create program item"
#elif L==4	// es
	"Crear &iacute;tem del programa"
#elif L==5	// fr
	"Cr&eacute;er &eacute;l&eacute;ment de programme"
#elif L==6	// gn
	"Ojapo elemento programa"
#elif L==7	// it
	"Creare articolo del programma"
#elif L==8	// pl
	"Utw&oacute;rz pozycj&eogon; programu"
#elif L==9	// pt
	"Criar item do programa"
#elif L==10	// tr
	"Program &ouml;&gbreve;esi olu&scedil;tur"
#endif
	,
	[ActReqRemPrgItm] =
#if   L==1	// ca
	"Request removal of program item"				// Necessita traducci
#elif L==2	// de
	"Request removal of program item"				// Need bersetzung
#elif L==3	// en
	"Request removal of program item"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de &iacute;tem del programa"
#elif L==5	// fr
	"Request removal of program item"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de &iacute;tem del programa"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of program item"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of program item"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of program item"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of program item"				// eviri lazim!
#endif
	,
	[ActRemPrgItm] =
#if   L==1	// ca
	"Eliminar &iacute;tem del programa"
#elif L==2	// de
	"Programmelement entfernen"
#elif L==3	// en
	"Remove program item"
#elif L==4	// es
	"Eliminar &iacute;tem del programa"
#elif L==5	// fr
	"Supprimer &eacute;l&eacute;ment de programme"
#elif L==6	// gn
	"Ojepe'a pe mba'e programa"
#elif L==7	// it
	"Rimuovere elemento dal programma"
#elif L==8	// pl
	"Usu&nacute; element programu"
#elif L==9	// pt
	"Remover item do programa"
#elif L==10	// tr
	"Program &ouml;&gbreve;esini kald&inodot;r"
#endif
	,
	[ActHidPrgItm] =
#if   L==1	// ca
	"Hide program item"			// Necessita traducci
#elif L==2	// de
	"Hide program item"			// Need bersetzung
#elif L==3	// en
	"Hide program item"
#elif L==4	// es
	"Ocultar &iacute;tem del programa"
#elif L==5	// fr
	"Hide program item"			// Besoin de traduction
#elif L==6	// gn
	"Ocultar &iacute;tem del programa"	// Okoteve traduccin
#elif L==7	// it
	"Hide program item"			// Bisogno di traduzione
#elif L==8	// pl
	"Hide program item"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide program item"			// Precisa de traduo
#elif L==10	// tr
	"Hide program item"			// eviri lazim!
#endif
	,
	[ActUnhPrgItm] =
#if   L==1	// ca
	"Show program item"			// Necessita traducci
#elif L==2	// de
	"Show program item"			// Need bersetzung
#elif L==3	// en
	"Show program item"
#elif L==4	// es
	"Mostrar &iacute;tem del programa"
#elif L==5	// fr
	"Show program item"			// Besoin de traduction
#elif L==6	// gn
	"Mostrar &iacute;tem del programa"	// Okoteve traduccin
#elif L==7	// it
	"Show program item"			// Bisogno di traduzione
#elif L==8	// pl
	"Show program item"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show program item"			// Precisa de traduo
#elif L==10	// tr
	"Show program item"			// eviri lazim!
#endif
	,
	[ActUp_PrgItm] =
#if   L==1	// ca
	"Move up program item"			// Necessita traducci
#elif L==2	// de
	"Move up program item"			// Need bersetzung
#elif L==3	// en
	"Move up program item"
#elif L==4	// es
	"Subir &iacute;tem del programa"
#elif L==5	// fr
	"Move up program item"			// Besoin de traduction
#elif L==6	// gn
	"Subir &iacute;tem del programa"	// Okoteve traduccin
#elif L==7	// it
	"Move up program item"			// Bisogno di traduzione
#elif L==8	// pl
	"Move up program item"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Move up program item"			// Precisa de traduo
#elif L==10	// tr
	"Move up program item"			// eviri lazim!
#endif
	,
	[ActDwnPrgItm] =
#if   L==1	// ca
	"Move down program item"		// Necessita traducci
#elif L==2	// de
	"Move down program item"		// Need bersetzung
#elif L==3	// en
	"Move down program item"
#elif L==4	// es
	"Bajar &iacute;tem del programa"
#elif L==5	// fr
	"Move down program item"		// Besoin de traduction
#elif L==6	// gn
	"Bajar &iacute;tem del programa"	// Okoteve traduccin
#elif L==7	// it
	"Move down program item"		// Bisogno di traduzione
#elif L==8	// pl
	"Move down program item"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Move down program item"		// Precisa de traduo
#elif L==10	// tr
	"Move down program item"		// eviri lazim!
#endif
	,
	[ActLftPrgItm] =
#if   L==1	// ca
	"Move left program item"			// Necessita traducci
#elif L==2	// de
	"Move left program item"			// Need bersetzung
#elif L==3	// en
	"Move left program item"
#elif L==4	// es
	"Mover a la izquierda &iacute;tem del programa"
#elif L==5	// fr
	"Move left program item"			// Besoin de traduction
#elif L==6	// gn
	"Mover a la izquierda &iacute;tem del programa"	// Okoteve traduccin
#elif L==7	// it
	"Move left program item"			// Bisogno di traduzione
#elif L==8	// pl
	"Move left program item"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Move left program item"			// Precisa de traduo
#elif L==10	// tr
	"Move left program item"			// eviri lazim!
#endif
	,
	[ActRgtPrgItm] =
#if   L==1	// ca
	"Move right program item"			// Necessita traducci
#elif L==2	// de
	"Move right program item"			// Need bersetzung
#elif L==3	// en
	"Move right program item"
#elif L==4	// es
	"Mover a la derecha &iacute;tem del programa"
#elif L==5	// fr
	"Move right program item"			// Besoin de traduction
#elif L==6	// gn
	"Mover a la derecha &iacute;tem del programa"	// Okoteve traduccin
#elif L==7	// it
	"Move right program item"			// Bisogno di traduzione
#elif L==8	// pl
	"Move right program item"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Move right program item"			// Precisa de traduo
#elif L==10	// tr
	"Move right program item"			// eviri lazim!
#endif
	,
	[ActExpSeePrgItm] =
#if   L==1	// ca
	"Expand program item"			// Necessita traducci
#elif L==2	// de
	"Expand program item"			// Need bersetzung
#elif L==3	// en
	"Expand program item"
#elif L==4	// es
	"Expandir &iacute;tem del programa"
#elif L==5	// fr
	"Expand program item"			// Besoin de traduction
#elif L==6	// gn
	"Expandir &iacute;tem del programa"	// Okoteve traduccin
#elif L==7	// it
	"Expand program item"			// Bisogno di traduzione
#elif L==8	// pl
	"Expand program item"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand program item"			// Precisa de traduo
#elif L==10	// tr
	"Expand program item"			// eviri lazim!
#endif
	,
	[ActConSeePrgItm] =
#if   L==1	// ca
	"Contract program item"			// Necessita traducci
#elif L==2	// de
	"Contract program item"			// Need bersetzung
#elif L==3	// en
	"Contract program item"
#elif L==4	// es
	"Contraer &iacute;tem del programa"
#elif L==5	// fr
	"Contract program item"			// Besoin de traduction
#elif L==6	// gn
	"Contraer &iacute;tem del programa"	// Okoteve traduccin
#elif L==7	// it
	"Contract program item"			// Bisogno di traduzione
#elif L==8	// pl
	"Contract program item"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract program item"			// Precisa de traduo
#elif L==10	// tr
	"Contract program item"			// eviri lazim!
#endif
	,
	[ActExpEdiPrgItm] =
#if   L==1	// ca
	"Expand program item when editing"		// Necessita traducci
#elif L==2	// de
	"Expand program item when editing"		// Need bersetzung
#elif L==3	// en
	"Expand program item when editing"
#elif L==4	// es
	"Expandir &iacute;tem del programa editando"
#elif L==5	// fr
	"Expand program item when editing"		// Besoin de traduction
#elif L==6	// gn
	"Expandir &iacute;tem del programa editando"	// Okoteve traduccin
#elif L==7	// it
	"Expand program item when editing"		// Bisogno di traduzione
#elif L==8	// pl
	"Expand program item when editing"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand program item when editing"		// Precisa de traduo
#elif L==10	// tr
	"Expand program item when editing"		// eviri lazim!
#endif
	,
	[ActConEdiPrgItm] =
#if   L==1	// ca
	"Contract program item when editing"		// Necessita traducci
#elif L==2	// de
	"Contract program item when editing"		// Need bersetzung
#elif L==3	// en
	"Contract program item when editing"
#elif L==4	// es
	"Contraer &iacute;tem del programa editando"
#elif L==5	// fr
	"Contract program item when editing"		// Besoin de traduction
#elif L==6	// gn
	"Contraer &iacute;tem del programa editando"	// Okoteve traduccin
#elif L==7	// it
	"Contract program item when editing"		// Bisogno di traduzione
#elif L==8	// pl
	"Contract program item when editing"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract program item when editing"		// Precisa de traduo
#elif L==10	// tr
	"Contract program item when editing"		// eviri lazim!
#endif
	,
	[ActSeeRscCli_InPrg] =
#if   L==1	// ca
	"Veure portapapers de recursos en programa"
#elif L==2	// de
	"Siehe Ressourcen-Zwischenablage im Programm"
#elif L==3	// en
	"See resource clipboard in program"
#elif L==4	// es
	"Ver portapapeles de recursos en programa"
#elif L==5	// fr
	"Voir le presse-papiers des ressources dans le programme"
#elif L==6	// gn
	"Ehecha portapapeles umi recurso o&itilde;va programa-pe"
#elif L==7	// it
	"Visualizza gli appunti delle risorse nel programma"
#elif L==8	// pl
	"Zobacz schowek zasob&oacute;w w programie"
#elif L==9	// pt
	"Ver &aacute;rea de transfer&ecirc;ncia de recursos no programa"
#elif L==10	// tr
	"Programdaki kaynak panosuna bak&inodot;n"
#endif
	,
	[ActRemRscCli_InPrg] =
#if   L==1	// ca
	"Eliminar portapapers de recursos en programa"
#elif L==2	// de
	"Entfernen Sie die Ressourcen-Zwischenablage im Programm"
#elif L==3	// en
	"Remove resource clipboard in program"
#elif L==4	// es
	"Eliminar portapapeles de recursos en programa"
#elif L==5	// fr
	"Supprimer le presse-papiers des ressources dans le programme"
#elif L==6	// gn
	"Embogue recurso portapapeles programa-pe"
#elif L==7	// it
	"Elimina gli appunti delle risorse nel programma"
#elif L==8	// pl
	"Usu&nacute; schowek zasob&oacute;w w programie"
#elif L==9	// pt
	"Remover &aacute;rea de transfer&ecirc;ncia de recursos no programa"
#elif L==10	// tr
	"Programdaki kaynak panosunu kald&inodot;r"
#endif
	,
	[ActFrmSeePrgRsc] =
#if   L==1	// ca
	"Veure recursos"
#elif L==2	// de
	"Siehe Ressourcen"
#elif L==3	// en
	"See resources"
#elif L==4	// es
	"Ver recursos"
#elif L==5	// fr
	"Voir ressources"
#elif L==6	// gn
	"Ehecha umi recurso"
#elif L==7	// it
	"Vedi risorse"
#elif L==8	// pl
	"Zobacz zasoby"
#elif L==9	// pt
	"Ver recursos"
#elif L==10	// tr
	"Kaynaklar&inodot; d&uuml;zenle"
#endif
	,
	[ActFrmEdiPrgRsc] =
#if   L==1	// ca
	"Editar recursos"
#elif L==2	// de
	"Ressourcen bearbeiten"
#elif L==3	// en
	"Edit resources"
#elif L==4	// es
	"Editar recursos"
#elif L==5	// fr
	"Modifier ressources"
#elif L==6	// gn
	"Editar recursos"	// Okoteve traduccin
#elif L==7	// it
	"Modifica risorse"
#elif L==8	// pl
	"Edytuj zasoby"
#elif L==9	// pt
	"Editar recursos"
#elif L==10	// tr
	"Kaynaklar&inodot; d&uuml;zenle"
#endif
	,
	[ActNewPrgRsc] =
#if   L==1	// ca
	"Create resource"	// Necessita traducci
#elif L==2	// de
	"Create resource"	// Need bersetzung
#elif L==3	// en
	"Create resource"
#elif L==4	// es
	"Crear recurso"
#elif L==5	// fr
	"Create resource"	// Besoin de traduction
#elif L==6	// gn
	"Crear recurso"		// Okoteve traduccin
#elif L==7	// it
	"Create resource"	// Bisogno di traduzione
#elif L==8	// pl
	"Create resource"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create resource"	// Precisa de traduo
#elif L==10	// tr
	"Create resource"	// eviri lazim!
#endif
	,
	[ActRenPrgRsc] =
#if   L==1	// ca
	"Rename resource"	// Necessita traducci
#elif L==2	// de
	"Rename resource"	// Need bersetzung
#elif L==3	// en
	"Rename resource"
#elif L==4	// es
	"Renombrar recurso"
#elif L==5	// fr
	"Rename resource"	// Besoin de traduction
#elif L==6	// gn
	"Renombrar recurso"	// Okoteve traduccin
#elif L==7	// it
	"Rename resource"	// Bisogno di traduzione
#elif L==8	// pl
	"Rename resource"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename resource"	// Precisa de traduo
#elif L==10	// tr
	"Rename resource"	// eviri lazim!
#endif
	,
	[ActReqRemPrgRsc] =
#if   L==1	// ca
	"Request removal of resource"	// Necessita traducci
#elif L==2	// de
	"Request removal of resource"	// Need bersetzung
#elif L==3	// en
	"Request removal of resource"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de recurso"
#elif L==5	// fr
	"Request removal of resource"	// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de recurso"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of resource"	// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of resource"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of resource"	// Precisa de traduo
#elif L==10	// tr
	"Request removal of resource"	// eviri lazim!
#endif
	,
	[ActRemPrgRsc] =
#if   L==1	// ca
	"Eliminar recurs"
#elif L==2	// de
	"Ressource entfernen"
#elif L==3	// en
	"Remove resource"
#elif L==4	// es
	"Eliminar recurso"
#elif L==5	// fr
	"Supprimer ressource"
#elif L==6	// gn
	"Eliminar recurso"	// Okoteve traduccin
#elif L==7	// it
	"Rimuovere risorsa"
#elif L==8	// pl
	"Usu&nacute; zas&oacute;b"
#elif L==9	// pt
	"Remover recurso"
#elif L==10	// tr
	"Kayna&gbreve;&inodot; kald&inodot;r"
#endif
	,
	[ActHidPrgRsc] =
#if   L==1	// ca
	"Hide resource"		// Necessita traducci
#elif L==2	// de
	"Hide resource"		// Need bersetzung
#elif L==3	// en
	"Hide resource"
#elif L==4	// es
	"Ocultar recurso"
#elif L==5	// fr
	"Hide resource"		// Besoin de traduction
#elif L==6	// gn
	"Ocultar recurso"	// Okoteve traduccin
#elif L==7	// it
	"Hide resource"		// Bisogno di traduzione
#elif L==8	// pl
	"Hide resource"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide resource"		// Precisa de traduo
#elif L==10	// tr
	"Hide resource"		// eviri lazim!
#endif
	,
	[ActUnhPrgRsc] =
#if   L==1	// ca
	"Unhide resource"	// Necessita traducci
#elif L==2	// de
	"Unhide resource"	// Need bersetzung
#elif L==3	// en
	"Unhide resource"
#elif L==4	// es
	"Mostrar recurso"
#elif L==5	// fr
	"Unhide resource"	// Besoin de traduction
#elif L==6	// gn
	"Mostrar recurso"	// Okoteve traduccin
#elif L==7	// it
	"Unhide resource"	// Bisogno di traduzione
#elif L==8	// pl
	"Unhide resource"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide resource"	// Precisa de traduo
#elif L==10	// tr
	"Unhide resource"	// eviri lazim!
#endif
	,
	[ActUp_PrgRsc] =
#if   L==1	// ca
	"Move up resource"	// Necessita traducci
#elif L==2	// de
	"Move up resource"	// Need bersetzung
#elif L==3	// en
	"Move up resource"
#elif L==4	// es
	"Subir recurso"
#elif L==5	// fr
	"Move up resource"	// Besoin de traduction
#elif L==6	// gn
	"Subir recurso"		// Okoteve traduccin
#elif L==7	// it
	"Move up resource"	// Bisogno di traduzione
#elif L==8	// pl
	"Move up resource"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Move up resource"	// Precisa de traduo
#elif L==10	// tr
	"Move up resource"	// eviri lazim!
#endif
	,
	[ActDwnPrgRsc] =
#if   L==1	// ca
	"Move down resource"	// Necessita traducci
#elif L==2	// de
	"Move down resource"	// Need bersetzung
#elif L==3	// en
	"Move down resource"
#elif L==4	// es
	"Bajar recurso"
#elif L==5	// fr
	"Move down resource"	// Besoin de traduction
#elif L==6	// gn
	"Bajar recurso"		// Okoteve traduccin
#elif L==7	// it
	"Move down resource"	// Bisogno di traduzione
#elif L==8	// pl
	"Move down resource"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Move down resource"	// Precisa de traduo
#elif L==10	// tr
	"Move down resource"	// eviri lazim!
#endif
	,
	[ActFrmChgLnkPrgRsc] =
#if   L==1	// ca
	"Edit resource link"		// Necessita traducci
#elif L==2	// de
	"Edit resource link"		// Need bersetzung
#elif L==3	// en
	"Edit resource link"
#elif L==4	// es
	"Editar enlace de recurso"
#elif L==5	// fr
	"Edit resource link"		// Besoin de traduction
#elif L==6	// gn
	"Editar enlace de recurso"	// Okoteve traduccin
#elif L==7	// it
	"Edit resource link"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit resource link"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit resource link"		// Precisa de traduo
#elif L==10	// tr
	"Edit resource link"		// eviri lazim!
#endif
	,
	[ActChgLnkPrgRsc] =
#if   L==1	// ca
	"Canviar enlla&ccedil; a recurs des del programa"
#elif L==2	// de
	"&Auml;ndern Sie den Link zur Ressource aus dem Programm"
#elif L==3	// en
	"Change link to resource from the program"
#elif L==4	// es
	"Cambiar enlace a recurso desde el programa"
#elif L==5	// fr
	"Modifier le lien vers la ressource du programme"
#elif L==6	// gn
	"Emoambue enlace recurso-pe programa-gui"
#elif L==7	// it
	"Modificare il collegamento alla risorsa dal programma"
#elif L==8	// pl
	"Zmie&nacute; link do zasobu z programu"
#elif L==9	// pt
	"Alterar link para recurso do programa"
#elif L==10	// tr
	"Programdan kayna&gbreve;a ba&gbreve;lant&inodot;y&inodot; de&gbreve;i&scedil;tir"
#endif
	,
	[ActSeeTchGui] =
#if   L==1	// ca
	"See the teaching guide of course"		// Necessita traducci
#elif L==2	// de
	"See the teaching guide of course"		// Need bersetzung
#elif L==3	// en
	"See the teaching guide of course"
#elif L==4	// es
	"Ver la gu&iacute;a docente de la asignatura"
#elif L==5	// fr
	"See the teaching guide of course"		// Besoin de traduction
#elif L==6	// gn
	"Ver la gu&iacute;a docente de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See the teaching guide of course"		// Bisogno di traduzione
#elif L==8	// pl
	"See the teaching guide of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the teaching guide of course"		// Precisa de traduo
#elif L==10	// tr
	"See the teaching guide of course"		// eviri lazim!
#endif
	,
	[ActEdiTchGui] =
#if   L==1	// ca
	"Edit teaching guide of course"				// Necessita traducci
#elif L==2	// de
	"Edit teaching guide of course"				// Need bersetzung
#elif L==3	// en
	"Edit teaching guide of course"
#elif L==4	// es
	"Editar la gu&iacute;a docente de la asignatura"
#elif L==5	// fr
	"Edit teaching guide of course"				// Besoin de traduction
#elif L==6	// gn
	"Editar la gu&iacute;a docente de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Edit teaching guide of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Edit teaching guide of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit teaching guide of course"				// Precisa de traduo
#elif L==10	// tr
	"Edit teaching guide of course"				// eviri lazim!
#endif
	,
	[ActChgFrcReaTchGui] =
#if   L==1	// ca
	"Change whether students are forced to read the teaching guide"		// Necessita traducci
#elif L==2	// de
	"Change whether students are forced to read the teaching guide"		// Need bersetzung
#elif L==3	// en
	"Change whether students are forced to read the teaching guide"
#elif L==4	// es
	"Cambiar si se obliga a los estudiantes a leer la gu&iacute;a docente"
#elif L==5	// fr
	"Change whether students are forced to read the teaching guide"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar si se obliga a los estudiantes a leer la gu&iacute;a docente"	// Okoteve traduccin
#elif L==7	// it
	"Change whether students are forced to read the teaching guide"		// Bisogno di traduzione
#elif L==8	// pl
	"Change whether students are forced to read the teaching guide"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change whether students are forced to read the teaching guide"		// Precisa de traduo
#elif L==10	// tr
	"Change whether students are forced to read the teaching guide"		// eviri lazim!
#endif
	,
	[ActChgHavReaTchGui] =
#if   L==1	// ca
	"Change if I have read the teaching guide"		// Necessita traducci
#elif L==2	// de
	"Change if I have read the teaching guide"		// Need bersetzung
#elif L==3	// en
	"Change if I have read the teaching guide"
#elif L==4	// es
	"Cambiar si he le&iacute;do la gu&iacute;a docente"
#elif L==5	// fr
	"Change if I have read the teaching guide"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar si he le&iacute;do la gu&iacute;a docente"	// Okoteve traduccin
#elif L==7	// it
	"Change if I have read the teaching guide"		// Bisogno di traduzione
#elif L==8	// pl
	"Change if I have read the teaching guide"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change if I have read the teaching guide"		// Precisa de traduo
#elif L==10	// tr
	"Change if I have read the teaching guide"		// eviri lazim!
#endif
	,
	[ActSelInfSrcTchGui] =
#if   L==1	// ca
	"Select the type of information shown in the teaching guide"			// Necessita traducci
#elif L==2	// de
	"Select the type of information shown in the teaching guide"			// Need bersetzung
#elif L==3	// en
	"Select the type of information shown in the teaching guide"
#elif L==4	// es
	"Seleccionar el tipo de informaci&oacute;n mostrada en la gu&iacute;a docente"
#elif L==5	// fr
	"Select the type of information shown in the teaching guide"			// Besoin de traduction
#elif L==6	// gn
	"Seleccionar el tipo de informaci&oacute;n mostrada en la gu&iacute;a docente"	// Okoteve traduccin
#elif L==7	// it
	"Select the type of information shown in the teaching guide"			// Bisogno di traduzione
#elif L==8	// pl
	"Select the type of information shown in the teaching guide"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Select the type of information shown in the teaching guide"			// Precisa de traduo
#elif L==10	// tr
	"Select the type of information shown in the teaching guide"			// eviri lazim!
#endif
	,
	[ActRcvURLTchGui] =
#if   L==1	// ca
	"Create URL in the teaching guide"		// Necessita traducci
#elif L==2	// de
	"Create URL in the teaching guide"		// Need bersetzung
#elif L==3	// en
	"Create URL in the teaching guide"
#elif L==4	// es
	"Crear una URL en la gu&iacute;a docente"
#elif L==5	// fr
	"Create URL in the teaching guide"		// Besoin de traduction
#elif L==6	// gn
	"Crear una URL en la gu&iacute;a docente"	// Okoteve traduccin
#elif L==7	// it
	"Create URL in the teaching guide"		// Bisogno di traduzione
#elif L==8	// pl
	"Create URL in the teaching guide"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create URL in the teaching guide"		// Precisa de traduo
#elif L==10	// tr
	"Create URL in the teaching guide"		// eviri lazim!
#endif
	,
	[ActRcvPagTchGui] =
#if   L==1	// ca
	"Create web page in the teaching guide"			// Necessita traducci
#elif L==2	// de
	"Create web page in the teaching guide"			// Need bersetzung
#elif L==3	// en
	"Create web page in the teaching guide"
#elif L==4	// es
	"Crear una p&aacute;gina web en la gu&iacute;a docente"
#elif L==5	// fr
	"Create web page in the teaching guide"			// Besoin de traduction
#elif L==6	// gn
	"Crear una p&aacute;gina web en la gu&iacute;a docente"	// Okoteve traduccin
#elif L==7	// it
	"Create web page in the teaching guide"			// Bisogno di traduzione
#elif L==8	// pl
	"Create web page in the teaching guide"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create web page in the teaching guide"			// Precisa de traduo
#elif L==10	// tr
	"Create web page in the teaching guide"			// eviri lazim!
#endif
	,
	[ActEditorTchGui] =
#if   L==1	// ca
	"Integrated editor of the teaching guide"	// Necessita traducci
#elif L==2	// de
	"Integrated editor of the teaching guide"	// Need bersetzung
#elif L==3	// en
	"Integrated editor of the teaching guide"
#elif L==4	// es
	"Editor integrado de la gu&iacute;a docente"
#elif L==5	// fr
	"Integrated editor of the teaching guide"	// Besoin de traduction
#elif L==6	// gn
	"Editor integrado de la gu&iacute;a docente"	// Okoteve traduccin
#elif L==7	// it
	"Integrated editor of the teaching guide"	// Bisogno di traduzione
#elif L==8	// pl
	"Integrated editor of the teaching guide"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Integrated editor of the teaching guide"	// Precisa de traduo
#elif L==10	// tr
	"Integrated editor of the teaching guide"	// eviri lazim!
#endif
	,
	[ActPlaTxtEdiTchGui] =
#if   L==1	// ca
	"Plain text editor of the teaching guide"		// Necessita traducci
#elif L==2	// de
	"Plain text editor of the teaching guide"		// Need bersetzung
#elif L==3	// en
	"Plain text editor of the teaching guide"
#elif L==4	// es
	"Editor de texto plano de la gu&iacute;a docente"
#elif L==5	// fr
	"Plain text editor of the teaching guide"		// Besoin de traduction
#elif L==6	// gn
	"Editor de texto plano de la gu&iacute;a docente"	// Okoteve traduccin
#elif L==7	// it
	"Plain text editor of the teaching guide"		// Bisogno di traduzione
#elif L==8	// pl
	"Plain text editor of the teaching guide"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Plain text editor of the teaching guide"		// Precisa de traduo
#elif L==10	// tr
	"Plain text editor of the teaching guide"		// eviri lazim!
#endif
	,
	[ActRchTxtEdiTchGui] =
#if   L==1	// ca
	"Rich text editor of the teaching guide"		// Necessita traducci
#elif L==2	// de
	"Rich text editor of the teaching guide"		// Need bersetzung
#elif L==3	// en
	"Rich text editor of the teaching guide"
#elif L==4	// es
	"Editor de texto enriquecido de la gu&iacute;a docente"
#elif L==5	// fr
	"Rich text editor of the teaching guide"		// Besoin de traduction
#elif L==6	// gn
	"Editor de texto enriquecido de la gu&iacute;a docente"	// Okoteve traduccin
#elif L==7	// it
	"Rich text editor of the teaching guide"		// Bisogno di traduzione
#elif L==8	// pl
	"Rich text editor of the teaching guide"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rich text editor of the teaching guide"		// Precisa de traduo
#elif L==10	// tr
	"Rich text editor of the teaching guide"		// eviri lazim!
#endif
	,
	[ActRcvPlaTxtTchGui] =
#if   L==1	// ca
	"Change plain text of the teaching guide"	// Necessita traducci
#elif L==2	// de
	"Change plain text of the teaching guide"	// Need bersetzung
#elif L==3	// en
	"Change plain text of the teaching guide"
#elif L==4	// es
	"Cambiar texto plano de la gu&iacute;a docente"
#elif L==5	// fr
	"Change plain text of the teaching guide"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar texto plano de la gu&iacute;a docente"	// Okoteve traduccin
#elif L==7	// it
	"Change plain text of the teaching guide"	// Bisogno di traduzione
#elif L==8	// pl
	"Change plain text of the teaching guide"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change plain text of the teaching guide"	// Precisa de traduo
#elif L==10	// tr
	"Change plain text of the teaching guide"	// eviri lazim!
#endif
	,
	[ActRcvRchTxtTchGui] =
#if   L==1	// ca
	"Change rich text of the teaching guide"		// Necessita traducci
#elif L==2	// de
	"Change rich text of the teaching guide"		// Need bersetzung
#elif L==3	// en
	"Change rich text of the teaching guide"
#elif L==4	// es
	"Cambiar texto enriquecido de la gu&iacute;a docente"
#elif L==5	// fr
	"Change rich text of the teaching guide"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar texto enriquecido de la gu&iacute;a docente"	// Okoteve traduccin
#elif L==7	// it
	"Change rich text of the teaching guide"		// Bisogno di traduzione
#elif L==8	// pl
	"Change rich text of the teaching guide"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change rich text of the teaching guide"		// Precisa de traduo
#elif L==10	// tr
	"Change rich text of the teaching guide"		// eviri lazim!
#endif
	,
/*
	[ActSeeSyl] =
#if   L==1	// ca
	"See the syllabus (lectures or practicals)"		// Necessita traducci
#elif L==2	// de
	"See the syllabus (lectures or practicals)"		// Need bersetzung
#elif L==3	// en
	"See the syllabus (lectures or practicals)"
#elif L==4	// es
	"Ver el temario (teor&iacute;a o pr&aacute;cticas)"
#elif L==5	// fr
	"See the syllabus (lectures or practicals)"		// Besoin de traduction
#elif L==6	// gn
	"Ver el temario (teor&iacute;a o pr&aacute;cticas)"	// Okoteve traduccin
#elif L==7	// it
	"See the syllabus (lectures or practicals)"		// Bisogno di traduzione
#elif L==8	// pl
	"See the syllabus (lectures or practicals)"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the syllabus (lectures or practicals)"		// Precisa de traduo
#elif L==10	// tr
	"See the syllabus (lectures or practicals)"		// eviri lazim!
#endif
	,
*/
	[ActSeeSyl] =
#if   L==1	// ca
	"See the syllabus"	// Necessita traducci
#elif L==2	// de
	"See the syllabus"	// Need bersetzung
#elif L==3	// en
	"See the syllabus"
#elif L==4	// es
	"Ver el temario"
#elif L==5	// fr
	"See the syllabus"	// Besoin de traduction
#elif L==6	// gn
	"Ver el temario"	// Okoteve traduccin
#elif L==7	// it
	"See the syllabus"	// Bisogno di traduzione
#elif L==8	// pl
	"See the syllabus"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the syllabus"	// Precisa de traduo
#elif L==10	// tr
	"See the syllabus"	// eviri lazim!
#endif
	,
	[ActEdiSyl] =
#if   L==1	// ca
	"Edit syllabus"		// Necessita traducci
#elif L==2	// de
	"Edit syllabus"		// Need bersetzung
#elif L==3	// en
	"Edit syllabus"
#elif L==4	// es
	"Editar temario"
#elif L==5	// fr
	"Edit syllabus"		// Besoin de traduction
#elif L==6	// gn
	"Editar temario"	// Okoteve traduccin
#elif L==7	// it
	"Edit syllabus"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit syllabus"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit syllabus"		// Precisa de traduo
#elif L==10	// tr
	"Edit syllabus"		// eviri lazim!
#endif
	,
	[ActDelItmSyl] =
#if   L==1	// ca
	"Remove item from syllabus"		// Necessita traducci
#elif L==2	// de
	"Remove item from syllabus"		// Need bersetzung
#elif L==3	// en
	"Remove item from syllabus"
#elif L==4	// es
	"Eliminar &iacute;tem del temario"
#elif L==5	// fr
	"Remove item from syllabus"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar &iacute;tem del temario"	// Okoteve traduccin
#elif L==7	// it
	"Remove item from syllabus"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove item from syllabus"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove item from syllabus"		// Precisa de traduo
#elif L==10	// tr
	"Remove item from syllabus"		// eviri lazim!
#endif
	,
	[ActUp_IteSyl] =
#if   L==1	// ca
	"Raise the position of a subtree of the syllabus"		// Necessita traducci
#elif L==2	// de
	"Raise the position of a subtree of the syllabus"		// Need bersetzung
#elif L==3	// en
	"Raise the position of a subtree of the syllabus"
#elif L==4	// es
	"Subir la posici&oacute;n de un sub&aacute;rbol del temario"
#elif L==5	// fr
	"Raise the position of a subtree of the syllabus"		// Besoin de traduction
#elif L==6	// gn
	"Subir la posici&oacute;n de un sub&aacute;rbol del temario"	// Okoteve traduccin
#elif L==7	// it
	"Raise the position of a subtree of the syllabus"		// Bisogno di traduzione
#elif L==8	// pl
	"Raise the position of a subtree of the syllabus"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Raise the position of a subtree of the syllabus"		// Precisa de traduo
#elif L==10	// tr
	"Raise the position of a subtree of the syllabus"		// eviri lazim!
#endif
	,
	[ActDwnIteSyl] =
#if   L==1	// ca
	"Lower the position of a subtree of the syllabus"		// Necessita traducci
#elif L==2	// de
	"Lower the position of a subtree of the syllabus"		// Need bersetzung
#elif L==3	// en
	"Lower the position of a subtree of the syllabus"
#elif L==4	// es
	"Bajar la posici&oacute;n de un sub&aacute;rbol del temario"
#elif L==5	// fr
	"Lower the position of a subtree of the syllabus"		// Besoin de traduction
#elif L==6	// gn
	"Bajar la posici&oacute;n de un sub&aacute;rbol del temario"	// Okoteve traduccin
#elif L==7	// it
	"Lower the position of a subtree of the syllabus"		// Bisogno di traduzione
#elif L==8	// pl
	"Lower the position of a subtree of the syllabus"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Lower the position of a subtree of the syllabus"		// Precisa de traduo
#elif L==10	// tr
	"Lower the position of a subtree of the syllabus"		// eviri lazim!
#endif
	,
	[ActRgtIteSyl] =
#if   L==1	// ca
	"Increase the level of an item on the syllabus"		// Necessita traducci
#elif L==2	// de
	"Increase the level of an item on the syllabus"		// Need bersetzung
#elif L==3	// en
	"Increase the level of an item on the syllabus"
#elif L==4	// es
	"Aumentar el nivel de un &iacute;tem del temario"
#elif L==5	// fr
	"Increase the level of an item on the syllabus"		// Besoin de traduction
#elif L==6	// gn
	"Aumentar el nivel de un &iacute;tem del temario"	// Okoteve traduccin
#elif L==7	// it
	"Increase the level of an item on the syllabus"		// Bisogno di traduzione
#elif L==8	// pl
	"Increase the level of an item on the syllabus"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Increase the level of an item on the syllabus"		// Precisa de traduo
#elif L==10	// tr
	"Increase the level of an item on the syllabus"		// eviri lazim!
#endif
	,
	[ActLftIteSyl] =
#if   L==1	// ca
	"Decrease the level of an item on the syllabus"		// Necessita traducci
#elif L==2	// de
	"Decrease the level of an item on the syllabus"		// Need bersetzung
#elif L==3	// en
	"Decrease the level of an item on the syllabus"
#elif L==4	// es
	"Disminuir el nivel de un &iacute;tem del temario"
#elif L==5	// fr
	"Decrease the level of an item on the syllabus"		// Besoin de traduction
#elif L==6	// gn
	"Disminuir el nivel de un &iacute;tem del temario"	// Okoteve traduccin
#elif L==7	// it
	"Decrease the level of an item on the syllabus"		// Bisogno di traduzione
#elif L==8	// pl
	"Decrease the level of an item on the syllabus"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Decrease the level of an item on the syllabus"		// Precisa de traduo
#elif L==10	// tr
	"Decrease the level of an item on the syllabus"		// eviri lazim!
#endif
	,
	[ActInsIteSyl] =
#if   L==1	// ca
	"Insert a new item in the syllabus"		// Necessita traducci
#elif L==2	// de
	"Insert a new item in the syllabus"		// Need bersetzung
#elif L==3	// en
	"Insert a new item in the syllabus"
#elif L==4	// es
	"Insertar un nuevo &iacute;tem en el temario"
#elif L==5	// fr
	"Insert a new item in the syllabus"		// Besoin de traduction
#elif L==6	// gn
	"Insertar un nuevo &iacute;tem en el temario"	// Okoteve traduccin
#elif L==7	// it
	"Insert a new item in the syllabus"		// Bisogno di traduzione
#elif L==8	// pl
	"Insert a new item in the syllabus"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Insert a new item in the syllabus"		// Precisa de traduo
#elif L==10	// tr
	"Insert a new item in the syllabus"		// eviri lazim!
#endif
	,
	[ActModIteSyl] =
#if   L==1	// ca
	"Change item in the syllabus"		// Necessita traducci
#elif L==2	// de
	"Change item in the syllabus"		// Need bersetzung
#elif L==3	// en
	"Change item in the syllabus"
#elif L==4	// es
	"Modificar un &iacute;tem del temario"
#elif L==5	// fr
	"Change item in the syllabus"		// Besoin de traduction
#elif L==6	// gn
	"Modificar un &iacute;tem del temario"	// Okoteve traduccin
#elif L==7	// it
	"Change item in the syllabus"		// Bisogno di traduzione
#elif L==8	// pl
	"Change item in the syllabus"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change item in the syllabus"		// Precisa de traduo
#elif L==10	// tr
	"Change item in the syllabus"		// eviri lazim!
#endif
	,
	[ActChgFrcReaSyl] =
#if   L==1	// ca
	"Change whether students are forced to read the syllabus"	// Necessita traducci
#elif L==2	// de
	"Change whether students are forced to read the syllabus"	// Need bersetzung
#elif L==3	// en
	"Change whether students are forced to read the syllabus"
#elif L==4	// es
	"Cambiar si se obliga a los estudiantes a leer el temario"
#elif L==5	// fr
	"Change whether students are forced to read the syllabus"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar si se obliga a los estudiantes a leer el temario"	// Okoteve traduccin
#elif L==7	// it
	"Change whether students are forced to read the syllabus"	// Bisogno di traduzione
#elif L==8	// pl
	"Change whether students are forced to read the syllabus"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change whether students are forced to read the syllabus"	// Precisa de traduo
#elif L==10	// tr
	"Change whether students are forced to read the syllabus"	// eviri lazim!
#endif
	,
	[ActChgHavReaSyl] =
#if   L==1	// ca
	"Change if I have read the syllabus"		// Necessita traducci
#elif L==2	// de
	"Change if I have read the syllabus"		// Need bersetzung
#elif L==3	// en
	"Change if I have read the syllabus"
#elif L==4	// es
	"Cambiar si he le&iacute;do el programa"
#elif L==5	// fr
	"Change if I have read the syllabus"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar si he le&iacute;do el programa"	// Okoteve traduccin
#elif L==7	// it
	"Change if I have read the syllabus"		// Bisogno di traduzione
#elif L==8	// pl
	"Change if I have read the syllabus"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change if I have read the syllabus"		// Precisa de traduo
#elif L==10	// tr
	"Change if I have read the syllabus"		// eviri lazim!
#endif
	,
	[ActSelInfSrcSyl] =
#if   L==1	// ca
	"Select the type of information shown in the syllabus"			// Necessita traducci
#elif L==2	// de
	"Select the type of information shown in the syllabus"			// Need bersetzung
#elif L==3	// en
	"Select the type of information shown in the syllabus"
#elif L==4	// es
	"Seleccionar el tipo de informaci&oacute;n mostrada en el programa"
#elif L==5	// fr
	"Select the type of information shown in the syllabus"			// Besoin de traduction
#elif L==6	// gn
	"Seleccionar el tipo de informaci&oacute;n mostrada en el programa"	// Okoteve traduccin
#elif L==7	// it
	"Select the type of information shown in the syllabus"			// Bisogno di traduzione
#elif L==8	// pl
	"Select the type of information shown in the syllabus"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Select the type of information shown in the syllabus"			// Precisa de traduo
#elif L==10	// tr
	"Select the type of information shown in the syllabus"			// eviri lazim!
#endif
	,
	[ActRcvURLSyl] =
#if   L==1	// ca
	"Create URL in the syllabus"		// Necessita traducci
#elif L==2	// de
	"Create URL in the syllabus"		// Need bersetzung
#elif L==3	// en
	"Create URL in the syllabus"
#elif L==4	// es
	"Crear una URL en el programa"
#elif L==5	// fr
	"Create URL in the syllabus"		// Besoin de traduction
#elif L==6	// gn
	"Crear una URL en el programa"		// Okoteve traduccin
#elif L==7	// it
	"Create URL in the syllabus"		// Bisogno di traduzione
#elif L==8	// pl
	"Create URL in the syllabus"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create URL in the syllabus"		// Precisa de traduo
#elif L==10	// tr
	"Create URL in the syllabus"		// eviri lazim!
#endif
	,
	[ActRcvPagSyl] =
#if   L==1	// ca
	"Create web page in the syllabus"		// Necessita traducci
#elif L==2	// de
	"Create web page in the syllabus"		// Need bersetzung
#elif L==3	// en
	"Create web page in the syllabus"
#elif L==4	// es
	"Crear una p&aacute;gina web en el programa"
#elif L==5	// fr
	"Create web page in the syllabus"		// Besoin de traduction
#elif L==6	// gn
	"Crear una p&aacute;gina web en el programa"	// Okoteve traduccin
#elif L==7	// it
	"Create web page in the syllabus"		// Bisogno di traduzione
#elif L==8	// pl
	"Create web page in the syllabus"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create web page in the syllabus"		// Precisa de traduo
#elif L==10	// tr
	"Create web page in the syllabus"		// eviri lazim!
#endif
	,
	[ActEditorSyl] =
#if   L==1	// ca
	"Integrated editor of the syllabus"	// Necessita traducci
#elif L==2	// de
	"Integrated editor of the syllabus"	// Need bersetzung
#elif L==3	// en
	"Integrated editor of the syllabus"
#elif L==4	// es
	"Editor integrado del programa"
#elif L==5	// fr
	"Integrated editor of the syllabus"	// Besoin de traduction
#elif L==6	// gn
	"Editor integrado del programa"		// Okoteve traduccin
#elif L==7	// it
	"Integrated editor of the syllabus"	// Bisogno di traduzione
#elif L==8	// pl
	"Integrated editor of the syllabus"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Integrated editor of the syllabus"	// Precisa de traduo
#elif L==10	// tr
	"Integrated editor of the syllabus"	// eviri lazim!
#endif
	,
	[ActPlaTxtEdiSyl] =
#if   L==1	// ca
	"Plain text editor of the syllabus"	// Necessita traducci
#elif L==2	// de
	"Plain text editor of the syllabus"	// Need bersetzung
#elif L==3	// en
	"Plain text editor of the syllabus"
#elif L==4	// es
	"Editor de texto plano del programa"
#elif L==5	// fr
	"Plain text editor of the syllabus"	// Besoin de traduction
#elif L==6	// gn
	"Editor de texto plano del programa"	// Okoteve traduccin
#elif L==7	// it
	"Plain text editor of the syllabus"	// Bisogno di traduzione
#elif L==8	// pl
	"Plain text editor of the syllabus"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Plain text editor of the syllabus"	// Precisa de traduo
#elif L==10	// tr
	"Plain text editor of the syllabus"	// eviri lazim!
#endif
	,
	[ActRchTxtEdiSyl] =
#if   L==1	// ca
	"Rich text editor of the syllabus"		// Necessita traducci
#elif L==2	// de
	"Rich text editor of the syllabus"		// Need bersetzung
#elif L==3	// en
	"Rich text editor of the syllabus"
#elif L==4	// es
	"Editor de texto enriquecido del programa"
#elif L==5	// fr
	"Rich text editor of the syllabus"		// Besoin de traduction
#elif L==6	// gn
	"Editor de texto enriquecido del programa"	// Okoteve traduccin
#elif L==7	// it
	"Rich text editor of the syllabus"		// Bisogno di traduzione
#elif L==8	// pl
	"Rich text editor of the syllabus"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rich text editor of the syllabus"		// Precisa de traduo
#elif L==10	// tr
	"Rich text editor of the syllabus"		// eviri lazim!
#endif
	,
	[ActRcvPlaTxtSyl] =
#if   L==1	// ca
	"Change plain text of the syllabus"	// Necessita traducci
#elif L==2	// de
	"Change plain text of the syllabus"	// Need bersetzung
#elif L==3	// en
	"Change plain text of the syllabus"
#elif L==4	// es
	"Cambiar texto plano del programa"
#elif L==5	// fr
	"Change plain text of the syllabus"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar texto plano del programaa"	// Okoteve traduccin
#elif L==7	// it
	"Change plain text of the syllabus"	// Bisogno di traduzione
#elif L==8	// pl
	"Change plain text of the syllabus"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change plain text of the syllabus"	// Precisa de traduo
#elif L==10	// tr
	"Change plain text of the syllabus"	// eviri lazim!
#endif
	,
	[ActRcvRchTxtSyl] =
#if   L==1	// ca
	"Change rich text of the syllabus"		// Necessita traducci
#elif L==2	// de
	"Change rich text of the syllabus"		// Need bersetzung
#elif L==3	// en
	"Change rich text of the syllabus"
#elif L==4	// es
	"Cambiar texto enriquecido del programa"
#elif L==5	// fr
	"Change rich text of the syllabus"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar texto enriquecido del programa"	// Okoteve traduccin
#elif L==7	// it
	"Change rich text of the syllabus"		// Bisogno di traduzione
#elif L==8	// pl
	"Change rich text of the syllabus"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change rich text of the syllabus"		// Precisa de traduo
#elif L==10	// tr
	"Change rich text of the syllabus"		// eviri lazim!
#endif
	,
	[ActSeeBib] =
#if   L==1	// ca
	"See the bibliography"		// Necessita traducci
#elif L==2	// de
	"See the bibliography"		// Need bersetzung
#elif L==3	// en
	"See the bibliography"
#elif L==4	// es
	"Ver la bibliograf&iacute;a"
#elif L==5	// fr
	"See the bibliography"		// Besoin de traduction
#elif L==6	// gn
	"Ver la bibliograf&iacute;a"	// Okoteve traduccin
#elif L==7	// it
	"See the bibliography"		// Bisogno di traduzione
#elif L==8	// pl
	"See the bibliography"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the bibliography"		// Precisa de traduo
#elif L==10	// tr
	"See the bibliography"		// eviri lazim!
#endif
	,
	[ActEdiBib] =
#if   L==1	// ca
	"Edit bibliography"		// Necessita traducci
#elif L==2	// de
	"Edit bibliography"		// Need bersetzung
#elif L==3	// en
	"Edit bibliography"
#elif L==4	// es
	"Editar la bibliograf&iacute;a"
#elif L==5	// fr
	"Edit bibliography"		// Besoin de traduction
#elif L==6	// gn
	"Editar la bibliograf&iacute;a"	// Okoteve traduccin
#elif L==7	// it
	"Edit bibliography"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit bibliography"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit bibliography"		// Precisa de traduo
#elif L==10	// tr
	"Edit bibliography"		// eviri lazim!
#endif
	,
	[ActChgFrcReaBib] =
#if   L==1	// ca
	"Change whether students are forced to read the bibliography"		// Necessita traducci
#elif L==2	// de
	"Change whether students are forced to read the bibliography"		// Need bersetzung
#elif L==3	// en
	"Change whether students are forced to read the bibliography"
#elif L==4	// es
	"Cambiar si se obliga a los estudiantes a leer la bibliograf&iacute;a"
#elif L==5	// fr
	"Change whether students are forced to read the bibliography"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar si se obliga a los estudiantes a leer la bibliograf&iacute;a"	// Okoteve traduccin
#elif L==7	// it
	"Change whether students are forced to read the bibliography"		// Bisogno di traduzione
#elif L==8	// pl
	"Change whether students are forced to read the bibliography"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change whether students are forced to read the bibliography"		// Precisa de traduo
#elif L==10	// tr
	"Change whether students are forced to read the bibliography"		// eviri lazim!
#endif
	,
	[ActChgHavReaBib] =
#if   L==1	// ca
	"Change if I have read the bibliography"		// Necessita traducci
#elif L==2	// de
	"Change if I have read the bibliography"		// Need bersetzung
#elif L==3	// en
	"Change if I have read the bibliography"
#elif L==4	// es
	"Cambiar si he le&iacute;do la bibliograf&iacute;a"
#elif L==5	// fr
	"Change if I have read the bibliography"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar si he le&iacute;do la bibliograf&iacute;a"	// Okoteve traduccin
#elif L==7	// it
	"Change if I have read the bibliography"		// Bisogno di traduzione
#elif L==8	// pl
	"Change if I have read the bibliography"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change if I have read the bibliography"		// Precisa de traduo
#elif L==10	// tr
	"Change if I have read the bibliography"		// eviri lazim!
#endif
	,
	[ActSelInfSrcBib] =
#if   L==1	// ca
	"Select the type of information shown in the bibliography"			// Necessita traducci
#elif L==2	// de
	"Select the type of information shown in the bibliography"			// Need bersetzung
#elif L==3	// en
	"Select the type of information shown in the bibliography"
#elif L==4	// es
	"Seleccionar el tipo de informaci&oacute;n mostrada en la bibliograf&iacute;a"
#elif L==5	// fr
	"Select the type of information shown in the bibliography"			// Besoin de traduction
#elif L==6	// gn
	"Seleccionar el tipo de informaci&oacute;n mostrada en la bibliograf&iacute;a"	// Okoteve traduccin
#elif L==7	// it
	"Select the type of information shown in the bibliography"			// Bisogno di traduzione
#elif L==8	// pl
	"Select the type of information shown in the bibliography"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Select the type of information shown in the bibliography"			// Precisa de traduo
#elif L==10	// tr
	"Select the type of information shown in the bibliography"			// eviri lazim!
#endif
	,
	[ActRcvURLBib] =
#if   L==1	// ca
	"Create URL in the bibliography"		// Necessita traducci
#elif L==2	// de
	"Create URL in the bibliography"		// Need bersetzung
#elif L==3	// en
	"Create URL in the bibliography"
#elif L==4	// es
	"Crear una URL en la bibliograf&iacute;a"
#elif L==5	// fr
	"Create URL in the bibliography"		// Besoin de traduction
#elif L==6	// gn
	"Crear una URL en la bibliograf&iacute;a"	// Okoteve traduccin
#elif L==7	// it
	"Create URL in the bibliography"		// Bisogno di traduzione
#elif L==8	// pl
	"Create URL in the bibliography"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create URL in the bibliography"		// Precisa de traduo
#elif L==10	// tr
	"Create URL in the bibliography"		// eviri lazim!
#endif
	,
	[ActRcvPagBib] =
#if   L==1	// ca
	"Create web page in the bibliography"			// Necessita traducci
#elif L==2	// de
	"Create web page in the bibliography"			// Need bersetzung
#elif L==3	// en
	"Create web page in the bibliography"
#elif L==4	// es
	"Crear una p&aacute;gina web en la bibliograf&iacute;a"
#elif L==5	// fr
	"Create web page in the bibliography"			// Besoin de traduction
#elif L==6	// gn
	"Crear una p&aacute;gina web en la bibliograf&iacute;a"	// Okoteve traduccin
#elif L==7	// it
	"Create web page in the bibliography"			// Bisogno di traduzione
#elif L==8	// pl
	"Create web page in the bibliography"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create web page in the bibliography"			// Precisa de traduo
#elif L==10	// tr
	"Create web page in the bibliography"			// eviri lazim!
#endif
	,
	[ActEditorBib] =
#if   L==1	// ca
	"Integrated editor of the bibliography"		// Necessita traducci
#elif L==2	// de
	"Integrated editor of the bibliography"		// Need bersetzung
#elif L==3	// en
	"Integrated editor of the bibliography"
#elif L==4	// es
	"Editor integrado de la bibliograf&iacute;a"
#elif L==5	// fr
	"Integrated editor of the bibliography"		// Besoin de traduction
#elif L==6	// gn
	"Editor integrado de la bibliograf&iacute;a"	// Okoteve traduccin
#elif L==7	// it
	"Integrated editor of the bibliography"		// Bisogno di traduzione
#elif L==8	// pl
	"Integrated editor of the bibliography"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Integrated editor of the bibliography"		// Precisa de traduo
#elif L==10	// tr
	"Integrated editor of the bibliography"		// eviri lazim!
#endif
	,
	[ActPlaTxtEdiBib] =
#if   L==1	// ca
	"Plain text editor of the bibliography"			// Necessita traducci
#elif L==2	// de
	"Plain text editor of the bibliography"			// Need bersetzung
#elif L==3	// en
	"Plain text editor of the bibliography"
#elif L==4	// es
	"Editor de texto plano de la bibliograf&iacute;a"
#elif L==5	// fr
	"Plain text editor of the bibliography"			// Besoin de traduction
#elif L==6	// gn
	"Editor de texto plano de la bibliograf&iacute;a"	// Okoteve traduccin
#elif L==7	// it
	"Plain text editor of the bibliography"			// Bisogno di traduzione
#elif L==8	// pl
	"Plain text editor of the bibliography"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Plain text editor of the bibliography"			// Precisa de traduo
#elif L==10	// tr
	"Plain text editor of the bibliography"			// eviri lazim!
#endif
	,
	[ActRchTxtEdiBib] =
#if   L==1	// ca
	"Rich text editor of the bibliography"			// Necessita traducci
#elif L==2	// de
	"Rich text editor of the bibliography"			// Need bersetzung
#elif L==3	// en
	"Rich text editor of the bibliography"
#elif L==4	// es
	"Editor de texto enriquecido de la bibliograf&iacute;a"
#elif L==5	// fr
	"Rich text editor of the bibliography"			// Besoin de traduction
#elif L==6	// gn
	"Editor de texto enriquecido de la bibliograf&iacute;a"	// Okoteve traduccin
#elif L==7	// it
	"Rich text editor of the bibliography"			// Bisogno di traduzione
#elif L==8	// pl
	"Rich text editor of the bibliography"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rich text editor of the bibliography"			// Precisa de traduo
#elif L==10	// tr
	"Rich text editor of the bibliography"			// eviri lazim!
#endif
	,
	[ActRcvPlaTxtBib] =
#if   L==1	// ca
	"Change plain text of the bibliography"		// Necessita traducci
#elif L==2	// de
	"Change plain text of the bibliography"		// Need bersetzung
#elif L==3	// en
	"Change plain text of the bibliography"
#elif L==4	// es
	"Cambiar texto plano de la bibliograf&iacute;a"
#elif L==5	// fr
	"Change plain text of the bibliography"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar texto plano de la bibliograf&iacute;a"	// Okoteve traduccin
#elif L==7	// it
	"Change plain text of the bibliography"		// Bisogno di traduzione
#elif L==8	// pl
	"Change plain text of the bibliography"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change plain text of the bibliography"		// Precisa de traduo
#elif L==10	// tr
	"Change plain text of the bibliography"		// eviri lazim!
#endif
	,
	[ActRcvRchTxtBib] =
#if   L==1	// ca
	"Change rich text of the bibliography"			// Necessita traducci
#elif L==2	// de
	"Change rich text of the bibliography"			// Need bersetzung
#elif L==3	// en
	"Change rich text of the bibliography"
#elif L==4	// es
	"Cambiar texto enriquecido de la bibliograf&iacute;a"
#elif L==5	// fr
	"Change rich text of the bibliography"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar texto enriquecido de la bibliograf&iacute;a"	// Okoteve traduccin
#elif L==7	// it
	"Change rich text of the bibliography"			// Bisogno di traduzione
#elif L==8	// pl
	"Change rich text of the bibliography"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change rich text of the bibliography"			// Precisa de traduo
#elif L==10	// tr
	"Change rich text of the bibliography"			// eviri lazim!
#endif
	,
	[ActSeeFAQ] =
#if   L==1	// ca
	"See the FAQ"	// Necessita traducci
#elif L==2	// de
	"See the FAQ"	// Need bersetzung
#elif L==3	// en
	"See the FAQ"
#elif L==4	// es
	"Ver la FAQ"
#elif L==5	// fr
	"See the FAQ"	// Besoin de traduction
#elif L==6	// gn
	"Ver la FAQ"	// Okoteve traduccin
#elif L==7	// it
	"See the FAQ"	// Bisogno di traduzione
#elif L==8	// pl
	"See the FAQ"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the FAQ"	// Precisa de traduo
#elif L==10	// tr
	"See the FAQ"	// eviri lazim!
#endif
	,
	[ActEdiFAQ] =
#if   L==1	// ca
	"Edit FAQ"		// Necessita traducci
#elif L==2	// de
	"Edit FAQ"		// Need bersetzung
#elif L==3	// en
	"Edit FAQ"
#elif L==4	// es
	"Editar la FAQ"
#elif L==5	// fr
	"Edit FAQ"		// Besoin de traduction
#elif L==6	// gn
	"Editar la FAQ"		// Okoteve traduccin
#elif L==7	// it
	"Edit FAQ"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit FAQ"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit FAQ"		// Precisa de traduo
#elif L==10	// tr
	"Edit FAQ"		// eviri lazim!
#endif
	,
	[ActChgFrcReaFAQ] =
#if   L==1	// ca
	"Change force students to read FAQ"			// Necessita traducci
#elif L==2	// de
	"Change force students to read FAQ"			// Need bersetzung
#elif L==3	// en
	"Change force students to read FAQ"
#elif L==4	// es
	"Cambiar si se obliga a los estudiantes a leer la FAQ"
#elif L==5	// fr
	"Change force students to read FAQ"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar si se obliga a los estudiantes a leer la FAQ"	// Okoteve traduccin
#elif L==7	// it
	"Change force students to read FAQ"			// Bisogno di traduzione
#elif L==8	// pl
	"Change force students to read FAQ"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change force students to read FAQ"			// Precisa de traduo
#elif L==10	// tr
	"Change force students to read FAQ"			// eviri lazim!
#endif
	,
	[ActChgHavReaFAQ] =
#if   L==1	// ca
	"Change if I have read the FAQ"		// Necessita traducci
#elif L==2	// de
	"Change if I have read the FAQ"		// Need bersetzung
#elif L==3	// en
	"Change if I have read the FAQ"
#elif L==4	// es
	"Cambiar si he le&iacute;do la FAQ"
#elif L==5	// fr
	"Change if I have read the FAQ"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar si he le&iacute;do la FAQ"	// Okoteve traduccin
#elif L==7	// it
	"Change if I have read the FAQ"		// Bisogno di traduzione
#elif L==8	// pl
	"Change if I have read the FAQ"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change if I have read the FAQ"		// Precisa de traduo
#elif L==10	// tr
	"Change if I have read the FAQ"		// eviri lazim!
#endif
	,
	[ActSelInfSrcFAQ] =
#if   L==1	// ca
	"Select the type of information shown in the FAQ"		// Necessita traducci
#elif L==2	// de
	"Select the type of information shown in the FAQ"		// Need bersetzung
#elif L==3	// en
	"Select the type of information shown in the FAQ"
#elif L==4	// es
	"Seleccionar el tipo de informaci&oacute;n mostrada en la FAQ"
#elif L==5	// fr
	"Select the type of information shown in the FAQ"		// Besoin de traduction
#elif L==6	// gn
	"Seleccionar el tipo de informaci&oacute;n mostrada en la FAQ"	// Okoteve traduccin
#elif L==7	// it
	"Select the type of information shown in the FAQ"		// Bisogno di traduzione
#elif L==8	// pl
	"Select the type of information shown in the FAQ"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Select the type of information shown in the FAQ"		// Precisa de traduo
#elif L==10	// tr
	"Select the type of information shown in the FAQ"		// eviri lazim!
#endif
	,
	[ActRcvURLFAQ] =
#if   L==1	// ca
	"Create URL in the FAQ"		// Necessita traducci
#elif L==2	// de
	"Create URL in the FAQ"		// Need bersetzung
#elif L==3	// en
	"Create URL in the FAQ"
#elif L==4	// es
	"Crear una URL en la FAQ"
#elif L==5	// fr
	"Create URL in the FAQ"		// Besoin de traduction
#elif L==6	// gn
	"Crear una URL en la FAQ"	// Okoteve traduccin
#elif L==7	// it
	"Create URL in the FAQ"		// Bisogno di traduzione
#elif L==8	// pl
	"Create URL in the FAQ"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create URL in the FAQ"		// Precisa de traduo
#elif L==10	// tr
	"Create URL in the FAQ"		// eviri lazim!
#endif
	,
	[ActRcvPagFAQ] =
#if   L==1	// ca
	"Create web page in the FAQ"		// Necessita traducci
#elif L==2	// de
	"Create web page in the FAQ"		// Need bersetzung
#elif L==3	// en
	"Create web page in the FAQ"
#elif L==4	// es
	"Crear una p&aacute;gina web en la FAQ"
#elif L==5	// fr
	"Create web page in the FAQ"		// Besoin de traduction
#elif L==6	// gn
	"Crear una p&aacute;gina web en la FAQ"	// Okoteve traduccin
#elif L==7	// it
	"Create web page in the FAQ"		// Bisogno di traduzione
#elif L==8	// pl
	"Create web page in the FAQ"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create web page in the FAQ"		// Precisa de traduo
#elif L==10	// tr
	"Create web page in the FAQ"		// eviri lazim!
#endif
	,
	[ActEditorFAQ] =
#if   L==1	// ca
	"Integrated editor of the FAQ"	// Necessita traducci
#elif L==2	// de
	"Integrated editor of the FAQ"	// Need bersetzung
#elif L==3	// en
	"Integrated editor of the FAQ"
#elif L==4	// es
	"Editor integrado de la FAQ"
#elif L==5	// fr
	"Integrated editor of the FAQ"	// Besoin de traduction
#elif L==6	// gn
	"Editor integrado de la FAQ"	// Okoteve traduccin
#elif L==7	// it
	"Integrated editor of the FAQ"	// Bisogno di traduzione
#elif L==8	// pl
	"Integrated editor of the FAQ"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Integrated editor of the FAQ"	// Precisa de traduo
#elif L==10	// tr
	"Integrated editor of the FAQ"	// eviri lazim!
#endif
	,
	[ActPlaTxtEdiFAQ] =
#if   L==1	// ca
	"Plain text editor of the FAQ"		// Necessita traducci
#elif L==2	// de
	"Plain text editor of the FAQ"		// Need bersetzung
#elif L==3	// en
	"Plain text editor of the FAQ"
#elif L==4	// es
	"Editor de texto plano de la FAQ"
#elif L==5	// fr
	"Plain text editor of the FAQ"		// Besoin de traduction
#elif L==6	// gn
	"Editor de texto plano de la FAQ"	// Okoteve traduccin
#elif L==7	// it
	"Plain text editor of the FAQ"		// Bisogno di traduzione
#elif L==8	// pl
	"Plain text editor of the FAQ"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Plain text editor of the FAQ"		// Precisa de traduo
#elif L==10	// tr
	"Plain text editor of the FAQ"		// eviri lazim!
#endif
	,
	[ActRchTxtEdiFAQ] =
#if   L==1	// ca
	"Rich text editor of the FAQ"		// Necessita traducci
#elif L==2	// de
	"Rich text editor of the FAQ"		// Need bersetzung
#elif L==3	// en
	"Rich text editor of the FAQ"
#elif L==4	// es
	"Editor de texto enriquecido de la FAQ"
#elif L==5	// fr
	"Rich text editor of the FAQ"		// Besoin de traduction
#elif L==6	// gn
	"Editor de texto enriquecido de la FAQ"	// Okoteve traduccin
#elif L==7	// it
	"Rich text editor of the FAQ"		// Bisogno di traduzione
#elif L==8	// pl
	"Rich text editor of the FAQ"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rich text editor of the FAQ"		// Precisa de traduo
#elif L==10	// tr
	"Rich text editor of the FAQ"		// eviri lazim!
#endif
	,
	[ActRcvPlaTxtFAQ] =
#if   L==1	// ca
	"Change plain text of the FAQ"	// Necessita traducci
#elif L==2	// de
	"Change plain text of the FAQ"	// Need bersetzung
#elif L==3	// en
	"Change plain text of the FAQ"
#elif L==4	// es
	"Cambiar texto plano de la FAQ"
#elif L==5	// fr
	"Change plain text of the FAQ"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar texto plano de la FAQ"	// Okoteve traduccin
#elif L==7	// it
	"Change plain text of the FAQ"	// Bisogno di traduzione
#elif L==8	// pl
	"Change plain text of the FAQ"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change plain text of the FAQ"	// Precisa de traduo
#elif L==10	// tr
	"Change plain text of the FAQ"	// eviri lazim!
#endif
	,
	[ActRcvRchTxtFAQ] =
#if   L==1	// ca
	"Change rich text of the FAQ"		// Necessita traducci
#elif L==2	// de
	"Change rich text of the FAQ"		// Need bersetzung
#elif L==3	// en
	"Change rich text of the FAQ"
#elif L==4	// es
	"Cambiar texto enriquecido de la FAQ"
#elif L==5	// fr
	"Change rich text of the FAQ"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar texto enriquecido de la FAQ"	// Okoteve traduccin
#elif L==7	// it
	"Change rich text of the FAQ"		// Bisogno di traduzione
#elif L==8	// pl
	"Change rich text of the FAQ"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change rich text of the FAQ"		// Precisa de traduo
#elif L==10	// tr
	"Change rich text of the FAQ"		// eviri lazim!
#endif
	,
	[ActSeeCrsLnk] =
#if   L==1	// ca
	"See the links related to the course"			// Necessita traducci
#elif L==2	// de
	"See the links related to the course"			// Need bersetzung
#elif L==3	// en
	"See the links related to the course"
#elif L==4	// es
	"Ver los enlaces relacionados con la asignatura"
#elif L==5	// fr
	"See the links related to the course"			// Besoin de traduction
#elif L==6	// gn
	"Ver los enlaces relacionados con la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See the links related to the course"			// Bisogno di traduzione
#elif L==8	// pl
	"See the links related to the course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the links related to the course"			// Precisa de traduo
#elif L==10	// tr
	"See the links related to the course"			// eviri lazim!
#endif
	,
	[ActEdiCrsLnk] =
#if   L==1	// ca
	"Edit course links"			// Necessita traducci
#elif L==2	// de
	"Edit course links"			// Need bersetzung
#elif L==3	// en
	"Edit course links"
#elif L==4	// es
	"Editar los enlaces de la asignatura"
#elif L==5	// fr
	"Edit course links"			// Besoin de traduction
#elif L==6	// gn
	"Editar los enlaces de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Edit course links"			// Bisogno di traduzione
#elif L==8	// pl
	"Edit course links"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit course links"			// Precisa de traduo
#elif L==10	// tr
	"Edit course links"			// eviri lazim!
#endif
	,
	[ActChgFrcReaCrsLnk] =
#if   L==1	// ca
	"Change whether students are forced to read the links"		// Necessita traducci
#elif L==2	// de
	"Change whether students are forced to read the links"		// Need bersetzung
#elif L==3	// en
	"Change whether students are forced to read the links"
#elif L==4	// es
	"Cambiar si se obliga a los estudiantes a leer los enlaces"
#elif L==5	// fr
	"Change whether students are forced to read the links"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar si se obliga a los estudiantes a leer los enlaces"	// Okoteve traduccin
#elif L==7	// it
	"Change whether students are forced to read the links"		// Bisogno di traduzione
#elif L==8	// pl
	"Change whether students are forced to read the links"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change whether students are forced to read the links"		// Precisa de traduo
#elif L==10	// tr
	"Change whether students are forced to read the links"		// eviri lazim!
#endif
	,
	[ActChgHavReaCrsLnk] =
#if   L==1	// ca
	"Change if I have read the course links"			// Necessita traducci
#elif L==2	// de
	"Change if I have read the course links"			// Need bersetzung
#elif L==3	// en
	"Change if I have read the course links"
#elif L==4	// es
	"Cambiar si he le&iacute;do los enlaces de la asignatura"
#elif L==5	// fr
	"Change if I have read the course links"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar si he le&iacute;do los enlaces de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change if I have read the course links"			// Bisogno di traduzione
#elif L==8	// pl
	"Change if I have read the course links"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change if I have read the course links"			// Precisa de traduo
#elif L==10	// tr
	"Change if I have read the course links"			// eviri lazim!
#endif
	,
	[ActSelInfSrcCrsLnk] =
#if   L==1	// ca
	"Select the type of information shown in the course links"				// Necessita traducci
#elif L==2	// de
	"Select the type of information shown in the course links"				// Need bersetzung
#elif L==3	// en
	"Select the type of information shown in the course links"
#elif L==4	// es
	"Seleccionar el tipo de informaci&oacute;n mostrada en los enlaces de la asignatura"
#elif L==5	// fr
	"Select the type of information shown in the course links"				// Besoin de traduction
#elif L==6	// gn
	"Seleccionar el tipo de informaci&oacute;n mostrada en los enlaces de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Select the type of information shown in the course links"				// Bisogno di traduzione
#elif L==8	// pl
	"Select the type of information shown in the course links"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Select the type of information shown in the course links"				// Precisa de traduo
#elif L==10	// tr
	"Select the type of information shown in the course links"				// eviri lazim!
#endif
	,
	[ActRcvURLCrsLnk] =
#if   L==1	// ca
	"Create URL in the course links"		// Necessita traducci
#elif L==2	// de
	"Create URL in the course links"		// Need bersetzung
#elif L==3	// en
	"Create URL in the course links"
#elif L==4	// es
	"Crear una URL en los enlaces de la asignatura"
#elif L==5	// fr
	"Create URL in the course links"		// Besoin de traduction
#elif L==6	// gn
	"Crear una URL en los enlaces de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create URL in the course links"		// Bisogno di traduzione
#elif L==8	// pl
	"Create URL in the course links"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create URL in the course links"		// Precisa de traduo
#elif L==10	// tr
	"Create URL in the course links"		// eviri lazim!
#endif
	,
	[ActRcvPagCrsLnk] =
#if   L==1	// ca
	"Create web page in the course links"				// Necessita traducci
#elif L==2	// de
	"Create web page in the course links"				// Need bersetzung
#elif L==3	// en
	"Create web page in the course links"
#elif L==4	// es
	"Crear una p&aacute;gina web en los enlaces de la asignatura"
#elif L==5	// fr
	"Create web page in the course links"				// Besoin de traduction
#elif L==6	// gn
	"Crear una p&aacute;gina web en los enlaces de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create web page in the course links"				// Bisogno di traduzione
#elif L==8	// pl
	"Create web page in the course links"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create web page in the course links"				// Precisa de traduo
#elif L==10	// tr
	"Create web page in the course links"				// eviri lazim!
#endif
	,
	[ActEditorCrsLnk] =
#if   L==1	// ca
	"Integrated editor of course links"			// Necessita traducci
#elif L==2	// de
	"Integrated editor of course links"			// Need bersetzung
#elif L==3	// en
	"Integrated editor of course links"
#elif L==4	// es
	"Editor integrado de los enlaces de la asignatura"
#elif L==5	// fr
	"Integrated editor of course links"			// Besoin de traduction
#elif L==6	// gn
	"Editor integrado de los enlaces de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Integrated editor of course links"			// Bisogno di traduzione
#elif L==8	// pl
	"Integrated editor of course links"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Integrated editor of course links"			// Precisa de traduo
#elif L==10	// tr
	"Integrated editor of course links"			// eviri lazim!
#endif
	,
	[ActPlaTxtEdiCrsLnk] =
#if   L==1	// ca
	"Plain text editor of course links"			// Necessita traducci
#elif L==2	// de
	"Plain text editor of course links"			// Need bersetzung
#elif L==3	// en
	"Plain text editor of course links"
#elif L==4	// es
	"Editor de texto plano de los enlaces de la asignatura"
#elif L==5	// fr
	"Plain text editor of course links"			// Besoin de traduction
#elif L==6	// gn
	"Editor de texto plano de los enlaces de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Plain text editor of course links"			// Bisogno di traduzione
#elif L==8	// pl
	"Plain text editor of course links"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Plain text editor of course links"			// Precisa de traduo
#elif L==10	// tr
	"Plain text editor of course links"			// eviri lazim!
#endif
	,
	[ActRchTxtEdiCrsLnk] =
#if   L==1	// ca
	"Rich text editor of course links"				// Necessita traducci
#elif L==2	// de
	"Rich text editor of course links"				// Need bersetzung
#elif L==3	// en
	"Rich text editor of course links"
#elif L==4	// es
	"Editor de texto enriquecido de los enlaces de la asignatura"
#elif L==5	// fr
	"Rich text editor of course links"				// Besoin de traduction
#elif L==6	// gn
	"Editor de texto enriquecido de los enlaces de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Rich text editor of course links"				// Bisogno di traduzione
#elif L==8	// pl
	"Rich text editor of course links"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rich text editor of course links"				// Precisa de traduo
#elif L==10	// tr
	"Rich text editor of course links"				// eviri lazim!
#endif
	,
	[ActRcvPlaTxtCrsLnk] =
#if   L==1	// ca
	"Change plain text of course links"			// Necessita traducci
#elif L==2	// de
	"Change plain text of course links"			// Need bersetzung
#elif L==3	// en
	"Change plain text of course links"
#elif L==4	// es
	"Cambiar texto plano de los enlaces de la asignatura"
#elif L==5	// fr
	"Change plain text of course links"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar texto plano de los enlaces de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change plain text of course links"			// Bisogno di traduzione
#elif L==8	// pl
	"Change plain text of course links"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change plain text of course links"			// Precisa de traduo
#elif L==10	// tr
	"Change plain text of course links"			// eviri lazim!
#endif
	,
	[ActRcvRchTxtCrsLnk] =
#if   L==1	// ca
	"Change rich text of course links"				// Necessita traducci
#elif L==2	// de
	"Change rich text of course links"				// Need bersetzung
#elif L==3	// en
	"Change rich text of course links"
#elif L==4	// es
	"Cambiar texto enriquecido de los enlaces de la asignatura"
#elif L==5	// fr
	"Change rich text of course links"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar texto enriquecido de los enlaces de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change rich text of course links"				// Bisogno di traduzione
#elif L==8	// pl
	"Change rich text of course links"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change rich text of course links"				// Precisa de traduo
#elif L==10	// tr
	"Change rich text of course links"				// eviri lazim!
#endif
	,
	[ActSeeAss] =
#if   L==1	// ca
	"See assessment system"			// Necessita traducci
#elif L==2	// de
	"See assessment system"			// Need bersetzung
#elif L==3	// en
	"See assessment system"
#elif L==4	// es
	"Ver sistema de evaluaci&oacute;n"
#elif L==5	// fr
	"See assessment system"			// Besoin de traduction
#elif L==6	// gn
	"Ver sistema de evaluaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See assessment system"			// Bisogno di traduzione
#elif L==8	// pl
	"See assessment system"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See assessment system"			// Precisa de traduo
#elif L==10	// tr
	"See assessment system"			// eviri lazim!
#endif
	,
	[ActEdiAss] =
#if   L==1	// ca
	"Edit assessment system"		// Necessita traducci
#elif L==2	// de
	"Edit assessment system"		// Need bersetzung
#elif L==3	// en
	"Edit assessment system"
#elif L==4	// es
	"Editar sistema de evaluaci&oacute;n"
#elif L==5	// fr
	"Edit assessment system"		// Besoin de traduction
#elif L==6	// gn
	"Editar sistema de evaluaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Edit assessment system"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit assessment system"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit assessment system"		// Precisa de traduo
#elif L==10	// tr
	"Edit assessment system"		// eviri lazim!
#endif
	,
	[ActChgFrcReaAss] =
#if   L==1	// ca
	"Change whether students are forced to read the assessment system"		// Necessita traducci
#elif L==2	// de
	"Change whether students are forced to read the assessment system"		// Need bersetzung
#elif L==3	// en
	"Change whether students are forced to read the assessment system"
#elif L==4	// es
	"Cambiar si se obliga a los estudiantes a leer el sistema de evaluaci&oacute;n"
#elif L==5	// fr
	"Change whether students are forced to read the assessment system"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar si se obliga a los estudiantes a leer el sistema de evaluaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change whether students are forced to read the assessment system"		// Bisogno di traduzione
#elif L==8	// pl
	"Change whether students are forced to read the assessment system"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change whether students are forced to read the assessment system"		// Precisa de traduo
#elif L==10	// tr
	"Change whether students are forced to read the assessment system"		// eviri lazim!
#endif
	,
	[ActChgHavReaAss] =
#if   L==1	// ca
	"Change if I have read the assessment system"			// Necessita traducci
#elif L==2	// de
	"Change if I have read the assessment system"			// Need bersetzung
#elif L==3	// en
	"Change if I have read the assessment system"
#elif L==4	// es
	"Cambiar si he le&iacute;do el sistema de evaluaci&oacute;n"
#elif L==5	// fr
	"Change if I have read the assessment system"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar si he le&iacute;do el sistema de evaluaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change if I have read the assessment system"			// Bisogno di traduzione
#elif L==8	// pl
	"Change if I have read the assessment system"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change if I have read the assessment system"			// Precisa de traduo
#elif L==10	// tr
	"Change if I have read the assessment system"			// eviri lazim!
#endif
	,
	[ActSelInfSrcAss] =
#if   L==1	// ca
	"Select the type of information shown in the assessment system"				// Necessita traducci
#elif L==2	// de
	"Select the type of information shown in the assessment system"				// Need bersetzung
#elif L==3	// en
	"Select the type of information shown in the assessment system"
#elif L==4	// es
	"Seleccionar el tipo de informaci&oacute;n mostrada en el sistema de evaluaci&oacute;n"
#elif L==5	// fr
	"Select the type of information shown in the assessment system"				// Besoin de traduction
#elif L==6	// gn
	"Seleccionar el tipo de informaci&oacute;n mostrada en el sistema de evaluaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Select the type of information shown in the assessment system"				// Bisogno di traduzione
#elif L==8	// pl
	"Select the type of information shown in the assessment system"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Select the type of information shown in the assessment system"				// Precisa de traduo
#elif L==10	// tr
	"Select the type of information shown in the assessment system"				// eviri lazim!
#endif
	,
	[ActRcvURLAss] =
#if   L==1	// ca
	"Create URL in the assessment system"			// Necessita traducci
#elif L==2	// de
	"Create URL in the assessment system"			// Need bersetzung
#elif L==3	// en
	"Create URL in the assessment system"
#elif L==4	// es
	"Crear una URL en el sistema de evaluaci&oacute;n"
#elif L==5	// fr
	"Create URL in the assessment system"			// Besoin de traduction
#elif L==6	// gn
	"Crear una URL en el sistema de evaluaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Create URL in the assessment system"			// Bisogno di traduzione
#elif L==8	// pl
	"Create URL in the assessment system"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create URL in the assessment system"			// Precisa de traduo
#elif L==10	// tr
	"Create URL in the assessment system"			// eviri lazim!
#endif
	,
	[ActRcvPagAss] =
#if   L==1	// ca
	"Create web page in the assessment system"				// Necessita traducci
#elif L==2	// de
	"Create web page in the assessment system"				// Need bersetzung
#elif L==3	// en
	"Create web page in the assessment system"
#elif L==4	// es
	"Crear una p&aacute;gina web en el sistema de evaluaci&oacute;n"
#elif L==5	// fr
	"Create web page in the assessment system"				// Besoin de traduction
#elif L==6	// gn
	"Crear una p&aacute;gina web en el sistema de evaluaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Create web page in the assessment system"				// Bisogno di traduzione
#elif L==8	// pl
	"Create web page in the assessment system"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create web page in the assessment system"				// Precisa de traduo
#elif L==10	// tr
	"Create web page in the assessment system"				// eviri lazim!
#endif
	,
	[ActEditorAss] =
#if   L==1	// ca
	"Integrated editor of the assessment system"		// Necessita traducci
#elif L==2	// de
	"Integrated editor of the assessment system"		// Need bersetzung
#elif L==3	// en
	"Integrated editor of the assessment system"
#elif L==4	// es
	"Editor integrado del sistema de evaluaci&oacute;n"
#elif L==5	// fr
	"Integrated editor of the assessment system"		// Besoin de traduction
#elif L==6	// gn
	"Editor integrado del sistema de evaluaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Integrated editor of the assessment system"		// Bisogno di traduzione
#elif L==8	// pl
	"Integrated editor of the assessment system"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Integrated editor of the assessment system"		// Precisa de traduo
#elif L==10	// tr
	"Integrated editor of the assessment system"		// eviri lazim!
#endif
	,
	[ActPlaTxtEdiAss] =
#if   L==1	// ca
	"Plain text editor of the assessment system"			// Necessita traducci
#elif L==2	// de
	"Plain text editor of the assessment system"			// Need bersetzung
#elif L==3	// en
	"Plain text editor of the assessment system"
#elif L==4	// es
	"Editor de texto plano del sistema de evaluaci&oacute;n"
#elif L==5	// fr
	"Plain text editor of the assessment system"			// Besoin de traduction
#elif L==6	// gn
	"Editor de texto plano del sistema de evaluaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Plain text editor of the assessment system"			// Bisogno di traduzione
#elif L==8	// pl
	"Plain text editor of the assessment system"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Plain text editor of the assessment system"			// Precisa de traduo
#elif L==10	// tr
	"Plain text editor of the assessment system"			// eviri lazim!
#endif
	,
	[ActRchTxtEdiAss] =
#if   L==1	// ca
	"Rich text editor of the assessment system"			// Necessita traducci
#elif L==2	// de
	"Rich text editor of the assessment system"			// Need bersetzung
#elif L==3	// en
	"Rich text editor of the assessment system"
#elif L==4	// es
	"Editor de texto enriquecido del sistema de evaluaci&oacute;n"
#elif L==5	// fr
	"Rich text editor of the assessment system"			// Besoin de traduction
#elif L==6	// gn
	"Editor de texto enriquecido del sistema de evaluaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Rich text editor of the assessment system"			// Bisogno di traduzione
#elif L==8	// pl
	"Rich text editor of the assessment system"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rich text editor of the assessment system"			// Precisa de traduo
#elif L==10	// tr
	"Rich text editor of the assessment system"			// eviri lazim!
#endif
	,
	[ActRcvPlaTxtAss] =
#if   L==1	// ca
	"Change plain text of the assessment system"		// Necessita traducci
#elif L==2	// de
	"Change plain text of the assessment system"		// Need bersetzung
#elif L==3	// en
	"Change plain text of the assessment system"
#elif L==4	// es
	"Cambiar texto plano del sistema de evaluaci&oacute;n"
#elif L==5	// fr
	"Change plain text of the assessment system"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar texto plano del sistema de evaluaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change plain text of the assessment system"		// Bisogno di traduzione
#elif L==8	// pl
	"Change plain text of the assessment system"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change plain text of the assessment system"		// Precisa de traduo
#elif L==10	// tr
	"Change plain text of the assessment system"		// eviri lazim!
#endif
	,
	[ActRcvRchTxtAss] =
#if   L==1	// ca
	"Change rich text of the assessment system"			// Necessita traducci
#elif L==2	// de
	"Change rich text of the assessment system"			// Need bersetzung
#elif L==3	// en
	"Change rich text of the assessment system"
#elif L==4	// es
	"Cambiar texto enriquecido del sistema de evaluaci&oacute;n"
#elif L==5	// fr
	"Change rich text of the assessment system"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar texto enriquecido del sistema de evaluaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change rich text of the assessment system"			// Bisogno di traduzione
#elif L==8	// pl
	"Change rich text of the assessment system"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change rich text of the assessment system"			// Precisa de traduo
#elif L==10	// tr
	"Change rich text of the assessment system"			// eviri lazim!
#endif
	,
	[ActSeeCrsTT] =
#if   L==1	// ca
	"See the course timetable"		// Necessita traducci
#elif L==2	// de
	"See the course timetable"		// Need bersetzung
#elif L==3	// en
	"See the course timetable"
#elif L==4	// es
	"Ver el horario de la asignatura"
#elif L==5	// fr
	"See the course timetable"		// Besoin de traduction
#elif L==6	// gn
	"Ver el horario de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See the course timetable"		// Bisogno di traduzione
#elif L==8	// pl
	"See the course timetable"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the course timetable"		// Precisa de traduo
#elif L==10	// tr
	"See the course timetable"		// eviri lazim!
#endif
	,
	[ActPrnCrsTT] =
#if   L==1	// ca
	"Show print view of course timetable"					// Necessita traducci
#elif L==2	// de
	"Show print view of course timetable"					// Need bersetzung
#elif L==3	// en
	"Show print view of course timetable"
#elif L==4	// es
	"Mostrar vista de impresi&oacute;n del horario de la asignatura"
#elif L==5	// fr
	"Show print view of course timetable"					// Besoin de traduction
#elif L==6	// gn
	"Mostrar vista de impresi&oacute;n del horario de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Show print view of course timetable"					// Bisogno di traduzione
#elif L==8	// pl
	"Show print view of course timetable"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show print view of course timetable"					// Precisa de traduo
#elif L==10	// tr
	"Show print view of course timetable"					// eviri lazim!
#endif
	,
	[ActEdiCrsTT] =
#if   L==1	// ca
	"Edit course timetable"			// Necessita traducci
#elif L==2	// de
	"Edit course timetable"			// Need bersetzung
#elif L==3	// en
	"Edit course timetable"
#elif L==4	// es
	"Editar horario de la asignatura"
#elif L==5	// fr
	"Edit course timetable"			// Besoin de traduction
#elif L==6	// gn
	"Editar horario de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Edit course timetable"			// Bisogno di traduzione
#elif L==8	// pl
	"Edit course timetable"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit course timetable"			// Precisa de traduo
#elif L==10	// tr
	"Edit course timetable"			// eviri lazim!
#endif
	,
	[ActChgCrsTT] =
#if   L==1	// ca
	"Change course timetable"		// Necessita traducci
#elif L==2	// de
	"Change course timetable"		// Need bersetzung
#elif L==3	// en
	"Change course timetable"
#elif L==4	// es
	"Cambiar horario de la asignatura"
#elif L==5	// fr
	"Change course timetable"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar horario de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change course timetable"		// Bisogno di traduzione
#elif L==8	// pl
	"Change course timetable"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change course timetable"		// Precisa de traduo
#elif L==10	// tr
	"Change course timetable"		// eviri lazim!
#endif
	,
	[ActChgCrsTT1stDay] =
#if   L==1	// ca
	"Change first day of week of course timetable"				// Necessita traducci
#elif L==2	// de
	"Change first day of week of course timetable"				// Need bersetzung
#elif L==3	// en
	"Change first day of week of course timetable"
#elif L==4	// es
	"Cambiar primer d&iacute;a de la semana del horario de la asignatura"
#elif L==5	// fr
	"Change first day of week of course timetable"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar primer d&iacute;a de la semana del horario de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change first day of week of course timetable"				// Bisogno di traduzione
#elif L==8	// pl
	"Change first day of week of course timetable"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change first day of week of course timetable"				// Precisa de traduo
#elif L==10	// tr
	"Change first day of week of course timetable"				// eviri lazim!
#endif
	,
	[ActSeeAllAsg] =
#if   L==1	// ca
	"See assignments"	// Necessita traducci
#elif L==2	// de
	"See assignments"	// Need bersetzung
#elif L==3	// en
	"See assignments"
#elif L==4	// es
	"Ver actividades"
#elif L==5	// fr
	"See assignments"	// Besoin de traduction
#elif L==6	// gn
	"Ver actividades"	// Okoteve traduccin
#elif L==7	// it
	"See assignments"	// Bisogno di traduzione
#elif L==8	// pl
	"See assignments"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See assignments"	// Precisa de traduo
#elif L==10	// tr
	"See assignments"	// eviri lazim!
#endif
	,
	[ActFrmNewAsg] =
#if   L==1	// ca
	"Edit new assignment"		// Necessita traducci
#elif L==2	// de
	"Edit new assignment"		// Need bersetzung
#elif L==3	// en
	"Edit new assignment"
#elif L==4	// es
	"Editar nueva actividad"
#elif L==5	// fr
	"Edit new assignment"		// Besoin de traduction
#elif L==6	// gn
	"Editar nueva actividad"	// Okoteve traduccin
#elif L==7	// it
	"Edit new assignment"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit new assignment"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new assignment"		// Precisa de traduo
#elif L==10	// tr
	"Edit new assignment"		// eviri lazim!
#endif
	,
	[ActEdiOneAsg] =
#if   L==1	// ca
	"Edit an assignment"	// Necessita traducci
#elif L==2	// de
	"Edit an assignment"	// Need bersetzung
#elif L==3	// en
	"Edit an assignment"
#elif L==4	// es
	"Editar una actividad"
#elif L==5	// fr
	"Edit an assignment"	// Besoin de traduction
#elif L==6	// gn
	"Editar una actividad"	// Okoteve traduccin
#elif L==7	// it
	"Edit an assignment"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit an assignment"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit an assignment"	// Precisa de traduo
#elif L==10	// tr
	"Edit an assignment"	// eviri lazim!
#endif
	,
	[ActSeeOneAsg] =
#if   L==1	// ca
	"View assignment"	// Necessita traducci
#elif L==2	// de
	"View assignment"	// Need bersetzung
#elif L==3	// en
	"View assignment"
#elif L==4	// es
	"Ver actividad"
#elif L==5	// fr
	"View assignment"	// Besoin de traduction
#elif L==6	// gn
	"Ver actividad"		// Okoteve traduccin
#elif L==7	// it
	"View assignment"	// Bisogno di traduzione
#elif L==8	// pl
	"View assignment"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"View assignment"	// Precisa de traduo
#elif L==10	// tr
	"View assignment"	// eviri lazim!
#endif
	,
	[ActPrnOneAsg] =
#if   L==1	// ca
	"Show print view of an assignment"			// Necessita traducci
#elif L==2	// de
	"Show print view of an assignment"			// Need bersetzung
#elif L==3	// en
	"Show print view of an assignment"
#elif L==4	// es
	"Mostrar vista de impresi&oacute;n de una actividad"
#elif L==5	// fr
	"Show print view of an assignment"			// Besoin de traduction
#elif L==6	// gn
	"Mostrar vista de impresi&oacute;n de una actividad"	// Okoteve traduccin
#elif L==7	// it
	"Show print view of an assignment"			// Bisogno di traduzione
#elif L==8	// pl
	"Show print view of an assignment"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show print view of an assignment"			// Precisa de traduo
#elif L==10	// tr
	"Show print view of an assignment"			// eviri lazim!
#endif
	,
	[ActNewAsg] =
#if   L==1	// ca
	"Crear activitat"
#elif L==2	// de
	"Aufgabe erstellen"
#elif L==3	// en
	"Create assignment"
#elif L==4	// es
	"Crear actividad"
#elif L==5	// fr
	"Cr&eacute;er activit&eacute;"
#elif L==6	// gn
	"Omohe&ntilde;&oacute;i tembiapo"
#elif L==7	// it
	"Creare attivit&agrave;"
#elif L==8	// pl
	"Utw&oacute;rz zadanie"
#elif L==9	// pt
	"Criar atividade"
#elif L==10	// tr
	"&Ouml;dev olu&scedil;tur"
#endif
	,
	[ActChgAsg] =
#if   L==1	// ca
	"Canviar activitat"
#elif L==2	// de
	"Aufgabe &auml;ndern"
#elif L==3	// en
	"Change assignment"
#elif L==4	// es
	"Cambiar actividad"
#elif L==5	// fr
	"Changer activit&eacute;"
#elif L==6	// gn
	"Omoambue tembiapo"
#elif L==7	// it
	"Cambiare attivit&agrave;"
#elif L==8	// pl
	"Zmie&nacute; zadanie"
#elif L==9	// pt
	"Alterar atividade"
#elif L==10	// tr
	"&Ouml;dev de&gbreve;i&scedil;tir"
#endif
	,
	[ActReqRemAsg] =
#if   L==1	// ca
	"Request removal of assignment"		// Necessita traducci
#elif L==2	// de
	"Request removal of assignment"		// Need bersetzung
#elif L==3	// en
	"Request removal of assignment"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de actividad"
#elif L==5	// fr
	"Request removal of assignment"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de actividad"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of assignment"		// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of assignment"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of assignment"		// Precisa de traduo
#elif L==10	// tr
	"Request removal of assignment"		// eviri lazim!
#endif
	,
	[ActRemAsg] =
#if   L==1	// ca
	"Eliminar activitat"
#elif L==2	// de
	"Aufgabe entfernen"
#elif L==3	// en
	"Remove assignment"
#elif L==4	// es
	"Eliminar actividad"
#elif L==5	// fr
	"Supprimer activit&eacute;"
#elif L==6	// gn
	"Eliminar actividad"	// Okoteve traduccin
#elif L==7	// it
	"Rimuovere attivit&agrave;"
#elif L==8	// pl
	"Usu&nacute; przypisanie"
#elif L==9	// pt
	"Remover atividade"
#elif L==10	// tr
	"Atamay&inodot; kald&inodot;r"
#endif
	,
	[ActHidAsg] =
#if   L==1	// ca
	"Hide assignment"	// Necessita traducci
#elif L==2	// de
	"Hide assignment"	// Need bersetzung
#elif L==3	// en
	"Hide assignment"
#elif L==4	// es
	"Ocultar actividad"
#elif L==5	// fr
	"Hide assignment"	// Besoin de traduction
#elif L==6	// gn
	"Ocultar actividad"	// Okoteve traduccin
#elif L==7	// it
	"Hide assignment"	// Bisogno di traduzione
#elif L==8	// pl
	"Hide assignment"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide assignment"	// Precisa de traduo
#elif L==10	// tr
	"Hide assignment"	// eviri lazim!
#endif
	,
	[ActUnhAsg] =
#if   L==1	// ca
	"Unhide assignment"	// Necessita traducci
#elif L==2	// de
	"Unhide assignment"	// Need bersetzung
#elif L==3	// en
	"Unhide assignment"
#elif L==4	// es
	"Mostrar actividad"
#elif L==5	// fr
	"Unhide assignment"	// Besoin de traduction
#elif L==6	// gn
	"Mostrar actividad"	// Okoteve traduccin
#elif L==7	// it
	"Unhide assignment"	// Bisogno di traduzione
#elif L==8	// pl
	"Unhide assignment"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide assignment"	// Precisa de traduo
#elif L==10	// tr
	"Unhide assignment"	// eviri lazim!
#endif
	,
	[ActReqLnkAsg] =
#if   L==1	// ca
	"Copy link to assignment"	// Necessita traducci
#elif L==2	// de
	"Copy link to assignment"	// Need bersetzung
#elif L==3	// en
	"Copy link to assignment"
#elif L==4	// es
	"Copiar enlace a actividad"
#elif L==5	// fr
	"Copy link to assignment"	// Besoin de traduction
#elif L==6	// gn
	"Copiar enlace a actividad"	// Okoteve traduccin
#elif L==7	// it
	"Copy link to assignment"	// Bisogno di traduzione
#elif L==8	// pl
	"Copy link to assignment"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Copy link to assignment"	// Precisa de traduo
#elif L==10	// tr
	"Copy link to assignment"	// eviri lazim!
#endif
	,
	[ActSeeAllPrj] =
#if   L==1	// ca
	"See projects"	// Necessita traducci
#elif L==2	// de
	"See projects"	// Need bersetzung
#elif L==3	// en
	"See projects"
#elif L==4	// es
	"Ver proyectos"
#elif L==5	// fr
	"See projects"	// Besoin de traduction
#elif L==6	// gn
	"Ver proyectos"	// Okoteve traduccin
#elif L==7	// it
	"See projects"	// Bisogno di traduzione
#elif L==8	// pl
	"See projects"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See projects"	// Precisa de traduo
#elif L==10	// tr
	"See projects"	// eviri lazim!
#endif
	,
	[ActCfgPrj] =
#if   L==1	// ca
	"Configurar tots els projectes"
#elif L==2	// de
	"Konfigurieren Sie alle Projekte"
#elif L==3	// en
	"Configure all projects"
#elif L==4	// es
	"Configurar todos los proyectos"
#elif L==5	// fr
	"Configurer tous les projets"
#elif L==6	// gn
	"Emohenda opaite tembiapor&atilde;"
#elif L==7	// it
	"Configurare tutti i progetti"
#elif L==8	// pl
	"Skonfigurowa&cacute; wszystkie projekty"
#elif L==9	// pt
	"Configurar todos os projetos"
#elif L==10	// tr
	"T&uuml;m projeleri yap&inodot;land&inodot;r&inodot;n"
#endif
	,
	[ActChgRubPrj] =
#if   L==1	// ca
	"Canviar r&uacute;briques associades a projectes"
#elif L==2	// de
	"&Auml;ndern Sie die mit Projekten verkn&uuml;pften Rubriken"
#elif L==3	// en
	"Change rubrics associated to projects"
#elif L==4	// es
	"Cambiar r&uacute;bricas asociadas a proyectos"
#elif L==5	// fr
	"Modifier les rubriques associ&eacute;es aux projets"
#elif L==6	// gn
	"Omoambue r&uacute;brica ojoaj&uacute;va umi proyecto rehe"
#elif L==7	// it
	"Modificare le rubriche associate ai progetti"
#elif L==8	// pl
	"Zmie&nacute; rubryki powi&aogon;zane z projektami"
#elif L==9	// pt
	"Alterar rubricas associadas a projetos"
#elif L==10	// tr
	"Projelerle ili&scedil;kili de&gbreve;erlendirme listelerini de&gbreve;i&scedil;tirin"
#endif
	,
	[ActChgNETCanCrePrj] =
#if   L==1	// ca
	"Canviar si els professors no editors poden crear projectes"
#elif L==2	// de
	"&Auml;ndern Sie, ob Lehrer, die keine Redakteure sind, Projekte erstellen k&ouml;nnen"
#elif L==3	// en
	"Change whether non-editor teachers can create projects"
#elif L==4	// es
	"Cambiar si los profesores no editores pueden crear proyectos"
#elif L==5	// fr
	"Modifier si les enseignants non &eacute;diteurs peuvent cr&eacute;er des projets"
#elif L==6	// gn
	"Emoambue ikat&uacute;pa umi mbo'eh&aacute;ra ndaha'&eacute;iva editor omohe&ntilde;&oacute;i proyecto"
#elif L==7	// it
	"Modificare se gli insegnanti non editori possono creare progetti"
#elif L==8	// pl
	"Zmie&nacute; czy nauczyciele nieedytuj&aogon;cy mog&aogon; tworzy&cacute; projekty"
#elif L==9	// pt
	"Alterar se professores n&atilde;o editores podem criar projetos"
#elif L==10	// tr
	"D&uuml;zenleyici olmayan &ouml;&gbreve;retmenlerin proje olu&scedil;turup olu&scedil;turamayaca&gbreve;&inodot;n&inodot; de&gbreve;i&scedil;tirin"
#endif
	,
	[ActReqUsrPrj] =
#if   L==1	// ca
	"Seleccionar usuaris per llistar els projectes"
#elif L==2	// de
	"W&auml;hlen Sie Benutzer aus, um ihre Projekte aufzulisten"
#elif L==3	// en
	"Select users to list their projects"
#elif L==4	// es
	"Seleccionar usuarios para listar sus proyectos"
#elif L==5	// fr
	"S&eacute;lectionner les utilisateurs pour lister leurs projets"
#elif L==6	// gn
	"Eiporavo puruh&aacute;ra emo&itilde; ha&gtilde;ua iproyectoku&eacute;ra"
#elif L==7	// it
	"Seleziona gli utenti per elencare i loro progetti"
#elif L==8	// pl
	"Wybierz u&zdot;ytkownik&oacute;w, aby wy&sacute;wietli&cacute; list&eogon; ich projekt&oacute;w"
#elif L==9	// pt
	"Selecionar usu&aacute;rios para listar seus projetos"
#elif L==10	// tr
	"Projelerini listelemek i&ccedil;in kullan&inodot;c&inodot;lar&inodot; se&ccedil;in"
#endif
	,
	[ActSeeTblAllPrj] =
#if   L==1	// ca
	"Show all projects in a table"			// Necessita traducci
#elif L==2	// de
	"Show all projects in a table"			// Need bersetzung
#elif L==3	// en
	"Show all projects in a table"
#elif L==4	// es
	"Mostrar todos los proyectos en una tabla"
#elif L==5	// fr
	"Show all projects in a table"			// Besoin de traduction
#elif L==6	// gn
	"Mostrar todos los proyectos en una tabla"	// Okoteve traduccin
#elif L==7	// it
	"Show all projects in a table"			// Bisogno di traduzione
#elif L==8	// pl
	"Show all projects in a table"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show all projects in a table"			// Precisa de traduo
#elif L==10	// tr
	"Show all projects in a table"			// eviri lazim!
#endif
	,
	[ActReqLckAllPrj] =
#if   L==1	// ca
	"Request locking of all projects"		// Necessita traducci
#elif L==2	// de
	"Request locking of all projects"		// Need bersetzung
#elif L==3	// en
	"Request locking of all projects"
#elif L==4	// es
	"Solicitar el bloqueo de todos los proyectos"
#elif L==5	// fr
	"Request locking of all projects"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar el bloqueo de todos los proyectos"	// Okoteve traduccin
#elif L==7	// it
	"Request locking of all projects"		// Bisogno di traduzione
#elif L==8	// pl
	"Request locking of all projects"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request locking of all projects"		// Precisa de traduo
#elif L==10	// tr
	"Request locking of all projects"		// eviri lazim!
#endif
	,
	[ActReqUnlAllPrj] =
#if   L==1	// ca
	"Request unlocking of all projects"			// Necessita traducci
#elif L==2	// de
	"Request unlocking of all projects"			// Need bersetzung
#elif L==3	// en
	"Request unlocking of all projects"
#elif L==4	// es
	"Solicitar el desbloqueo de todos los proyectos"
#elif L==5	// fr
	"Request unlocking of all projects"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar el desbloqueo de todos los proyectos"	// Okoteve traduccin
#elif L==7	// it
	"Request unlocking of all projects"			// Bisogno di traduzione
#elif L==8	// pl
	"Request unlocking of all projects"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request unlocking of all projects"			// Precisa de traduo
#elif L==10	// tr
	"Request unlocking of all projects"			// eviri lazim!
#endif
	,
	[ActLckAllPrj] =
#if   L==1	// ca
	"Lock all projects"		// Necessita traducci
#elif L==2	// de
	"Lock all projects"		// Need bersetzung
#elif L==3	// en
	"Lock all projects"
#elif L==4	// es
	"Bloquear todos los proyectos"
#elif L==5	// fr
	"Lock all projects"		// Besoin de traduction
#elif L==6	// gn
	"Bloquear todos los proyectos"	// Okoteve traduccin
#elif L==7	// it
	"Lock all projects"		// Bisogno di traduzione
#elif L==8	// pl
	"Lock all projects"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Lock all projects"		// Precisa de traduo
#elif L==10	// tr
	"Lock all projects"		// eviri lazim!
#endif
	,
	[ActUnlAllPrj] =
#if   L==1	// ca
	"Unlock all projects"			// Necessita traducci
#elif L==2	// de
	"Unlock all projects"			// Need bersetzung
#elif L==3	// en
	"Unlock all projects"
#elif L==4	// es
	"Desbloquear todos los proyectos"
#elif L==5	// fr
	"Unlock all projects"			// Besoin de traduction
#elif L==6	// gn
	"Desbloquear todos los proyectos"	// Okoteve traduccin
#elif L==7	// it
	"Unlock all projects"			// Bisogno di traduzione
#elif L==8	// pl
	"Unlock all projects"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unlock all projects"			// Precisa de traduo
#elif L==10	// tr
	"Unlock all projects"			// eviri lazim!
#endif
	,
	[ActFrmNewPrj] =
#if   L==1	// ca
	"Edit new project"	// Necessita traducci
#elif L==2	// de
	"Edit new project"	// Need bersetzung
#elif L==3	// en
	"Edit new project"
#elif L==4	// es
	"Editar nuevo proyecto"
#elif L==5	// fr
	"Edit new project"	// Besoin de traduction
#elif L==6	// gn
	"Editar nuevo proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Edit new project"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit new project"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new project"	// Precisa de traduo
#elif L==10	// tr
	"Edit new project"	// eviri lazim!
#endif
	,
	[ActEdiOnePrj] =
#if   L==1	// ca
	"Edit a project"	// Necessita traducci
#elif L==2	// de
	"Edit a project"	// Need bersetzung
#elif L==3	// en
	"Edit a project"
#elif L==4	// es
	"Editar proyecto"
#elif L==5	// fr
	"Edit a project"	// Besoin de traduction
#elif L==6	// gn
	"Editar proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Edit a project"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit a project"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit a project"	// Precisa de traduo
#elif L==10	// tr
	"Edit a project"	// eviri lazim!
#endif
	,
	[ActSeeOnePrj] =
#if   L==1	// ca
	"Ver projecte"
#elif L==2	// de
	"Projekt anzeigen"
#elif L==3	// en
	"Show project"
#elif L==4	// es
	"Ver proyecto"
#elif L==5	// fr
	"Voir projet"
#elif L==6	// gn
	"Ver proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Ver progetto"
#elif L==8	// pl
	"Poka&zdot; projekt"
#elif L==9	// pt
	"Mostrar projeto"
#elif L==10	// tr
	"Projeyi g&ouml;ster"
#endif
	,
	[ActPrnOnePrj] =
#if   L==1	// ca
	"Show print view of a project"				// Necessita traducci
#elif L==2	// de
	"Show print view of a project"				// Need bersetzung
#elif L==3	// en
	"Show print view of a project"
#elif L==4	// es
	"Mostrar vista de impresi&oacute;n de un proyecto"
#elif L==5	// fr
	"Show print view of a project"				// Besoin de traduction
#elif L==6	// gn
	"Mostrar vista de impresi&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Show print view of a project"				// Bisogno di traduzione
#elif L==8	// pl
	"Show print view of a project"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show print view of a project"				// Precisa de traduo
#elif L==10	// tr
	"Show print view of a project"				// eviri lazim!
#endif
	,
	[ActNewPrj] =
#if   L==1	// ca
	"Crear projecte"
#elif L==2	// de
	"Projekt eingeben"
#elif L==3	// en
	"Create project"
#elif L==4	// es
	"Crear proyecto"
#elif L==5	// fr
	"Cr&eacute;er projet"
#elif L==6	// gn
	"Omohe&ntilde;&oacute;i proyecto"
#elif L==7	// it
	"Creare progetto"
#elif L==8	// pl
	"Utw&oacute;rz projekt"
#elif L==9	// pt
	"Criar projeto"
#elif L==10	// tr
	"Proje olu&scedil;tur"
#endif
	,
	[ActChgPrj] =
#if   L==1	// ca
	"Canviar projecte"
#elif L==2	// de
	"Projekt &auml;ndern"
#elif L==3	// en
	"Change project"
#elif L==4	// es
	"Cambiar proyecto"
#elif L==5	// fr
	"Modifier projet"
#elif L==6	// gn
	"Omoambue proyecto"
#elif L==7	// it
	"Cambia progetto"
#elif L==8	// pl
	"Zmie&nacute; projekt"
#elif L==9	// pt
	"Alterar projeto"
#elif L==10	// tr
	"Projeyi de&gbreve;i&scedil;tir"
#endif
	,
	[ActReqRemPrj] =
#if   L==1	// ca
	"Request removal of project"			// Necessita traducci
#elif L==2	// de
	"Request removal of project"			// Need bersetzung
#elif L==3	// en
	"Request removal of project"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de proyecto"
#elif L==5	// fr
	"Request removal of project"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of project"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of project"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of project"			// eviri lazim!
#endif
	,
	[ActRemPrj] =
#if   L==1	// ca
	"Eliminar projecte"
#elif L==2	// de
	"Projekt entfernen"
#elif L==3	// en
	"Remove project"
#elif L==4	// es
	"Eliminar proyecto"
#elif L==5	// fr
	"Supprimer projet"
#elif L==6	// gn
	"Eliminar proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Rimuovere progetto"
#elif L==8	// pl
	"Usu&nacute; projekt"
#elif L==9	// pt
	"Remover projeto"
#elif L==10	// tr
	"Projeyi kald&inodot;r"
#endif
	,
	[ActHidPrj] =
#if   L==1	// ca
	"Hide project"		// Necessita traducci
#elif L==2	// de
	"Hide project"		// Need bersetzung
#elif L==3	// en
	"Hide project"
#elif L==4	// es
	"Ocultar un proyecto"
#elif L==5	// fr
	"Hide project"		// Besoin de traduction
#elif L==6	// gn
	"Ocultar un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Hide project"		// Bisogno di traduzione
#elif L==8	// pl
	"Hide project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide project"		// Precisa de traduo
#elif L==10	// tr
	"Hide project"		// eviri lazim!
#endif
	,
	[ActUnhPrj] =
#if   L==1	// ca
	"Unhide project"	// Necessita traducci
#elif L==2	// de
	"Unhide project"	// Need bersetzung
#elif L==3	// en
	"Unhide project"
#elif L==4	// es
	"Mostrar proyecto"
#elif L==5	// fr
	"Unhide project"	// Besoin de traduction
#elif L==6	// gn
	"Mostrar proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Unhide project"	// Bisogno di traduzione
#elif L==8	// pl
	"Unhide project"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide project"	// Precisa de traduo
#elif L==10	// tr
	"Unhide project"	// eviri lazim!
#endif
	,
	[ActLckPrj] =
#if   L==1	// ca
	"Lock project edition"			// Necessita traducci
#elif L==2	// de
	"Lock project edition"			// Need bersetzung
#elif L==3	// en
	"Lock project edition"
#elif L==4	// es
	"Bloquear edici&oacute;n de proyectos"
#elif L==5	// fr
	"Lock project edition"			// Besoin de traduction
#elif L==6	// gn
	"Bloquear edici&oacute;n de proyectos"	// Okoteve traduccin
#elif L==7	// it
	"Lock project edition"			// Bisogno di traduzione
#elif L==8	// pl
	"Lock project edition"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Lock project edition"			// Precisa de traduo
#elif L==10	// tr
	"Lock project edition"			// eviri lazim!
#endif
	,
	[ActUnlPrj] =
#if   L==1	// ca
	"Unlock project edition"			// Necessita traducci
#elif L==2	// de
	"Unlock project edition"			// Need bersetzung
#elif L==3	// en
	"Unlock project edition"
#elif L==4	// es
	"Desbloquear edici&oacute;n de proyectos"
#elif L==5	// fr
	"Unlock project edition"			// Besoin de traduction
#elif L==6	// gn
	"Desbloquear edici&oacute;n de proyectos"	// Okoteve traduccin
#elif L==7	// it
	"Unlock project edition"			// Bisogno di traduzione
#elif L==8	// pl
	"Unlock project edition"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unlock project edition"			// Precisa de traduo
#elif L==10	// tr
	"Unlock project edition"			// eviri lazim!
#endif
	,
	[ActChgPrjRev] =
#if   L==1	// ca
	"Change review status of a project"			// Necessita traducci
#elif L==2	// de
	"Change review status of a project"			// Need bersetzung
#elif L==3	// en
	"Change review status of a project"
#elif L==4	// es
	"Cambiar estado de revisi&oacute;n de un proyecto"
#elif L==5	// fr
	"Change review status of a project"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar estado de revisi&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Change review status of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Change review status of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change review status of a project"			// Precisa de traduo
#elif L==10	// tr
	"Change review status of a project"			// eviri lazim!
#endif
	,
	[ActReqAddStdPrj] =
#if   L==1	// ca
	"Request registering a student in a project"			// Necessita traducci
#elif L==2	// de
	"Request registering a student in a project"			// Need bersetzung
#elif L==3	// en
	"Request registering a student in a project"
#elif L==4	// es
	"Solicitar inscripci&oacute;n de estudiante en un proyecto"
#elif L==5	// fr
	"Request registering a student in a project"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar inscripci&oacute;n de estudiante en un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Request registering a student in a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Request registering a student in a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request registering a student in a project"			// Precisa de traduo
#elif L==10	// tr
	"Request registering a student in a project"			// eviri lazim!
#endif
	,
	[ActReqAddTutPrj] =
#if   L==1	// ca
	"Request registering a tutor in a project"			// Necessita traducci
#elif L==2	// de
	"Request registering a tutor in a project"			// Need bersetzung
#elif L==3	// en
	"Request registering a tutor in a project"
#elif L==4	// es
	"Solicitar inscripci&oacute;n de un tutor en un proyecto"
#elif L==5	// fr
	"Request registering a tutor in a project"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar inscripci&oacute;n de un tutor en un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Request registering a tutor in a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Request registering a tutor in a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request registering a tutor in a project"			// Precisa de traduo
#elif L==10	// tr
	"Request registering a tutor in a project"			// eviri lazim!
#endif
	,
	[ActReqAddEvlPrj] =
#if   L==1	// ca
	"Request registering an evaluator in a project"			// Necessita traducci
#elif L==2	// de
	"Request registering an evaluator in a project"			// Need bersetzung
#elif L==3	// en
	"Request registering an evaluator in a project"
#elif L==4	// es
	"Solicitar inscripci&oacute;n de un evaluador en un proyecto"
#elif L==5	// fr
	"Request registering an evaluator in a project"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar inscripci&oacute;n de un evaluador en un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Request registering an evaluator in a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Request registering an evaluator in a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request registering an evaluator in a project"			// Precisa de traduo
#elif L==10	// tr
	"Request registering an evaluator in a project"			// eviri lazim!
#endif
	,
	[ActAddStdPrj] =
#if   L==1	// ca
	"Register a student in a project"		// Necessita traducci
#elif L==2	// de
	"Register a student in a project"		// Need bersetzung
#elif L==3	// en
	"Register a student in a project"
#elif L==4	// es
	"Inscribir un estudiante en un proyecto"
#elif L==5	// fr
	"Register a student in a project"		// Besoin de traduction
#elif L==6	// gn
	"Inscribir un estudiante en un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Register a student in a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Register a student in a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Register a student in a project"		// Precisa de traduo
#elif L==10	// tr
	"Register a student in a project"		// eviri lazim!
#endif
	,
	[ActAddTutPrj] =
#if   L==1	// ca
	"Register a tutor in a project"		// Necessita traducci
#elif L==2	// de
	"Register a tutor in a project"		// Need bersetzung
#elif L==3	// en
	"Register a tutor in a project"
#elif L==4	// es
	"Inscribir un tutor en un proyecto"
#elif L==5	// fr
	"Register a tutor in a project"		// Besoin de traduction
#elif L==6	// gn
	"Inscribir un tutor en un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Register a tutor in a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Register a tutor in a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Register a tutor in a project"		// Precisa de traduo
#elif L==10	// tr
	"Register a tutor in a project"		// eviri lazim!
#endif
	,
	[ActAddEvlPrj] =
#if   L==1	// ca
	"Register an evaluator in a project"	// Necessita traducci
#elif L==2	// de
	"Register an evaluator in a project"	// Need bersetzung
#elif L==3	// en
	"Register an evaluator in a project"
#elif L==4	// es
	"Inscribir un evaluador en un proyecto"
#elif L==5	// fr
	"Register an evaluator in a project"	// Besoin de traduction
#elif L==6	// gn
	"Inscribir un evaluador en un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Register an evaluator in a project"	// Bisogno di traduzione
#elif L==8	// pl
	"Register an evaluator in a project"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Register an evaluator in a project"	// Precisa de traduo
#elif L==10	// tr
	"Register an evaluator in a project"	// eviri lazim!
#endif
	,
	[ActReqRemStdPrj] =
#if   L==1	// ca
	"Request removing a student from a project"			// Necessita traducci
#elif L==2	// de
	"Request removing a student from a project"			// Need bersetzung
#elif L==3	// en
	"Request removing a student from a project"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de estudiante de un proyecto"
#elif L==5	// fr
	"Request removing a student from a project"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de estudiante de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Request removing a student from a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removing a student from a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removing a student from a project"			// Precisa de traduo
#elif L==10	// tr
	"Request removing a student from a project"			// eviri lazim!
#endif
	,
	[ActReqRemTutPrj] =
#if   L==1	// ca
	"Request removing a tutor from a project"			// Necessita traducci
#elif L==2	// de
	"Request removing a tutor from a project"			// Need bersetzung
#elif L==3	// en
	"Request removing a tutor from a project"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de un tutor de un proyecto"
#elif L==5	// fr
	"Request removing a tutor from a project"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de un tutor de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Request removing a tutor from a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removing a tutor from a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removing a tutor from a project"			// Precisa de traduo
#elif L==10	// tr
	"Request removing a tutor from a project"			// eviri lazim!
#endif
	,
	[ActReqRemEvlPrj] =
#if   L==1	// ca
	"Request removing an evaluator from a project"			// Necessita traducci
#elif L==2	// de
	"Request removing an evaluator from a project"			// Need bersetzung
#elif L==3	// en
	"Request removing an evaluator from a project"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de un evaluador de un proyecto"
#elif L==5	// fr
	"Request removing an evaluator from a project"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de un evaluador de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Request removing an evaluator from a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removing an evaluator from a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removing an evaluator from a project"			// Precisa de traduo
#elif L==10	// tr
	"Request removing an evaluator from a project"			// eviri lazim!
#endif
	,
	[ActRemStdPrj] =
#if   L==1	// ca
	"Eliminar estudiante de un proyecto"	// Necessita traducci
#elif L==2	// de
	"Eliminar estudiante de un proyecto"	// Need bersetzung
#elif L==3	// en
	"Remove student from a project"
#elif L==4	// es
	"Eliminar estudiante de un proyecto"
#elif L==5	// fr
	"Eliminar estudiante de un proyecto"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar estudiante de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Eliminar estudiante de un proyecto"	// Bisogno di traduzione
#elif L==8	// pl
	"Eliminar estudiante de un proyecto"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Eliminar estudiante de un proyecto"	// Precisa de traduo
#elif L==10	// tr
	"Remove student from a project"		// eviri lazim!
#endif
	,
	[ActRemTutPrj] =
#if   L==1	// ca
	"Remove tutor from a project"	// Necessita traducci
#elif L==2	// de
	"Remove tutor from a project"	// Need bersetzung
#elif L==3	// en
	"Remove tutor from a project"
#elif L==4	// es
	"Eliminar tutor de un proyecto"
#elif L==5	// fr
	"Remove tutor from a project"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar tutor de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Remove tutor from a project"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove tutor from a project"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove tutor from a project"	// Precisa de traduo
#elif L==10	// tr
	"Remove tutor from a project"	// eviri lazim!
#endif
	,
	[ActRemEvlPrj] =
#if   L==1	// ca
	"Remove evaluator from a project"	// Necessita traducci
#elif L==2	// de
	"Remove evaluator from a project"	// Need bersetzung
#elif L==3	// en
	"Remove evaluator from a project"
#elif L==4	// es
	"Eliminar evaluador de un proyecto"
#elif L==5	// fr
	"Remove evaluator from a project"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar evaluador de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Remove evaluator from a project"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove evaluator from a project"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove evaluator from a project"	// Precisa de traduo
#elif L==10	// tr
	"Remove evaluator from a project"	// eviri lazim!
#endif
	,
	[ActChgPrjSco] =
#if   L==1	// ca
	"Canviar la puntuaci&oacute; d'un criteri en un projecte"
#elif L==2	// de
	"&Auml;ndern Sie die Punktzahl eines Kriteriums in einem Projekt"
#elif L==3	// en
	"Change the score of a criterion in a project"
#elif L==4	// es
	"Cambiar la puntuaci&oacute;n de un criterio en un proyecto"
#elif L==5	// fr
	"Modifier le score d'un crit&egrave;re dans un projet"
#elif L==6	// gn
	"Omoambue puntuaci&oacute;n pete&icirc; criterio pete&icirc; proyecto-pe"
#elif L==7	// it
	"Modificare il punteggio di un criterio in un progetto"
#elif L==8	// pl
	"Zmie&nacute; wynik kryterium w projekcie"
#elif L==9	// pt
	"Alterar a pontua&ccedil;&atilde;o de um crit&eacute;rio em um projeto"
#elif L==10	// tr
	"Bir projedeki bir kriterin puan&inodot;n&inodot; de&gbreve;i&scedil;tirin"
#endif
	,
	[ActReqLnkPrj] =
#if   L==1	// ca
	"Copy link to project"		// Necessita traducci
#elif L==2	// de
	"Copy link to project"		// Need bersetzung
#elif L==3	// en
	"Copy link to project"
#elif L==4	// es
	"Copiar enlace a proyecto"
#elif L==5	// fr
	"Copy link to project"		// Besoin de traduction
#elif L==6	// gn
	"Copiar enlace a proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Copy link to project"		// Bisogno di traduzione
#elif L==8	// pl
	"Copy link to project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Copy link to project"		// Precisa de traduo
#elif L==10	// tr
	"Copy link to project"		// eviri lazim!
#endif
	,
	[ActAdmDocPrj] =
#if   L==1	// ca
	"Administrar zona de documents de projecte"
#elif L==2	// de
	"Bereich Projektdokumente verwalten"
#elif L==3	// en
	"Manage project documents zone"
#elif L==4	// es
	"Administrar zona de documentos de proyecto"
#elif L==5	// fr
	"G&eacute;rer la zone des documents du projet"
#elif L==6	// gn
	"Administrar zona de documentos de proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Gestisci la zona dei documenti di progetto"
#elif L==8	// pl
	"Zarz&oaogon;dzaj stref&aogon; dokument&oacute;w projektu"
#elif L==9	// pt
	"Gerenciar zona de documentos do projeto"
#elif L==10	// tr
	"Proje belgeleri b&ouml;lgesini y&ouml;net"
#endif
	,
	[ActReqRemFilDocPrj] =
#if   L==1	// ca
	"Request removal of file from documents zone of a project"			// Necessita traducci
#elif L==2	// de
	"Request removal of file from documents zone of a project"			// Need bersetzung
#elif L==3	// en
	"Request removal of file from documents zone of a project"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de un proyecto"
#elif L==5	// fr
	"Request removal of file from documents zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from documents zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from documents zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from documents zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from documents zone of a project"			// eviri lazim!
#endif
	,
	[ActRemFilDocPrj] =
#if   L==1	// ca
	"Remove file from documents zone of a project"		// Necessita traducci
#elif L==2	// de
	"Remove file from documents zone of a project"		// Need bersetzung
#elif L==3	// en
	"Remove file from documents zone of a project"
#elif L==4	// es
	"Eliminar archivo de zona de documentos de un proyecto"
#elif L==5	// fr
	"Remove file from documents zone of a project"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from documents zone of a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from documents zone of a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from documents zone of a project"		// Precisa de traduo
#elif L==10	// tr
	"Remove file from documents zone of a project"		// eviri lazim!
#endif
	,
	[ActRemFolDocPrj] =
#if   L==1	// ca
	"Remove empty folder from documents zone of a project"			// Necessita traducci
#elif L==2	// de
	"Remove empty folder from documents zone of a project"			// Need bersetzung
#elif L==3	// en
	"Remove empty folder from documents zone of a project"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona de documentos de un proyecto"
#elif L==5	// fr
	"Remove empty folder from documents zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from documents zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from documents zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from documents zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from documents zone of a project"			// eviri lazim!
#endif
	,
	[ActCopDocPrj] =
#if   L==1	// ca
	"Set source of copy in documents zone of a project"			// Necessita traducci
#elif L==2	// de
	"Set source of copy in documents zone of a project"			// Need bersetzung
#elif L==3	// en
	"Set source of copy in documents zone of a project"
#elif L==4	// es
	"Establecer origen de copia en zona de documentos de un proyecto"
#elif L==5	// fr
	"Set source of copy in documents zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in documents zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in documents zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in documents zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in documents zone of a project"			// eviri lazim!
#endif
	,
	[ActPasDocPrj] =
#if   L==1	// ca
	"Paste folder/file into documents zone of a project"		// Necessita traducci
#elif L==2	// de
	"Paste folder/file into documents zone of a project"		// Need bersetzung
#elif L==3	// en
	"Paste folder/file into documents zone of a project"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de documentos de un proyecto"
#elif L==5	// fr
	"Paste folder/file into documents zone of a project"		// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file into documents zone of a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file into documents zone of a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file into documents zone of a project"		// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file into documents zone of a project"		// eviri lazim!
#endif
	,
	[ActRemTreDocPrj] =
#if   L==1	// ca
	"Remove non-empty folder from documents zone of a project"		// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from documents zone of a project"		// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from documents zone of a project"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona de documentos de un proyecto"
#elif L==5	// fr
	"Remove non-empty folder from documents zone of a project"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from documents zone of a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from documents zone of a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from documents zone of a project"		// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from documents zone of a project"		// eviri lazim!
#endif
	,
	[ActFrmCreDocPrj] =
#if   L==1	// ca
	"Edit new folder/file/link in documents zone of a project"			// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in documents zone of a project"			// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in documents zone of a project"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de documentos de un proyecto"
#elif L==5	// fr
	"Edit new folder/file/link in documents zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in documents zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in documents zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in documents zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in documents zone of a project"			// eviri lazim!
#endif
	,
	[ActCreFolDocPrj] =
#if   L==1	// ca
	"Create new folder in documents zone of a project"		// Necessita traducci
#elif L==2	// de
	"Create new folder in documents zone of a project"		// Need bersetzung
#elif L==3	// en
	"Create new folder in documents zone of a project"
#elif L==4	// es
	"Crear nueva carpeta en zona de documentos de un proyecto"
#elif L==5	// fr
	"Create new folder in documents zone of a project"		// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in documents zone of a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in documents zone of a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in documents zone of a project"		// Precisa de traduo
#elif L==10	// tr
	"Create new folder in documents zone of a project"		// eviri lazim!
#endif
	,
	[ActCreLnkDocPrj] =
#if   L==1	// ca
	"Create new link in documents zone of a project"		// Necessita traducci
#elif L==2	// de
	"Create new link in documents zone of a project"		// Need bersetzung
#elif L==3	// en
	"Create new link in documents zone of a project"
#elif L==4	// es
	"Crear nuevo enlace en zona de documentos de un proyecto"
#elif L==5	// fr
	"Create new link in documents zone of a project"		// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in documents zone of a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in documents zone of a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in documents zone of a project"		// Precisa de traduo
#elif L==10	// tr
	"Create new link in documents zone of a project"		// eviri lazim!
#endif
	,
	[ActRenFolDocPrj] =
#if   L==1	// ca
	"Rename folder in documents zone of a project"			// Necessita traducci
#elif L==2	// de
	"Rename folder in documents zone of a project"			// Need bersetzung
#elif L==3	// en
	"Rename folder in documents zone of a project"
#elif L==4	// es
	"Renombrar carpeta en zona de documentos de un proyecto"
#elif L==5	// fr
	"Rename folder in documents zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in documents zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in documents zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in documents zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"Rename folder in documents zone of a project"			// eviri lazim!
#endif
	,
	[ActRcvFilDocPrjDZ] =
#if   L==1	// ca
	"Send file in documents zone of a project using Dropzone.js"			// Necessita traducci
#elif L==2	// de
	"Send file in documents zone of a project using Dropzone.js"			// Need bersetzung
#elif L==3	// en
	"Send file in documents zone of a project using Dropzone.js"
#elif L==4	// es
	"Enviar archivo en zona de documentos de un proyecto usando Dropzone.js"
#elif L==5	// fr
	"Send file in documents zone of a project using Dropzone.js"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo en zona de documentos de un proyecto usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file in documents zone of a project using Dropzone.js"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file in documents zone of a project using Dropzone.js"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file in documents zone of a project using Dropzone.js"			// Precisa de traduo
#elif L==10	// tr
	"Send file in documents zone of a project using Dropzone.js"			// eviri lazim!
#endif
	,
	[ActRcvFilDocPrjCla] =
#if   L==1	// ca
	"Send file in documents zone of a project using the classic way"			// Necessita traducci
#elif L==2	// de
	"Send file in documents zone of a project using the classic way"			// Need bersetzung
#elif L==3	// en
	"Send file in documents zone of a project using the classic way"
#elif L==4	// es
	"Enviar archivo en zona de documentos de un proyecto de la forma cl&aacute;sica"
#elif L==5	// fr
	"Send file in documents zone of a project using the classic way"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo en zona de documentos de un proyecto de la forma cl&aacute;sica"	// Okoteve traduccin
#elif L==7	// it
	"Send file in documents zone of a project using the classic way"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file in documents zone of a project using the classic way"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file in documents zone of a project using the classic way"			// Precisa de traduo
#elif L==10	// tr
	"Send file in documents zone of a project using the classic way"			// eviri lazim!
#endif
	,
	[ActExpDocPrj] =
#if   L==1	// ca
	"Expand folder in documents zone of a project"		// Necessita traducci
#elif L==2	// de
	"Expand folder in documents zone of a project"		// Need bersetzung
#elif L==3	// en
	"Expand folder in documents zone of a project"
#elif L==4	// es
	"Expandir carpeta en zona de documentos de un proyecto"
#elif L==5	// fr
	"Expand folder in documents zone of a project"		// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in documents zone of a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in documents zone of a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in documents zone of a project"		// Precisa de traduo
#elif L==10	// tr
	"Expand folder in documents zone of a project"		// eviri lazim!
#endif
	,
	[ActConDocPrj] =
#if   L==1	// ca
	"Contract folder in documents zone of a project"	// Necessita traducci
#elif L==2	// de
	"Contract folder in documents zone of a project"	// Need bersetzung
#elif L==3	// en
	"Contract folder in documents zone of a project"
#elif L==4	// es
	"Contraer carpeta en zona de documentos de un proyecto"
#elif L==5	// fr
	"Contract folder in documents zone of a project"	// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in documents zone of a project"	// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in documents zone of a project"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in documents zone of a project"	// Precisa de traduo
#elif L==10	// tr
	"Contract folder in documents zone of a project"	// eviri lazim!
#endif
	,
	[ActZIPDocPrj] =
#if   L==1	// ca
	"Compress folder in documents zone of a project"		// Necessita traducci
#elif L==2	// de
	"Compress folder in documents zone of a project"		// Need bersetzung
#elif L==3	// en
	"Compress folder in documents zone of a project"
#elif L==4	// es
	"Comprimir carpeta en zona de documentos de un proyecto"
#elif L==5	// fr
	"Compress folder in documents zone of a project"		// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in documents zone of a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in documents zone of a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in documents zone of a project"		// Precisa de traduo
#elif L==10	// tr
	"Compress folder in documents zone of a project"		// eviri lazim!
#endif
	,
	[ActReqDatDocPrj] =
#if   L==1	// ca
	"See file metadata in documents zone of a project"		// Necessita traducci
#elif L==2	// de
	"See file metadata in documents zone of a project"		// Need bersetzung
#elif L==3	// en
	"See file metadata in documents zone of a project"
#elif L==4	// es
	"Ver metadatos de archivo en zona de documentos de un proyecto"
#elif L==5	// fr
	"See file metadata in documents zone of a project"		// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in documents zone of a project"		// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in documents zone of a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in documents zone of a project"		// Precisa de traduo
#elif L==10	// tr
	"See file metadata in documents zone of a project"		// eviri lazim!
#endif
	,
	[ActChgDatDocPrj] =
#if   L==1	// ca
	"Change file metadata in documents zone of a project"			// Necessita traducci
#elif L==2	// de
	"Change file metadata in documents zone of a project"			// Need bersetzung
#elif L==3	// en
	"Change file metadata in documents zone of a project"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de documentos de un proyecto"
#elif L==5	// fr
	"Change file metadata in documents zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in documents zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in documents zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in documents zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in documents zone of a project"			// eviri lazim!
#endif
	,
	[ActDowDocPrj] =
#if   L==1	// ca
	"Download file from documents zone of a project"		// Necessita traducci
#elif L==2	// de
	"Download file from documents zone of a project"		// Need bersetzung
#elif L==3	// en
	"Download file from documents zone of a project"
#elif L==4	// es
	"Descargar archivo en zona de documentos de un proyecto"
#elif L==5	// fr
	"Download file from documents zone of a project"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo en zona de documentos de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Download file from documents zone of a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from documents zone of a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from documents zone of a project"		// Precisa de traduo
#elif L==10	// tr
	"Download file from documents zone of a project"		// eviri lazim!
#endif
	,
	[ActAdmAssPrj] =
#if   L==1	// ca
	"Manage a assessment zone of a project"			// Necessita traducci
#elif L==2	// de
	"Manage a assessment zone of a project"			// Need bersetzung
#elif L==3	// en
	"Manage a assessment zone of a project"
#elif L==4	// es
	"Administrar zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Manage a assessment zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Manage a assessment zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Manage a assessment zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage a assessment zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"Manage a assessment zone of a project"			// eviri lazim!
#endif
	,
	[ActReqRemFilAssPrj] =
#if   L==1	// ca
	"Request removal of file from assessment zone of a project"				// Necessita traducci
#elif L==2	// de
	"Request removal of file from assessment zone of a project"				// Need bersetzung
#elif L==3	// en
	"Request removal of file from assessment zone of a project"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Request removal of file from assessment zone of a project"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from assessment zone of a project"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from assessment zone of a project"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from assessment zone of a project"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from assessment zone of a project"				// eviri lazim!
#endif
	,
	[ActRemFilAssPrj] =
#if   L==1	// ca
	"Remove file from assessment zone of a project"			// Necessita traducci
#elif L==2	// de
	"Remove file from assessment zone of a project"			// Need bersetzung
#elif L==3	// en
	"Remove file from assessment zone of a project"
#elif L==4	// es
	"Eliminar archivo de zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Remove file from assessment zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from assessment zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from assessment zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from assessment zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"Remove file from assessment zone of a project"			// eviri lazim!
#endif
	,
	[ActRemFolAssPrj] =
#if   L==1	// ca
	"Remove empty folder from assessment zone of a project"				// Necessita traducci
#elif L==2	// de
	"Remove empty folder from assessment zone of a project"				// Need bersetzung
#elif L==3	// en
	"Remove empty folder from assessment zone of a project"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Remove empty folder from assessment zone of a project"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from assessment zone of a project"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from assessment zone of a project"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from assessment zone of a project"				// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from assessment zone of a project"				// eviri lazim!
#endif
	,
	[ActCopAssPrj] =
#if   L==1	// ca
	"Set source of copy in the assessment zone of a project"			// Necessita traducci
#elif L==2	// de
	"Set source of copy in the assessment zone of a project"			// Need bersetzung
#elif L==3	// en
	"Set source of copy in the assessment zone of a project"
#elif L==4	// es
	"Establecer origen de copia en zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Set source of copy in the assessment zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in the assessment zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in the assessment zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in the assessment zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in the assessment zone of a project"			// eviri lazim!
#endif
	,
	[ActPasAssPrj] =
#if   L==1	// ca
	"Paste folder/file into assessment zone of a project"			// Necessita traducci
#elif L==2	// de
	"Paste folder/file into assessment zone of a project"			// Need bersetzung
#elif L==3	// en
	"Paste folder/file into assessment zone of a project"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Paste folder/file into assessment zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file into assessment zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file into assessment zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file into assessment zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file into assessment zone of a project"			// eviri lazim!
#endif
	,
	[ActRemTreAssPrj] =
#if   L==1	// ca
	"Remove non-empty folder from assessment zone of a project"			// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from assessment zone of a project"			// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from assessment zone of a project"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Remove non-empty folder from assessment zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from assessment zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from assessment zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from assessment zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from assessment zone of a project"			// eviri lazim!
#endif
	,
	[ActFrmCreAssPrj] =
#if   L==1	// ca
	"Edit new folder/file/link in the assessment zone of a project"				// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in the assessment zone of a project"				// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in the assessment zone of a project"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Edit new folder/file/link in the assessment zone of a project"				// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in the assessment zone of a project"				// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in the assessment zone of a project"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in the assessment zone of a project"				// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in the assessment zone of a project"				// eviri lazim!
#endif
	,
	[ActCreFolAssPrj] =
#if   L==1	// ca
	"Create new folder in the assessment zone of a project"			// Necessita traducci
#elif L==2	// de
	"Create new folder in the assessment zone of a project"			// Need bersetzung
#elif L==3	// en
	"Create new folder in the assessment zone of a project"
#elif L==4	// es
	"Crear nueva carpeta en zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Create new folder in the assessment zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in the assessment zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in the assessment zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in the assessment zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"Create new folder in the assessment zone of a project"			// eviri lazim!
#endif
	,
	[ActCreLnkAssPrj] =
#if   L==1	// ca
	"Create new link in the assessment zone of a project"			// Necessita traducci
#elif L==2	// de
	"Create new link in the assessment zone of a project"			// Need bersetzung
#elif L==3	// en
	"Create new link in the assessment zone of a project"
#elif L==4	// es
	"Crear nuevo enlace en zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Create new link in the assessment zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in the assessment zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in the assessment zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in the assessment zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"Create new link in the assessment zone of a project"			// eviri lazim!
#endif
	,
	[ActRenFolAssPrj] =
#if   L==1	// ca
	"Rename folder in the assessment zone of a project"		// Necessita traducci
#elif L==2	// de
	"Rename folder in the assessment zone of a project"		// Need bersetzung
#elif L==3	// en
	"Rename folder in the assessment zone of a project"
#elif L==4	// es
	"Renombrar carpeta en zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Rename folder in the assessment zone of a project"		// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in the assessment zone of a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in the assessment zone of a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in the assessment zone of a project"		// Precisa de traduo
#elif L==10	// tr
	"Rename folder in the assessment zone of a project"		// eviri lazim!
#endif
	,
	[ActRcvFilAssPrjDZ] =
#if   L==1	// ca
	"Send file to the assessment zone of a project using Dropzone.js"		// Necessita traducci
#elif L==2	// de
	"Send file to the assessment zone of a project using Dropzone.js"		// Need bersetzung
#elif L==3	// en
	"Send file to the assessment zone of a project using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona de evaluaci&oacute;n de un proyecto usando Dropzone.js"
#elif L==5	// fr
	"Send file to the assessment zone of a project using Dropzone.js"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de evaluaci&oacute;n de un proyecto usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to the assessment zone of a project using Dropzone.js"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to the assessment zone of a project using Dropzone.js"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to the assessment zone of a project using Dropzone.js"		// Precisa de traduo
#elif L==10	// tr
	"Send file to the assessment zone of a project using Dropzone.js"		// eviri lazim!
#endif
	,
	[ActRcvFilAssPrjCla] =
#if   L==1	// ca
	"Enviar a file in the assessment zone of a project using the classic way"		// Necessita traducci
#elif L==2	// de
	"Enviar a file in the assessment zone of a project using the classic way"		// Need bersetzung
#elif L==3	// en
	"Enviar a file in the assessment zone of a project using the classic way"
#elif L==4	// es
	"Enviar archivo a zona de evaluaci&oacute;n de un proyecto de forma tradicional"
#elif L==5	// fr
	"Enviar a file in the assessment zone of a project using the classic way"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de evaluaci&oacute;n de un proyecto de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Enviar a file in the assessment zone of a project using the classic way"		// Bisogno di traduzione
#elif L==8	// pl
	"Enviar a file in the assessment zone of a project using the classic way"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enviar a file in the assessment zone of a project using the classic way"		// Precisa de traduo
#elif L==10	// tr
	"Enviar a file in the assessment zone of a project using the classic way"		// eviri lazim!
#endif
	,
	[ActExpAssPrj] =
#if   L==1	// ca
	"Expand folder in the assessment zone of a project"		// Necessita traducci
#elif L==2	// de
	"Expand folder in the assessment zone of a project"		// Need bersetzung
#elif L==3	// en
	"Expand folder in the assessment zone of a project"
#elif L==4	// es
	"Expandir carpeta en zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Expand folder in the assessment zone of a project"		// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in the assessment zone of a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in the assessment zone of a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in the assessment zone of a project"		// Precisa de traduo
#elif L==10	// tr
	"Expand folder in the assessment zone of a project"		// eviri lazim!
#endif
	,
	[ActConAssPrj] =
#if   L==1	// ca
	"Contract folder in the assessment zone of a project"		// Necessita traducci
#elif L==2	// de
	"Contract folder in the assessment zone of a project"		// Need bersetzung
#elif L==3	// en
	"Contract folder in the assessment zone of a project"
#elif L==4	// es
	"Contraer carpeta en zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Contract folder in the assessment zone of a project"		// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in the assessment zone of a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in the assessment zone of a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in the assessment zone of a project"		// Precisa de traduo
#elif L==10	// tr
	"Contract folder in the assessment zone of a project"		// eviri lazim!
#endif
	,
	[ActZIPAssPrj] =
#if   L==1	// ca
	"Compress folder in the assessment zone of a project"		// Necessita traducci
#elif L==2	// de
	"Compress folder in the assessment zone of a project"		// Need bersetzung
#elif L==3	// en
	"Compress folder in the assessment zone of a project"
#elif L==4	// es
	"Comprimir carpeta en zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Compress folder in the assessment zone of a project"		// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in the assessment zone of a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in the assessment zone of a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in the assessment zone of a project"		// Precisa de traduo
#elif L==10	// tr
	"Compress folder in the assessment zone of a project"		// eviri lazim!
#endif
	,
	[ActReqDatAssPrj] =
#if   L==1	// ca
	"See file metadata in the assessment zone of a project"			// Necessita traducci
#elif L==2	// de
	"See file metadata in the assessment zone of a project"			// Need bersetzung
#elif L==3	// en
	"See file metadata in the assessment zone of a project"
#elif L==4	// es
	"Ver metadatos de archivo en zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"See file metadata in the assessment zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in the assessment zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in the assessment zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in the assessment zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in the assessment zone of a project"			// eviri lazim!
#endif
	,
	[ActChgDatAssPrj] =
#if   L==1	// ca
	"Change file metadata in the assessment zone of a project"			// Necessita traducci
#elif L==2	// de
	"Change file metadata in the assessment zone of a project"			// Need bersetzung
#elif L==3	// en
	"Change file metadata in the assessment zone of a project"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Change file metadata in the assessment zone of a project"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in the assessment zone of a project"			// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in the assessment zone of a project"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in the assessment zone of a project"			// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in the assessment zone of a project"			// eviri lazim!
#endif
	,
	[ActDowAssPrj] =
#if   L==1	// ca
	"Download file from the assessment zone of a project"		// Necessita traducci
#elif L==2	// de
	"Download file from the assessment zone of a project"		// Need bersetzung
#elif L==3	// en
	"Download file from the assessment zone of a project"
#elif L==4	// es
	"Descargar archivo de zona de evaluaci&oacute;n de un proyecto"
#elif L==5	// fr
	"Download file from the assessment zone of a project"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de evaluaci&oacute;n de un proyecto"	// Okoteve traduccin
#elif L==7	// it
	"Download file from the assessment zone of a project"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from the assessment zone of a project"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from the assessment zone of a project"		// Precisa de traduo
#elif L==10	// tr
	"Download file from the assessment zone of a project"		// eviri lazim!
#endif
	,
	[ActSeeAllCfe] =
#if   L==1	// ca
	"See exam announcements"	// Necessita traducci
#elif L==2	// de
	"See exam announcements"	// Need bersetzung
#elif L==3	// en
	"See exam announcements"
#elif L==4	// es
	"Ver convocatorias de examen"
#elif L==5	// fr
	"See exam announcements"	// Besoin de traduction
#elif L==6	// gn
	"Ver convocatorias de examen"	// Okoteve traduccin
#elif L==7	// it
	"See exam announcements"	// Bisogno di traduzione
#elif L==8	// pl
	"See exam announcements"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See exam announcements"	// Precisa de traduo
#elif L==10	// tr
	"See exam announcements"	// eviri lazim!
#endif
	,
	[ActSeeOneCfe] =
#if   L==1	// ca
	"See exam announcement"		// Necessita traducci
#elif L==2	// de
	"See exam announcement"		// Need bersetzung
#elif L==3	// en
	"See exam announcement"
#elif L==4	// es
	"Ver convocatoria de examen"
#elif L==5	// fr
	"See exam announcement"		// Besoin de traduction
#elif L==6	// gn
	"Ver convocatoria de examen"	// Okoteve traduccin
#elif L==7	// it
	"See exam announcement"		// Bisogno di traduzione
#elif L==8	// pl
	"See exam announcement"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See exam announcement"		// Precisa de traduo
#elif L==10	// tr
	"See exam announcement"		// eviri lazim!
#endif
	,
	[ActSeeDatCfe] =
#if   L==1	// ca
	"See exam announcements of a given date"	// Necessita traducci
#elif L==2	// de
	"See exam announcements of a given date"	// Need bersetzung
#elif L==3	// en
	"See exam announcements of a given date"
#elif L==4	// es
	"Ver convocatorias de examen de una fecha dada"
#elif L==5	// fr
	"See exam announcements of a given date"	// Besoin de traduction
#elif L==6	// gn
	"Ver convocatorias de examen de una fecha dada"	// Okoteve traduccin
#elif L==7	// it
	"See exam announcements of a given date"	// Bisogno di traduzione
#elif L==8	// pl
	"See exam announcements of a given date"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See exam announcements of a given date"	// Precisa de traduo
#elif L==10	// tr
	"See exam announcements of a given date"	// eviri lazim!
#endif
	,
	[ActEdiCfe] =
#if   L==1	// ca
	"Edit an exam announcement"		// Necessita traducci
#elif L==2	// de
	"Edit an exam announcement"		// Need bersetzung
#elif L==3	// en
	"Edit an exam announcement"
#elif L==4	// es
	"Editar una convocatoria de examen"
#elif L==5	// fr
	"Edit an exam announcement"		// Besoin de traduction
#elif L==6	// gn
	"Editar una convocatoria de examen"	// Okoteve traduccin
#elif L==7	// it
	"Edit an exam announcement"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit an exam announcement"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit an exam announcement"		// Precisa de traduo
#elif L==10	// tr
	"Edit an exam announcement"		// eviri lazim!
#endif
	,
	[ActRcvCfe] =
#if   L==1	// ca
	"Send an exam announcement"		// Necessita traducci
#elif L==2	// de
	"Send an exam announcement"		// Need bersetzung
#elif L==3	// en
	"Send an exam announcement"
#elif L==4	// es
	"Enviar una convocatoria de examen"
#elif L==5	// fr
	"Send an exam announcement"		// Besoin de traduction
#elif L==6	// gn
	"Enviar una convocatoria de examen"	// Okoteve traduccin
#elif L==7	// it
	"Send an exam announcement"		// Bisogno di traduzione
#elif L==8	// pl
	"Send an exam announcement"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send an exam announcement"		// Precisa de traduo
#elif L==10	// tr
	"Send an exam announcement"		// eviri lazim!
#endif
	,
	[ActPrnCfe] =
#if   L==1	// ca
	"See an exam announcement ready to be printed"		// Necessita traducci
#elif L==2	// de
	"See an exam announcement ready to be printed"		// Need bersetzung
#elif L==3	// en
	"See an exam announcement ready to be printed"
#elif L==4	// es
	"Ver una convocatoria de examen lista para imprimir"
#elif L==5	// fr
	"See an exam announcement ready to be printed"		// Besoin de traduction
#elif L==6	// gn
	"Ver una convocatoria de examen lista para imprimir"	// Okoteve traduccin
#elif L==7	// it
	"See an exam announcement ready to be printed"		// Bisogno di traduzione
#elif L==8	// pl
	"See an exam announcement ready to be printed"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See an exam announcement ready to be printed"		// Precisa de traduo
#elif L==10	// tr
	"See an exam announcement ready to be printed"		// eviri lazim!
#endif
	,
	[ActReqRemCfe] =
#if   L==1	// ca
	"Request removal of exam announcement"			// Necessita traducci
#elif L==2	// de
	"Request removal of exam announcement"			// Need bersetzung
#elif L==3	// en
	"Request removal of exam announcement"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de convocatoria de examen"
#elif L==5	// fr
	"Request removal of exam announcement"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de convocatoria de examen"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of exam announcement"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of exam announcement"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of exam announcement"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of exam announcement"			// eviri lazim!
#endif
	,
	[ActRemCfe] =
#if   L==1	// ca
	"Remove exam announcement"		// Necessita traducci
#elif L==2	// de
	"Remove exam announcement"		// Need bersetzung
#elif L==3	// en
	"Remove exam announcement"
#elif L==4	// es
	"Eliminar convocatoria de examen"
#elif L==5	// fr
	"Remove exam announcement"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar convocatoria de examen"	// Okoteve traduccin
#elif L==7	// it
	"Remove exam announcement"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove exam announcement"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove exam announcement"		// Precisa de traduo
#elif L==10	// tr
	"Remove exam announcement"		// eviri lazim!
#endif
	,
	[ActHidCfe] =
#if   L==1	// ca
	"Hide exam announcement"		// Necessita traducci
#elif L==2	// de
	"Hide exam announcement"		// Need bersetzung
#elif L==3	// en
	"Hide exam announcement"
#elif L==4	// es
	"Ocultar convocatoria de examen"
#elif L==5	// fr
	"Hide exam announcement"		// Besoin de traduction
#elif L==6	// gn
	"Ocultar convocatoria de examen"	// Okoteve traduccin
#elif L==7	// it
	"Hide exam announcement"		// Bisogno di traduzione
#elif L==8	// pl
	"Hide exam announcement"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide exam announcement"		// Precisa de traduo
#elif L==10	// tr
	"Hide exam announcement"		// eviri lazim!
#endif
	,
	[ActUnhCfe] =
#if   L==1	// ca
	"Unhide exam announcement"		// Necessita traducci
#elif L==2	// de
	"Unhide exam announcement"		// Need bersetzung
#elif L==3	// en
	"Unhide exam announcement"
#elif L==4	// es
	"Mostrar convocatoria de examen"
#elif L==5	// fr
	"Unhide exam announcement"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar convocatoria de examen"	// Okoteve traduccin
#elif L==7	// it
	"Unhide exam announcement"		// Bisogno di traduzione
#elif L==8	// pl
	"Unhide exam announcement"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide exam announcement"		// Precisa de traduo
#elif L==10	// tr
	"Unhide exam announcement"		// eviri lazim!
#endif
	,
	[ActReqLnkCfe] =
#if   L==1	// ca
	"Copy link to exam announcement"		// Necessita traducci
#elif L==2	// de
	"Copy link to exam announcement"		// Need bersetzung
#elif L==3	// en
	"Copy link to exam announcement"
#elif L==4	// es
	"Copiar enlace a convocatoria de examen"
#elif L==5	// fr
	"Copy link to exam announcement"		// Besoin de traduction
#elif L==6	// gn
	"Copiar enlace a convocatoria de examen"	// Okoteve traduccin
#elif L==7	// it
	"Copy link to exam announcement"		// Bisogno di traduzione
#elif L==8	// pl
	"Copy link to exam announcement"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Copy link to exam announcement"		// Precisa de traduo
#elif L==10	// tr
	"Copy link to exam announcement"		// eviri lazim!
#endif
	,
	[ActEdiTstQst] =
#if   L==1	// ca
	"Request edition of test questions"		// Necessita traducci
#elif L==2	// de
	"Request edition of test questions"		// Need bersetzung
#elif L==3	// en
	"Request edition of test questions"
#elif L==4	// es
	"Solicitar edici&oacute;n de preguntas de test"
#elif L==5	// fr
	"Request edition of test questions"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar edici&oacute;n de preguntas de test"	// Okoteve traduccin
#elif L==7	// it
	"Request edition of test questions"		// Bisogno di traduzione
#elif L==8	// pl
	"Request edition of test questions"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request edition of test questions"		// Precisa de traduo
#elif L==10	// tr
	"Request edition of test questions"		// eviri lazim!
#endif
	,
	[ActEdiOneTstQst] =
#if   L==1	// ca
	"Edit a test question"		// Necessita traducci
#elif L==2	// de
	"Edit a test question"		// Need bersetzung
#elif L==3	// en
	"Edit a test question"
#elif L==4	// es
	"Editar una pregunta de test"
#elif L==5	// fr
	"Edit a test question"		// Besoin de traduction
#elif L==6	// gn
	"Editar una pregunta de test"	// Okoteve traduccin
#elif L==7	// it
	"Edit a test question"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit a test question"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit a test question"		// Precisa de traduo
#elif L==10	// tr
	"Edit a test question"		// eviri lazim!
#endif
	,
	[ActReqImpTstQst] =
#if   L==1	// ca
	"Request an XML file with test questions to import"		// Necessita traducci
#elif L==2	// de
	"Request an XML file with test questions to import"		// Need bersetzung
#elif L==3	// en
	"Request an XML file with test questions to import"
#elif L==4	// es
	"Solicitar un archivo XML con preguntas de test para importar"
#elif L==5	// fr
	"Request an XML file with test questions to import"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar un archivo XML con preguntas de test para importar"	// Okoteve traduccin
#elif L==7	// it
	"Request an XML file with test questions to import"		// Bisogno di traduzione
#elif L==8	// pl
	"Request an XML file with test questions to import"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request an XML file with test questions to import"		// Precisa de traduo
#elif L==10	// tr
	"Request an XML file with test questions to import"		// eviri lazim!
#endif
	,
	[ActImpTstQst] =
#if   L==1	// ca
	"Import test questions from XML file"		// Necessita traducci
#elif L==2	// de
	"Import test questions from XML file"		// Need bersetzung
#elif L==3	// en
	"Import test questions from XML file"
#elif L==4	// es
	"Importar preguntas de test de archivo XML"
#elif L==5	// fr
	"Import test questions from XML file"		// Besoin de traduction
#elif L==6	// gn
	"Importar preguntas de test de archivo XML"	// Okoteve traduccin
#elif L==7	// it
	"Import test questions from XML file"		// Bisogno di traduzione
#elif L==8	// pl
	"Import test questions from XML file"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Import test questions from XML file"		// Precisa de traduo
#elif L==10	// tr
	"Import test questions from XML file"		// eviri lazim!
#endif
	,
	[ActLstTstQst] =
#if   L==1	// ca
	"List test questions for edition"		// Necessita traducci
#elif L==2	// de
	"List test questions for edition"		// Need bersetzung
#elif L==3	// en
	"List test questions for edition"
#elif L==4	// es
	"Listar preguntas de test para edici&oacute;n"
#elif L==5	// fr
	"List test questions for edition"		// Besoin de traduction
#elif L==6	// gn
	"Listar preguntas de test para edici&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"List test questions for edition"		// Bisogno di traduzione
#elif L==8	// pl
	"List test questions for edition"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List test questions for edition"		// Precisa de traduo
#elif L==10	// tr
	"List test questions for edition"		// eviri lazim!
#endif
	,
	[ActNewTstQst] =
#if   L==1	// ca
	"Crear pregunta"
#elif L==2	// de
	"Frage erstellen"
#elif L==3	// en
	"Create question"
#elif L==4	// es
	"Crear pregunta"
#elif L==5	// fr
	"Cr&eacute;er question"
#elif L==6	// gn
	"Crear pregunta"	// Okoteve traduccin
#elif L==7	// it
	"Crea domanda"
#elif L==8	// pl
	"Utw&oacute;rz pytanie"
#elif L==9	// pt
	"Criar pergunta"
#elif L==10	// tr
	"Create question"	// eviri lazim!
#endif
	,
	[ActChgTstQst] =
#if   L==1	// ca
	"Change test question"		// Necessita traducci
#elif L==2	// de
	"Change test question"		// Need bersetzung
#elif L==3	// en
	"Change test question"
#elif L==4	// es
	"Cambiar pregunta de test"
#elif L==5	// fr
	"Change test question"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar pregunta de test"	// Okoteve traduccin
#elif L==7	// it
	"Change test question"		// Bisogno di traduzione
#elif L==8	// pl
	"Change test question"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change test question"		// Precisa de traduo
#elif L==10	// tr
	"Change test question"		// eviri lazim!
#endif
	,
	[ActReqRemSevTstQst] =
#if   L==1	// ca
	"Request removing several test questions"			// Necessita traducci
#elif L==2	// de
	"Request removing several test questions"			// Need bersetzung
#elif L==3	// en
	"Request removing several test questions"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de varias preguntas de test"
#elif L==5	// fr
	"Request removing several test questions"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de varias preguntas de test"	// Okoteve traduccin
#elif L==7	// it
	"Request removing several test questions"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removing several test questions"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removing several test questions"			// Precisa de traduo
#elif L==10	// tr
	"Request removing several test questions"			// eviri lazim!
#endif
	,
	[ActRemSevTstQst] =
#if   L==1	// ca
	"Remove several test questions"		// Necessita traducci
#elif L==2	// de
	"Remove several test questions"		// Need bersetzung
#elif L==3	// en
	"Remove several test questions"
#elif L==4	// es
	"Eliminar varias preguntas de test"
#elif L==5	// fr
	"Remove several test questions"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar varias preguntas de test"	// Okoteve traduccin
#elif L==7	// it
	"Remove several test questions"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove several test questions"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove several test questions"		// Precisa de traduo
#elif L==10	// tr
	"Remove several test questions"		// eviri lazim!
#endif
	,
	[ActReqRemOneTstQst] =
#if   L==1	// ca
	"Request removing one test question"			// Necessita traducci
#elif L==2	// de
	"Request removing one test question"			// Need bersetzung
#elif L==3	// en
	"Request removing one test question"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de pregunta de test"
#elif L==5	// fr
	"Request removing one test question"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de pregunta de test"	// Okoteve traduccin
#elif L==7	// it
	"Request removing one test question"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removing one test question"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removing one test question"			// Precisa de traduo
#elif L==10	// tr
	"Request removing one test question"			// eviri lazim!
#endif
	,
	[ActRemOneTstQst] =
#if   L==1	// ca
	"Remove test question"		// Necessita traducci
#elif L==2	// de
	"Remove test question"		// Need bersetzung
#elif L==3	// en
	"Remove test question"
#elif L==4	// es
	"Eliminar pregunta de test"
#elif L==5	// fr
	"Remove test question"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar pregunta de test"	// Okoteve traduccin
#elif L==7	// it
	"Remove test question"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove test question"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove test question"		// Precisa de traduo
#elif L==10	// tr
	"Remove test question"		// eviri lazim!
#endif
	,
	[ActChgShfTstQst] =
#if   L==1	// ca
	"Change shuffle of a test question"	// Necessita traducci
#elif L==2	// de
	"Change shuffle of a test question"	// Need bersetzung
#elif L==3	// en
	"Change shuffle of a test question"
#elif L==4	// es
	"Cambiar baraje de pregunta de test"
#elif L==5	// fr
	"Change shuffle of a test question"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar baraje de pregunta de test"	// Okoteve traduccin
#elif L==7	// it
	"Change shuffle of a test question"	// Bisogno di traduzione
#elif L==8	// pl
	"Change shuffle of a test question"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change shuffle of a test question"	// Precisa de traduo
#elif L==10	// tr
	"Change shuffle of a test question"	// eviri lazim!
#endif
	,
	[ActEdiTag] =
#if   L==1	// ca
	"Edit tags in the question bank"		// Necessita traducci
#elif L==2	// de
	"Edit tags in the question bank"		// Need bersetzung
#elif L==3	// en
	"Edit tags in the question bank"
#elif L==4	// es
	"Editar descriptores del banco de preguntas"
#elif L==5	// fr
	"Edit tags in the question bank"		// Besoin de traduction
#elif L==6	// gn
	"Editar descriptores del banco de preguntas"	// Okoteve traduccin
#elif L==7	// it
	"Edit tags in the question bank"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit tags in the question bank"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit tags in the question bank"		// Precisa de traduo
#elif L==10	// tr
	"Edit tags in the question bank"		// eviri lazim!
#endif
	,
	[ActEnaTag] =
#if   L==1	// ca
	"Enable tag in the question bank"		// Necessita traducci
#elif L==2	// de
	"Enable tag in the question bank"		// Need bersetzung
#elif L==3	// en
	"Enable tag in the question bank"
#elif L==4	// es
	"Habilitar descriptor del banco de preguntas"
#elif L==5	// fr
	"Enable tag in the question bank"		// Besoin de traduction
#elif L==6	// gn
	"Habilitar descriptor del banco de preguntas"	// Okoteve traduccin
#elif L==7	// it
	"Enable tag in the question bank"		// Bisogno di traduzione
#elif L==8	// pl
	"Enable tag in the question bank"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enable tag in the question bank"		// Precisa de traduo
#elif L==10	// tr
	"Enable tag in the question bank"		// eviri lazim!
#endif
	,
	[ActDisTag] =
#if   L==1	// ca
	"Disable tag in the question bank"		// Necessita traducci
#elif L==2	// de
	"Disable tag in the question bank"		// Need bersetzung
#elif L==3	// en
	"Disable tag in the question bank"
#elif L==4	// es
	"Inhabilitar descriptor del banco de preguntas"
#elif L==5	// fr
	"Disable tag in the question bank"		// Besoin de traduction
#elif L==6	// gn
	"Inhabilitar descriptor del banco de preguntas"	// Okoteve traduccin
#elif L==7	// it
	"Disable tag in the question bank"		// Bisogno di traduzione
#elif L==8	// pl
	"Disable tag in the question bank"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Disable tag in the question bank"		// Precisa de traduo
#elif L==10	// tr
	"Disable tag in the question bank"		// eviri lazim!
#endif
	,
	[ActRenTag] =
#if   L==1	// ca
	"Rename tag in the question bank"		// Necessita traducci
#elif L==2	// de
	"Rename tag in the question bank"		// Need bersetzung
#elif L==3	// en
	"Rename tag in the question bank"
#elif L==4	// es
	"Renombrar descriptor del banco de preguntas"
#elif L==5	// fr
	"Rename tag in the question bank"		// Besoin de traduction
#elif L==6	// gn
	"Renombrar descriptor del banco de preguntas"	// Okoteve traduccin
#elif L==7	// it
	"Rename tag in the question bank"		// Bisogno di traduzione
#elif L==8	// pl
	"Rename tag in the question bank"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename tag in the question bank"		// Precisa de traduo
#elif L==10	// tr
	"Rename tag in the question bank"		// eviri lazim!
#endif
	,
	[ActReqTst] =
#if   L==1	// ca
	"Request a test"	// Necessita traducci
#elif L==2	// de
	"Request a test"	// Need bersetzung
#elif L==3	// en
	"Request a test"
#elif L==4	// es
	"Solicitar un test"
#elif L==5	// fr
	"Request a test"	// Besoin de traduction
#elif L==6	// gn
	"Solicitar un test"	// Okoteve traduccin
#elif L==7	// it
	"Request a test"	// Bisogno di traduzione
#elif L==8	// pl
	"Request a test"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request a test"	// Precisa de traduo
#elif L==10	// tr
	"Request a test"	// eviri lazim!
#endif
	,
	[ActSeeTst] =
#if   L==1	// ca
	"See a test"	// Necessita traducci
#elif L==2	// de
	"See a test"	// Need bersetzung
#elif L==3	// en
	"See a test"
#elif L==4	// es
	"Ver un test"
#elif L==5	// fr
	"See a test"	// Besoin de traduction
#elif L==6	// gn
	"Ver un test"	// Okoteve traduccin
#elif L==7	// it
	"See a test"	// Bisogno di traduzione
#elif L==8	// pl
	"See a test"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See a test"	// Precisa de traduo
#elif L==10	// tr
	"See a test"	// eviri lazim!
#endif
	,
	[ActReqAssTst] =
#if   L==1	// ca
	"Request assessment of a test"			// Necessita traducci
#elif L==2	// de
	"Request assessment of a test"			// Need bersetzung
#elif L==3	// en
	"Request assessment of a test"
#elif L==4	// es
	"Solicitar evaluaci&oacute;n de un test"
#elif L==5	// fr
	"Request assessment of a test"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar evaluaci&oacute;n de un test"	// Okoteve traduccin
#elif L==7	// it
	"Request assessment of a test"			// Bisogno di traduzione
#elif L==8	// pl
	"Request assessment of a test"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request assessment of a test"			// Precisa de traduo
#elif L==10	// tr
	"Request assessment of a test"			// eviri lazim!
#endif
	,
	[ActAssTst] =
#if   L==1	// ca
	"Assess a test"		// Necessita traducci
#elif L==2	// de
	"Assess a test"		// Need bersetzung
#elif L==3	// en
	"Assess a test"
#elif L==4	// es
	"Evaluar un test"
#elif L==5	// fr
	"Assess a test"		// Besoin de traduction
#elif L==6	// gn
	"Evaluar un test"	// Okoteve traduccin
#elif L==7	// it
	"Assess a test"		// Bisogno di traduzione
#elif L==8	// pl
	"Assess a test"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Assess a test"		// Precisa de traduo
#elif L==10	// tr
	"Assess a test"		// eviri lazim!
#endif
	,
	[ActCfgTst] =
#if   L==1	// ca
	"See test configuration"		// Necessita traducci
#elif L==2	// de
	"See test configuration"		// Need bersetzung
#elif L==3	// en
	"See test configuration"
#elif L==4	// es
	"Ver configuraci&oacute;n de test"
#elif L==5	// fr
	"See test configuration"		// Besoin de traduction
#elif L==6	// gn
	"Ver configuraci&oacute;n de test"	// Okoteve traduccin
#elif L==7	// it
	"See test configuration"		// Bisogno di traduzione
#elif L==8	// pl
	"See test configuration"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See test configuration"		// Precisa de traduo
#elif L==10	// tr
	"See test configuration"		// eviri lazim!
#endif
	,
	[ActRcvCfgTst] =
#if   L==1	// ca
	"Change test configuration"		// Necessita traducci
#elif L==2	// de
	"Change test configuration"		// Need bersetzung
#elif L==3	// en
	"Change test configuration"
#elif L==4	// es
	"Cambiar configuraci&oacute;n de test"
#elif L==5	// fr
	"Change test configuration"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar configuraci&oacute;n de test"	// Okoteve traduccin
#elif L==7	// it
	"Change test configuration"		// Bisogno di traduzione
#elif L==8	// pl
	"Change test configuration"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change test configuration"		// Precisa de traduo
#elif L==10	// tr
	"Change test configuration"		// eviri lazim!
#endif
	,
	[ActReqSeeMyTstRes] =
#if   L==1	// ca
	"Request to see my test results"	// Necessita traducci
#elif L==2	// de
	"Request to see my test results"	// Need bersetzung
#elif L==3	// en
	"Request to see my test results"
#elif L==4	// es
	"Solicitar ver mis resultados de test"
#elif L==5	// fr
	"Request to see my test results"	// Besoin de traduction
#elif L==6	// gn
	"Solicitar ver mis resultados de test"	// Okoteve traduccin
#elif L==7	// it
	"Request to see my test results"	// Bisogno di traduzione
#elif L==8	// pl
	"Request to see my test results"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request to see my test results"	// Precisa de traduo
#elif L==10	// tr
	"Request to see my test results"	// eviri lazim!
#endif
	,
	[ActSeeMyTstResCrs] =
#if   L==1	// ca
	"See my test results"		// Necessita traducci
#elif L==2	// de
	"See my test results"		// Need bersetzung
#elif L==3	// en
	"See my test results"
#elif L==4	// es
	"Ver mis resultados de test"
#elif L==5	// fr
	"See my test results"		// Besoin de traduction
#elif L==6	// gn
	"Ver mis resultados de test"	// Okoteve traduccin
#elif L==7	// it
	"See my test results"		// Bisogno di traduzione
#elif L==8	// pl
	"See my test results"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See my test results"		// Precisa de traduo
#elif L==10	// tr
	"See my test results"		// eviri lazim!
#endif
	,
	[ActSeeOneTstResMe] =
#if   L==1	// ca
	"See one of my test results"		// Necessita traducci
#elif L==2	// de
	"See one of my test results"		// Need bersetzung
#elif L==3	// en
	"See one of my test results"
#elif L==4	// es
	"Ver uno de mis resultados de test"
#elif L==5	// fr
	"See one of my test results"		// Besoin de traduction
#elif L==6	// gn
	"Ver uno de mis resultados de test"	// Okoteve traduccin
#elif L==7	// it
	"See one of my test results"		// Bisogno di traduzione
#elif L==8	// pl
	"See one of my test results"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See one of my test results"		// Precisa de traduo
#elif L==10	// tr
	"See one of my test results"		// eviri lazim!
#endif
	,
	[ActReqSeeUsrTstRes] =
#if   L==1	// ca
	"Request test results for several users"		// Necessita traducci
#elif L==2	// de
	"Request test results for several users"		// Need bersetzung
#elif L==3	// en
	"Request test results for several users"
#elif L==4	// es
	"Solicitar resultados de test de varios usuarios"
#elif L==5	// fr
	"Request test results for several users"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar resultados de test de varios usuarios"	// Okoteve traduccin
#elif L==7	// it
	"Request test results for several users"		// Bisogno di traduzione
#elif L==8	// pl
	"Request test results for several users"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request test results for several users"		// Precisa de traduo
#elif L==10	// tr
	"Request test results for several users"		// eviri lazim!
#endif
	,
	[ActSeeUsrTstResCrs] =
#if   L==1	// ca
	"See test results for several users"		// Necessita traducci
#elif L==2	// de
	"See test results for several users"		// Need bersetzung
#elif L==3	// en
	"See test results for several users"
#elif L==4	// es
	"Ver los resultados de test de varios usuarios"
#elif L==5	// fr
	"See test results for several users"		// Besoin de traduction
#elif L==6	// gn
	"Ver los resultados de test de varios usuarios"	// Okoteve traduccin
#elif L==7	// it
	"See test results for several users"		// Bisogno di traduzione
#elif L==8	// pl
	"See test results for several users"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See test results for several users"		// Precisa de traduo
#elif L==10	// tr
	"See test results for several users"		// eviri lazim!
#endif
	,
	[ActSeeOneTstResOth] =
#if   L==1	// ca
	"See a test result for a user"		// Necessita traducci
#elif L==2	// de
	"See a test result for a user"		// Need bersetzung
#elif L==3	// en
	"See a test result for a user"
#elif L==4	// es
	"Ver un resultado de test de usuario"
#elif L==5	// fr
	"See a test result for a user"		// Besoin de traduction
#elif L==6	// gn
	"Ver un resultado de test de usuario"	// Okoteve traduccin
#elif L==7	// it
	"See a test result for a user"		// Bisogno di traduzione
#elif L==8	// pl
	"See a test result for a user"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See a test result for a user"		// Precisa de traduo
#elif L==10	// tr
	"See a test result for a user"		// eviri lazim!
#endif
	,
	[ActSeeAllExa] =
#if   L==1	// ca
	"See exams"			// Necessita traducci
#elif L==2	// de
	"See exams"			// Need bersetzung
#elif L==3	// en
	"See exams"
#elif L==4	// es
	"Ver ex&aacute;menes"
#elif L==5	// fr
	"See exams"			// Besoin de traduction
#elif L==6	// gn
	"Ver ex&aacute;menes"		// Okoteve traduccin
#elif L==7	// it
	"See exams"			// Bisogno di traduzione
#elif L==8	// pl
	"See exams"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See exams"			// Precisa de traduo
#elif L==10	// tr
	"See exams"			// eviri lazim!
#endif
	,
	[ActSeeOneExa] =
#if   L==1	// ca
	"Veure examen"
#elif L==2	// de
	"Siehe Pr&uuml;fung"
#elif L==3	// en
	"See exam"
#elif L==4	// es
	"Ver examen"
#elif L==5	// fr
	"Voir examen"
#elif L==6	// gn
	"Ehecha examen"
#elif L==7	// it
	"Vedi esame"
#elif L==8	// pl
	"Zobacz egzamin"
#elif L==9	// pt
	"Ver exame"
#elif L==10	// tr
	"S&inodot;nava bak&inodot;n"
#endif
	,
	[ActFrmNewExa] =
#if   L==1	// ca
	"Request new exam"		// Necessita traducci
#elif L==2	// de
	"Request new exam"		// Need bersetzung
#elif L==3	// en
	"Request new exam"
#elif L==4	// es
	"Solicitar nuevo examen"
#elif L==5	// fr
	"Request new exam"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar nuevo examen"	// Okoteve traduccin
#elif L==7	// it
	"Request new exam"		// Bisogno di traduzione
#elif L==8	// pl
	"Request new exam"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request new exam"		// Precisa de traduo
#elif L==10	// tr
	"Request new exam"		// eviri lazim!
#endif
	,
	[ActEdiOneExa] =
#if   L==1	// ca
	"Request exam edition"			// Necessita traducci
#elif L==2	// de
	"Request exam edition"			// Need bersetzung
#elif L==3	// en
	"Request exam edition"
#elif L==4	// es
	"Solicitar edici&oacute;n de examen"
#elif L==5	// fr
	"Request exam edition"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar edici&oacute;n de examen"	// Okoteve traduccin
#elif L==7	// it
	"Request exam edition"			// Bisogno di traduzione
#elif L==8	// pl
	"Request exam edition"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request exam edition"			// Precisa de traduo
#elif L==10	// tr
	"Request exam edition"			// eviri lazim!
#endif
	,
	[ActNewExa] =
#if   L==1	// ca
	"Crear examen"
#elif L==2	// de
	"Pr&uuml;fung erstellen"
#elif L==3	// en
	"Create exam"
#elif L==4	// es
	"Crear examen"
#elif L==5	// fr
	"Cr&eacute;er exam"
#elif L==6	// gn
	"Crear examen"	// Okoteve traduccin
#elif L==7	// it
	"Creare esame"
#elif L==8	// pl
	"Utw&oacute;rz egzamin"
#elif L==9	// pt
	"Criar exame"
#elif L==10	// tr
	"Create exam"	// eviri lazim!
#endif
	,
	[ActChgExa] =
#if   L==1	// ca
	"Change exam"		// Necessita traducci
#elif L==2	// de
	"Change exam"		// Need bersetzung
#elif L==3	// en
	"Change exam"
#elif L==4	// es
	"Cambiar examen"
#elif L==5	// fr
	"Change exam"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar examen"	// Okoteve traduccin
#elif L==7	// it
	"Change exam"		// Bisogno di traduzione
#elif L==8	// pl
	"Change exam"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change exam"		// Precisa de traduo
#elif L==10	// tr
	"Change exam"		// eviri lazim!
#endif
	,
	[ActReqRemExa] =
#if   L==1	// ca
	"Request exam removal"				// Necessita traducci
#elif L==2	// de
	"Request exam removal"				// Need bersetzung
#elif L==3	// en
	"Request exam removal"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de examen"
#elif L==5	// fr
	"Request exam removal"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de examen"	// Okoteve traduccin
#elif L==7	// it
	"Request exam removal"				// Bisogno di traduzione
#elif L==8	// pl
	"Request exam removal"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request exam removal"				// Precisa de traduo
#elif L==10	// tr
	"Request exam removal"				// eviri lazim!
#endif
	,
	[ActRemExa] =
#if   L==1	// ca
	"Eliminar examen"
#elif L==2	// de
	"Pr&uuml;fung entfernen"
#elif L==3	// en
	"Remove exam"
#elif L==4	// es
	"Eliminar examen"
#elif L==5	// fr
	"Supprimer examen"
#elif L==6	// gn
	"Eliminar examen"	// Okoteve traduccin
#elif L==7	// it
	"Rimuovere esame"
#elif L==8	// pl
	"Usu&nacute; egzamin"
#elif L==9	// pt
	"Remover exame"
#elif L==10	// tr
	"S&inodot;nav&inodot; kald&inodot;r"
#endif
	,
	[ActHidExa] =
#if   L==1	// ca
	"Hide exam"		// Necessita traducci
#elif L==2	// de
	"Hide exam"		// Need bersetzung
#elif L==3	// en
	"Hide exam"
#elif L==4	// es
	"Ocultar examen"
#elif L==5	// fr
	"Hide exam"		// Besoin de traduction
#elif L==6	// gn
	"Ocultar examen"	// Okoteve traduccin
#elif L==7	// it
	"Hide exam"		// Bisogno di traduzione
#elif L==8	// pl
	"Hide exam"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide exam"		// Precisa de traduo
#elif L==10	// tr
	"Hide exam"		// eviri lazim!
#endif
	,
	[ActUnhExa] =
#if   L==1	// ca
	"Unhide exam"		// Necessita traducci
#elif L==2	// de
	"Unhide exam"		// Need bersetzung
#elif L==3	// en
	"Unhide exam"
#elif L==4	// es
	"Mostrar examen"
#elif L==5	// fr
	"Unhide exam"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar examen"	// Okoteve traduccin
#elif L==7	// it
	"Unhide exam"		// Bisogno di traduzione
#elif L==8	// pl
	"Unhide exam"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide exam"		// Precisa de traduo
#elif L==10	// tr
	"Unhide exam"		// eviri lazim!
#endif
	,
	[ActReqLnkExa] =
#if   L==1	// ca
	"Copy link to exam"		// Necessita traducci
#elif L==2	// de
	"Copy link to exam"		// Need bersetzung
#elif L==3	// en
	"Copy link to exam"
#elif L==4	// es
	"Copiar enlace a examen"
#elif L==5	// fr
	"Copy link to exam"		// Besoin de traduction
#elif L==6	// gn
	"Copiar enlace a examen"	// Okoteve traduccin
#elif L==7	// it
	"Copy link to exam"		// Bisogno di traduzione
#elif L==8	// pl
	"Copy link to exam"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Copy link to exam"		// Precisa de traduo
#elif L==10	// tr
	"Copy link to exam"		// eviri lazim!
#endif
	,
	[ActNewExaSet] =
#if   L==1	// ca
	"Crear conjunt de preguntes"
#elif L==2	// de
	"Satz von Fragen erstellen"
#elif L==3	// en
	"Create set of questions"
#elif L==4	// es
	"Crear conjunto de preguntas"
#elif L==5	// fr
	"Cr&eacute;er ensemble de questions"
#elif L==6	// gn
	"Ojapo porandu &ntilde;emohenda"
#elif L==7	// it
	"Creare set di domande"
#elif L==8	// pl
	"Utw&oacute;rz zestaw pyta&nacute;"
#elif L==9	// pt
	"Criar conjunto de perguntas"
#elif L==10	// tr
	"Soru grubu olu&scedil;tur"
#endif
	,
	[ActReqRemExaSet] =
#if   L==1	// ca
	"Request set of questions removal"			// Necessita traducci
#elif L==2	// de
	"Request set of questions removal"			// Need bersetzung
#elif L==3	// en
	"Request set of questions removal"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de conjunto de preguntas"
#elif L==5	// fr
	"Request set of questions removal"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de conjunto de preguntas"	// Okoteve traduccin
#elif L==7	// it
	"Request set of questions removal"			// Bisogno di traduzione
#elif L==8	// pl
	"Request set of questions removal"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request set of questions removal"			// Precisa de traduo
#elif L==10	// tr
	"Request set of questions removal"			// eviri lazim!
#endif
	,
	[ActRemExaSet] =
#if   L==1	// ca
	"Eliminar conjunt de preguntes"
#elif L==2	// de
	"Satz von Fragen entfernen"
#elif L==3	// en
	"Remove set of questions"
#elif L==4	// es
	"Eliminar conjunto de preguntas"
#elif L==5	// fr
	"Supprimer ensemble de questions"
#elif L==6	// gn
	"Eliminar conjunto de preguntas"	// Okoteve traduccin
#elif L==7	// it
	"Rimuovere set di domande"
#elif L==8	// pl
	"Usu&nacute; zestaw pyta&nacute;"
#elif L==9	// pt
	"Remover conjunto de perguntas"
#elif L==10	// tr
	"Soru grubunu kald&inodot;r"
#endif
	,
	[ActUp_ExaSet] =
#if   L==1	// ca
	"Move up set of questions"			// Necessita traducci
#elif L==2	// de
	"Move up set of questions"			// Need bersetzung
#elif L==3	// en
	"Move up set of questions"
#elif L==4	// es
	"Mover hacia arriba conjunto de preguntas"
#elif L==5	// fr
	"Move up set of questions"			// Besoin de traduction
#elif L==6	// gn
	"Mover hacia arriba conjunto de preguntas"	// Okoteve traduccin
#elif L==7	// it
	"Move up set of questions"			// Bisogno di traduzione
#elif L==8	// pl
	"Move up set of questions"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Move up set of questions"			// Precisa de traduo
#elif L==10	// tr
	"Move up set of questions"			// eviri lazim!
#endif
	,
	[ActDwnExaSet] =
#if   L==1	// ca
	"Move down set of questions"			// Necessita traducci
#elif L==2	// de
	"Move down set of questions"			// Need bersetzung
#elif L==3	// en
	"Move down set of questions"
#elif L==4	// es
	"Mover hacia abajo conjunto de preguntas"
#elif L==5	// fr
	"Move down set of questions"			// Besoin de traduction
#elif L==6	// gn
	"Mover hacia abajo conjunto de preguntas"	// Okoteve traduccin
#elif L==7	// it
	"Move down set of questions"			// Bisogno di traduzione
#elif L==8	// pl
	"Move down set of questions"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Move down set of questions"			// Precisa de traduo
#elif L==10	// tr
	"Move down set of questions"			// eviri lazim!
#endif
	,
	[ActChgTitExaSet] =
#if   L==1	// ca
	"Change set of questions title"				// Necessita traducci
#elif L==2	// de
	"Change set of questions title"				// Need bersetzung
#elif L==3	// en
	"Change set of questions title"
#elif L==4	// es
	"Cambiar t&iacute;tulo de conjunto de preguntas"
#elif L==5	// fr
	"Change set of questions title"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar t&iacute;tulo de conjunto de preguntas"	// Okoteve traduccin
#elif L==7	// it
	"Change set of questions title"				// Bisogno di traduzione
#elif L==8	// pl
	"Change set of questions title"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change set of questions title"				// Precisa de traduo
#elif L==10	// tr
	"Change set of questions title"				// eviri lazim!
#endif
	,
	[ActChgNumQstExaSet] =
#if   L==1	// ca
	"Change number of questions from set to each exam print"		// Necessita traducci
#elif L==2	// de
	"Change number of questions from set to each exam print"		// Need bersetzung
#elif L==3	// en
	"Change number of questions from set to each exam print"
#elif L==4	// es
	"Cambiar n&ordm; de preguntas del conjunto en cada examen impreso"
#elif L==5	// fr
	"Change number of questions from set to each exam print"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar n&ordm; de preguntas del conjunto en cada examen impreso"	// Okoteve traduccin
#elif L==7	// it
	"Change number of questions from set to each exam print"		// Bisogno di traduzione
#elif L==8	// pl
	"Change number of questions from set to each exam print"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change number of questions from set to each exam print"		// Precisa de traduo
#elif L==10	// tr
	"Change number of questions from set to each exam print"		// eviri lazim!
#endif
	,
	[ActReqAddQstExaSet] =
#if   L==1	// ca
	"Request add questions to exam"			// Necessita traducci
#elif L==2	// de
	"Request add questions to exam"			// Need bersetzung
#elif L==3	// en
	"Request add questions to exam"
#elif L==4	// es
	"Solicitar a&ntilde;adir preguntas a examen"
#elif L==5	// fr
	"Request add questions to exam"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar a&ntilde;adir preguntas a examen"	// Okoteve traduccin
#elif L==7	// it
	"Request add questions to exam"			// Bisogno di traduzione
#elif L==8	// pl
	"Request add questions to exam"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request add questions to exam"			// Precisa de traduo
#elif L==10	// tr
	"Request add questions to exam"			// eviri lazim!
#endif
	,
	[ActLstTstQstForSet] =
#if   L==1	// ca
	"List questions for exam"		// Necessita traducci
#elif L==2	// de
	"List questions for exam"		// Need bersetzung
#elif L==3	// en
	"List questions for exam"
#elif L==4	// es
	"Listar preguntas para examen"
#elif L==5	// fr
	"List questions for exam"		// Besoin de traduction
#elif L==6	// gn
	"Listar preguntas para examen"	// Okoteve traduccin
#elif L==7	// it
	"List questions for exam"		// Bisogno di traduzione
#elif L==8	// pl
	"List questions for exam"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List questions for exam"		// Precisa de traduo
#elif L==10	// tr
	"List questions for exam"		// eviri lazim!
#endif
	,
	[ActAddQstToExa] =
#if   L==1	// ca
	"Add questions to exam"			// Necessita traducci
#elif L==2	// de
	"Add questions to exam"			// Need bersetzung
#elif L==3	// en
	"Add questions to exam"
#elif L==4	// es
	"A&ntilde;adir preguntas a examen"
#elif L==5	// fr
	"Add questions to exam"			// Besoin de traduction
#elif L==6	// gn
	"A&ntilde;adir preguntas a examen"	// Okoteve traduccin
#elif L==7	// it
	"Add questions to exam"			// Bisogno di traduzione
#elif L==8	// pl
	"Add questions to exam"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Add questions to exam"			// Precisa de traduo
#elif L==10	// tr
	"Add questions to exam"			// eviri lazim!
#endif
	,
	[ActReqRemSetQst] =
#if   L==1	// ca
	"Request exam question removal"				// Necessita traducci
#elif L==2	// de
	"Request exam question removal"				// Need bersetzung
#elif L==3	// en
	"Request exam question removal"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de pregunta de examen"
#elif L==5	// fr
	"Request exam question removal"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de pregunta de examen"	// Okoteve traduccin
#elif L==7	// it
	"Request exam question removal"				// Bisogno di traduzione
#elif L==8	// pl
	"Request exam question removal"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request exam question removal"				// Precisa de traduo
#elif L==10	// tr
	"Request exam question removal"				// eviri lazim!
#endif
	,
	[ActRemExaQst] =
#if   L==1	// ca
	"Remove exam question"		// Necessita traducci
#elif L==2	// de
	"Remove exam question"		// Need bersetzung
#elif L==3	// en
	"Remove exam question"
#elif L==4	// es
	"Eliminar pregunta de examen"
#elif L==5	// fr
	"Remove exam question"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar pregunta de examen"	// Okoteve traduccin
#elif L==7	// it
	"Remove exam question"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove exam question"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove exam question"		// Precisa de traduo
#elif L==10	// tr
	"Remove exam question"		// eviri lazim!
#endif
	,
	[ActValSetQst] =
#if   L==1	// ca
	"Validar pregunta d'examen"
#elif L==2	// de
	"Pr&uuml;fungsfrage validieren"
#elif L==3	// en
	"Validate exam question"
#elif L==4	// es
	"Validar pregunta de examen"
#elif L==5	// fr
	"Valider question d'examen"
#elif L==6	// gn
	"Validar pregunta de examen"	// Okoteve traduccin
#elif L==7	// it
	"Validare domanda d'esame"
#elif L==8	// pl
	"Potwierd&zacute; pytanie egzaminacyjne"
#elif L==9	// pt
	"Validar pergunta do exame"
#elif L==10	// tr
	"S&inodot;nav sorusunu do&gbreve;rula"
#endif
	,
	[ActInvSetQst] =
#if   L==1	// ca
	"Invalidar pregunta d'examen"
#elif L==2	// de
	"Pr&uuml;fungsfrage ung&uuml;ltig machen"
#elif L==3	// en
	"Invalidate exam question"
#elif L==4	// es
	"Invalidar pregunta de examen"
#elif L==5	// fr
	"Invalider question d'examen"
#elif L==6	// gn
	"Invalidar pregunta de examen"	// Okoteve traduccin
#elif L==7	// it
	"Invalidare domanda d'esame"
#elif L==8	// pl
	"Uniewa&zdot;nij pytanie egzaminacyjne"
#elif L==9	// pt
	"Invalidar pergunta do exame"
#elif L==10	// tr
	"Ge&ccedil;ersiz s&inodot;nav sorusu"
#endif
	,
	[ActReqNewExaSes] =
#if   L==1	// ca
	"Request new exam session"			// Necessita traducci
#elif L==2	// de
	"Request new exam session"			// Need bersetzung
#elif L==3	// en
	"Request new exam session"
#elif L==4	// es
	"Solicitar nueva sesi&oacute;n de examen"
#elif L==5	// fr
	"Request new exam session"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar nueva sesi&oacute;n de examen"	// Okoteve traduccin
#elif L==7	// it
	"Request new exam session"			// Bisogno di traduzione
#elif L==8	// pl
	"Request new exam session"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request new exam session"			// Precisa de traduo
#elif L==10	// tr
	"Request new exam session"			// eviri lazim!
#endif
	,
	[ActReqChgExaSes] =
#if   L==1	// ca
	"Edit exam session"			// Necessita traducci
#elif L==2	// de
	"Edit exam session"			// Need bersetzung
#elif L==3	// en
	"Edit exam session"
#elif L==4	// es
	"Editar sesi&oacute;n de examen"
#elif L==5	// fr
	"Edit exam session"			// Besoin de traduction
#elif L==6	// gn
	"Editar sesi&oacute;n de examen"	// Okoteve traduccin
#elif L==7	// it
	"Edit exam session"			// Bisogno di traduzione
#elif L==8	// pl
	"Edit exam session"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit exam session"			// Precisa de traduo
#elif L==10	// tr
	"Edit exam session"			// eviri lazim!
#endif
	,
	[ActNewExaSes] =
#if   L==1	// ca
	"Crear sessi&oacute; d'examen"
#elif L==2	// de
	"Pr&uuml;fungssitzung erstellen"
#elif L==3	// en
	"Create exam session"
#elif L==4	// es
	"Crear sesi&oacute;n de examen"
#elif L==5	// fr
	"Cr&eacute;er session d'examen"
#elif L==6	// gn
	"Omohe&ntilde;&oacute;i sesi&oacute;n de examen"
#elif L==7	// it
	"Creare sessione d'esame"
#elif L==8	// pl
	"Utw&oacute;rz sesj&eogon; egzaminacyjn&aogon;"
#elif L==9	// pt
	"Criar sess&atilde;o de exame"
#elif L==10	// tr
	"S&inodot;nav oturumu olu&scedil;tur"
#endif
	,
	[ActChgExaSes] =
#if   L==1	// ca
	"Canviar sessi&oacute; d'examen"
#elif L==2	// de
	"Pr&uuml;fungssitzung &auml;ndern"
#elif L==3	// en
	"Change exam session"
#elif L==4	// es
	"Cambiar sesi&oacute;n de examen"
#elif L==5	// fr
	"Modifier session d'examen"
#elif L==6	// gn
	"Omoambue sesi&oacute;n de examen"
#elif L==7	// it
	"Cambia sessione d'esame"
#elif L==8	// pl
	"Zmieni&cacute; sesj&eogon; egzaminacyjn&aogon;"
#elif L==9	// pt
	"Alterar sess&atilde;o de exame"
#elif L==10	// tr
	"S&inodot;nav oturumu de&gbreve;i&scedil;tir"
#endif
	,
	[ActReqRemExaSes] =
#if   L==1	// ca
	"Request exam session removal"					// Necessita traducci
#elif L==2	// de
	"Request exam session removal"					// Need bersetzung
#elif L==3	// en
	"Request exam session removal"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de sesi&oacute;n de examen"
#elif L==5	// fr
	"Request exam session removal"					// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de sesi&oacute;n de examen"	// Okoteve traduccin
#elif L==7	// it
	"Request exam session removal"					// Bisogno di traduzione
#elif L==8	// pl
	"Request exam session removal"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request exam session removal"					// Precisa de traduo
#elif L==10	// tr
	"Request exam session removal"					// eviri lazim!
#endif
	,
	[ActRemExaSes] =
#if   L==1	// ca
	"Remove exam session"			// Necessita traducci
#elif L==2	// de
	"Remove exam session"			// Need bersetzung
#elif L==3	// en
	"Remove exam session"
#elif L==4	// es
	"Eliminar sesi&oacute;n de examen"
#elif L==5	// fr
	"Remove exam session"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar sesi&oacute;n de examen"	// Okoteve traduccin
#elif L==7	// it
	"Remove exam session"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove exam session"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove exam session"			// Precisa de traduo
#elif L==10	// tr
	"Remove exam session"			// eviri lazim!
#endif
	,
	[ActHidExaSes] =
#if   L==1	// ca
	"Hide exam session"			// Necessita traducci
#elif L==2	// de
	"Hide exam session"			// Need bersetzung
#elif L==3	// en
	"Hide exam session"
#elif L==4	// es
	"Ocultar sesi&oacute;n de examen"
#elif L==5	// fr
	"Ocultar sesi&oacute;n de examen"	// Besoin de traduction
#elif L==6	// gn
	"Hide exam session"			// Okoteve traduccin
#elif L==7	// it
	"Hide exam session"			// Bisogno di traduzione
#elif L==8	// pl
	"Hide exam session"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide exam session"			// Precisa de traduo
#elif L==10	// tr
	"Hide exam session"			// eviri lazim!
#endif
	,
	[ActUnhExaSes] =
#if   L==1	// ca
	"Unhide exam session"			// Necessita traducci
#elif L==2	// de
	"Unhide exam session"			// Need bersetzung
#elif L==3	// en
	"Unhide exam session"
#elif L==4	// es
	"Mostrar sesi&oacute;n de examen"
#elif L==5	// fr
	"Unhide exam session"			// Besoin de traduction
#elif L==6	// gn
	"Mostrar sesi&oacute;n de examen"	// Okoteve traduccin
#elif L==7	// it
	"Unhide exam session"			// Bisogno di traduzione
#elif L==8	// pl
	"Unhide exam session"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide exam session"			// Precisa de traduo
#elif L==10	// tr
	"Unhide exam session"			// eviri lazim!
#endif
	,
	[ActSeeExaPrn] =
#if   L==1	// ca
	"Comen&ccedil;ar / reprendre examen"
#elif L==2	// de
	"Pr&uacute;fung starten / fortsetzen"
#elif L==3	// en
	"Start / resume exam"
#elif L==4	// es
	"Comenzar / reanudar examen"
#elif L==5	// fr
	"Commencer / reprendre examen"
#elif L==6	// gn
	"Comenzar / reanudar examen"		// Okoteve traduccin
#elif L==7	// it
	"Avvia / riprendi esame"
#elif L==8	// pl
	"Rozpocznij / wzn&oacute;w egzamin"
#elif L==9	// pt
	"Iniciar / retomar exame"
#elif L==10	// tr
	"Start / resume exam"			// eviri lazim!
#endif
	,
	[ActAnsExaPrn] =
#if   L==1	// ca
	"Respondre pregunta d'examen"
#elif L==2	// de
	"Beantworten Sie die Pr&uuml;fungsfrage"
#elif L==3	// en
	"Answer exam question"
#elif L==4	// es
	"Responder pregunta de examen"
#elif L==5	// fr
	"R&eacute;pondre question d'examen"
#elif L==6	// gn
	"Responder pregunta de examen"		// Okoteve traduccin
#elif L==7	// it
	"Rispondi domanda d'esame"
#elif L==8	// pl
	"Odpowiedz pytanie egzaminacyjne"
#elif L==9	// pt
	"Responda pergunta do exame"
#elif L==10	// tr
	"Answer exam question"			// eviri lazim!
#endif
	,
	[ActEndExaPrn] =
#if   L==1	// ca
	"Finalitzar examen"
#elif L==2	// de
	"Pr&uuml;fung beenden"
#elif L==3	// en
	"End exam"
#elif L==4	// es
	"Finalizar examen"
#elif L==5	// fr
	"Terminer examen"
#elif L==6	// gn
	"Finalizar examen"			// Okoteve traduccin
#elif L==7	// it
	"Finire esame"
#elif L==8	// pl
	"Zako&nacute;czy&cacute; egzamin"
#elif L==9	// pt
	"Terminar exame"
#elif L==10	// tr
	"End exam"				// eviri lazim!
#endif
	,
	[ActSeeMyExaResCrs] =
#if   L==1	// ca
	"See my exam results"			// Necessita traducci
#elif L==2	// de
	"See my exam results"			// Need bersetzung
#elif L==3	// en
	"See my exam results"
#elif L==4	// es
	"Ver mis resultados de ex&aacute;menes"
#elif L==5	// fr
	"See my exam results"			// Besoin de traduction
#elif L==6	// gn
	"Ver mis resultados de ex&aacute;menes"	// Okoteve traduccin
#elif L==7	// it
	"See my exam results"			// Bisogno di traduzione
#elif L==8	// pl
	"See my exam results"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See my exam results"			// Precisa de traduo
#elif L==10	// tr
	"See my exam results"			// eviri lazim!
#endif
	,
	[ActSeeMyExaResExa] =
#if   L==1	// ca
	"See my results in exam"	// Necessita traducci
#elif L==2	// de
	"See my results in exam"	// Need bersetzung
#elif L==3	// en
	"See my results in exam"
#elif L==4	// es
	"Ver mis resultados en examen"
#elif L==5	// fr
	"See my results in exam"	// Besoin de traduction
#elif L==6	// gn
	"Ver mis resultados en examen"	// Okoteve traduccin
#elif L==7	// it
	"See my results in exam"	// Bisogno di traduzione
#elif L==8	// pl
	"See my results in exam"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See my results in exam"	// Precisa de traduo
#elif L==10	// tr
	"See my results in exam"	// eviri lazim!
#endif
	,
	[ActSeeMyExaResSes] =
#if   L==1	// ca
	"See my results in exam session"			// Necessita traducci
#elif L==2	// de
	"See my results in exam session"			// Need bersetzung
#elif L==3	// en
	"See my results in exam session"
#elif L==4	// es
	"Ver mis resultados en una sesi&oacute;n de examen"
#elif L==5	// fr
	"See my results in exam session"			// Besoin de traduction
#elif L==6	// gn
	"Ver mis resultados en una sesi&oacute;n de examen"	// Okoteve traduccin
#elif L==7	// it
	"See my results in exam session"			// Bisogno di traduzione
#elif L==8	// pl
	"See my results in exam session"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See my results in exam session"			// Precisa de traduo
#elif L==10	// tr
	"See my results in exam session"			// eviri lazim!
#endif
	,
	[ActSeeOneExaResMe] =
#if   L==1	// ca
	"See deatils of one of my exam results"			// Necessita traducci
#elif L==2	// de
	"See deatils of one of my exam results"			// Need bersetzung
#elif L==3	// en
	"See deatils of one of my exam results"
#elif L==4	// es
	"Ver detalles de uno de mis resultados de examen"
#elif L==5	// fr
	"See deatils of one of my exam results"			// Besoin de traduction
#elif L==6	// gn
	"Ver detalles de uno de mis resultados de examen"	// Okoteve traduccin
#elif L==7	// it
	"See deatils of one of my exam results"			// Bisogno di traduzione
#elif L==8	// pl
	"See deatils of one of my exam results"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See deatils of one of my exam results"			// Precisa de traduo
#elif L==10	// tr
	"See deatils of one of my exam results"			// eviri lazim!
#endif
	,
	[ActReqSeeUsrExaRes] =
#if   L==1	// ca
	"Select users to see all their exam results"			// Necessita traducci
#elif L==2	// de
	"Select users to see all their exam results"			// Need bersetzung
#elif L==3	// en
	"Select users to see all their exam results"
#elif L==4	// es
	"Seleccionar usuarios para ver todos sus resultados de examen"
#elif L==5	// fr
	"Select users to see all their exam results"			// Besoin de traduction
#elif L==6	// gn
	"Seleccionar usuarios para ver todos sus resultados de examen"	// Okoteve traduccin
#elif L==7	// it
	"Select users to see all their exam results"			// Bisogno di traduzione
#elif L==8	// pl
	"Select users to see all their exam results"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Select users to see all their exam results"			// Precisa de traduo
#elif L==10	// tr
	"Select users to see all their exam results"			// eviri lazim!
#endif
	,
	[ActSeeUsrExaResCrs] =
#if   L==1	// ca
	"See all exam results of selected users"			// Necessita traducci
#elif L==2	// de
	"See all exam results of selected users"			// Need bersetzung
#elif L==3	// en
	"See all exam results of selected users"
#elif L==4	// es
	"Ver todos los resultados de examen de usuarios seleccionados"
#elif L==5	// fr
	"See all exam results of selected users"			// Besoin de traduction
#elif L==6	// gn
	"Ver todos los resultados de examen de usuarios seleccionados"	// Okoteve traduccin
#elif L==7	// it
	"See all exam results of selected users"			// Bisogno di traduzione
#elif L==8	// pl
	"See all exam results of selected users"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See all exam results of selected users"			// Precisa de traduo
#elif L==10	// tr
	"See all exam results of selected users"			// eviri lazim!
#endif
	,
	[ActSeeUsrExaResExa] =
#if   L==1	// ca
	"See results of selected users in exam"			// Necessita traducci
#elif L==2	// de
	"See results of selected users in exam"			// Need bersetzung
#elif L==3	// en
	"See results of selected users in exam"
#elif L==4	// es
	"Ver resultados de usuarios seleccionados en examen"
#elif L==5	// fr
	"See results of selected users in exam"			// Besoin de traduction
#elif L==6	// gn
	"Ver resultados de usuarios seleccionados en examen"	// Okoteve traduccin
#elif L==7	// it
	"See results of selected users in exam"			// Bisogno di traduzione
#elif L==8	// pl
	"See results of selected users in exam"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See results of selected users in exam"			// Precisa de traduo
#elif L==10	// tr
	"See results of selected users in exam"			// eviri lazim!
#endif
	,
	[ActSeeUsrExaResSes] =
#if   L==1	// ca
	"See results of selected users in exam session"				// Necessita traducci
#elif L==2	// de
	"See results of selected users in exam session"				// Need bersetzung
#elif L==3	// en
	"See results of selected users in exam session"
#elif L==4	// es
	"Ver resultados de usuarios seleccionados en sesi&oacute;n de examen"
#elif L==5	// fr
	"See results of selected users in exam session"				// Besoin de traduction
#elif L==6	// gn
	"Ver resultados de usuarios seleccionados en sesi&oacute;n de examen"	// Okoteve traduccin
#elif L==7	// it
	"See results of selected users in exam session"				// Bisogno di traduzione
#elif L==8	// pl
	"See results of selected users in exam session"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See results of selected users in exam session"				// Precisa de traduo
#elif L==10	// tr
	"See results of selected users in exam session"				// eviri lazim!
#endif
	,
	[ActSeeOneExaResOth] =
#if   L==1	// ca
	"See details of one of the exam results of a user"		// Necessita traducci
#elif L==2	// de
	"See details of one of the exam results of a user"		// Need bersetzung
#elif L==3	// en
	"See details of one of the exam results of a user"
#elif L==4	// es
	"Ver detalles de uno de los resultados de examen de un usuario"
#elif L==5	// fr
	"See details of one of the exam results of a user"		// Besoin de traduction
#elif L==6	// gn
	"Ver detalles de uno de los resultados de examen de un usuario"	// Okoteve traduccin
#elif L==7	// it
	"See details of one of the exam results of a user"		// Bisogno di traduzione
#elif L==8	// pl
	"See details of one of the exam results of a user"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See details of one of the exam results of a user"		// Precisa de traduo
#elif L==10	// tr
	"See details of one of the exam results of a user"		// eviri lazim!
#endif
	,
	[ActChgVisExaRes] =
#if   L==1	// ca
	"Change visibility of exam results"		// Necessita traducci
#elif L==2	// de
	"Change visibility of exam results"		// Need bersetzung
#elif L==3	// en
	"Change visibility of exam results"
#elif L==4	// es
	"Cambiar visibilidad de resultados de examen"
#elif L==5	// fr
	"Change visibility of exam results"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar visibilidad de resultados de examen"	// Okoteve traduccin
#elif L==7	// it
	"Change visibility of exam results"		// Bisogno di traduzione
#elif L==8	// pl
	"Change visibility of exam results"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change visibility of exam results"		// Precisa de traduo
#elif L==10	// tr
	"Change visibility of exam results"		// eviri lazim!
#endif
	,
	[ActSeeAllGam] =
#if   L==1	// ca
	"See games"		// Necessita traducci
#elif L==2	// de
	"See games"		// Need bersetzung
#elif L==3	// en
	"See games"
#elif L==4	// es
	"Ver juegos"
#elif L==5	// fr
	"See games"		// Besoin de traduction
#elif L==6	// gn
	"Ver juegos"		// Okoteve traduccin
#elif L==7	// it
	"See games"		// Bisogno di traduzione
#elif L==8	// pl
	"See games"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See games"		// Precisa de traduo
#elif L==10	// tr
	"See games"		// eviri lazim!
#endif
	,
	[ActSeeOneGam] =
#if   L==1	// ca
	"See game"	// Necessita traducci
#elif L==2	// de
	"See game"	// Need bersetzung
#elif L==3	// en
	"See game"
#elif L==4	// es
	"Ver juego"
#elif L==5	// fr
	"See game"	// Besoin de traduction
#elif L==6	// gn
	"Ver juego"	// Okoteve traduccin
#elif L==7	// it
	"See game"	// Bisogno di traduzione
#elif L==8	// pl
	"See game"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See game"	// Precisa de traduo
#elif L==10	// tr
	"See game"	// eviri lazim!
#endif
	,
	[ActReqNewMch] =
#if   L==1	// ca
	"Request creation of new match"			// Necessita traducci
#elif L==2	// de
	"Request creation of new match"			// Need bersetzung
#elif L==3	// en
	"Request creation of new match"
#elif L==4	// es
	"Solicitar creaci&oacute;n de nueva partida"
#elif L==5	// fr
	"Request creation of new match"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar creaci&oacute;n de nueva partida"	// Okoteve traduccin
#elif L==7	// it
	"Request creation of new match"			// Bisogno di traduzione
#elif L==8	// pl
	"Request creation of new match"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request creation of new match"			// Precisa de traduo
#elif L==10	// tr
	"Request creation of new match"			// eviri lazim!
#endif
	,
	[ActReqChgMch] =
#if   L==1	// ca
	"Request edition of match"			// Necessita traducci
#elif L==2	// de
	"Request edition of match"			// Need bersetzung
#elif L==3	// en
	"Request edition of match"
#elif L==4	// es
	"Solicitar creaci&oacute;n de nueva partida"
#elif L==5	// fr
	"Request edition of match"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar creaci&oacute;n de nueva partida"	// Okoteve traduccin
#elif L==7	// it
	"Request edition of match"			// Bisogno di traduzione
#elif L==8	// pl
	"Request edition of match"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request edition of match"			// Precisa de traduo
#elif L==10	// tr
	"Request edition of match"			// eviri lazim!
#endif
	,
	[ActNewMch] =
#if   L==1	// ca
	"Create new match and show it in another tab"			// Necessita traducci
#elif L==2	// de
	"Create new match and show it in another tab"			// Need bersetzung
#elif L==3	// en
	"Create new match and show it in another tab"
#elif L==4	// es
	"Crear nueva partida y mostrarla en otra pesta&ntilde;a"
#elif L==5	// fr
	"Create new match and show it in another tab"			// Besoin de traduction
#elif L==6	// gn
	"Crear nueva partida y mostrarla en otra pesta&ntilde;a"	// Okoteve traduccin
#elif L==7	// it
	"Create new match and show it in another tab"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new match and show it in another tab"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new match and show it in another tab"			// Precisa de traduo
#elif L==10	// tr
	"Create new match and show it in another tab"			// eviri lazim!
#endif
	,
	[ActChgMch] =
#if   L==1	// ca
	"Change match"		// Necessita traducci
#elif L==2	// de
	"Change match"		// Need bersetzung
#elif L==3	// en
	"Change match"
#elif L==4	// es
	"Cambiar partida"
#elif L==5	// fr
	"Change match"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar partida"	// Okoteve traduccin
#elif L==7	// it
	"Change match"		// Bisogno di traduzione
#elif L==8	// pl
	"Change match"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change match"		// Precisa de traduo
#elif L==10	// tr
	"Change match"		// eviri lazim!
#endif
	,
	[ActReqRemMch] =
#if   L==1	// ca
	"Request removal of match"			// Necessita traducci
#elif L==2	// de
	"Request removal of match"			// Need bersetzung
#elif L==3	// en
	"Request removal of match"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de partida"
#elif L==5	// fr
	"Request removal of match"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de partida"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of match"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of match"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of match"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of match"			// eviri lazim!
#endif
	,
	[ActRemMch] =
#if   L==1	// ca
	"Eliminar partida"
#elif L==2	// de
	"Spiel entfernen"
#elif L==3	// en
	"Remove match"
#elif L==4	// es
	"Eliminar partida"
#elif L==5	// fr
	"Supprimer match"
#elif L==6	// gn
	"Eliminar partida"	// Okoteve traduccin
#elif L==7	// it
	"Rimuovere partita"
#elif L==8	// pl
	"Usu&nacute; mecz"
#elif L==9	// pt
	"Remover jogo"
#elif L==10	// tr
	"E&scedil;le&scedil;meyi kald&inodot;r"
#endif
	,
	[ActResMch] =
#if   L==1	// ca
	"Resume match showing current question in another tab"			// Necessita traducci
#elif L==2	// de
	"Resume match showing current question in another tab"			// Need bersetzung
#elif L==3	// en
	"Resume match showing current question in another tab"
#elif L==4	// es
	"Reanudar partida mostrando la pregunta actual en otra pesta&ntilde;a"
#elif L==5	// fr
	"Resume match showing current question in another tab"			// Besoin de traduction
#elif L==6	// gn
	"Reanudar partida mostrando la pregunta actual en otra pesta&ntilde;a"	// Okoteve traduccin
#elif L==7	// it
	"Resume match showing current question in another tab"			// Bisogno di traduzione
#elif L==8	// pl
	"Resume match showing current question in another tab"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Resume match showing current question in another tab"			// Precisa de traduo
#elif L==10	// tr
	"Resume match showing current question in another tab"			// eviri lazim!
#endif
	,
	[ActBckMch] =
#if   L==1	// ca
	"Go back when playing a match"			// Necessita traducci
#elif L==2	// de
	"Go back when playing a match"			// Need bersetzung
#elif L==3	// en
	"Go back when playing a match"
#elif L==4	// es
	"Ir atr&aacute;s mientras se juega una partida"
#elif L==5	// fr
	"Go back when playing a match"			// Besoin de traduction
#elif L==6	// gn
	"Ir atr&aacute;s mientras se juega una partida"	// Okoteve traduccin
#elif L==7	// it
	"Go back when playing a match"			// Bisogno di traduzione
#elif L==8	// pl
	"Go back when playing a match"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Go back when playing a match"			// Precisa de traduo
#elif L==10	// tr
	"Go back when playing a match"			// eviri lazim!
#endif
	,
	[ActPlyPauMch] =
#if   L==1	// ca
	"Play/pause current match"	// Necessita traducci
#elif L==2	// de
	"Play/pause current match"	// Need bersetzung
#elif L==3	// en
	"Play/pause current match"
#elif L==4	// es
	"Jugar/pausar partida actual"
#elif L==5	// fr
	"Play/pause current match"	// Besoin de traduction
#elif L==6	// gn
	"Jugar/pausar partida actual"	// Okoteve traduccin
#elif L==7	// it
	"Play/pause current match"	// Bisogno di traduzione
#elif L==8	// pl
	"Play/pause current match"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Play/pause current match"	// Precisa de traduo
#elif L==10	// tr
	"Play/pause current match"	// eviri lazim!
#endif
	,
	[ActFwdMch] =
#if   L==1	// ca
	"Go forward when playing a match"		// Necessita traducci
#elif L==2	// de
	"Go forward when playing a match"		// Need bersetzung
#elif L==3	// en
	"Go forward when playing a match"
#elif L==4	// es
	"Ir adelante mientras se juega una partida"
#elif L==5	// fr
	"Go forward when playing a match"		// Besoin de traduction
#elif L==6	// gn
	"Ir adelante mientras se juega una partida"	// Okoteve traduccin
#elif L==7	// it
	"Go forward when playing a match"		// Bisogno di traduzione
#elif L==8	// pl
	"Go forward when playing a match"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Go forward when playing a match"		// Precisa de traduo
#elif L==10	// tr
	"Go forward when playing a match"		// eviri lazim!
#endif
	,
	[ActChgNumColMch] =
#if   L==1	// ca
	"Change number of columns when playing a match"				// Necessita traducci
#elif L==2	// de
	"Change number of columns when playing a match"				// Need bersetzung
#elif L==3	// en
	"Change number of columns when playing a match"
#elif L==4	// es
	"Cambiar n&uacute;mero de columnas mientras se juega una partida"
#elif L==5	// fr
	"Change number of columns when playing a match"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar n&uacute;mero de columnas mientras se juega una partida"	// Okoteve traduccin
#elif L==7	// it
	"Change number of columns when playing a match"				// Bisogno di traduzione
#elif L==8	// pl
	"Change number of columns when playing a match"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change number of columns when playing a match"				// Precisa de traduo
#elif L==10	// tr
	"Change number of columns when playing a match"				// eviri lazim!
#endif
	,
	[ActChgVisResMchQst] =
#if   L==1	// ca
	"Change visibility of question results when playing a match"				// Necessita traducci
#elif L==2	// de
	"Change visibility of question results when playing a match"				// Need bersetzung
#elif L==3	// en
	"Change visibility of question results when playing a match"
#elif L==4	// es
	"Cambiar visibilidad de los resultados de pregunta mientras se juega una partida"
#elif L==5	// fr
	"Change visibility of question results when playing a match"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar visibilidad de los resultados de pregunta mientras se juega una partida"	// Okoteve traduccin
#elif L==7	// it
	"Change visibility of question results when playing a match"				// Bisogno di traduzione
#elif L==8	// pl
	"Change visibility of question results when playing a match"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change visibility of question results when playing a match"				// Precisa de traduo
#elif L==10	// tr
	"Change visibility of question results when playing a match"				// eviri lazim!
#endif
	,
	[ActMchCntDwn] =
#if   L==1	// ca
	"Start match countdown"					// Necessita traducci
#elif L==2	// de
	"Start match countdown"					// Need bersetzung
#elif L==3	// en
	"Start match countdown"
#elif L==4	// es
	"Comenzar la cuenta atr&aacute;s en una partida"
#elif L==5	// fr
	"Start match countdown"					// Besoin de traduction
#elif L==6	// gn
	"Comenzar la cuenta atr&aacute;s en una partida"	// Okoteve traduccin
#elif L==7	// it
	"Start match countdown"					// Bisogno di traduzione
#elif L==8	// pl
	"Start match countdown"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Start match countdown"					// Precisa de traduo
#elif L==10	// tr
	"Start match countdown"					// eviri lazim!
#endif
	,
	[ActRefMchTch] =
#if   L==1	// ca
	"Refresh current question when playing a match (as teacher)"			// Necessita traducci
#elif L==2	// de
	"Refresh current question when playing a match (as teacher)"			// Need bersetzung
#elif L==3	// en
	"Refresh current question when playing a match (as teacher)"
#elif L==4	// es
	"Refrescar pregunta actual mientras se juega una partida (como profesor)"
#elif L==5	// fr
	"Refresh current question when playing a match (as teacher)"			// Besoin de traduction
#elif L==6	// gn
	"Refrescar pregunta actual mientras se juega una partida (como profesor)"	// Okoteve traduccin
#elif L==7	// it
	"Refresh current question when playing a match (as teacher)"			// Bisogno di traduzione
#elif L==8	// pl
	"Refresh current question when playing a match (as teacher)"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Refresh current question when playing a match (as teacher)"			// Precisa de traduo
#elif L==10	// tr
	"Refresh current question when playing a match (as teacher)"			// eviri lazim!
#endif
	,
	[ActJoiMch] =
#if   L==1	// ca
	"Show current question when playing a match (as student)"			// Necessita traducci
#elif L==2	// de
	"Show current question when playing a match (as student)"			// Need bersetzung
#elif L==3	// en
	"Show current question when playing a match (as student)"
#elif L==4	// es
	"Refrescar pregunta actual mientras se juega una partida (como estudiante)"
#elif L==5	// fr
	"Show current question when playing a match (as student)"			// Besoin de traduction
#elif L==6	// gn
	"Refrescar pregunta actual mientras se juega una partida (como estudiante)"	// Okoteve traduccin
#elif L==7	// it
	"Show current question when playing a match (as student)"			// Bisogno di traduzione
#elif L==8	// pl
	"Show current question when playing a match (as student)"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show current question when playing a match (as student)"			// Precisa de traduo
#elif L==10	// tr
	"Show current question when playing a match (as student)"			// eviri lazim!
#endif
	,
	[ActSeeMchAnsQstStd] =
#if   L==1	// ca
	"View my answer to match question"		// Necessita traducci
#elif L==2	// de
	"View my answer to match question"		// Need bersetzung
#elif L==3	// en
	"View my answer to match question"
#elif L==4	// es
	"Ver mi respuesta a pregunta de partida"
#elif L==5	// fr
	"View my answer to match question"		// Besoin de traduction
#elif L==6	// gn
	"Ver mi respuesta a pregunta de partida"	// Okoteve traduccin
#elif L==7	// it
	"View my answer to match question"		// Bisogno di traduzione
#elif L==8	// pl
	"View my answer to match question"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"View my answer to match question"		// Precisa de traduo
#elif L==10	// tr
	"View my answer to match question"		// eviri lazim!
#endif
	,
	[ActRemMchAnsQstStd] =
#if   L==1	// ca
	"Remove my answer to match question"		// Necessita traducci
#elif L==2	// de
	"Remove my answer to match question"		// Need bersetzung
#elif L==3	// en
	"Remove my answer to match question"
#elif L==4	// es
	"Eliminar mi respuesta a pregunta de partida"
#elif L==5	// fr
	"Remove my answer to match question"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar mi respuesta a pregunta de partida"	// Okoteve traduccin
#elif L==7	// it
	"Remove my answer to match question"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove my answer to match question"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove my answer to match question"		// Precisa de traduo
#elif L==10	// tr
	"Remove my answer to match question"		// eviri lazim!
#endif
	,
	[ActAnsMchQstStd] =
#if   L==1	// ca
	"Answer match question"		// Necessita traducci
#elif L==2	// de
	"Answer match question"		// Need bersetzung
#elif L==3	// en
	"Answer match question"
#elif L==4	// es
	"Responder pregunta de partida"
#elif L==5	// fr
	"Answer match question"		// Besoin de traduction
#elif L==6	// gn
	"Responder pregunta de partida"	// Okoteve traduccin
#elif L==7	// it
	"Answer match question"		// Bisogno di traduzione
#elif L==8	// pl
	"Answer match question"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Answer match question"		// Precisa de traduo
#elif L==10	// tr
	"Answer match question"		// eviri lazim!
#endif
	,
	[ActRefMchStd] =
#if   L==1	// ca
	"Refresh current question while playing a match (as student)"			// Necessita traducci
#elif L==2	// de
	"Refresh current question while playing a match (as student)"			// Need bersetzung
#elif L==3	// en
	"Refresh current question while playing a match (as student)"
#elif L==4	// es
	"Refrescar pregunta actual mientras se juega una partida (como estudiante)"
#elif L==5	// fr
	"Refresh current question while playing a match (as student)"			// Besoin de traduction
#elif L==6	// gn
	"Refrescar pregunta actual mientras se juega una partida (como estudiante)"	// Okoteve traduccin
#elif L==7	// it
	"Refresh current question while playing a match (as student)"			// Bisogno di traduzione
#elif L==8	// pl
	"Refresh current question while playing a match (as student)"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Refresh current question while playing a match (as student)"			// Precisa de traduo
#elif L==10	// tr
	"Refresh current question while playing a match (as student)"			// eviri lazim!
#endif
	,
	[ActSeeMyMchResCrs] =
#if   L==1	// ca
	"See all my matches results"		// Necessita traducci
#elif L==2	// de
	"See all my matches results"		// Need bersetzung
#elif L==3	// en
	"See all my matches results"
#elif L==4	// es
	"Ver todos mis resultados en partidas"
#elif L==5	// fr
	"See all my matches results"		// Besoin de traduction
#elif L==6	// gn
	"Ver todos mis resultados en partidas"	// Okoteve traduccin
#elif L==7	// it
	"See all my matches results"		// Bisogno di traduzione
#elif L==8	// pl
	"See all my matches results"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See all my matches results"		// Precisa de traduo
#elif L==10	// tr
	"See all my matches results"		// eviri lazim!
#endif
	,
	[ActSeeMyMchResGam] =
#if   L==1	// ca
	"See all my matches results in game"		// Necessita traducci
#elif L==2	// de
	"See all my matches results in game"		// Need bersetzung
#elif L==3	// en
	"See all my matches results in game"
#elif L==4	// es
	"Ver todos mis resultados en partidas de juego"
#elif L==5	// fr
	"See all my matches results in game"		// Besoin de traduction
#elif L==6	// gn
	"Ver todos mis resultados en partidas de juego"	// Okoteve traduccin
#elif L==7	// it
	"See all my matches results in game"		// Bisogno di traduzione
#elif L==8	// pl
	"See all my matches results in game"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See all my matches results in game"		// Precisa de traduo
#elif L==10	// tr
	"See all my matches results in game"		// eviri lazim!
#endif
	,
	[ActSeeMyMchResMch] =
#if   L==1	// ca
	"See my results in match"	// Necessita traducci
#elif L==2	// de
	"See my results in match"	// Need bersetzung
#elif L==3	// en
	"See my results in match"
#elif L==4	// es
	"Ver mis resultados en partida"
#elif L==5	// fr
	"See my results in match"	// Besoin de traduction
#elif L==6	// gn
	"Ver mis resultados en partida"	// Okoteve traduccin
#elif L==7	// it
	"See my results in match"	// Bisogno di traduzione
#elif L==8	// pl
	"See my results in match"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See my results in match"	// Precisa de traduo
#elif L==10	// tr
	"See my results in match"	// eviri lazim!
#endif
	,
	[ActSeeOneMchResMe] =
#if   L==1	// ca
	"See details of match result mine as student"				// Necessita traducci
#elif L==2	// de
	"See details of match result mine as student"				// Need bersetzung
#elif L==3	// en
	"See details of match result mine as student"
#elif L==4	// es
	"Ver detalles del resultado de una partida m&iacute;a como estudiante"
#elif L==5	// fr
	"See details of match result mine as student"				// Besoin de traduction
#elif L==6	// gn
	"Ver detalles del resultado de una partida m&iacute;a como estudiante"	// Okoteve traduccin
#elif L==7	// it
	"See details of match result mine as student"				// Bisogno di traduzione
#elif L==8	// pl
	"See details of match result mine as student"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See details of match result mine as student"				// Precisa de traduo
#elif L==10	// tr
	"See details of match result mine as student"				// eviri lazim!
#endif
	,
	[ActReqSeeUsrMchRes] =
#if   L==1	// ca
	"Select users and range of dates to see matches results"			// Necessita traducci
#elif L==2	// de
	"Select users and range of dates to see matches results"			// Need bersetzung
#elif L==3	// en
	"Select users and range of dates to see matches results"
#elif L==4	// es
	"Seleccionar usuarios y rango de fechas para ver resultados de partidas"
#elif L==5	// fr
	"Select users and range of dates to see matches results"			// Besoin de traduction
#elif L==6	// gn
	"Seleccionar usuarios y rango de fechas para ver resultados de partidas"	// Okoteve traduccin
#elif L==7	// it
	"Select users and range of dates to see matches results"			// Bisogno di traduzione
#elif L==8	// pl
	"Select users and range of dates to see matches results"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Select users and range of dates to see matches results"			// Precisa de traduo
#elif L==10	// tr
	"Select users and range of dates to see matches results"			// eviri lazim!
#endif
	,
	[ActSeeUsrMchResCrs] =
#if   L==1	// ca
	"See all matches results of selected users"					// Necessita traducci
#elif L==2	// de
	"See all matches results of selected users"					// Need bersetzung
#elif L==3	// en
	"See all matches results of selected users"
#elif L==4	// es
	"Ver los resultados de todas las partidas de los usuarios seleccionados"
#elif L==5	// fr
	"See all matches results of selected users"					// Besoin de traduction
#elif L==6	// gn
	"Ver los resultados de todas las partidas de los usuarios seleccionados"	// Okoteve traduccin
#elif L==7	// it
	"See all matches results of selected users"					// Bisogno di traduzione
#elif L==8	// pl
	"See all matches results of selected users"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See all matches results of selected users"					// Precisa de traduo
#elif L==10	// tr
	"See all matches results of selected users"					// eviri lazim!
#endif
	,
	[ActSeeUsrMchResGam] =
#if   L==1	// ca
	"See all matches results in game"		// Necessita traducci
#elif L==2	// de
	"See all matches results in game"		// Need bersetzung
#elif L==3	// en
	"See all matches results in game"
#elif L==4	// es
	"Ver resultados de todas las partidas de un juego"
#elif L==5	// fr
	"See all matches results in game"		// Besoin de traduction
#elif L==6	// gn
	"Ver resultados de todas las partidas de un juego"	// Okoteve traduccin
#elif L==7	// it
	"See all matches results in game"		// Bisogno di traduzione
#elif L==8	// pl
	"See all matches results in game"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See all matches results in game"		// Precisa de traduo
#elif L==10	// tr
	"See all matches results in game"		// eviri lazim!
#endif
	,
	[ActSeeUsrMchResMch] =
#if   L==1	// ca
	"See user's results in match"		// Necessita traducci
#elif L==2	// de
	"See user's results in match"		// Need bersetzung
#elif L==3	// en
	"See user's results in match"
#elif L==4	// es
	"Ver resultados de usuario en partida"
#elif L==5	// fr
	"See user's results in match"		// Besoin de traduction
#elif L==6	// gn
	"Ver resultados de usuario en partida"	// Okoteve traduccin
#elif L==7	// it
	"See user's results in match"		// Bisogno di traduzione
#elif L==8	// pl
	"See user's results in match"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See user's results in match"		// Precisa de traduo
#elif L==10	// tr
	"See user's results in match"		// eviri lazim!
#endif
	,
	[ActSeeOneMchResOth] =
#if   L==1	// ca
	"See details of match result of a user"			// Necessita traducci
#elif L==2	// de
	"See details of match result of a user"			// Need bersetzung
#elif L==3	// en
	"See details of match result of a user"
#elif L==4	// es
	"Ver detalles del resultado de partida de un usuario"
#elif L==5	// fr
	"See details of match result of a user"			// Besoin de traduction
#elif L==6	// gn
	"Ver detalles del resultado de partida de un usuario"	// Okoteve traduccin
#elif L==7	// it
	"See details of match result of a user"			// Bisogno di traduzione
#elif L==8	// pl
	"See details of match result of a user"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See details of match result of a user"			// Precisa de traduo
#elif L==10	// tr
	"See details of match result of a user"			// eviri lazim!
#endif
	,
	[ActChgVisResMchUsr] =
#if   L==1	// ca
	"Change visibility of match results"			// Necessita traducci
#elif L==2	// de
	"Change visibility of match results"			// Need bersetzung
#elif L==3	// en
	"Change visibility of match results"
#elif L==4	// es
	"Cambiar visibilidad de los resultados de partidas"
#elif L==5	// fr
	"Change visibility of match results"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar visibilidad de los resultados de partidas"	// Okoteve traduccin
#elif L==7	// it
	"Change visibility of match results"			// Bisogno di traduzione
#elif L==8	// pl
	"Change visibility of match results"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change visibility of match results"			// Precisa de traduo
#elif L==10	// tr
	"Change visibility of match results"			// eviri lazim!
#endif
	,
	[ActLstOneGam] =
#if   L==1	// ca
	"View game and its questions"	// Necessita traducci
#elif L==2	// de
	"View game and its questions"	// Need bersetzung
#elif L==3	// en
	"View game and its questions"
#elif L==4	// es
	"Ver juego y sus preguntas"
#elif L==5	// fr
	"View game and its questions"	// Besoin de traduction
#elif L==6	// gn
	"Ver juego y sus preguntas"	// Okoteve traduccin
#elif L==7	// it
	"View game and its questions"	// Bisogno di traduzione
#elif L==8	// pl
	"View game and its questions"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"View game and its questions"	// Precisa de traduo
#elif L==10	// tr
	"View game and its questions"	// eviri lazim!
#endif
	,
	[ActFrmNewGam] =
#if   L==1	// ca
	"Edit new game"		// Necessita traducci
#elif L==2	// de
	"Edit new game"		// Need bersetzung
#elif L==3	// en
	"Edit new game"
#elif L==4	// es
	"Editar nuevo juego"
#elif L==5	// fr
	"Edit new game"		// Besoin de traduction
#elif L==6	// gn
	"Editar nuevo juego"	// Okoteve traduccin
#elif L==7	// it
	"Edit new game"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit new game"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new game"		// Precisa de traduo
#elif L==10	// tr
	"Edit new game"		// eviri lazim!
#endif
	,
	[ActEdiOneGam] =
#if   L==1	// ca
	"Edit game"	// Necessita traducci
#elif L==2	// de
	"Edit game"	// Need bersetzung
#elif L==3	// en
	"Edit game"
#elif L==4	// es
	"Editar juego"
#elif L==5	// fr
	"Edit game"	// Besoin de traduction
#elif L==6	// gn
	"Editar juego"	// Okoteve traduccin
#elif L==7	// it
	"Edit game"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit game"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit game"	// Precisa de traduo
#elif L==10	// tr
	"Edit game"	// eviri lazim!
#endif
	,
	[ActNewGam] =
#if   L==1	// ca
	"Crear joc"
#elif L==2	// de
	"Spiel erstellen"
#elif L==3	// en
	"Create game"
#elif L==4	// es
	"Crear juego"
#elif L==5	// fr
	"Cr&eacute;er jeu"
#elif L==6	// gn
	"Crear juego"	// Okoteve traduccin
#elif L==7	// it
	"Creare gioco"
#elif L==8	// pl
	"Utw&oacute;rz gra"
#elif L==9	// pt
	"Criar jogo"
#elif L==10	// tr
	"Create game"	// eviri lazim!
#endif
	,
	[ActChgGam] =
#if   L==1	// ca
	"Change game"	// Necessita traducci
#elif L==2	// de
	"Change game"	// Need bersetzung
#elif L==3	// en
	"Change game"
#elif L==4	// es
	"Cambiar juego"
#elif L==5	// fr
	"Change game"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar juego"	// Okoteve traduccin
#elif L==7	// it
	"Change game"	// Bisogno di traduzione
#elif L==8	// pl
	"Change game"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change game"	// Precisa de traduo
#elif L==10	// tr
	"Change game"	// eviri lazim!
#endif
	,
	[ActReqRemGam] =
#if   L==1	// ca
	"Request removal of game"		// Necessita traducci
#elif L==2	// de
	"Request removal of game"		// Need bersetzung
#elif L==3	// en
	"Request removal of game"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de juego"
#elif L==5	// fr
	"Request removal of game"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de juego"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of game"		// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of game"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of game"		// Precisa de traduo
#elif L==10	// tr
	"Request removal of game"		// eviri lazim!
#endif
	,
	[ActRemGam] =
#if   L==1	// ca
	"Eliminar joc"
#elif L==2	// de
	"Spiel entfernen"
#elif L==3	// en
	"Remove game"
#elif L==4	// es
	"Eliminar juego"
#elif L==5	// fr
	"Supprimer jeu"
#elif L==6	// gn
	"Eliminar juego"	// Okoteve traduccin
#elif L==7	// it
	"Rimuovere gioco"
#elif L==8	// pl
	"Usu&nacute; gra"
#elif L==9	// pt
	"Remover jogo"
#elif L==10	// tr
	"Oyunu kald&inodot;r"
#endif
	,
	[ActHidGam] =
#if   L==1	// ca
	"Hide game"	// Necessita traducci
#elif L==2	// de
	"Hide game"	// Need bersetzung
#elif L==3	// en
	"Hide game"
#elif L==4	// es
	"Ocultar juego"
#elif L==5	// fr
	"Hide game"	// Besoin de traduction
#elif L==6	// gn
	"Ocultar juego"	// Okoteve traduccin
#elif L==7	// it
	"Hide game"	// Bisogno di traduzione
#elif L==8	// pl
	"Hide game"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide game"	// Precisa de traduo
#elif L==10	// tr
	"Hide game"	// eviri lazim!
#endif
	,
	[ActUnhGam] =
#if   L==1	// ca
	"Show game"	// Necessita traducci
#elif L==2	// de
	"Show game"	// Need bersetzung
#elif L==3	// en
	"Show game"
#elif L==4	// es
	"Mostrar juego"
#elif L==5	// fr
	"Show game"	// Besoin de traduction
#elif L==6	// gn
	"Mostrar juego"	// Okoteve traduccin
#elif L==7	// it
	"Show game"	// Bisogno di traduzione
#elif L==8	// pl
	"Show game"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show game"	// Precisa de traduo
#elif L==10	// tr
	"Show game"	// eviri lazim!
#endif
	,
	[ActAddOneGamQst] =
#if   L==1	// ca
	"Add new question to game"			// Necessita traducci
#elif L==2	// de
	"Add new question to game"			// Need bersetzung
#elif L==3	// en
	"Add new question to game"
#elif L==4	// es
	"A&ntilde;adir una nueva pregunta a juego"
#elif L==5	// fr
	"Add new question to game"			// Besoin de traduction
#elif L==6	// gn
	"A&ntilde;adir una nueva pregunta a juego"	// Okoteve traduccin
#elif L==7	// it
	"Add new question to game"			// Bisogno di traduzione
#elif L==8	// pl
	"Add new question to game"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Add new question to game"			// Precisa de traduo
#elif L==10	// tr
	"Add new question to game"			// eviri lazim!
#endif
	,
	[ActGamLstTstQst] =
#if   L==1	// ca
	"List questions to add some of them to game"			// Necessita traducci
#elif L==2	// de
	"List questions to add some of them to game"			// Need bersetzung
#elif L==3	// en
	"List questions to add some of them to game"
#elif L==4	// es
	"Listar preguntas para a&ntilde;adir algunas de ellas a juego"
#elif L==5	// fr
	"List questions to add some of them to game"			// Besoin de traduction
#elif L==6	// gn
	"Listar preguntas para a&ntilde;adir algunas de ellas a juego"	// Okoteve traduccin
#elif L==7	// it
	"List questions to add some of them to game"			// Bisogno di traduzione
#elif L==8	// pl
	"List questions to add some of them to game"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List questions to add some of them to game"			// Precisa de traduo
#elif L==10	// tr
	"List questions to add some of them to game"			// eviri lazim!
#endif
	,
	[ActAddTstQstToGam] =
#if   L==1	// ca
	"Add selected test questions to game"		// Necessita traducci
#elif L==2	// de
	"Add selected test questions to game"		// Need bersetzung
#elif L==3	// en
	"Add selected test questions to game"
#elif L==4	// es
	"A&ntilde;adir preguntas seleccionadas a juego"
#elif L==5	// fr
	"Add selected test questions to game"		// Besoin de traduction
#elif L==6	// gn
	"A&ntilde;adir preguntas seleccionadas a juego"	// Okoteve traduccin
#elif L==7	// it
	"Add selected test questions to game"		// Bisogno di traduzione
#elif L==8	// pl
	"Add selected test questions to game"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Add selected test questions to game"		// Precisa de traduo
#elif L==10	// tr
	"Add selected test questions to game"		// eviri lazim!
#endif
	,
	[ActReqRemGamQst] =
#if   L==1	// ca
	"Request removal of game question"			// Necessita traducci
#elif L==2	// de
	"Request removal of game question"			// Need bersetzung
#elif L==3	// en
	"Request removal of game question"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de pregunta de juego"
#elif L==5	// fr
	"Request removal of game question"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de pregunta de un juego"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of game question"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of game question"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of game question"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of game question"			// eviri lazim!
#endif
	,
	[ActRemGamQst] =
#if   L==1	// ca
	"Confirm removal of game question"			// Necessita traducci
#elif L==2	// de
	"Confirm removal of game question"			// Need bersetzung
#elif L==3	// en
	"Confirm removal of game question"
#elif L==4	// es
	"Confirmar eliminaci&oacute;n de pregunta de juego"
#elif L==5	// fr
	"Confirm removal of game question"			// Besoin de traduction
#elif L==6	// gn
	"Confirmar eliminaci&oacute;n de pregunta de juego"	// Okoteve traduccin
#elif L==7	// it
	"Confirm removal of game question"			// Bisogno di traduzione
#elif L==8	// pl
	"Confirm removal of game question"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Confirm removal of game question"			// Precisa de traduo
#elif L==10	// tr
	"Confirm removal of game question"			// eviri lazim!
#endif
	,
	[ActUp_GamQst] =
#if   L==1	// ca
	"Move up game question"			// Necessita traducci
#elif L==2	// de
	"Move up game question"			// Need bersetzung
#elif L==3	// en
	"Move up game question"
#elif L==4	// es
	"Mover hacia arriba pregunta de juego"
#elif L==5	// fr
	"Move up game question"			// Besoin de traduction
#elif L==6	// gn
	"Mover hacia arriba pregunta de juego"	// Okoteve traduccin
#elif L==7	// it
	"Move up game question"			// Bisogno di traduzione
#elif L==8	// pl
	"Move up game question"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Move up game question"			// Precisa de traduo
#elif L==10	// tr
	"Move up game question"			// eviri lazim!
#endif
	,
	[ActDwnGamQst] =
#if   L==1	// ca
	"Move down game question"		// Necessita traducci
#elif L==2	// de
	"Move down game question"		// Need bersetzung
#elif L==3	// en
	"Move down game question"
#elif L==4	// es
	"Mover hacia abajo pregunta de juego"
#elif L==5	// fr
	"Move down game question"		// Besoin de traduction
#elif L==6	// gn
	"Mover hacia abajo pregunta de juego"	// Okoteve traduccin
#elif L==7	// it
	"Move down game question"		// Bisogno di traduzione
#elif L==8	// pl
	"Move down game question"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Move down game question"		// Precisa de traduo
#elif L==10	// tr
	"Move down game question"		// eviri lazim!
#endif
	,
	[ActReqLnkGam] =
#if   L==1	// ca
	"Copy link to game"	// Necessita traducci
#elif L==2	// de
	"Copy link to game"	// Need bersetzung
#elif L==3	// en
	"Copy link to game"
#elif L==4	// es
	"Copiar enlace a juego"
#elif L==5	// fr
	"Copy link to game"	// Besoin de traduction
#elif L==6	// gn
	"Copiar enlace a juego"	// Okoteve traduccin
#elif L==7	// it
	"Copy link to game"	// Bisogno di traduzione
#elif L==8	// pl
	"Copy link to game"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Copy link to game"	// Precisa de traduo
#elif L==10	// tr
	"Copy link to game"	// eviri lazim!
#endif
	,
	[ActSeeAllRub] =
#if   L==1	// ca
	"See rubrics"		// Necessita traducci
#elif L==2	// de
	"See rubrics"		// Need bersetzung
#elif L==3	// en
	"See rubrics"
#elif L==4	// es
	"Ver r&uacute;bricas"
#elif L==5	// fr
	"See rubrics"		// Besoin de traduction
#elif L==6	// gn
	"Ver r&uacute;bricas"	// Okoteve traduccin
#elif L==7	// it
	"See rubrics"		// Bisogno di traduzione
#elif L==8	// pl
	"See rubrics"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See rubrics"		// Precisa de traduo
#elif L==10	// tr
	"See rubrics"		// eviri lazim!
#endif
	,
	[ActSeeOneRub] =
#if   L==1	// ca
	"Veure r&uacute;brica"
#elif L==2	// de
	"Siehe Rubrik"
#elif L==3	// en
	"See rubric"
#elif L==4	// es
	"Ver r&uacute;brica"
#elif L==5	// fr
	"Voir rubrique"
#elif L==6	// gn
	"Ehecha r&uacute;brica"
#elif L==7	// it
	"Vedi rubrica"
#elif L==8	// pl
	"Zobacz rubryk&eogon;"
#elif L==9	// pt
	"Ver rubrica"
#elif L==10	// tr
	"De&gbreve;erlendirme tablosuna bak&inodot;n"
#endif
	,
	[ActFrmNewRub] =
#if   L==1	// ca
	"Editar nova r&uacute;brica"
#elif L==2	// de
	"Neue Rubrik bearbeiten"
#elif L==3	// en
	"Edit new rubric"
#elif L==4	// es
	"Editar nueva r&uacute;brica"
#elif L==5	// fr
	"Modifier nouvelle rubrique"
#elif L==6	// gn
	"Emohenda r&uacute;brica pyahu"
#elif L==7	// it
	"Modificare nuova rubrica"
#elif L==8	// pl
	"Edytuj now&aogon; rubryk&eogon;"
#elif L==9	// pt
	"Editar nova rubrica"
#elif L==10	// tr
	"Yeni puan anahtar&inodot;n&inodot; d&uacute;zenle"
#endif
	,
	[ActEdiOneRub] =
#if   L==1	// ca
	"Editar r&uacute;brica"
#elif L==2	// de
	"Rubrik bearbeiten"
#elif L==3	// en
	"Edit rubric"
#elif L==4	// es
	"Editar r&uacute;brica"
#elif L==5	// fr
	"Modifier rubrique"
#elif L==6	// gn
	"Editar r&uacute;brica rehegua"
#elif L==7	// it
	"Modificare rubrica"
#elif L==8	// pl
	"Edytuj rubryk&eogon;"
#elif L==9	// pt
	"Editar rubrica"
#elif L==10	// tr
	"Puan anahtar&inodot;n&inodot; d&uacute;zenle"
#endif
	,
	[ActNewRub] =
#if   L==1	// ca
	"Crear r&uacute;brica"
#elif L==2	// de
	"Rubrik erstellen"
#elif L==3	// en
	"Create rubric"
#elif L==4	// es
	"Crear r&uacute;brica"
#elif L==5	// fr
	"Cr&eacute;er rubrique"
#elif L==6	// gn
	"Omohe&ntilde;&oacute;i  r&uacute;brica"
#elif L==7	// it
	"Creare rubrica"
#elif L==8	// pl
	"Utw&oacute;rz rubryk&eogon;"
#elif L==9	// pt
	"Criar rubrica"
#elif L==10	// tr
	"De&gbreve;erlendirme listesi olu&scedil;turun"
#endif
	,
	[ActChgRub] =
#if   L==1	// ca
	"Canviar r&uacute;brica"
#elif L==2	// de
	"Rubrik wechseln"
#elif L==3	// en
	"Change rubric"
#elif L==4	// es
	"Cambiar r&uacute;brica"
#elif L==5	// fr
	"Changer rubrique"
#elif L==6	// gn
	"Omoambue r&uacute;brica"
#elif L==7	// it
	"Cambiare rubrica"
#elif L==8	// pl
	"Zmieni&cacute; rubryk&eogon;"
#elif L==9	// pt
	"Mudar rubrica"
#elif L==10	// tr
	"Puan anahtar&inodot;n&inodot; de&gbreve;i&scedil;tir"
#endif
	,
	[ActReqRemRub] =
#if   L==1	// ca
	"Sol&middot;licitar eliminaci&oacute; de r&uacute;brica"
#elif L==2	// de
	"Entfernung der Rubrik beantragen"
#elif L==3	// en
	"Request removal of rubric"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de r&uacute;brica"
#elif L==5	// fr
	"Demander suppression de rubrique"
#elif L==6	// gn
	"Ojerure ojeipe'a hagu&atilde; r&uacute;brica"
#elif L==7	// it
	"Richiesta rimozione di rubrica"
#elif L==8	// pl
	"Popro&sacute; o usuni&eogon;cie rubryki"
#elif L==9	// pt
	"Solicitar remo&ccedil;&atilde;o de rubrica"
#elif L==10	// tr
	"Puan anahtar&inodot;n&inodot;n kald&inodot;r&inodot;lmas&inodot;n&inodot; talep etme"
#endif
	,
	[ActRemRub] =
#if   L==1	// ca
	"Eliminar r&uacute;brica"
#elif L==2	// de
	"Rubrik entfernen"
#elif L==3	// en
	"Remove rubric"
#elif L==4	// es
	"Eliminar r&uacute;brica"
#elif L==5	// fr
	"Supprimer rubrique"
#elif L==6	// gn
	"Ojepe'a pe r&uacute;brica"
#elif L==7	// it
	"Rimuovere rubrica"
#elif L==8	// pl
	"Usu&nacute; rubryk&eogon;"
#elif L==9	// pt
	"Remover rubrica"
#elif L==10	// tr
	"Puan anahtar&inodot;n&inodot; kald&inodot;r"
#endif
	,
	[ActReqLnkRub] =
#if   L==1	// ca
	"Copiar enlla&ccedil; a r&uacute;brica"
#elif L==2	// de
	"Link zur Rubrik kopieren"
#elif L==3	// en
	"Copy link to rubric"
#elif L==4	// es
	"Copiar enlace a r&uacute;brica"
#elif L==5	// fr
	"Copier le lien vers la rubrique"
#elif L==6	// gn
	"Ekopia enlace rubrica-pe"
#elif L==7	// it
	"Copiare il link alla rubrica"
#elif L==8	// pl
	"Skopiuj link do rubryki"
#elif L==9	// pt
	"Copiar link para rubrica"
#elif L==10	// tr
	"Ba&gbreve;lant&inodot;y&inodot; puan anahtar&inodot;na kopyala"
#endif
	,
	[ActSeeRscCli_InRub] =
#if   L==1	// ca
	"Veure portapapers de recursos en r&uacute;briques"
#elif L==2	// de
	"Siehe Ressourcen-Zwischenablage im Rubriken"
#elif L==3	// en
	"See resource clipboard in rubrics"
#elif L==4	// es
	"Ver portapapeles de recursos en r&uacute;bricas"
#elif L==5	// fr
	"Voir le presse-papiers des ressources dans les rubriques"
#elif L==6	// gn
	"Ehecha recurso portapapeles umi rubrica-pe"
#elif L==7	// it
	"Visualizza gli appunti delle risorse nelle rubriche"
#elif L==8	// pl
	"Zobacz schowek zasob&oacute;w w rubrykach"
#elif L==9	// pt
	"Ver &aacute;rea de transfer&ecirc;ncia de recursos nas rubricas"
#elif L==10	// tr
	"De&gbreve;erlendirme listelerinde kaynak panosuna bak&inodot;n"
#endif
	,
	[ActRemRscCli_InRub] =
#if   L==1	// ca
	"Eliminar portapapers de recursos en r&uacute;briques"
#elif L==2	// de
	"Entfernen Sie die Ressourcen-Zwischenablage im Rubriken"
#elif L==3	// en
	"Remove resource clipboard in rubrics"
#elif L==4	// es
	"Eliminar portapapeles de recursos en r&uacute;bricas"
#elif L==5	// fr
	"Supprimer le presse-papiers des ressources dans les rubriques"
#elif L==6	// gn
	"Embogue recurso portapapeles umi rubrica-pe"
#elif L==7	// it
	"Elimina gli appunti delle risorse nelle rubriche"
#elif L==8	// pl
	"Usu&nacute; schowek zasob&oacute;w w rubrykach"
#elif L==9	// pt
	"Remover &aacute;rea de transfer&ecirc;ncia de recursos nas rubricas"
#elif L==10	// tr
	"De&gbreve;erlendirme listelerinde kaynak panosunu kald&inodot;r"
#endif
	,
	[ActNewRubCri] =
#if   L==1	// ca
	"Crear criteri"
#elif L==2	// de
	"Kriterium eingeben"
#elif L==3	// en
	"Create criterion"
#elif L==4	// es
	"Crear criterio"
#elif L==5	// fr
	"Cr&eacute;er crit&egrave;re"
#elif L==6	// gn
	"Omohe&ntilde;&oacute;i criterio"
#elif L==7	// it
	"Crear criterio"
#elif L==8	// pl
	"Utw&oacute;rz kryterium"
#elif L==9	// pt
	"Criar crit&eacute;rio"
#elif L==10	// tr
	"&Ouml;l&ccedil;&uuml;t olu&scedil;tur"
#endif
	,
	[ActReqRemRubCri] =
#if   L==1	// ca
	"Sol&middot;licitar eliminaci&oacute; de criteri de r&uacute;brica"
#elif L==2	// de
	"Entfernen von Bewertungskriterien beantragen"
#elif L==3	// en
	"Request rubric criterion removal"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de criterio de r&uacute;brica"
#elif L==5	// fr
	"Demander la suppression des crit&egrave;res de la rubrique"
#elif L==6	// gn
	"Ojerure ojeipe'a hagu&atilde; criterio r&uacute;brico rehegua"
#elif L==7	// it
	"Richiedere la rimozione dei criteri di rubrica"
#elif L==8	// pl
	"Popro&sacute; o usuni&eogon;cie kryteri&oacute;w rubryk"
#elif L==9	// pt
	"Solicitar a remo&ccedil;&atilde;o dos crit&eacute;rios de rubrica"
#elif L==10	// tr
	"Dereceli puanlama anahtar&inodot; kriterlerinin kald&inodot;r&inodot;lmas&inodot;n&inodot; talep edin"
#endif
	,
	[ActRemRubCri] =
#if   L==1	// ca
	"Eliminar criteri de r&uacute;brica"
#elif L==2	// de
	"Rubrikkriterien entfernen"
#elif L==3	// en
	"Remove rubric criterion"
#elif L==4	// es
	"Eliminar criterio de r&uacute;brica"
#elif L==5	// fr
	"Supprimer crit&egrave;re de rubrique"
#elif L==6	// gn
	"Ojepe'a pete&itilde; criterio r&uacute;brica rehegua"
#elif L==7	// it
	"Rimuovere criterio di rubrica"
#elif L==8	// pl
	"Usu&nacute; kryterium rubryki"
#elif L==9	// pt
	"Remover crit&eacute;rio de rubrica"
#elif L==10	// tr
	"Dereceli puanlama anahtar&inodot; &ouml;l&ccedil;&uuml;t&uuml;n&uuml; kald&inodot;rma"
#endif
	,
	[ActUp_RubCri] =
#if   L==1	// ca
	"Moure cap amunt criteri de r&uacute;brica"
#elif L==2	// de
	"Rubrikkriterien nach oben verschieben"
#elif L==3	// en
	"Move up rubric criterion"
#elif L==4	// es
	"Mover hacia arriba criterio de r&uacute;brica"
#elif L==5	// fr
	"Monter crit&egrave;re de rubrique"
#elif L==6	// gn
	"Oemotenonde criterio r&uacute;brico yvate gotyo"
#elif L==7	// it
	"Spostare verso l'alto criterio di rubrica"
#elif L==8	// pl
	"Przenie&sacute; kryteria rubryk w g&oacute;r&eogon;"
#elif L==9	// pt
	"Subir crit&eacute;rio de rubrica"
#elif L==10	// tr
	"Dereceli puanlama anahtar&inodot; &ouml;l&ccedil;&uuml;tlerini yukar&inodot; ta&scedil;&inodot;"
#endif
	,
	[ActDwnRubCri] =
#if   L==1	// ca
	"Moure cap avall criteri de r&uacute;brica"
#elif L==2	// de
	"Rubrikkriterien nach unten verschieben"
#elif L==3	// en
	"Move down rubric criterion"
#elif L==4	// es
	"Mover hacia abajo criterio de r&uacute;brica"
#elif L==5	// fr
	"D&eacute;placer vers le bas crit&egrave;re de rubrique"
#elif L==6	// gn
	"Oemotenonde criterio r&uacute;brico yvate gotyo"
#elif L==7	// it
	"Spostare verso il basso criterio di rubrica"
#elif L==8	// pl
	"Przesu&nacute; w d&oacute;&lstrok; kryteria rubryk"
#elif L==9	// pt
	"Mover para baixo crit&eacute;rio de rubrica"
#elif L==10	// tr
	"Dereceli puanlama anahtar&inodot; &ouml;l&ccedil;&uuml;tlerini a&scedil;a&gbreve;&inodot; ta&scedil;&inodot;"
#endif
	,
	[ActChgTitRubCri] =
#if   L==1	// ca
	"Canviar t&iacute;tol de criteri de r&uacute;brica"
#elif L==2	// de
	"Rubrikkriterientitel &auml;ndern"
#elif L==3	// en
	"Change rubric criterion title"
#elif L==4	// es
	"Cambiar t&iacute;tulo de criterio de r&uacute;brica"
#elif L==5	// fr
	"Modifier titre de crit&egrave;re de rubrique"
#elif L==6	// gn
	"Omoambue criterio r&uacute;brica t&iacute;tulo rehegua"
#elif L==7	// it
	"Cambiare titolo di criterio di rubrica"
#elif L==8	// pl
	"Zmie&nacute; tytu&lstrok; kryterium rubryki"
#elif L==9	// pt
	"Alterar t&iacute;tulo do crit&eacute;rio de rubrica"
#elif L==10	// tr
	"Puan anahtar&inodot; &ouml;l&ccedil;&uuml;t ba&scedil;l&inodot;&gbreve;&inodot;n&inodot; de&gbreve;i&scedil;tir"				// eviri lazim!
#endif
	,
	[ActChgLnkRubCri] =
#if   L==1	// ca
	"Canviar enlla&ccedil; a recurs des de r&uacute;brica"
#elif L==2	// de
	"Link zu Ressource aus Rubrik &auml;ndern"
#elif L==3	// en
	"Change link to resource from rubric"
#elif L==4	// es
	"Cambiar enlace a recurso desde r&uacute;brica"
#elif L==5	// fr
	"Modifier lien vers ressource &agrave; partir de rubrique"
#elif L==6	// gn
	"Omoambue enlace recurso-pe r&uacute;brica-gui"
#elif L==7	// it
	"Modificare il collegamento alla risorsa dalla rubrica"
#elif L==8	// pl
	"Zmie&nacute; link do zasobu z rubryki"
#elif L==9	// pt
	"Alterar link para recurso da rubrica"
#elif L==10	// tr
	"Puan anahtar&inodot;ndan kayna&gbreve;a ba&gbreve;lant&inodot;y&inodot; de&gbreve;i&scedil;tir"
#endif
	,
	[ActChgMinRubCri] =
#if   L==1	// ca
	"Canviar valor m&iacute;nim de criteri de r&uacute;brica"
#elif L==2	// de
	"Mindestwert des Rubrikkriteriums &auml;ndern"
#elif L==3	// en
	"Change rubric criterion minimum value"
#elif L==4	// es
	"Cambiar valor m&iacute;nimo de criterio de r&uacute;brica"
#elif L==5	// fr
	"Modifier valeur minimale de crit&egrave;re de rubrique"
#elif L==6	// gn
	"Omoambue criterio r&uacute;brica valor m&iacute;nimo rehegua"
#elif L==7	// it
	"Cambiare valore minimo di criterio di rubrica"
#elif L==8	// pl
	"Zmie&nacute; minimaln&aogon; warto&sacute;&cacute; kryteri&oacute;w rubryki"
#elif L==9	// pt
	"Alterar valor m&iacute;nimo do crit&eacute;rio de rubrica"
#elif L==10	// tr
	"Dereceli puanlama anahtar&inodot; &ouml;l&ccedil;&uuml;t&uuml; minimum de&gbreve;erini de&gbreve;i&scedil;tir"
#endif
	,
	[ActChgMaxRubCri] =
#if   L==1	// ca
	"Canviar valor m&agrave;xim de criteri de r&uacute;brica"
#elif L==2	// de
	"Maximalwert des Rubrikkriteriums &auml;ndern"
#elif L==3	// en
	"Change rubric criterion maximum value"
#elif L==4	// es
	"Cambiar valor m&aacute;ximo de criterio de r&uacute;brica"
#elif L==5	// fr
	"Modifier valeur maximale de crit&egrave;re de rubrique"
#elif L==6	// gn
	"Omoambue criterio r&uacute;brica valor m&iacute;nimo rehegua"
#elif L==7	// it
	"Cambiare valore massimo di criterio di rubrica"
#elif L==8	// pl
	"Zmie&nacute; maksymaln&aogon; warto&sacute;&cacute; kryteri&oacute;w rubryki"
#elif L==9	// pt
	"Alterar valor m&aacute;ximo do crit&eacute;rio de rubrica"
#elif L==10	// tr
	"Puan anahtar&inodot; &ouml;l&ccedil;&uuml;t&uuml; maksimum de&gbreve;erini de&gbreve;i&scedil;tir"
#endif
	,
	[ActChgWeiRubCri] =
#if   L==1	// ca
	"Canviar pes de criteri de r&uacute;brica"
#elif L==2	// de
	"Gewichtung der Rubrikkriterien &auml;ndern"
#elif L==3	// en
	"Change rubric criterion weight"
#elif L==4	// es
	"Cambiar peso de criterio de r&uacute;brica"
#elif L==5	// fr
	"Modifier poids de crit&egrave;re de rubrique"
#elif L==6	// gn
	"Omoambue criterio r&uacute;brica peso rehegua"
#elif L==7	// it
	"Cambiare peso di criterio di rubrica"
#elif L==8	// pl
	"Zmie&nacute; wag&eogon; kryterium rubryki"
#elif L==9	// pt
	"Alterar peso do crit&eacute;rio de rubrica"
#elif L==10	// tr
	"Puan anahtar&inodot; &ouml;l&ccedil;&uuml;t a&gbreve;&inodot;rl&inodot;&gbreve;&inodot;n&inodot; de&gbreve;i&scedil;tir"
#endif
	,
	[ActSeeAdmDocIns] =
#if   L==1	// ca
	"Documents zone of institution (see or manage)"			// Necessita traducci
#elif L==2	// de
	"Documents zone of institution (see or manage)"			// Need bersetzung
#elif L==3	// en
	"Documents zone of institution (see or manage)"
#elif L==4	// es
	"Zona de documentos de instituci&oacute;n (ver o administrar)"
#elif L==5	// fr
	"Documents zone of institution (see or manage)"			// Besoin de traduction
#elif L==6	// gn
	"Zona de documentos de instituci&oacute;n (ver o administrar)"	// Okoteve traduccin
#elif L==7	// it
	"Documents zone of institution (see or manage)"			// Bisogno di traduzione
#elif L==8	// pl
	"Documents zone of institution (see or manage)"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Documents zone of institution (see or manage)"			// Precisa de traduo
#elif L==10	// tr
	"Documents zone of institution (see or manage)"			// eviri lazim!
#endif
	,
	[ActChgToSeeDocIns] =
#if   L==1	// ca
	"Change documents zone of institution to view mode"		// Necessita traducci
#elif L==2	// de
	"Change documents zone of institution to view mode"		// Need bersetzung
#elif L==3	// en
	"Change documents zone of institution to view mode"
#elif L==4	// es
	"Cambiar zona de documentos de instituci&oacute;n a modo vista"
#elif L==5	// fr
	"Change documents zone of institution to view mode"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar zona de documentos de instituci&oacute;n a modo vista"	// Okoteve traduccin
#elif L==7	// it
	"Change documents zone of institution to view mode"		// Bisogno di traduzione
#elif L==8	// pl
	"Change documents zone of institution to view mode"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change documents zone of institution to view mode"		// Precisa de traduo
#elif L==10	// tr
	"Change documents zone of institution to view mode"		// eviri lazim!
#endif
	,
	[ActSeeDocIns] =
#if   L==1	// ca
	"See documents zone of the institution"			// Necessita traducci
#elif L==2	// de
	"See documents zone of the institution"			// Need bersetzung
#elif L==3	// en
	"See documents zone of the institution"
#elif L==4	// es
	"Ver zona de documentos de la instituci&oacute;n"
#elif L==5	// fr
	"See documents zone of the institution"			// Besoin de traduction
#elif L==6	// gn
	"Ver zona de documentos de la instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See documents zone of the institution"			// Bisogno di traduzione
#elif L==8	// pl
	"See documents zone of the institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See documents zone of the institution"			// Precisa de traduo
#elif L==10	// tr
	"See documents zone of the institution"			// eviri lazim!
#endif
	,
	[ActExpSeeDocIns] =
#if   L==1	// ca
	"Expand folder in institution documents"			// Necessita traducci
#elif L==2	// de
	"Expand folder in institution documents"			// Need bersetzung
#elif L==3	// en
	"Expand folder in institution documents"
#elif L==4	// es
	"Expandir carpeta en zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Expand folder in institution documents"			// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in institution documents"			// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in institution documents"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in institution documents"			// Precisa de traduo
#elif L==10	// tr
	"Expand folder in institution documents"			// eviri lazim!
#endif
	,
	[ActConSeeDocIns] =
#if   L==1	// ca
	"Contract folder in institution documents"			// Necessita traducci
#elif L==2	// de
	"Contract folder in institution documents"			// Need bersetzung
#elif L==3	// en
	"Contract folder in institution documents"
#elif L==4	// es
	"Contraer carpeta en zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Contract folder in institution documents"			// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in institution documents"			// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in institution documents"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in institution documents"			// Precisa de traduo
#elif L==10	// tr
	"Contract folder in institution documents"			// eviri lazim!
#endif
	,
	[ActZIPSeeDocIns] =
#if   L==1	// ca
	"Compress folder in institution documents"			// Necessita traducci
#elif L==2	// de
	"Compress folder in institution documents"			// Need bersetzung
#elif L==3	// en
	"Compress folder in institution documents"
#elif L==4	// es
	"Comprimir carpeta en zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Compress folder in institution documents"			// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in institution documents"			// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in institution documents"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in institution documents"			// Precisa de traduo
#elif L==10	// tr
	"Compress folder in institution documents"			// eviri lazim!
#endif
	,
	[ActReqDatSeeDocIns] =
#if   L==1	// ca
	"See file metadata in documents zone of institution"			// Necessita traducci
#elif L==2	// de
	"See file metadata in documents zone of institution"			// Need bersetzung
#elif L==3	// en
	"See file metadata in documents zone of institution"
#elif L==4	// es
	"Ver metadatos de archivo en zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"See file metadata in documents zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in documents zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in documents zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in documents zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in documents zone of institution"			// eviri lazim!
#endif
	,
	[ActDowSeeDocIns] =
#if   L==1	// ca
	"Download file from documents zone of institution"		// Necessita traducci
#elif L==2	// de
	"Download file from documents zone of institution"		// Need bersetzung
#elif L==3	// en
	"Download file from documents zone of institution"
#elif L==4	// es
	"Descargar archivo de zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Download file from documents zone of institution"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Download file from documents zone of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from documents zone of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from documents zone of institution"		// Precisa de traduo
#elif L==10	// tr
	"Download file from documents zone of institution"		// eviri lazim!
#endif
	,
	[ActChgToAdmDocIns] =
#if   L==1	// ca
	"Change to administration mode of institution documents"			// Necessita traducci
#elif L==2	// de
	"Change to administration mode of institution documents"			// Need bersetzung
#elif L==3	// en
	"Change to administration mode of institution documents"
#elif L==4	// es
	"Cambiar modo de administraci&oacute;n de los documentos de instituci&oacute;n"
#elif L==5	// fr
	"Change to administration mode of institution documents"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar modo de administraci&oacute;n de los documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change to administration mode of institution documents"			// Bisogno di traduzione
#elif L==8	// pl
	"Change to administration mode of institution documents"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change to administration mode of institution documents"			// Precisa de traduo
#elif L==10	// tr
	"Change to administration mode of institution documents"			// eviri lazim!
#endif
	,
	[ActAdmDocIns] =
#if   L==1	// ca
	"Manage documents zone of the institution"			// Necessita traducci
#elif L==2	// de
	"Manage documents zone of the institution"			// Need bersetzung
#elif L==3	// en
	"Manage documents zone of the institution"
#elif L==4	// es
	"Administrar zona de documentos de la instituci&oacute;n"
#elif L==5	// fr
	"Manage documents zone of the institution"			// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de documentos de la instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Manage documents zone of the institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Manage documents zone of the institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage documents zone of the institution"			// Precisa de traduo
#elif L==10	// tr
	"Manage documents zone of the institution"			// eviri lazim!
#endif
	,
	[ActReqRemFilDocIns] =
#if   L==1	// ca
	"Request removal of file in documents zone of institution"				// Necessita traducci
#elif L==2	// de
	"Request removal of file in documents zone of institution"				// Need bersetzung
#elif L==3	// en
	"Request removal of file in documents zone of institution"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Request removal of file in documents zone of institution"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file in documents zone of institution"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file in documents zone of institution"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file in documents zone of institution"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of file in documents zone of institution"				// eviri lazim!
#endif
	,
	[ActRemFilDocIns] =
#if   L==1	// ca
	"Remove file in documents zone of institution"			// Necessita traducci
#elif L==2	// de
	"Remove file in documents zone of institution"			// Need bersetzung
#elif L==3	// en
	"Remove file in documents zone of institution"
#elif L==4	// es
	"Eliminar archivo de zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Remove file in documents zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove file in documents zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove file in documents zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file in documents zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Remove file in documents zone of institution"			// eviri lazim!
#endif
	,
	[ActRemFolDocIns] =
#if   L==1	// ca
	"Remove empty folder documents zone of institution"				// Necessita traducci
#elif L==2	// de
	"Remove empty folder documents zone of institution"				// Need bersetzung
#elif L==3	// en
	"Remove empty folder documents zone of institution"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Remove empty folder documents zone of institution"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder documents zone of institution"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder documents zone of institution"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder documents zone of institution"				// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder documents zone of institution"				// eviri lazim!
#endif
	,
	[ActCopDocIns] =
#if   L==1	// ca
	"Set source of copy in documents zone of institution"				// Necessita traducci
#elif L==2	// de
	"Set source of copy in documents zone of institution"				// Need bersetzung
#elif L==3	// en
	"Set source of copy in documents zone of institution"
#elif L==4	// es
	"Establecer origen de copia en zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Set source of copy in documents zone of institution"				// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in documents zone of institution"				// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in documents zone of institution"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in documents zone of institution"				// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in documents zone of institution"				// eviri lazim!
#endif
	,
	[ActPasDocIns] =
#if   L==1	// ca
	"Paste folder/file in documents zone of institution"			// Necessita traducci
#elif L==2	// de
	"Paste folder/file in documents zone of institution"			// Need bersetzung
#elif L==3	// en
	"Paste folder/file in documents zone of institution"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Paste folder/file in documents zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in documents zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in documents zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in documents zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in documents zone of institution"			// eviri lazim!
#endif
	,
	[ActRemTreDocIns] =
#if   L==1	// ca
	"Remove non-empty folder from documents zone of institution"			// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from documents zone of institution"			// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from documents zone of institution"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Remove non-empty folder from documents zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from documents zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from documents zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from documents zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from documents zone of institution"			// eviri lazim!
#endif
	,
	[ActFrmCreDocIns] =
#if   L==1	// ca
	"Form to create folder/file in documents zone of institution"				// Necessita traducci
#elif L==2	// de
	"Form to create folder/file in documents zone of institution"				// Need bersetzung
#elif L==3	// en
	"Form to create folder/file in documents zone of institution"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Form to create folder/file in documents zone of institution"				// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Form to create folder/file in documents zone of institution"				// Bisogno di traduzione
#elif L==8	// pl
	"Form to create folder/file in documents zone of institution"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Form to create folder/file in documents zone of institution"				// Precisa de traduo
#elif L==10	// tr
	"Form to create folder/file in documents zone of institution"				// eviri lazim!
#endif
	,
	[ActCreFolDocIns] =
#if   L==1	// ca
	"Create new folder in documents zone of institution"			// Necessita traducci
#elif L==2	// de
	"Create new folder in documents zone of institution"			// Need bersetzung
#elif L==3	// en
	"Create new folder in documents zone of institution"
#elif L==4	// es
	"Crear nueva carpeta en zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Create new folder in documents zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in documents zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in documents zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in documents zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Create new folder in documents zone of institution"			// eviri lazim!
#endif
	,
	[ActCreLnkDocIns] =
#if   L==1	// ca
	"Create new link in documents zone of institution"			// Necessita traducci
#elif L==2	// de
	"Create new link in documents zone of institution"			// Need bersetzung
#elif L==3	// en
	"Create new link in documents zone of institution"
#elif L==4	// es
	"Crear una nuevo enlace zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Create new link in documents zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Crear una nuevo enlace zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in documents zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in documents zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in documents zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Create new link in documents zone of institution"			// eviri lazim!
#endif
	,
	[ActRenFolDocIns] =
#if   L==1	// ca
	"Rename folder in documents zone of institution"		// Necessita traducci
#elif L==2	// de
	"Rename folder in documents zone of institution"		// Need bersetzung
#elif L==3	// en
	"Rename folder in documents zone of institution"
#elif L==4	// es
	"Renombrar carpeta en zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Rename folder in documents zone of institution"		// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in documents zone of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in documents zone of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in documents zone of institution"		// Precisa de traduo
#elif L==10	// tr
	"Rename folder in documents zone of institution"		// eviri lazim!
#endif
	,
	[ActRcvFilDocInsDZ] =
#if   L==1	// ca
	"Send file to documents zone of institution using Dropzone.js"			// Necessita traducci
#elif L==2	// de
	"Send file to documents zone of institution using Dropzone.js"			// Need bersetzung
#elif L==3	// en
	"Send file to documents zone of institution using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona de documentos de instituci&oacute;n usando Dropzone.js"
#elif L==5	// fr
	"Send file to documents zone of institution using Dropzone.js"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de documentos de instituci&oacute;n usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to documents zone of institution using Dropzone.js"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to documents zone of institution using Dropzone.js"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to documents zone of institution using Dropzone.js"			// Precisa de traduo
#elif L==10	// tr
	"Send file to documents zone of institution using Dropzone.js"			// eviri lazim!
#endif
	,
	[ActRcvFilDocInsCla] =
#if   L==1	// ca
	"Send file in documents zone of institution using the classic way"			// Necessita traducci
#elif L==2	// de
	"Send file in documents zone of institution using the classic way"			// Need bersetzung
#elif L==3	// en
	"Send file in documents zone of institution using the classic way"
#elif L==4	// es
	"Enviar archivo a zona de documentos de instituci&oacute;n de forma tradicional"
#elif L==5	// fr
	"Send file in documents zone of institution using the classic way"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de documentos de instituci&oacute;n de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file in documents zone of institution using the classic way"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file in documents zone of institution using the classic way"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file in documents zone of institution using the classic way"			// Precisa de traduo
#elif L==10	// tr
	"Send file in documents zone of institution using the classic way"			// eviri lazim!
#endif
	,
	[ActExpAdmDocIns] =
#if   L==1	// ca
	"Expand folder when managing documents zone of institution"			// Necessita traducci
#elif L==2	// de
	"Expand folder when managing documents zone of institution"			// Need bersetzung
#elif L==3	// en
	"Expand folder when managing documents zone of institution"
#elif L==4	// es
	"Expandir carpeta al administrar zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Expand folder when managing documents zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta al administrar zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder when managing documents zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder when managing documents zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder when managing documents zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Expand folder when managing documents zone of institution"			// eviri lazim!
#endif
	,
	[ActConAdmDocIns] =
#if   L==1	// ca
	"Contract folder when managing documents zone of institution"			// Necessita traducci
#elif L==2	// de
	"Contract folder when managing documents zone of institution"			// Need bersetzung
#elif L==3	// en
	"Contract folder when managing documents zone of institution"
#elif L==4	// es
	"Contraer carpeta al administrar zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Contract folder when managing documents zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta al administrar zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder when managing documents zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder when managing documents zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder when managing documents zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Contract folder when managing documents zone of institution"			// eviri lazim!
#endif
	,
	[ActZIPAdmDocIns] =
#if   L==1	// ca
	"Compress folder when managing documents zone of institution"			// Necessita traducci
#elif L==2	// de
	"Compress folder when managing documents zone of institution"			// Need bersetzung
#elif L==3	// en
	"Compress folder when managing documents zone of institution"
#elif L==4	// es
	"Comprimir carpeta al administrar zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Compress folder when managing documents zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta al administrar zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder when managing documents zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder when managing documents zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder when managing documents zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Compress folder when managing documents zone of institution"			// eviri lazim!
#endif
	,
	[ActUnhDocIns] =
#if   L==1	// ca
	"Unhide folder/file of documents zone of institution"					// Necessita traducci
#elif L==2	// de
	"Unhide folder/file of documents zone of institution"					// Need bersetzung
#elif L==3	// en
	"Unhide folder/file of documents zone of institution"
#elif L==4	// es
	"Mostrar carpeta/archivo al administrar zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Unhide folder/file of documents zone of institution"					// Besoin de traduction
#elif L==6	// gn
	"Mostrar carpeta/archivo al administrar zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Unhide folder/file of documents zone of institution"					// Bisogno di traduzione
#elif L==8	// pl
	"Unhide folder/file of documents zone of institution"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide folder/file of documents zone of institution"					// Precisa de traduo
#elif L==10	// tr
	"Unhide folder/file of documents zone of institution"					// eviri lazim!
#endif
	,
	[ActHidDocIns] =
#if   L==1	// ca
	"Hide folder/file of documents zone of institution"					// Necessita traducci
#elif L==2	// de
	"Hide folder/file of documents zone of institution"					// Need bersetzung
#elif L==3	// en
	"Hide folder/file of documents zone of institution"
#elif L==4	// es
	"Ocultar carpeta/archivo al administrar zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Hide folder/file of documents zone of institution"					// Besoin de traduction
#elif L==6	// gn
	"Ocultar carpeta/archivo al administrar zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Hide folder/file of documents zone of institution"					// Bisogno di traduzione
#elif L==8	// pl
	"Hide folder/file of documents zone of institution"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide folder/file of documents zone of institution"					// Precisa de traduo
#elif L==10	// tr
	"Hide folder/file of documents zone of institution"					// eviri lazim!
#endif
	,
	[ActReqDatAdmDocIns] =
#if   L==1	// ca
	"See file metadata in documents zone of institution"			// Necessita traducci
#elif L==2	// de
	"See file metadata in documents zone of institution"			// Need bersetzung
#elif L==3	// en
	"See file metadata in documents zone of institution"
#elif L==4	// es
	"Ver metadatos de archivo en zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"See file metadata in documents zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in documents zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in documents zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in documents zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in documents zone of institution"			// eviri lazim!
#endif
	,
	[ActChgDatAdmDocIns] =
#if   L==1	// ca
	"Change file metadata in documents zone of institution"				// Necessita traducci
#elif L==2	// de
	"Change file metadata in documents zone of institution"				// Need bersetzung
#elif L==3	// en
	"Change file metadata in documents zone of institution"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Change file metadata in documents zone of institution"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in documents zone of institution"				// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in documents zone of institution"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in documents zone of institution"				// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in documents zone of institution"				// eviri lazim!
#endif
	,
	[ActDowAdmDocIns] =
#if   L==1	// ca
	"Download file from documents zone of institution"		// Necessita traducci
#elif L==2	// de
	"Download file from documents zone of institution"		// Need bersetzung
#elif L==3	// en
	"Download file from documents zone of institution"
#elif L==4	// es
	"Descargar archivo de zona de documentos de instituci&oacute;n"
#elif L==5	// fr
	"Download file from documents zone of institution"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de documentos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Download file from documents zone of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from documents zone of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from documents zone of institution"		// Precisa de traduo
#elif L==10	// tr
	"Download file from documents zone of institution"		// eviri lazim!
#endif
	,
	[ActAdmShaIns] =
#if   L==1	// ca
	"Manage shared files zone of institution"				// Necessita traducci
#elif L==2	// de
	"Manage shared files zone of institution"				// Need bersetzung
#elif L==3	// en
	"Manage shared files zone of institution"
#elif L==4	// es
	"Administrar zona de archivos compartidos de instituci&oacute;n"
#elif L==5	// fr
	"Manage shared files zone of institution"				// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de archivos compartidos de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Manage shared files zone of institution"				// Bisogno di traduzione
#elif L==8	// pl
	"Manage shared files zone of institution"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage shared files zone of institution"				// Precisa de traduo
#elif L==10	// tr
	"Manage shared files zone of institution"				// eviri lazim!
#endif
	,
	[ActReqRemFilShaIns] =
#if   L==1	// ca
	"Request removal of file in shared zone of institution"				// Necessita traducci
#elif L==2	// de
	"Request removal of file in shared zone of institution"				// Need bersetzung
#elif L==3	// en
	"Request removal of file in shared zone of institution"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo compartido de instituci&oacute;n"
#elif L==5	// fr
	"Request removal of file in shared zone of institution"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo compartido de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file in shared zone of institution"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file in shared zone of institution"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file in shared zone of institution"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of file in shared zone of institution"				// eviri lazim!
#endif
	,
	[ActRemFilShaIns] =
#if   L==1	// ca
	"Remove file from shared zone of institution"		// Necessita traducci
#elif L==2	// de
	"Remove file from shared zone of institution"		// Need bersetzung
#elif L==3	// en
	"Remove file from shared zone of institution"
#elif L==4	// es
	"Eliminar archivo compartido de instituci&oacute;n"
#elif L==5	// fr
	"Remove file from shared zone of institution"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo compartido de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from shared zone of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from shared zone of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from shared zone of institution"		// Precisa de traduo
#elif L==10	// tr
	"Remove file from shared zone of institution"		// eviri lazim!
#endif
	,
	[ActRemFolShaIns] =
#if   L==1	// ca
	"Remove empty folder from shared zone of institution"	// Necessita traducci
#elif L==2	// de
	"Remove empty folder from shared zone of institution"	// Need bersetzung
#elif L==3	// en
	"Remove empty folder from shared zone of institution"
#elif L==4	// es
	"Eliminar carpeta compartida de instituci&oacute;n"
#elif L==5	// fr
	"Remove empty folder from shared zone of institution"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta compartida de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from shared zone of institution"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from shared zone of institution"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from shared zone of institution"	// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from shared zone of institution"	// eviri lazim!
#endif
	,
	[ActCopShaIns] =
#if   L==1	// ca
	"Set source of copy in shared zone of institution"			// Necessita traducci
#elif L==2	// de
	"Set source of copy in shared zone of institution"			// Need bersetzung
#elif L==3	// en
	"Set source of copy in shared zone of institution"
#elif L==4	// es
	"Establecer origen de copia en zona compartida de instituci&oacute;n"
#elif L==5	// fr
	"Set source of copy in shared zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona compartida de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in shared zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in shared zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in shared zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in shared zone of institution"			// eviri lazim!
#endif
	,
	[ActPasShaIns] =
#if   L==1	// ca
	"Paste folder/file in shared zone of institution"			// Necessita traducci
#elif L==2	// de
	"Paste folder/file in shared zone of institution"			// Need bersetzung
#elif L==3	// en
	"Paste folder/file in shared zone of institution"
#elif L==4	// es
	"Pegar carpeta/archivo en zona compartida de instituci&oacute;n"
#elif L==5	// fr
	"Paste folder/file in shared zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona compartida de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in shared zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in shared zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in shared zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in shared zone of institution"			// eviri lazim!
#endif
	,
	[ActRemTreShaIns] =
#if   L==1	// ca
	"Remove non-empty folder from shared zone of institution"			// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from shared zone of institution"			// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from shared zone of institution"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona compartida de instituci&oacute;n"
#elif L==5	// fr
	"Remove non-empty folder from shared zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona compartida de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from shared zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from shared zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from shared zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from shared zone of institution"			// eviri lazim!
#endif
	,
	[ActFrmCreShaIns] =
#if   L==1	// ca
	"Form to create folder/file in shared zone of institution"			// Necessita traducci
#elif L==2	// de
	"Form to create folder/file in shared zone of institution"			// Need bersetzung
#elif L==3	// en
	"Form to create folder/file in shared zone of institution"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona compartida de instituci&oacute;n"
#elif L==5	// fr
	"Form to create folder/file in shared zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona compartida de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Form to create folder/file in shared zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Form to create folder/file in shared zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Form to create folder/file in shared zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Form to create folder/file in shared zone of institution"			// eviri lazim!
#endif
	,
	[ActCreFolShaIns] =
#if   L==1	// ca
	"Create new folder in shared zone of institution"		// Necessita traducci
#elif L==2	// de
	"Create new folder in shared zone of institution"		// Need bersetzung
#elif L==3	// en
	"Create new folder in shared zone of institution"
#elif L==4	// es
	"Crear nueva carpeta en zona compartida de instituci&oacute;n"
#elif L==5	// fr
	"Create new folder in shared zone of institution"		// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona compartida de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in shared zone of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in shared zone of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in shared zone of institution"		// Precisa de traduo
#elif L==10	// tr
	"Create new folder in shared zone of institution"		// eviri lazim!
#endif
	,
	[ActCreLnkShaIns] =
#if   L==1	// ca
	"Create new link in shared zone of institution"			// Necessita traducci
#elif L==2	// de
	"Create new link in shared zone of institution"			// Need bersetzung
#elif L==3	// en
	"Create new link in shared zone of institution"
#elif L==4	// es
	"Crear nuevo enlace en zona compartida de instituci&oacute;n"
#elif L==5	// fr
	"Create new link in shared zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona compartida de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in shared zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in shared zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in shared zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Create new link in shared zone of institution"			// eviri lazim!
#endif
	,
	[ActRenFolShaIns] =
#if   L==1	// ca
	"Rename folder in shared zone of institution"			// Necessita traducci
#elif L==2	// de
	"Rename folder in shared zone of institution"			// Need bersetzung
#elif L==3	// en
	"Rename folder in shared zone of institution"
#elif L==4	// es
	"Renombrar carpeta de zona compartida de instituci&oacute;n"
#elif L==5	// fr
	"Rename folder in shared zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta de zona compartida de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in shared zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in shared zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in shared zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Rename folder in shared zone of institution"			// eviri lazim!
#endif
	,
	[ActRcvFilShaInsDZ] =
#if   L==1	// ca
	"Send file to shared zone of institution using Dropzone.js"			// Necessita traducci
#elif L==2	// de
	"Send file to shared zone of institution using Dropzone.js"			// Need bersetzung
#elif L==3	// en
	"Send file to shared zone of institution using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona compartida de instituci&oacute;n usando Dropzone.js"
#elif L==5	// fr
	"Send file to shared zone of institution using Dropzone.js"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona compartida de instituci&oacute;n usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to shared zone of institution using Dropzone.js"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to shared zone of institution using Dropzone.js"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to shared zone of institution using Dropzone.js"			// Precisa de traduo
#elif L==10	// tr
	"Send file to shared zone of institution using Dropzone.js"			// eviri lazim!
#endif
	,
	[ActRcvFilShaInsCla] =
#if   L==1	// ca
	"Send file to shared zone of institution using the classic way"			// Necessita traducci
#elif L==2	// de
	"Send file to shared zone of institution using the classic way"			// Need bersetzung
#elif L==3	// en
	"Send file to shared zone of institution using the classic way"
#elif L==4	// es
	"Enviar archivo a zona compartida de instituci&oacute;n de forma tradicional"
#elif L==5	// fr
	"Send file to shared zone of institution using the classic way"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona compartida de instituci&oacute;n de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file to shared zone of institution using the classic way"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to shared zone of institution using the classic way"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to shared zone of institution using the classic way"			// Precisa de traduo
#elif L==10	// tr
	"Send file to shared zone of institution using the classic way"			// eviri lazim!
#endif
	,
	[ActExpShaIns] =
#if   L==1	// ca
	"Expand folder in shared zone of institution"			// Necessita traducci
#elif L==2	// de
	"Expand folder in shared zone of institution"			// Need bersetzung
#elif L==3	// en
	"Expand folder in shared zone of institution"
#elif L==4	// es
	"Expandir carpeta en zona compartida de instituci&oacute;n"
#elif L==5	// fr
	"Expand folder in shared zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona compartida de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in shared zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in shared zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in shared zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Expand folder in shared zone of institution"			// eviri lazim!
#endif
	,
	[ActConShaIns] =
#if   L==1	// ca
	"Contract folder in shared zone of institution"			// Necessita traducci
#elif L==2	// de
	"Contract folder in shared zone of institution"			// Need bersetzung
#elif L==3	// en
	"Contract folder in shared zone of institution"
#elif L==4	// es
	"Contraer carpeta en zona compartida de instituci&oacute;n"
#elif L==5	// fr
	"Contract folder in shared zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona compartida de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in shared zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in shared zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in shared zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Contract folder in shared zone of institution"			// eviri lazim!
#endif
	,
	[ActZIPShaIns] =
#if   L==1	// ca
	"Compress folder in shared zone of institution"			// Necessita traducci
#elif L==2	// de
	"Compress folder in shared zone of institution"			// Need bersetzung
#elif L==3	// en
	"Compress folder in shared zone of institution"
#elif L==4	// es
	"Comprimir carpeta en zona compartida de instituci&oacute;n"
#elif L==5	// fr
	"Compress folder in shared zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona compartida de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in shared zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in shared zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in shared zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Compress folder in shared zone of institution"			// eviri lazim!
#endif
	,
	[ActReqDatShaIns] =
#if   L==1	// ca
	"See file metadata in shared zone of institution"			// Necessita traducci
#elif L==2	// de
	"See file metadata in shared zone of institution"			// Need bersetzung
#elif L==3	// en
	"See file metadata in shared zone of institution"
#elif L==4	// es
	"Ver metadatos de archivo en zona compartida de instituci&oacute;n"
#elif L==5	// fr
	"See file metadata in shared zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona compartida de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in shared zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in shared zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in shared zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in shared zone of institution"			// eviri lazim!
#endif
	,
	[ActChgDatShaIns] =
#if   L==1	// ca
	"Change file metadata in shared zone of institution"			// Necessita traducci
#elif L==2	// de
	"Change file metadata in shared zone of institution"			// Need bersetzung
#elif L==3	// en
	"Change file metadata in shared zone of institution"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona compartida de instituci&oacute;n"
#elif L==5	// fr
	"Change file metadata in shared zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona compartida de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in shared zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in shared zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in shared zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in shared zone of institution"			// eviri lazim!
#endif
	,
	[ActDowShaIns] =
#if   L==1	// ca
	"Download file from shared zone of institution"			// Necessita traducci
#elif L==2	// de
	"Download file from shared zone of institution"			// Need bersetzung
#elif L==3	// en
	"Download file from shared zone of institution"
#elif L==4	// es
	"Descargar archivo de zona compartida de instituci&oacute;n"
#elif L==5	// fr
	"Download file from shared zone of institution"			// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona compartida de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Download file from shared zone of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Download file from shared zone of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from shared zone of institution"			// Precisa de traduo
#elif L==10	// tr
	"Download file from shared zone of institution"			// eviri lazim!
#endif
	,
	[ActSeeAdmDocCtr] =
#if   L==1	// ca
	"Documents zone of center (see or manage)"		// Necessita traducci
#elif L==2	// de
	"Documents zone of center (see or manage)"		// Need bersetzung
#elif L==3	// en
	"Documents zone of center (see or manage)"
#elif L==4	// es
	"Zona de documentos de centro (ver o administrar)"
#elif L==5	// fr
	"Documents zone of center (see or manage)"		// Besoin de traduction
#elif L==6	// gn
	"Zona de documentos de centro (ver o administrar)"	// Okoteve traduccin
#elif L==7	// it
	"Documents zone of center (see or manage)"		// Bisogno di traduzione
#elif L==8	// pl
	"Documents zone of center (see or manage)"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Documents zone of center (see or manage)"		// Precisa de traduo
#elif L==10	// tr
	"Documents zone of center (see or manage)"		// eviri lazim!
#endif
	,
	[ActChgToSeeDocCtr] =
#if   L==1	// ca
	"Change documents zone of center to view mode"		// Necessita traducci
#elif L==2	// de
	"Change documents zone of center to view mode"		// Need bersetzung
#elif L==3	// en
	"Change documents zone of center to view mode"
#elif L==4	// es
	"Cambiar zona de documentos de centro a modo vista"
#elif L==5	// fr
	"Change documents zone of center to view mode"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar zona de documentos de centro a modo vista"	// Okoteve traduccin
#elif L==7	// it
	"Change documents zone of center to view mode"		// Bisogno di traduzione
#elif L==8	// pl
	"Change documents zone of center to view mode"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change documents zone of center to view mode"		// Precisa de traduo
#elif L==10	// tr
	"Change documents zone of center to view mode"		// eviri lazim!
#endif
	,
	[ActSeeDocCtr] =
#if   L==1	// ca
	"See documents zone of the center"	// Necessita traducci
#elif L==2	// de
	"See documents zone of the center"	// Need bersetzung
#elif L==3	// en
	"See documents zone of the center"
#elif L==4	// es
	"Ver zona de documentos del centro"
#elif L==5	// fr
	"See documents zone of the center"	// Besoin de traduction
#elif L==6	// gn
	"Ver zona de documentos del centro"	// Okoteve traduccin
#elif L==7	// it
	"See documents zone of the center"	// Bisogno di traduzione
#elif L==8	// pl
	"See documents zone of the center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See documents zone of the center"	// Precisa de traduo
#elif L==10	// tr
	"See documents zone of the center"	// eviri lazim!
#endif
	,
	[ActExpSeeDocCtr] =
#if   L==1	// ca
	"Expand folder in documents zone of center"		// Necessita traducci
#elif L==2	// de
	"Expand folder in documents zone of center"		// Need bersetzung
#elif L==3	// en
	"Expand folder in documents zone of center"
#elif L==4	// es
	"Expandir carpeta en zona de documentos de centro"
#elif L==5	// fr
	"Expand folder in documents zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in documents zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in documents zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in documents zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Expand folder in documents zone of center"		// eviri lazim!
#endif
	,
	[ActConSeeDocCtr] =
#if   L==1	// ca
	"Contract folder in documents zone of center"		// Necessita traducci
#elif L==2	// de
	"Contract folder in documents zone of center"		// Need bersetzung
#elif L==3	// en
	"Contract folder in documents zone of center"
#elif L==4	// es
	"Contraer carpeta en zona de documentos de centro"
#elif L==5	// fr
	"Contract folder in documents zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in documents zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in documents zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in documents zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Contract folder in documents zone of center"		// eviri lazim!
#endif
	,
	[ActZIPSeeDocCtr] =
#if   L==1	// ca
	"Compress folder in documents zone of center"		// Necessita traducci
#elif L==2	// de
	"Compress folder in documents zone of center"		// Need bersetzung
#elif L==3	// en
	"Compress folder in documents zone of center"
#elif L==4	// es
	"Comprimir carpeta en zona de documentos de centro"
#elif L==5	// fr
	"Compress folder in documents zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in documents zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in documents zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in documents zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Compress folder in documents zone of center"		// eviri lazim!
#endif
	,
	[ActReqDatSeeDocCtr] =
#if   L==1	// ca
	"See file metadata in documents zone of center"			// Necessita traducci
#elif L==2	// de
	"See file metadata in documents zone of center"			// Need bersetzung
#elif L==3	// en
	"See file metadata in documents zone of center"
#elif L==4	// es
	"Ver metadatos de archivo en zona de documentos de centro"
#elif L==5	// fr
	"See file metadata in documents zone of center"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in documents zone of center"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in documents zone of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in documents zone of center"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in documents zone of center"			// eviri lazim!
#endif
	,
	[ActDowSeeDocCtr] =
#if   L==1	// ca
	"Download file from documents zone of center"		// Necessita traducci
#elif L==2	// de
	"Download file from documents zone of center"		// Need bersetzung
#elif L==3	// en
	"Download file from documents zone of center"
#elif L==4	// es
	"Descargar archivo de zona de documentos de centro"
#elif L==5	// fr
	"Download file from documents zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Download file from documents zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from documents zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from documents zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Download file from documents zone of center"		// eviri lazim!
#endif
	,
	[ActChgToAdmDocCtr] =
#if   L==1	// ca
	"Change documents zone of center to management mode"			// Necessita traducci
#elif L==2	// de
	"Change documents zone of center to management mode"			// Need bersetzung
#elif L==3	// en
	"Change documents zone of center to management mode"
#elif L==4	// es
	"Cambiar zona de documentos de centro a modo administraci&oacute;n"
#elif L==5	// fr
	"Change documents zone of center to management mode"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar zona de documentos de centro a modo administraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change documents zone of center to management mode"			// Bisogno di traduzione
#elif L==8	// pl
	"Change documents zone of center to management mode"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change documents zone of center to management mode"			// Precisa de traduo
#elif L==10	// tr
	"Change documents zone of center to management mode"			// eviri lazim!
#endif
	,
	[ActAdmDocCtr] =
#if   L==1	// ca
	"Manage documents zone of the center"		// Necessita traducci
#elif L==2	// de
	"Manage documents zone of the center"		// Need bersetzung
#elif L==3	// en
	"Manage documents zone of the center"
#elif L==4	// es
	"Administrar zona de documentos del centro"
#elif L==5	// fr
	"Manage documents zone of the center"		// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de documentos del centro"	// Okoteve traduccin
#elif L==7	// it
	"Manage documents zone of the center"		// Bisogno di traduzione
#elif L==8	// pl
	"Manage documents zone of the center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage documents zone of the center"		// Precisa de traduo
#elif L==10	// tr
	"Manage documents zone of the center"		// eviri lazim!
#endif
	,
	[ActReqRemFilDocCtr] =
#if   L==1	// ca
	"Request removal of file from documents zone of center"				// Necessita traducci
#elif L==2	// de
	"Request removal of file from documents zone of center"				// Need bersetzung
#elif L==3	// en
	"Request removal of file from documents zone of center"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de centro"
#elif L==5	// fr
	"Request removal of file from documents zone of center"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from documents zone of center"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from documents zone of center"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from documents zone of center"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from documents zone of center"				// eviri lazim!
#endif
	,
	[ActRemFilDocCtr] =
#if   L==1	// ca
	"Remove file from documents zone of center"		// Necessita traducci
#elif L==2	// de
	"Remove file from documents zone of center"		// Need bersetzung
#elif L==3	// en
	"Remove file from documents zone of center"
#elif L==4	// es
	"Eliminar archivo de zona de documentos de centro"
#elif L==5	// fr
	"Remove file from documents zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from documents zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from documents zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from documents zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Remove file from documents zone of center"		// eviri lazim!
#endif
	,
	[ActRemFolDocCtr] =
#if   L==1	// ca
	"Remove empty folder documents zone of center"			// Necessita traducci
#elif L==2	// de
	"Remove empty folder documents zone of center"			// Need bersetzung
#elif L==3	// en
	"Remove empty folder documents zone of center"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona de documentos de centro"
#elif L==5	// fr
	"Remove empty folder documents zone of center"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder documents zone of center"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder documents zone of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder documents zone of center"			// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder documents zone of center"			// eviri lazim!
#endif
	,
	[ActCopDocCtr] =
#if   L==1	// ca
	"Set source of copy in documents zone of center"		// Necessita traducci
#elif L==2	// de
	"Set source of copy in documents zone of center"		// Need bersetzung
#elif L==3	// en
	"Set source of copy in documents zone of center"
#elif L==4	// es
	"Establecer origen de copia en zona de documentos de centro"
#elif L==5	// fr
	"Set source of copy in documents zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in documents zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in documents zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in documents zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in documents zone of center"		// eviri lazim!
#endif
	,
	[ActPasDocCtr] =
#if   L==1	// ca
	"Paste folder/file in documents zone of center"		// Necessita traducci
#elif L==2	// de
	"Paste folder/file in documents zone of center"		// Need bersetzung
#elif L==3	// en
	"Paste folder/file in documents zone of center"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de documentos de centro"
#elif L==5	// fr
	"Paste folder/file in documents zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in documents zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in documents zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in documents zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in documents zone of center"		// eviri lazim!
#endif
	,
	[ActRemTreDocCtr] =
#if   L==1	// ca
	"Remove non-empty folder from documents zone of center"			// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from documents zone of center"			// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from documents zone of center"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona de documentos de centro"
#elif L==5	// fr
	"Remove non-empty folder from documents zone of center"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from documents zone of center"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from documents zone of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from documents zone of center"			// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from documents zone of center"			// eviri lazim!
#endif
	,
	[ActFrmCreDocCtr] =
#if   L==1	// ca
	"Edit new folder/file/link in documents zone of center"			// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in documents zone of center"			// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in documents zone of center"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de documentos de centro"
#elif L==5	// fr
	"Edit new folder/file/link in documents zone of center"			// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in documents zone of center"			// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in documents zone of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in documents zone of center"			// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in documents zone of center"			// eviri lazim!
#endif
	,
	[ActCreFolDocCtr] =
#if   L==1	// ca
	"Create new folder in documents zone of center"		// Necessita traducci
#elif L==2	// de
	"Create new folder in documents zone of center"		// Need bersetzung
#elif L==3	// en
	"Create new folder in documents zone of center"
#elif L==4	// es
	"Crear nueva carpeta en zona de documentos de centro"
#elif L==5	// fr
	"Create new folder in documents zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in documents zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in documents zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in documents zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Create new folder in documents zone of center"		// eviri lazim!
#endif
	,
	[ActCreLnkDocCtr] =
#if   L==1	// ca
	"Create new link in documents zone of center"		// Necessita traducci
#elif L==2	// de
	"Create new link in documents zone of center"		// Need bersetzung
#elif L==3	// en
	"Create new link in documents zone of center"
#elif L==4	// es
	"Crear nuevo enlace en zona de documentos de centro"
#elif L==5	// fr
	"Create new link in documents zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in documents zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in documents zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in documents zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Create new link in documents zone of center"		// eviri lazim!
#endif
	,
	[ActRenFolDocCtr] =
#if   L==1	// ca
	"Rename folder in documents zone of center"		// Necessita traducci
#elif L==2	// de
	"Rename folder in documents zone of center"		// Need bersetzung
#elif L==3	// en
	"Rename folder in documents zone of center"
#elif L==4	// es
	"Renombrar carpeta en zona de documentos de centro"
#elif L==5	// fr
	"Rename folder in documents zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in documents zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in documents zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in documents zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Rename folder in documents zone of center"		// eviri lazim!
#endif
	,
	[ActRcvFilDocCtrDZ] =
#if   L==1	// ca
	"Send file to documents zone of center using Dropzone.js"		// Necessita traducci
#elif L==2	// de
	"Send file to documents zone of center using Dropzone.js"		// Need bersetzung
#elif L==3	// en
	"Send file to documents zone of center using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona de documentos de centro usando Dropzone.js"
#elif L==5	// fr
	"Send file to documents zone of center using Dropzone.js"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de documentos de centro usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to documents zone of center using Dropzone.js"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to documents zone of center using Dropzone.js"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to documents zone of center using Dropzone.js"		// Precisa de traduo
#elif L==10	// tr
	"Send file to documents zone of center using Dropzone.js"		// eviri lazim!
#endif
	,
	[ActRcvFilDocCtrCla] =
#if   L==1	// ca
	"Send file to documents zone of center using the classic way"		// Necessita traducci
#elif L==2	// de
	"Send file to documents zone of center using the classic way"		// Need bersetzung
#elif L==3	// en
	"Send file to documents zone of center using the classic way"
#elif L==4	// es
	"Enviar archivo a zona de documentos de centro de forma tradicional"
#elif L==5	// fr
	"Send file to documents zone of center using the classic way"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de documentos de centro de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file to documents zone of center using the classic way"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to documents zone of center using the classic way"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to documents zone of center using the classic way"		// Precisa de traduo
#elif L==10	// tr
	"Send file to documents zone of center using the classic way"		// eviri lazim!
#endif
	,
	[ActExpAdmDocCtr] =
#if   L==1	// ca
	"Expand folder when managing documents zone of center"		// Necessita traducci
#elif L==2	// de
	"Expand folder when managing documents zone of center"		// Need bersetzung
#elif L==3	// en
	"Expand folder when managing documents zone of center"
#elif L==4	// es
	"Expandir carpeta al administrar zona de documentos de centro"
#elif L==5	// fr
	"Expand folder when managing documents zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta al administrar zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder when managing documents zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder when managing documents zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder when managing documents zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Expand folder when managing documents zone of center"		// eviri lazim!
#endif
	,
	[ActConAdmDocCtr] =
#if   L==1	// ca
	"Contract folder when managing documents zone of center"	// Necessita traducci
#elif L==2	// de
	"Contract folder when managing documents zone of center"	// Need bersetzung
#elif L==3	// en
	"Contract folder when managing documents zone of center"
#elif L==4	// es
	"Contraer carpeta al administrar zona de documentos de centro"
#elif L==5	// fr
	"Contract folder when managing documents zone of center"	// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta al administrar zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder when managing documents zone of center"	// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder when managing documents zone of center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder when managing documents zone of center"	// Precisa de traduo
#elif L==10	// tr
	"Contract folder when managing documents zone of center"	// eviri lazim!
#endif
	,
	[ActZIPAdmDocCtr] =
#if   L==1	// ca
	"Compress folder when managing documents zone of center"	// Necessita traducci
#elif L==2	// de
	"Compress folder when managing documents zone of center"	// Need bersetzung
#elif L==3	// en
	"Compress folder when managing documents zone of center"
#elif L==4	// es
	"Comprimir carpeta al administrar zona de documentos de centro"
#elif L==5	// fr
	"Compress folder when managing documents zone of center"	// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta al administrar zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder when managing documents zone of center"	// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder when managing documents zone of center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder when managing documents zone of center"	// Precisa de traduo
#elif L==10	// tr
	"Compress folder when managing documents zone of center"	// eviri lazim!
#endif
	,
	[ActUnhDocCtr] =
#if   L==1	// ca
	"Unhide folder/file of documents zone of center"		// Necessita traducci
#elif L==2	// de
	"Unhide folder/file of documents zone of center"		// Need bersetzung
#elif L==3	// en
	"Unhide folder/file of documents zone of center"
#elif L==4	// es
	"Mostrar carpeta/archivo en zona de documentos de centro"
#elif L==5	// fr
	"Unhide folder/file of documents zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar carpeta/archivo en zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Unhide folder/file of documents zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Unhide folder/file of documents zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide folder/file of documents zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Unhide folder/file of documents zone of center"		// eviri lazim!
#endif
	,
	[ActHidDocCtr] =
#if   L==1	// ca
	"Hide folder/file of documents zone of center"			// Necessita traducci
#elif L==2	// de
	"Hide folder/file of documents zone of center"			// Need bersetzung
#elif L==3	// en
	"Hide folder/file of documents zone of center"
#elif L==4	// es
	"Ocultar carpeta/archivo en zona de documentos de centro"
#elif L==5	// fr
	"Hide folder/file of documents zone of center"			// Besoin de traduction
#elif L==6	// gn
	"Ocultar carpeta/archivo en zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Hide folder/file of documents zone of center"			// Bisogno di traduzione
#elif L==8	// pl
	"Hide folder/file of documents zone of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide folder/file of documents zone of center"			// Precisa de traduo
#elif L==10	// tr
	"Hide folder/file of documents zone of center"			// eviri lazim!
#endif
	,
	[ActReqDatAdmDocCtr] =
#if   L==1	// ca
	"See file metadata in documents zone of center"			// Necessita traducci
#elif L==2	// de
	"See file metadata in documents zone of center"			// Need bersetzung
#elif L==3	// en
	"See file metadata in documents zone of center"
#elif L==4	// es
	"Ver metadatos de archivo en zona de documentos de centro"
#elif L==5	// fr
	"See file metadata in documents zone of center"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in documents zone of center"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in documents zone of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in documents zone of center"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in documents zone of center"			// eviri lazim!
#endif
	,
	[ActChgDatAdmDocCtr] =
#if   L==1	// ca
	"Change file metadata in documents zone of center"		// Necessita traducci
#elif L==2	// de
	"Change file metadata in documents zone of center"		// Need bersetzung
#elif L==3	// en
	"Change file metadata in documents zone of center"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de documentos de centro"
#elif L==5	// fr
	"Change file metadata in documents zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in documents zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in documents zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in documents zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in documents zone of center"		// eviri lazim!
#endif
	,
	[ActDowAdmDocCtr] =
#if   L==1	// ca
	"Download file from documents zone of center"		// Necessita traducci
#elif L==2	// de
	"Download file from documents zone of center"		// Need bersetzung
#elif L==3	// en
	"Download file from documents zone of center"
#elif L==4	// es
	"Descargar archivo de zona de documentos de centro"
#elif L==5	// fr
	"Download file from documents zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de documentos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Download file from documents zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from documents zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from documents zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Download file from documents zone of center"		// eviri lazim!
#endif
	,
	[ActAdmShaCtr] =
#if   L==1	// ca
	"Manage shared files zone of center"			// Necessita traducci
#elif L==2	// de
	"Manage shared files zone of center"			// Need bersetzung
#elif L==3	// en
	"Manage shared files zone of center"
#elif L==4	// es
	"Administrar zona de archivos compartidos de centro"
#elif L==5	// fr
	"Manage shared files zone of center"			// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de archivos compartidos de centro"	// Okoteve traduccin
#elif L==7	// it
	"Manage shared files zone of center"			// Bisogno di traduzione
#elif L==8	// pl
	"Manage shared files zone of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage shared files zone of center"			// Precisa de traduo
#elif L==10	// tr
	"Manage shared files zone of center"			// eviri lazim!
#endif
	,
	[ActReqRemFilShaCtr] =
#if   L==1	// ca
	"Request removal of shared file of center"			// Necessita traducci
#elif L==2	// de
	"Request removal of shared file of center"			// Need bersetzung
#elif L==3	// en
	"Request removal of shared file of center"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo compartido de centro"
#elif L==5	// fr
	"Request removal of shared file of center"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo compartido de centro"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of shared file of center"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of shared file of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of shared file of center"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of shared file of center"			// eviri lazim!
#endif
	,
	[ActRemFilShaCtr] =
#if   L==1	// ca
	"Remove shared file of center"		// Necessita traducci
#elif L==2	// de
	"Remove shared file of center"		// Need bersetzung
#elif L==3	// en
	"Remove shared file of center"
#elif L==4	// es
	"Eliminar archivo compartido de centro"
#elif L==5	// fr
	"Remove shared file of center"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo compartido de centro"	// Okoteve traduccin
#elif L==7	// it
	"Remove shared file of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove shared file of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove shared file of center"		// Precisa de traduo
#elif L==10	// tr
	"Remove shared file of center"		// eviri lazim!
#endif
	,
	[ActRemFolShaCtr] =
#if   L==1	// ca
	"Remove empty folder from shared zone of center"		// Necessita traducci
#elif L==2	// de
	"Remove empty folder from shared zone of center"		// Need bersetzung
#elif L==3	// en
	"Remove empty folder from shared zone of center"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona compartida de centro"
#elif L==5	// fr
	"Remove empty folder from shared zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona compartida de centro"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from shared zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from shared zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from shared zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from shared zone of center"		// eviri lazim!
#endif
	,
	[ActCopShaCtr] =
#if   L==1	// ca
	"Set source of copy in shared zone of center"			// Necessita traducci
#elif L==2	// de
	"Set source of copy in shared zone of center"			// Need bersetzung
#elif L==3	// en
	"Set source of copy in shared zone of center"
#elif L==4	// es
	"Establecer origen de copia en zona compartida de centro"
#elif L==5	// fr
	"Set source of copy in shared zone of center"			// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona compartida de centro"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in shared zone of center"			// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in shared zone of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in shared zone of center"			// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in shared zone of center"			// eviri lazim!
#endif
	,
	[ActPasShaCtr] =
#if   L==1	// ca
	"Paste folder/file in shared zone of center"		// Necessita traducci
#elif L==2	// de
	"Paste folder/file in shared zone of center"		// Need bersetzung
#elif L==3	// en
	"Paste folder/file in shared zone of center"
#elif L==4	// es
	"Pegar carpeta/archivo en zona compartida de centro"
#elif L==5	// fr
	"Paste folder/file in shared zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona compartida de centro"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in shared zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in shared zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in shared zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in shared zone of center"		// eviri lazim!
#endif
	,
	[ActRemTreShaCtr] =
#if   L==1	// ca
	"Remove non-empty folder from shared zone of center"		// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from shared zone of center"		// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from shared zone of center"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona compartida de centro"
#elif L==5	// fr
	"Remove non-empty folder from shared zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona compartida de centro"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from shared zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from shared zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from shared zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from shared zone of center"		// eviri lazim!
#endif
	,
	[ActFrmCreShaCtr] =
#if   L==1	// ca
	"Edit new folder/file/link in shared zone of center"			// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in shared zone of center"			// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in shared zone of center"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona compartida de centro"
#elif L==5	// fr
	"Edit new folder/file/link in shared zone of center"			// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona compartida de centro"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in shared zone of center"			// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in shared zone of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in shared zone of center"			// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in shared zone of center"			// eviri lazim!
#endif
	,
	[ActCreFolShaCtr] =
#if   L==1	// ca
	"Create new folder in shared zone of center"		// Necessita traducci
#elif L==2	// de
	"Create new folder in shared zone of center"		// Need bersetzung
#elif L==3	// en
	"Create new folder in shared zone of center"
#elif L==4	// es
	"Crear nueva carpeta en zona compartida de centro"
#elif L==5	// fr
	"Create new folder in shared zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona compartida de centro"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in shared zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in shared zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in shared zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Create new folder in shared zone of center"		// eviri lazim!
#endif
	,
	[ActCreLnkShaCtr] =
#if   L==1	// ca
	"Create new link in shared zone of center"		// Necessita traducci
#elif L==2	// de
	"Create new link in shared zone of center"		// Need bersetzung
#elif L==3	// en
	"Create new link in shared zone of center"
#elif L==4	// es
	"Crear nuevo enlace en zona compartida de centro"
#elif L==5	// fr
	"Create new link in shared zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona compartida de centro"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in shared zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in shared zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in shared zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Create new link in shared zone of center"		// eviri lazim!
#endif
	,
	[ActRenFolShaCtr] =
#if   L==1	// ca
	"Rename folder in shared zone of center"		// Necessita traducci
#elif L==2	// de
	"Rename folder in shared zone of center"		// Need bersetzung
#elif L==3	// en
	"Rename folder in shared zone of center"
#elif L==4	// es
	"Renombrar carpeta en zona compartida de centro"
#elif L==5	// fr
	"Rename folder in shared zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona compartida de centro"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in shared zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in shared zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in shared zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Rename folder in shared zone of center"		// eviri lazim!
#endif
	,
	[ActRcvFilShaCtrDZ] =
#if   L==1	// ca
	"Send file to shared zone of center using Dropzone.js"		// Necessita traducci
#elif L==2	// de
	"Send file to shared zone of center using Dropzone.js"		// Need bersetzung
#elif L==3	// en
	"Send file to shared zone of center using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona compartida de centro usando Dropzone.js"
#elif L==5	// fr
	"Send file to shared zone of center using Dropzone.js"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona compartida de centro usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to shared zone of center using Dropzone.js"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to shared zone of center using Dropzone.js"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to shared zone of center using Dropzone.js"		// Precisa de traduo
#elif L==10	// tr
	"Send file to shared zone of center using Dropzone.js"		// eviri lazim!
#endif
	,
	[ActRcvFilShaCtrCla] =
#if   L==1	// ca
	"Send file to shared zone of center using the classic way"		// Necessita traducci
#elif L==2	// de
	"Send file to shared zone of center using the classic way"		// Need bersetzung
#elif L==3	// en
	"Send file to shared zone of center using the classic way"
#elif L==4	// es
	"Enviar archivo a zona compartida de centro de forma tradicional"
#elif L==5	// fr
	"Send file to shared zone of center using the classic way"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona compartida de centro de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file to shared zone of center using the classic way"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to shared zone of center using the classic way"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to shared zone of center using the classic way"		// Precisa de traduo
#elif L==10	// tr
	"Send file to shared zone of center using the classic way"		// eviri lazim!
#endif
	,
	[ActExpShaCtr] =
#if   L==1	// ca
	"Expand folder in shared zone of center"	// Necessita traducci
#elif L==2	// de
	"Expand folder in shared zone of center"	// Need bersetzung
#elif L==3	// en
	"Expand folder in shared zone of center"
#elif L==4	// es
	"Expandir carpeta en zona compartida de centro"
#elif L==5	// fr
	"Expand folder in shared zone of center"	// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona compartida de centro"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in shared zone of center"	// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in shared zone of center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in shared zone of center"	// Precisa de traduo
#elif L==10	// tr
	"Expand folder in shared zone of center"	// eviri lazim!
#endif
	,
	[ActConShaCtr] =
#if   L==1	// ca
	"Contract folder in shared zone of center"	// Necessita traducci
#elif L==2	// de
	"Contract folder in shared zone of center"	// Need bersetzung
#elif L==3	// en
	"Contract folder in shared zone of center"
#elif L==4	// es
	"Contraer carpeta en zona compartida de centro"
#elif L==5	// fr
	"Contract folder in shared zone of center"	// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona compartida de centro"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in shared zone of center"	// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in shared zone of center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in shared zone of center"	// Precisa de traduo
#elif L==10	// tr
	"Contract folder in shared zone of center"	// eviri lazim!
#endif
	,
	[ActZIPShaCtr] =
#if   L==1	// ca
	"Compress folder in shared zone of center"		// Necessita traducci
#elif L==2	// de
	"Compress folder in shared zone of center"		// Need bersetzung
#elif L==3	// en
	"Compress folder in shared zone of center"
#elif L==4	// es
	"Comprimir carpeta en zona compartida de centro"
#elif L==5	// fr
	"Compress folder in shared zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona compartida de centro"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in shared zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in shared zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in shared zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Compress folder in shared zone of center"		// eviri lazim!
#endif
	,
	[ActReqDatShaCtr] =
#if   L==1	// ca
	"See file metadata in shared zone of center"		// Necessita traducci
#elif L==2	// de
	"See file metadata in shared zone of center"		// Need bersetzung
#elif L==3	// en
	"See file metadata in shared zone of center"
#elif L==4	// es
	"Ver metadatos de archivo en zona compartida de centro"
#elif L==5	// fr
	"See file metadata in shared zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona compartida de centro"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in shared zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in shared zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in shared zone of center"		// Precisa de traduo
#elif L==10	// tr
	"See file metadata in shared zone of center"		// eviri lazim!
#endif
	,
	[ActChgDatShaCtr] =
#if   L==1	// ca
	"Change file metadata in shared zone of center"			// Necessita traducci
#elif L==2	// de
	"Change file metadata in shared zone of center"			// Need bersetzung
#elif L==3	// en
	"Change file metadata in shared zone of center"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona compartida de centro"
#elif L==5	// fr
	"Change file metadata in shared zone of center"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona compartida de centro"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in shared zone of center"			// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in shared zone of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in shared zone of center"			// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in shared zone of center"			// eviri lazim!
#endif
	,
	[ActDowShaCtr] =
#if   L==1	// ca
	"Download file from shared zone of center"		// Necessita traducci
#elif L==2	// de
	"Download file from shared zone of center"		// Need bersetzung
#elif L==3	// en
	"Download file from shared zone of center"
#elif L==4	// es
	"Descargar archivo de zona compartida de centro"
#elif L==5	// fr
	"Download file from shared zone of center"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona compartida de centro"	// Okoteve traduccin
#elif L==7	// it
	"Download file from shared zone of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from shared zone of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from shared zone of center"		// Precisa de traduo
#elif L==10	// tr
	"Download file from shared zone of center"		// eviri lazim!
#endif
	,
	[ActSeeAdmDocDeg] =
#if   L==1	// ca
	"Documents zone of degree (see or manage)"				// Necessita traducci
#elif L==2	// de
	"Documents zone of degree (see or manage)"				// Need bersetzung
#elif L==3	// en
	"Documents zone of degree (see or manage)"
#elif L==4	// es
	"Zona de documentos de la titulaci&oacute;n (ver o administrar)"
#elif L==5	// fr
	"Documents zone of degree (see or manage)"				// Besoin de traduction
#elif L==6	// gn
	"Zona de documentos de la titulaci&oacute;n (ver o administrar)"	// Okoteve traduccin
#elif L==7	// it
	"Documents zone of degree (see or manage)"				// Bisogno di traduzione
#elif L==8	// pl
	"Documents zone of degree (see or manage)"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Documents zone of degree (see or manage)"				// Precisa de traduo
#elif L==10	// tr
	"Documents zone of degree (see or manage)"				// eviri lazim!
#endif
	,
	[ActChgToSeeDocDeg] =
#if   L==1	// ca
	"Change documents zone of degree to view mode"				// Necessita traducci
#elif L==2	// de
	"Change documents zone of degree to view mode"				// Need bersetzung
#elif L==3	// en
	"Change documents zone of degree to view mode"
#elif L==4	// es
	"Cambiar zona de documentos de la titulaci&oacute;n a modo vista"
#elif L==5	// fr
	"Change documents zone of degree to view mode"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar zona de documentos de la titulaci&oacute;n a modo vista"	// Okoteve traduccin
#elif L==7	// it
	"Change documents zone of degree to view mode"				// Bisogno di traduzione
#elif L==8	// pl
	"Change documents zone of degree to view mode"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change documents zone of degree to view mode"				// Precisa de traduo
#elif L==10	// tr
	"Change documents zone of degree to view mode"				// eviri lazim!
#endif
	,
	[ActSeeDocDeg] =
#if   L==1	// ca
	"See documents zone of the degree"			// Necessita traducci
#elif L==2	// de
	"See documents zone of the degree"			// Need bersetzung
#elif L==3	// en
	"See documents zone of the degree"
#elif L==4	// es
	"Ver zona de documentos de la titulaci&oacute;n"
#elif L==5	// fr
	"See documents zone of the degree"			// Besoin de traduction
#elif L==6	// gn
	"Ver zona de documentos de la titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See documents zone of the degree"			// Bisogno di traduzione
#elif L==8	// pl
	"See documents zone of the degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See documents zone of the degree"			// Precisa de traduo
#elif L==10	// tr
	"See documents zone of the degree"			// eviri lazim!
#endif
	,
	[ActExpSeeDocDeg] =
#if   L==1	// ca
	"Expand folder in documents zone of degree"			// Necessita traducci
#elif L==2	// de
	"Expand folder in documents zone of degree"			// Need bersetzung
#elif L==3	// en
	"Expand folder in documents zone of degree"
#elif L==4	// es
	"Expandir carpeta en zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Expand folder in documents zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in documents zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in documents zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in documents zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Expand folder in documents zone of degree"			// eviri lazim!
#endif
	,
	[ActConSeeDocDeg] =
#if   L==1	// ca
	"Contract folder in documents zone of degree"			// Necessita traducci
#elif L==2	// de
	"Contract folder in documents zone of degree"			// Need bersetzung
#elif L==3	// en
	"Contract folder in documents zone of degree"
#elif L==4	// es
	"Contraer carpeta en zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Contract folder in documents zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in documents zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in documents zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in documents zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Contract folder in documents zone of degree"			// eviri lazim!
#endif
	,
	[ActZIPSeeDocDeg] =
#if   L==1	// ca
	"Compress folder in documents zone of degree"			// Necessita traducci
#elif L==2	// de
	"Compress folder in documents zone of degree"			// Need bersetzung
#elif L==3	// en
	"Compress folder in documents zone of degree"
#elif L==4	// es
	"Comprimir carpeta en zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Compress folder in documents zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in documents zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in documents zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in documents zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Compress folder in documents zone of degree"			// eviri lazim!
#endif
	,
	[ActReqDatSeeDocDeg] =
#if   L==1	// ca
	"See file metadata in documents zone of degree"				// Necessita traducci
#elif L==2	// de
	"See file metadata in documents zone of degree"				// Need bersetzung
#elif L==3	// en
	"See file metadata in documents zone of degree"
#elif L==4	// es
	"Ver metadatos de archivo en zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"See file metadata in documents zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in documents zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in documents zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in documents zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"See file metadata in documents zone of degree"				// eviri lazim!
#endif
	,
	[ActDowSeeDocDeg] =
#if   L==1	// ca
	"Download file from documents zone of degree"			// Necessita traducci
#elif L==2	// de
	"Download file from documents zone of degree"			// Need bersetzung
#elif L==3	// en
	"Download file from documents zone of degree"
#elif L==4	// es
	"Descargar archivo de zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Download file from documents zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Download file from documents zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Download file from documents zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from documents zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Download file from documents zone of degree"			// eviri lazim!
#endif
	,
	[ActChgToAdmDocDeg] =
#if   L==1	// ca
	"Change documents zone of degree to management mode"				// Necessita traducci
#elif L==2	// de
	"Change documents zone of degree to management mode"				// Need bersetzung
#elif L==3	// en
	"Change documents zone of degree to management mode"
#elif L==4	// es
	"Cambiar zona de documentos de titulaci&oacute;n a modo administraci&oacute;n"
#elif L==5	// fr
	"Change documents zone of degree to management mode"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar zona de documentos de titulaci&oacute;n a modo administraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change documents zone of degree to management mode"				// Bisogno di traduzione
#elif L==8	// pl
	"Change documents zone of degree to management mode"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change documents zone of degree to management mode"				// Precisa de traduo
#elif L==10	// tr
	"Change documents zone of degree to management mode"				// eviri lazim!
#endif
	,
	[ActAdmDocDeg] =
#if   L==1	// ca
	"Manage documents zone of the degree"				// Necessita traducci
#elif L==2	// de
	"Manage documents zone of the degree"				// Need bersetzung
#elif L==3	// en
	"Manage documents zone of the degree"
#elif L==4	// es
	"Administrar zona de documentos de la titulaci&oacute;n"
#elif L==5	// fr
	"Manage documents zone of the degree"				// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de documentos de la titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Manage documents zone of the degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Manage documents zone of the degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage documents zone of the degree"				// Precisa de traduo
#elif L==10	// tr
	"Manage documents zone of the degree"				// eviri lazim!
#endif
	,
	[ActReqRemFilDocDeg] =
#if   L==1	// ca
	"Request removal of file from documents zone of degree"					// Necessita traducci
#elif L==2	// de
	"Request removal of file from documents zone of degree"					// Need bersetzung
#elif L==3	// en
	"Request removal of file from documents zone of degree"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Request removal of file from documents zone of degree"					// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from documents zone of degree"					// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from documents zone of degree"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from documents zone of degree"					// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from documents zone of degree"					// eviri lazim!
#endif
	,
	[ActRemFilDocDeg] =
#if   L==1	// ca
	"Remove file from documents zone of degree"			// Necessita traducci
#elif L==2	// de
	"Remove file from documents zone of degree"			// Need bersetzung
#elif L==3	// en
	"Remove file from documents zone of degree"
#elif L==4	// es
	"Eliminar archivo de zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Remove file from documents zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from documents zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from documents zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from documents zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Remove file from documents zone of degree"			// eviri lazim!
#endif
	,
	[ActRemFolDocDeg] =
#if   L==1	// ca
	"Remove empty folder from documents zone of degree"				// Necessita traducci
#elif L==2	// de
	"Remove empty folder from documents zone of degree"				// Need bersetzung
#elif L==3	// en
	"Remove empty folder from documents zone of degree"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Remove empty folder from documents zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from documents zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from documents zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from documents zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from documents zone of degree"				// eviri lazim!
#endif
	,
	[ActCopDocDeg] =
#if   L==1	// ca
	"Set source of copy in documents zone of degree"			// Necessita traducci
#elif L==2	// de
	"Set source of copy in documents zone of degree"			// Need bersetzung
#elif L==3	// en
	"Set source of copy in documents zone of degree"
#elif L==4	// es
	"Establecer origen de copia zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Set source of copy in documents zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in documents zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in documents zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in documents zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in documents zone of degree"			// eviri lazim!
#endif
	,
	[ActPasDocDeg] =
#if   L==1	// ca
	"Paste folder/file in documents zone of degree"				// Necessita traducci
#elif L==2	// de
	"Paste folder/file in documents zone of degree"				// Need bersetzung
#elif L==3	// en
	"Paste folder/file in documents zone of degree"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Paste folder/file in documents zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in documents zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in documents zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in documents zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in documents zone of degree"				// eviri lazim!
#endif
	,
	[ActRemTreDocDeg] =
#if   L==1	// ca
	"Remove non-empty folder from documents zone of degree"				// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from documents zone of degree"				// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from documents zone of degree"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Remove non-empty folder from documents zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from documents zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from documents zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from documents zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from documents zone of degree"				// eviri lazim!
#endif
	,
	[ActFrmCreDocDeg] =
#if   L==1	// ca
	"Edit new folder/file/link in documents zone of degree"					// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in documents zone of degree"					// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in documents zone of degree"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Edit new folder/file/link in documents zone of degree"					// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in documents zone of degree"					// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in documents zone of degree"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in documents zone of degree"					// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in documents zone of degree"					// eviri lazim!
#endif
	,
	[ActCreFolDocDeg] =
#if   L==1	// ca
	"Create new folder in documents zone of degree"				// Necessita traducci
#elif L==2	// de
	"Create new folder in documents zone of degree"				// Need bersetzung
#elif L==3	// en
	"Create new folder in documents zone of degree"
#elif L==4	// es
	"Crear nueva carpeta en zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Create new folder in documents zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in documents zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in documents zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in documents zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"Create new folder in documents zone of degree"				// eviri lazim!
#endif
	,
	[ActCreLnkDocDeg] =
#if   L==1	// ca
	"Create new link in documents zone of degree"			// Necessita traducci
#elif L==2	// de
	"Create new link in documents zone of degree"			// Need bersetzung
#elif L==3	// en
	"Create new link in documents zone of degree"
#elif L==4	// es
	"Crear nuevo enlace en zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Create new link in documents zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in documents zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in documents zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in documents zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Create new link in documents zone of degree"			// eviri lazim!
#endif
	,
	[ActRenFolDocDeg] =
#if   L==1	// ca
	"Rename folder in documents zone of degree"			// Necessita traducci
#elif L==2	// de
	"Rename folder in documents zone of degree"			// Need bersetzung
#elif L==3	// en
	"Rename folder in documents zone of degree"
#elif L==4	// es
	"Renombrar carpeta en zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Rename folder in documents zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in documents zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in documents zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in documents zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Rename folder in documents zone of degree"			// eviri lazim!
#endif
	,
	[ActRcvFilDocDegDZ] =
#if   L==1	// ca
	"Send file to documents zone of degree using Dropzone.js"			// Necessita traducci
#elif L==2	// de
	"Send file to documents zone of degree using Dropzone.js"			// Need bersetzung
#elif L==3	// en
	"Send file to documents zone of degree using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona de documentos de titulaci&oacute;n usando Dropzone.js"
#elif L==5	// fr
	"Send file to documents zone of degree using Dropzone.js"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de documentos de titulaci&oacute;n usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to documents zone of degree using Dropzone.js"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to documents zone of degree using Dropzone.js"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to documents zone of degree using Dropzone.js"			// Precisa de traduo
#elif L==10	// tr
	"Send file to documents zone of degree using Dropzone.js"			// eviri lazim!
#endif
	,
	[ActRcvFilDocDegCla] =
#if   L==1	// ca
	"Send file to documents zone of degree using the classic way"			// Necessita traducci
#elif L==2	// de
	"Send file to documents zone of degree using the classic way"			// Need bersetzung
#elif L==3	// en
	"Send file to documents zone of degree using the classic way"
#elif L==4	// es
	"Enviar archivo a zona de documentos de titulaci&oacute;n de forma tradicional"
#elif L==5	// fr
	"Send file to documents zone of degree using the classic way"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de documentos de titulaci&oacute;n de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file to documents zone of degree using the classic way"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to documents zone of degree using the classic way"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to documents zone of degree using the classic way"			// Precisa de traduo
#elif L==10	// tr
	"Send file to documents zone of degree using the classic way"			// eviri lazim!
#endif
	,
	[ActExpAdmDocDeg] =
#if   L==1	// ca
	"Expand folder when managing documents zone of degree"				// Necessita traducci
#elif L==2	// de
	"Expand folder when managing documents zone of degree"				// Need bersetzung
#elif L==3	// en
	"Expand folder when managing documents zone of degree"
#elif L==4	// es
	"Expandir carpeta al administrar zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Expand folder when managing documents zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta al administrar zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder when managing documents zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder when managing documents zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder when managing documents zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"Expand folder when managing documents zone of degree"				// eviri lazim!
#endif
	,
	[ActConAdmDocDeg] =
#if   L==1	// ca
	"Contract folder when managing documents zone of degree"			// Necessita traducci
#elif L==2	// de
	"Contract folder when managing documents zone of degree"			// Need bersetzung
#elif L==3	// en
	"Contract folder when managing documents zone of degree"
#elif L==4	// es
	"Contraer carpeta al administrar zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Contract folder when managing documents zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta al administrar zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder when managing documents zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder when managing documents zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder when managing documents zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Contract folder when managing documents zone of degree"			// eviri lazim!
#endif
	,
	[ActZIPAdmDocDeg] =
#if   L==1	// ca
	"Compress folder when mamaging documents zone of degree"			// Necessita traducci
#elif L==2	// de
	"Compress folder when mamaging documents zone of degree"			// Need bersetzung
#elif L==3	// en
	"Compress folder when mamaging documents zone of degree"
#elif L==4	// es
	"Comprimir carpeta al administrar zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Compress folder when mamaging documents zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta al administrar zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder when mamaging documents zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder when mamaging documents zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder when mamaging documents zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Compress folder when mamaging documents zone of degree"			// eviri lazim!
#endif
	,
	[ActUnhDocDeg] =
#if   L==1	// ca
	"Unhide folder/file in documents zone of degree"			// Necessita traducci
#elif L==2	// de
	"Unhide folder/file in documents zone of degree"			// Need bersetzung
#elif L==3	// en
	"Unhide folder/file in documents zone of degree"
#elif L==4	// es
	"Mostrar carpeta/archivo en zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Unhide folder/file in documents zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Mostrar carpeta/archivo en zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Unhide folder/file in documents zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Unhide folder/file in documents zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide folder/file in documents zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Unhide folder/file in documents zone of degree"			// eviri lazim!
#endif
	,
	[ActHidDocDeg] =
#if   L==1	// ca
	"Hide folder/file in documents zone of degree"				// Necessita traducci
#elif L==2	// de
	"Hide folder/file in documents zone of degree"				// Need bersetzung
#elif L==3	// en
	"Hide folder/file in documents zone of degree"
#elif L==4	// es
	"Ocultar carpeta/archivo en zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Hide folder/file in documents zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Ocultar carpeta/archivo en zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Hide folder/file in documents zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Hide folder/file in documents zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide folder/file in documents zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"Hide folder/file in documents zone of degree"				// eviri lazim!
#endif
	,
	[ActReqDatAdmDocDeg] =
#if   L==1	// ca
	"See file metadata in documents zone of degree"				// Necessita traducci
#elif L==2	// de
	"See file metadata in documents zone of degree"				// Need bersetzung
#elif L==3	// en
	"See file metadata in documents zone of degree"
#elif L==4	// es
	"Ver metadatos de archivo en zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"See file metadata in documents zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in documents zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in documents zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in documents zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"See file metadata in documents zone of degree"				// eviri lazim!
#endif
	,
	[ActChgDatAdmDocDeg] =
#if   L==1	// ca
	"Change file metadata in documents zone of degree"				// Necessita traducci
#elif L==2	// de
	"Change file metadata in documents zone of degree"				// Need bersetzung
#elif L==3	// en
	"Change file metadata in documents zone of degree"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Change file metadata in documents zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in documents zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in documents zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in documents zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in documents zone of degree"				// eviri lazim!
#endif
	,
	[ActDowAdmDocDeg] =
#if   L==1	// ca
	"Download file from documents zone of degree"			// Necessita traducci
#elif L==2	// de
	"Download file from documents zone of degree"			// Need bersetzung
#elif L==3	// en
	"Download file from documents zone of degree"
#elif L==4	// es
	"Descargar archivo de zona de documentos de titulaci&oacute;n"
#elif L==5	// fr
	"Download file from documents zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de documentos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Download file from documents zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Download file from documents zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from documents zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Download file from documents zone of degree"			// eviri lazim!
#endif
	,
	[ActAdmShaDeg] =
#if   L==1	// ca
	"Manage shared files zone of degree"				// Necessita traducci
#elif L==2	// de
	"Manage shared files zone of degree"				// Need bersetzung
#elif L==3	// en
	"Manage shared files zone of degree"
#elif L==4	// es
	"Administrar zona de archivos compartidos de titulaci&oacute;n"
#elif L==5	// fr
	"Manage shared files zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de archivos compartidos de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Manage shared files zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Manage shared files zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage shared files zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"Manage shared files zone of degree"				// eviri lazim!
#endif
	,
	[ActReqRemFilShaDeg] =
#if   L==1	// ca
	"Request removal of file from shared zone of degree"				// Necessita traducci
#elif L==2	// de
	"Request removal of file from shared zone of degree"				// Need bersetzung
#elif L==3	// en
	"Request removal of file from shared zone of degree"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo compartido de titulaci&oacute;n"
#elif L==5	// fr
	"Request removal of file from shared zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo compartido de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from shared zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from shared zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from shared zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from shared zone of degree"				// eviri lazim!
#endif
	,
	[ActRemFilShaDeg] =
#if   L==1	// ca
	"Remove shared file from shared zone of degree"			// Necessita traducci
#elif L==2	// de
	"Remove shared file from shared zone of degree"			// Need bersetzung
#elif L==3	// en
	"Remove shared file from shared zone of degree"
#elif L==4	// es
	"Eliminar archivo de zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"Remove shared file from shared zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove shared file from shared zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove shared file from shared zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove shared file from shared zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Remove shared file from shared zone of degree"			// eviri lazim!
#endif
	,
	[ActRemFolShaDeg] =
#if   L==1	// ca
	"Remove empty folder from shared zone of degree"			// Necessita traducci
#elif L==2	// de
	"Remove empty folder from shared zone of degree"			// Need bersetzung
#elif L==3	// en
	"Remove empty folder from shared zone of degree"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"Remove empty folder from shared zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from shared zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from shared zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from shared zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from shared zone of degree"			// eviri lazim!
#endif
	,
	[ActCopShaDeg] =
#if   L==1	// ca
	"Set source of copy in shared zone of degree"				// Necessita traducci
#elif L==2	// de
	"Set source of copy in shared zone of degree"				// Need bersetzung
#elif L==3	// en
	"Set source of copy in shared zone of degree"
#elif L==4	// es
	"Establecer origen de copia en zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"Set source of copy in shared zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in shared zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in shared zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in shared zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in shared zone of degree"				// eviri lazim!
#endif
	,
	[ActPasShaDeg] =
#if   L==1	// ca
	"Paste folder/file in shared zone of degree"			// Necessita traducci
#elif L==2	// de
	"Paste folder/file in shared zone of degree"			// Need bersetzung
#elif L==3	// en
	"Paste folder/file in shared zone of degree"
#elif L==4	// es
	"Pegar carpeta/archivo en zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"Paste folder/file in shared zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in shared zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in shared zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in shared zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in shared zone of degree"			// eviri lazim!
#endif
	,
	[ActRemTreShaDeg] =
#if   L==1	// ca
	"Remove non-empty folder from shared zone of degree"				// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from shared zone of degree"				// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from shared zone of degree"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"Remove non-empty folder from shared zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from shared zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from shared zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from shared zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from shared zone of degree"				// eviri lazim!
#endif
	,
	[ActFrmCreShaDeg] =
#if   L==1	// ca
	"Edit new folder/file/link in shared zone of degree"				// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in shared zone of degree"				// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in shared zone of degree"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"Edit new folder/file/link in shared zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in shared zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in shared zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in shared zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in shared zone of degree"				// eviri lazim!
#endif
	,
	[ActCreFolShaDeg] =
#if   L==1	// ca
	"Create new folder in shared zone of degree"			// Necessita traducci
#elif L==2	// de
	"Create new folder in shared zone of degree"			// Need bersetzung
#elif L==3	// en
	"Create new folder in shared zone of degree"
#elif L==4	// es
	"Crear nueva carpeta en zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"Create new folder in shared zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in shared zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in shared zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in shared zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Create new folder in shared zone of degree"			// eviri lazim!
#endif
	,
	[ActCreLnkShaDeg] =
#if   L==1	// ca
	"Create new link in shared zone of degree"			// Necessita traducci
#elif L==2	// de
	"Create new link in shared zone of degree"			// Need bersetzung
#elif L==3	// en
	"Create new link in shared zone of degree"
#elif L==4	// es
	"Crear nuevo enlace en zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"Create new link in shared zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in shared zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in shared zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in shared zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Create new link in shared zone of degree"			// eviri lazim!
#endif
	,
	[ActRenFolShaDeg] =
#if   L==1	// ca
	"Rename folder in shared zone of degree"			// Necessita traducci
#elif L==2	// de
	"Rename folder in shared zone of degree"			// Need bersetzung
#elif L==3	// en
	"Rename folder in shared zone of degree"
#elif L==4	// es
	"Renombrar carpeta en zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"Rename folder in shared zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in shared zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in shared zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in shared zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Rename folder in shared zone of degree"			// eviri lazim!
#endif
	,
	[ActRcvFilShaDegDZ] =
#if   L==1	// ca
	"Send file to shared zone of degree using Dropzone.js"				// Necessita traducci
#elif L==2	// de
	"Send file to shared zone of degree using Dropzone.js"				// Need bersetzung
#elif L==3	// en
	"Send file to shared zone of degree using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona compartida de titulaci&oacute;n usando Dropzone.js"
#elif L==5	// fr
	"Send file to shared zone of degree using Dropzone.js"				// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona compartida de titulaci&oacute;n usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to shared zone of degree using Dropzone.js"				// Bisogno di traduzione
#elif L==8	// pl
	"Send file to shared zone of degree using Dropzone.js"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to shared zone of degree using Dropzone.js"				// Precisa de traduo
#elif L==10	// tr
	"Send file to shared zone of degree using Dropzone.js"				// eviri lazim!
#endif
	,
	[ActRcvFilShaDegCla] =
#if   L==1	// ca
	"Send file in shared zone of degree using the classic way"			// Necessita traducci
#elif L==2	// de
	"Send file in shared zone of degree using the classic way"			// Need bersetzung
#elif L==3	// en
	"Send file in shared zone of degree using the classic way"
#elif L==4	// es
	"Enviar archivo a zona compartida de titulaci&oacute;n de forma tradicional"
#elif L==5	// fr
	"Send file in shared zone of degree using the classic way"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona compartida de titulaci&oacute;n de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file in shared zone of degree using the classic way"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file in shared zone of degree using the classic way"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file in shared zone of degree using the classic way"			// Precisa de traduo
#elif L==10	// tr
	"Send file in shared zone of degree using the classic way"			// eviri lazim!
#endif
	,
	[ActExpShaDeg] =
#if   L==1	// ca
	"Expand folder in shared zone of degree"			// Necessita traducci
#elif L==2	// de
	"Expand folder in shared zone of degree"			// Need bersetzung
#elif L==3	// en
	"Expand folder in shared zone of degree"
#elif L==4	// es
	"Expandir carpeta en zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"Expand folder in shared zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in shared zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in shared zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in shared zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Expand folder in shared zone of degree"			// eviri lazim!
#endif
	,
	[ActConShaDeg] =
#if   L==1	// ca
	"Contract folder in shared zone of degree"			// Necessita traducci
#elif L==2	// de
	"Contract folder in shared zone of degree"			// Need bersetzung
#elif L==3	// en
	"Contract folder in shared zone of degree"
#elif L==4	// es
	"Contraer carpeta en zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"Contract folder in shared zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in shared zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in shared zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in shared zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Contract folder in shared zone of degree"			// eviri lazim!
#endif
	,
	[ActZIPShaDeg] =
#if   L==1	// ca
	"Compress folder in shared zone of degree"			// Necessita traducci
#elif L==2	// de
	"Compress folder in shared zone of degree"			// Need bersetzung
#elif L==3	// en
	"Compress folder in shared zone of degree"
#elif L==4	// es
	"Comprimir carpeta en zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"Compress folder in shared zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in shared zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in shared zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in shared zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Compress folder in shared zone of degree"			// eviri lazim!
#endif
	,
	[ActReqDatShaDeg] =
#if   L==1	// ca
	"See file metadata in shared zone of degree"				// Necessita traducci
#elif L==2	// de
	"See file metadata in shared zone of degree"				// Need bersetzung
#elif L==3	// en
	"See file metadata in shared zone of degree"
#elif L==4	// es
	"Ver metadatos de archivo en zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"See file metadata in shared zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in shared zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in shared zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in shared zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"See file metadata in shared zone of degree"				// eviri lazim!
#endif
	,
	[ActChgDatShaDeg] =
#if   L==1	// ca
	"Change file metadata in shared zone of degree"				// Necessita traducci
#elif L==2	// de
	"Change file metadata in shared zone of degree"				// Need bersetzung
#elif L==3	// en
	"Change file metadata in shared zone of degree"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"Change file metadata in shared zone of degree"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in shared zone of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in shared zone of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in shared zone of degree"				// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in shared zone of degree"				// eviri lazim!
#endif
	,
	[ActDowShaDeg] =
#if   L==1	// ca
	"Download file from shared zone of degree"			// Necessita traducci
#elif L==2	// de
	"Download file from shared zone of degree"			// Need bersetzung
#elif L==3	// en
	"Download file from shared zone of degree"
#elif L==4	// es
	"Descargar archivo de zona compartida de titulaci&oacute;n"
#elif L==5	// fr
	"Download file from shared zone of degree"			// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona compartida de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Download file from shared zone of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Download file from shared zone of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from shared zone of degree"			// Precisa de traduo
#elif L==10	// tr
	"Download file from shared zone of degree"			// eviri lazim!
#endif
	,
	[ActSeeAdmDocCrsGrp] =
#if   L==1	// ca
	"Documents zone of course (see or manage)"		// Necessita traducci
#elif L==2	// de
	"Documents zone of course (see or manage)"		// Need bersetzung
#elif L==3	// en
	"Documents zone of course (see or manage)"
#elif L==4	// es
	"Zona de documentos de asignatura (ver o administrar)"
#elif L==5	// fr
	"Documents zone of course (see or manage)"		// Besoin de traduction
#elif L==6	// gn
	"Zona de documentos de asignatura (ver o administrar)"	// Okoteve traduccin
#elif L==7	// it
	"Documents zone of course (see or manage)"		// Bisogno di traduzione
#elif L==8	// pl
	"Documents zone of course (see or manage)"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Documents zone of course (see or manage)"		// Precisa de traduo
#elif L==10	// tr
	"Documents zone of course (see or manage)"		// eviri lazim!
#endif
	,
	[ActChgToSeeDocCrs] =
#if   L==1	// ca
	"Change documents zone of course/group to view mode"		// Necessita traducci
#elif L==2	// de
	"Change documents zone of course/group to view mode"		// Need bersetzung
#elif L==3	// en
	"Change documents zone of course/group to view mode"
#elif L==4	// es
	"Cambiar zona de documentos de asignatura/grupo a modo vista"
#elif L==5	// fr
	"Change documents zone of course/group to view mode"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar zona de documentos de asignatura/grupo a modo vista"	// Okoteve traduccin
#elif L==7	// it
	"Change documents zone of course/group to view mode"		// Bisogno di traduzione
#elif L==8	// pl
	"Change documents zone of course/group to view mode"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change documents zone of course/group to view mode"		// Precisa de traduo
#elif L==10	// tr
	"Change documents zone of course/group to view mode"		// eviri lazim!
#endif
	,
	[ActSeeDocCrs] =
#if   L==1	// ca
	"Veure zona de documents de l'assignatura"
#elif L==2	// de
	"Siehe Dokumentenbereich der Kurs"
#elif L==3	// en
	"See document area of the course"
#elif L==4	// es
	"Ver zona de documentos de la asignatura"
#elif L==5	// fr
	"Voir la zone de documents de la mati&egrave;re"
#elif L==6	// gn
	"Ver zona de documentos de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Vedi area documenti del corso"
#elif L==8	// pl
	"Zobacz obszar dokumentu kursu"
#elif L==9	// pt
	"Ver a &aacute;rea de documentos da disciplina"
#elif L==10	// tr
	"Kursun belge alan&inodot;na bak&inodot;n"
#endif
	,
	[ActExpSeeDocCrs] =
#if   L==1	// ca
	"Expand folder in documents zone of course"		// Necessita traducci
#elif L==2	// de
	"Expand folder in documents zone of course"		// Need bersetzung
#elif L==3	// en
	"Expand folder in documents zone of course"
#elif L==4	// es
	"Expandir carpeta en zona de documentos de asignatura"
#elif L==5	// fr
	"Expand folder in documents zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in documents zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in documents zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in documents zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Expand folder in documents zone of course"		// eviri lazim!
#endif
	,
	[ActConSeeDocCrs] =
#if   L==1	// ca
	"Contract folder in documents zone of course"		// Necessita traducci
#elif L==2	// de
	"Contract folder in documents zone of course"		// Need bersetzung
#elif L==3	// en
	"Contract folder in documents zone of course"
#elif L==4	// es
	"Contraer carpeta en zona de documentos de asignatura"
#elif L==5	// fr
	"Contract folder in documents zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in documents zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in documents zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in documents zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Contract folder in documents zone of course"		// eviri lazim!
#endif
	,
	[ActZIPSeeDocCrs] =
#if   L==1	// ca
	"Compress folder in documents zone of course"		// Necessita traducci
#elif L==2	// de
	"Compress folder in documents zone of course"		// Need bersetzung
#elif L==3	// en
	"Compress folder in documents zone of course"
#elif L==4	// es
	"Comprimir carpeta en zona de documentos de asignatura"
#elif L==5	// fr
	"Compress folder in documents zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in documents zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in documents zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in documents zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Compress folder in documents zone of course"		// eviri lazim!
#endif
	,
	[ActReqDatSeeDocCrs] =
#if   L==1	// ca
	"See file metadata in documents zone of course"			// Necessita traducci
#elif L==2	// de
	"See file metadata in documents zone of course"			// Need bersetzung
#elif L==3	// en
	"See file metadata in documents zone of course"
#elif L==4	// es
	"Ver metadatos de archivo en zona de documentos de asignatura"
#elif L==5	// fr
	"See file metadata in documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in documents zone of course"			// eviri lazim!
#endif
	,
	[ActReqLnkSeeDocCrs] =
#if   L==1	// ca
	"Copy link to file when showing course documents area"			// Necessita traducci
#elif L==2	// de
	"Copy link to file when showing course documents area"			// Need bersetzung
#elif L==3	// en
	"Copy link to file when showing course documents area"
#elif L==4	// es
	"Copiar enlace a archivo viendo zona de documentos de asignatura"
#elif L==5	// fr
	"Copy link to file when showing course documents area"			// Besoin de traduction
#elif L==6	// gn
	"Copiar enlace a archivo viendo zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Copy link to file when showing course documents area"			// Bisogno di traduzione
#elif L==8	// pl
	"Copy link to file when showing course documents area"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Copy link to file when showing course documents area"			// Precisa de traduo
#elif L==10	// tr
	"Copy link to file when showing course documents area"			// eviri lazim!
#endif
	,
	[ActDowSeeDocCrs] =
#if   L==1	// ca
	"Download file from documents zone of course"		// Necessita traducci
#elif L==2	// de
	"Download file from documents zone of course"		// Need bersetzung
#elif L==3	// en
	"Download file from documents zone of course"
#elif L==4	// es
	"Descargar archivo de zona de documentos de asignatura"
#elif L==5	// fr
	"Download file from documents zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Download file from documents zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from documents zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from documents zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Download file from documents zone of course"		// eviri lazim!
#endif
	,
	[ActSeeDocGrp] =
#if   L==1	// ca
	"See documents zone of this group"	// Necessita traducci
#elif L==2	// de
	"See documents zone of this group"	// Need bersetzung
#elif L==3	// en
	"See documents zone of this group"
#elif L==4	// es
	"Ver zona de documentos del grupo"
#elif L==5	// fr
	"See documents zone of this group"	// Besoin de traduction
#elif L==6	// gn
	"Ver zona de documentos del grupo"	// Okoteve traduccin
#elif L==7	// it
	"See documents zone of this group"	// Bisogno di traduzione
#elif L==8	// pl
	"See documents zone of this group"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See documents zone of this group"	// Precisa de traduo
#elif L==10	// tr
	"See documents zone of this group"	// eviri lazim!
#endif
	,
	[ActExpSeeDocGrp] =
#if   L==1	// ca
	"Expand folder in documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Expand folder in documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Expand folder in documents zone of group"
#elif L==4	// es
	"Expandir carpeta en zona de documentos de grupo"
#elif L==5	// fr
	"Expand folder in documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Expand folder in documents zone of group"		// eviri lazim!
#endif
	,
	[ActConSeeDocGrp] =
#if   L==1	// ca
	"Contract folder in documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Contract folder in documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Contract folder in documents zone of group"
#elif L==4	// es
	"Contraer carpeta en zona de documentos de grupo"
#elif L==5	// fr
	"Contract folder in documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Contract folder in documents zone of group"		// eviri lazim!
#endif
	,
	[ActZIPSeeDocGrp] =
#if   L==1	// ca
	"Compress folder in documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Compress folder in documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Compress folder in documents zone of group"
#elif L==4	// es
	"Comprimir carpeta en zona de documentos de grupo"
#elif L==5	// fr
	"Compress folder in documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Compress folder in documents zone of group"		// eviri lazim!
#endif
	,
	[ActReqDatSeeDocGrp] =
#if   L==1	// ca
	"See file metadata in documents zone of group"			// Necessita traducci
#elif L==2	// de
	"See file metadata in documents zone of group"			// Need bersetzung
#elif L==3	// en
	"See file metadata in documents zone of group"
#elif L==4	// es
	"Ver metadatos de archivo en zona de documentos de grupo"
#elif L==5	// fr
	"See file metadata in documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in documents zone of group"			// eviri lazim!
#endif
	,
	[ActDowSeeDocGrp] =
#if   L==1	// ca
	"Download file from documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Download file from documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Download file from documents zone of group"
#elif L==4	// es
	"Descargar archivo de zona de documentos de grupo"
#elif L==5	// fr
	"Download file from documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Download file from documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Download file from documents zone of group"		// eviri lazim!
#endif
	,
	[ActChgToAdmDocCrs] =
#if   L==1	// ca
	"Change documents zone of course/group to management mode"			// Necessita traducci
#elif L==2	// de
	"Change documents zone of course/group to management mode"			// Need bersetzung
#elif L==3	// en
	"Change documents zone of course/group to management mode"
#elif L==4	// es
	"Cambiar zona de documentos de asignatura/grupo a modo administraci&oacute;n"
#elif L==5	// fr
	"Change documents zone of course/group to management mode"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar zona de documentos de asignatura/grupo a modo administraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change documents zone of course/group to management mode"			// Bisogno di traduzione
#elif L==8	// pl
	"Change documents zone of course/group to management mode"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change documents zone of course/group to management mode"			// Precisa de traduo
#elif L==10	// tr
	"Change documents zone of course/group to management mode"			// eviri lazim!
#endif
	,
	[ActAdmDocCrs] =
#if   L==1	// ca
	"Manage documents zone of the course"			// Necessita traducci
#elif L==2	// de
	"Manage documents zone of the course"			// Need bersetzung
#elif L==3	// en
	"Manage documents zone of the course"
#elif L==4	// es
	"Administrar zona de documentos de la asignatura"
#elif L==5	// fr
	"Manage documents zone of the course"			// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de documentos de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Manage documents zone of the course"			// Bisogno di traduzione
#elif L==8	// pl
	"Manage documents zone of the course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage documents zone of the course"			// Precisa de traduo
#elif L==10	// tr
	"Manage documents zone of the course"			// eviri lazim!
#endif
	,
	[ActReqRemFilDocCrs] =
#if   L==1	// ca
	"Request removal of file in documents zone of course"				// Necessita traducci
#elif L==2	// de
	"Request removal of file in documents zone of course"				// Need bersetzung
#elif L==3	// en
	"Request removal of file in documents zone of course"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de asignatura"
#elif L==5	// fr
	"Request removal of file in documents zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file in documents zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file in documents zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file in documents zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of file in documents zone of course"				// eviri lazim!
#endif
	,
	[ActRemFilDocCrs] =
#if   L==1	// ca
	"Remove file in documents zone of course"		// Necessita traducci
#elif L==2	// de
	"Remove file in documents zone of course"		// Need bersetzung
#elif L==3	// en
	"Remove file in documents zone of course"
#elif L==4	// es
	"Eliminar archivo de zona de documentos de asignatura"
#elif L==5	// fr
	"Remove file in documents zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove file in documents zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove file in documents zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file in documents zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Remove file in documents zone of course"		// eviri lazim!
#endif
	,
	[ActRemFolDocCrs] =
#if   L==1	// ca
	"Remove empty folder from documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Remove empty folder from documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Remove empty folder from documents zone of course"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona de documentos de asignatura"
#elif L==5	// fr
	"Remove empty folder from documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from documents zone of course"			// eviri lazim!
#endif
	,
	[ActCopDocCrs] =
#if   L==1	// ca
	"Set source of copy in documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Set source of copy in documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Set source of copy in documents zone of course"
#elif L==4	// es
	"Establecer origen de copia en zona de documentos de asignatura"
#elif L==5	// fr
	"Set source of copy in documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in documents zone of course"			// eviri lazim!
#endif
	,
	[ActPasDocCrs] =
#if   L==1	// ca
	"Paste folder/file in documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Paste folder/file in documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Paste folder/file in documents zone of course"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de documentos de asignatura"
#elif L==5	// fr
	"Paste folder/file in documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in documents zone of course"			// eviri lazim!
#endif
	,
	[ActRemTreDocCrs] =
#if   L==1	// ca
	"Remove non-empty folder from documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from documents zone of course"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona de documentos de asignatura"
#elif L==5	// fr
	"Remove non-empty folder from documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from documents zone of course"			// eviri lazim!
#endif
	,
	[ActFrmCreDocCrs] =
#if   L==1	// ca
	"Edit new folder/file/link in documents zone of course"				// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in documents zone of course"				// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in documents zone of course"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de documentos de asignatura"
#elif L==5	// fr
	"Edit new folder/file/link in documents zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in documents zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in documents zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in documents zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in documents zone of course"				// eviri lazim!
#endif
	,
	[ActCreFolDocCrs] =
#if   L==1	// ca
	"Create new folder in documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Create new folder in documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Create new folder in documents zone of course"
#elif L==4	// es
	"Crear nueva carpeta en zona de documentos de asignatura"
#elif L==5	// fr
	"Create new folder in documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Create new folder in documents zone of course"			// eviri lazim!
#endif
	,
	[ActCreLnkDocCrs] =
#if   L==1	// ca
	"Create new link in documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Create new link in documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Create new link in documents zone of course"
#elif L==4	// es
	"Crear nuevo enlace en zona de documentos de asignatura"
#elif L==5	// fr
	"Create new link in documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Create new link in documents zone of course"			// eviri lazim!
#endif
	,
	[ActRenFolDocCrs] =
#if   L==1	// ca
	"Rename folder in documents zone of course"		// Necessita traducci
#elif L==2	// de
	"Rename folder in documents zone of course"		// Need bersetzung
#elif L==3	// en
	"Rename folder in documents zone of course"
#elif L==4	// es
	"Renombrar carpeta en zona de documentos de asignatura"
#elif L==5	// fr
	"Rename folder in documents zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in documents zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in documents zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in documents zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Rename folder in documents zone of course"		// eviri lazim!
#endif
	,
	[ActRcvFilDocCrsDZ] =
#if   L==1	// ca
	"Send file to documents zone of course using Dropzone.js"		// Necessita traducci
#elif L==2	// de
	"Send file to documents zone of course using Dropzone.js"		// Need bersetzung
#elif L==3	// en
	"Send file to documents zone of course using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona de documentos de asignatura usando Dropzone.js"
#elif L==5	// fr
	"Send file to documents zone of course using Dropzone.js"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de documentos de asignatura usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to documents zone of course using Dropzone.js"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to documents zone of course using Dropzone.js"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to documents zone of course using Dropzone.js"		// Precisa de traduo
#elif L==10	// tr
	"Send file to documents zone of course using Dropzone.js"		// eviri lazim!
#endif
	,
	[ActRcvFilDocCrsCla] =
#if   L==1	// ca
	"Send file in documents zone of course using the classic way"			// Necessita traducci
#elif L==2	// de
	"Send file in documents zone of course using the classic way"			// Need bersetzung
#elif L==3	// en
	"Send file in documents zone of course using the classic way"
#elif L==4	// es
	"Enviar archivo a zona de documentos de asignatura de forma tradicional"
#elif L==5	// fr
	"Send file in documents zone of course using the classic way"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de documentos de asignatura de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file in documents zone of course using the classic way"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file in documents zone of course using the classic way"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file in documents zone of course using the classic way"			// Precisa de traduo
#elif L==10	// tr
	"Send file in documents zone of course using the classic way"			// eviri lazim!
#endif
	,
	[ActExpAdmDocCrs] =
#if   L==1	// ca
	"Expand folder when managing documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Expand folder when managing documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Expand folder when managing documents zone of course"
#elif L==4	// es
	"Expandir carpeta al administrar zona de documentos de asignatura"
#elif L==5	// fr
	"Expand folder when managing documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta al administrar zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder when managing documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder when managing documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder when managing documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Expand folder when managing documents zone of course"			// eviri lazim!
#endif
	,
	[ActConAdmDocCrs] =
#if   L==1	// ca
	"Contract folder when managing documents zone of course"		// Necessita traducci
#elif L==2	// de
	"Contract folder when managing documents zone of course"		// Need bersetzung
#elif L==3	// en
	"Contract folder when managing documents zone of course"
#elif L==4	// es
	"Contraer carpeta al administrar zona de documentos de asignatura"
#elif L==5	// fr
	"Contract folder when managing documents zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta al administrar zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder when managing documents zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder when managing documents zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder when managing documents zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Contract folder when managing documents zone of course"		// eviri lazim!
#endif
	,
	[ActZIPAdmDocCrs] =
#if   L==1	// ca
	"Compress folder when managing documents zone of course"		// Necessita traducci
#elif L==2	// de
	"Compress folder when managing documents zone of course"		// Need bersetzung
#elif L==3	// en
	"Compress folder when managing documents zone of course"
#elif L==4	// es
	"Comprimir carpeta al administrar zona de documentos de asignatura"
#elif L==5	// fr
	"Compress folder when managing documents zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta al administrar zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder when managing documents zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder when managing documents zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder when managing documents zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Compress folder when managing documents zone of course"		// eviri lazim!
#endif
	,
	[ActUnhDocCrs] =
#if   L==1	// ca
	"Unhide folder/file in documents zone of course"		// Necessita traducci
#elif L==2	// de
	"Unhide folder/file in documents zone of course"		// Need bersetzung
#elif L==3	// en
	"Unhide folder/file in documents zone of course"
#elif L==4	// es
	"Mostrar carpeta/archivo en zona de documentos de asignatura"
#elif L==5	// fr
	"Unhide folder/file in documents zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar carpeta/archivo en zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Unhide folder/file in documents zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Unhide folder/file in documents zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide folder/file in documents zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Unhide folder/file in documents zone of course"		// eviri lazim!
#endif
	,
	[ActHidDocCrs] =
#if   L==1	// ca
	"Hide folder/file in documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Hide folder/file in documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Hide folder/file in documents zone of course"
#elif L==4	// es
	"Ocultar carpeta/archivo en zona de documentos de asignatura"
#elif L==5	// fr
	"Hide folder/file in documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Ocultar carpeta/archivo en zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Hide folder/file in documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Hide folder/file in documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide folder/file in documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Hide folder/file in documents zone of course"			// eviri lazim!
#endif
	,
	[ActReqDatAdmDocCrs] =
#if   L==1	// ca
	"See file metadata in documents zone of course"			// Necessita traducci
#elif L==2	// de
	"See file metadata in documents zone of course"			// Need bersetzung
#elif L==3	// en
	"See file metadata in documents zone of course"
#elif L==4	// es
	"Ver metadatos de archivo en zona de documentos de asignatura"
#elif L==5	// fr
	"See file metadata in documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in documents zone of course"			// eviri lazim!
#endif
	,
	[ActChgDatAdmDocCrs] =
#if   L==1	// ca
	"Change file metadata in documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Change file metadata in documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Change file metadata in documents zone of course"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de documentos de asignatura"
#elif L==5	// fr
	"Change file metadata in documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in documents zone of course"			// eviri lazim!
#endif
	,
	[ActReqLnkAdmDocCrs] =
#if   L==1	// ca
	"Copy link to file when managing course documents area"				// Necessita traducci
#elif L==2	// de
	"Copy link to file when managing course documents area"				// Need bersetzung
#elif L==3	// en
	"Copy link to file when managing course documents area"
#elif L==4	// es
	"Copiar enlace a archivo administrando zona de documentos de asignatura"
#elif L==5	// fr
	"Copy link to file when managing course documents area"				// Besoin de traduction
#elif L==6	// gn
	"Copiar enlace a archivo administrando zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Copy link to file when managing course documents area"				// Bisogno di traduzione
#elif L==8	// pl
	"Copy link to file when managing course documents area"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Copy link to file when managing course documents area"				// Precisa de traduo
#elif L==10	// tr
	"Copy link to file when managing course documents area"				// eviri lazim!
#endif
	,
	[ActDowAdmDocCrs] =
#if   L==1	// ca
	"Download file from documents zone of course"		// Necessita traducci
#elif L==2	// de
	"Download file from documents zone of course"		// Need bersetzung
#elif L==3	// en
	"Download file from documents zone of course"
#elif L==4	// es
	"Descargar archivo de zona de documentos de asignatura"
#elif L==5	// fr
	"Download file from documents zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de documentos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Download file from documents zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from documents zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from documents zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Download file from documents zone of course"		// eviri lazim!
#endif
	,
	[ActAdmDocGrp] =
#if   L==1	// ca
	"Manage documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Manage documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Manage documents zone of group"
#elif L==4	// es
	"Administrar zona de documentos de grupo"
#elif L==5	// fr
	"Manage documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Manage documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Manage documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Manage documents zone of group"		// eviri lazim!
#endif
	,
	[ActReqRemFilDocGrp] =
#if   L==1	// ca
	"Request removal of file from documents zone of group"				// Necessita traducci
#elif L==2	// de
	"Request removal of file from documents zone of group"				// Need bersetzung
#elif L==3	// en
	"Request removal of file from documents zone of group"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de grupo"
#elif L==5	// fr
	"Request removal of file from documents zone of group"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from documents zone of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from documents zone of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from documents zone of group"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from documents zone of group"				// eviri lazim!
#endif
	,
	[ActRemFilDocGrp] =
#if   L==1	// ca
	"Remove file from documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Remove file from documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Remove file from documents zone of group"
#elif L==4	// es
	"Eliminar archivo de zona de documentos de grupo"
#elif L==5	// fr
	"Remove file from documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Remove file from documents zone of group"		// eviri lazim!
#endif
	,
	[ActRemFolDocGrp] =
#if   L==1	// ca
	"Remove empty folder from documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Remove empty folder from documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Remove empty folder from documents zone of group"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona de documentos de grupo"
#elif L==5	// fr
	"Remove empty folder from documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from documents zone of group"		// eviri lazim!
#endif
	,
	[ActCopDocGrp] =
#if   L==1	// ca
	"Set source of copy in documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Set source of copy in documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Set source of copy in documents zone of group"
#elif L==4	// es
	"Establecer origen de copia en zona de documentos de grupo"
#elif L==5	// fr
	"Set source of copy in documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in documents zone of group"			// eviri lazim!
#endif
	,
	[ActPasDocGrp] =
#if   L==1	// ca
	"Paste folder/file in documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Paste folder/file in documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Paste folder/file in documents zone of group"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de documentos de grupo"
#elif L==5	// fr
	"Paste folder/file in documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in documents zone of group"		// eviri lazim!
#endif
	,
	[ActRemTreDocGrp] =
#if   L==1	// ca
	"Remove non-empty folder from documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from documents zone of group"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona de documentos de grupo"
#elif L==5	// fr
	"Remove non-empty folder from documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from documents zone of group"			// eviri lazim!
#endif
	,
	[ActFrmCreDocGrp] =
#if   L==1	// ca
	"Edit new folder/file/link in documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in documents zone of group"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de documentos de grupo"
#elif L==5	// fr
	"Edit new folder/file/link in documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in documents zone of group"			// eviri lazim!
#endif
	,
	[ActCreFolDocGrp] =
#if   L==1	// ca
	"Create new folder in documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Create new folder in documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Create new folder in documents zone of group"
#elif L==4	// es
	"Crear nueva carpeta en zona de documentos de grupo"
#elif L==5	// fr
	"Create new folder in documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Create new folder in documents zone of group"		// eviri lazim!
#endif
	,
	[ActCreLnkDocGrp] =
#if   L==1	// ca
	"Create new link in documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Create new link in documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Create new link in documents zone of group"
#elif L==4	// es
	"Crear nuevo enlace en zona de documentos de grupo"
#elif L==5	// fr
	"Create new link in documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Create new link in documents zone of group"		// eviri lazim!
#endif
	,
	[ActRenFolDocGrp] =
#if   L==1	// ca
	"Rename folder in documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Rename folder in documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Rename folder in documents zone of group"
#elif L==4	// es
	"Renombrar carpeta en zona de documentos de grupo"
#elif L==5	// fr
	"Rename folder in documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Rename folder in documents zone of group"		// eviri lazim!
#endif
	,
	[ActRcvFilDocGrpDZ] =
#if   L==1	// ca
	"Send file to documents zone of group using Dropzone.js"		// Necessita traducci
#elif L==2	// de
	"Send file to documents zone of group using Dropzone.js"		// Need bersetzung
#elif L==3	// en
	"Send file to documents zone of group using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona de documentos de grupo mediante Dropzone.js"
#elif L==5	// fr
	"Send file to documents zone of group using Dropzone.js"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de documentos de grupo mediante Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to documents zone of group using Dropzone.js"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to documents zone of group using Dropzone.js"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to documents zone of group using Dropzone.js"		// Precisa de traduo
#elif L==10	// tr
	"Send file to documents zone of group using Dropzone.js"		// eviri lazim!
#endif
	,
	[ActRcvFilDocGrpCla] =
#if   L==1	// ca
	"Send file to documents zone of group using the classic way"		// Necessita traducci
#elif L==2	// de
	"Send file to documents zone of group using the classic way"		// Need bersetzung
#elif L==3	// en
	"Send file to documents zone of group using the classic way"
#elif L==4	// es
	"Enviar archivo a zona de documentos de grupo de forma tradicional"
#elif L==5	// fr
	"Send file to documents zone of group using the classic way"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de documentos de grupo de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file to documents zone of group using the classic way"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to documents zone of group using the classic way"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to documents zone of group using the classic way"		// Precisa de traduo
#elif L==10	// tr
	"Send file to documents zone of group using the classic way"		// eviri lazim!
#endif
	,
	[ActExpAdmDocGrp] =
#if   L==1	// ca
	"Expand folder when managing documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Expand folder when managing documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Expand folder when managing documents zone of group"
#elif L==4	// es
	"Expandir carpeta al administrar zona de documentos de grupo"
#elif L==5	// fr
	"Expand folder when managing documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta al administrar zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder when managing documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder when managing documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder when managing documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Expand folder when managing documents zone of group"		// eviri lazim!
#endif
	,
	[ActConAdmDocGrp] =
#if   L==1	// ca
	"Contract folder when mamaging documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Contract folder when mamaging documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Contract folder when mamaging documents zone of group"
#elif L==4	// es
	"Contraer carpeta al administrar zona de documentos de grupo"
#elif L==5	// fr
	"Contract folder when mamaging documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta al administrar zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder when mamaging documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder when mamaging documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder when mamaging documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Contract folder when mamaging documents zone of group"		// eviri lazim!
#endif
	,
	[ActZIPAdmDocGrp] =
#if   L==1	// ca
	"Compress folder when managing documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Compress folder when managing documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Compress folder when managing documents zone of group"
#elif L==4	// es
	"Comprimir carpeta al administrar zona de documentos de grupo"
#elif L==5	// fr
	"Compress folder when managing documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta al administrar zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder when managing documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder when managing documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder when managing documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Compress folder when managing documents zone of group"		// eviri lazim!
#endif
	,
	[ActUnhDocGrp] =
#if   L==1	// ca
	"Unhide folder/file in documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Unhide folder/file in documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Unhide folder/file in documents zone of group"
#elif L==4	// es
	"Mostrar carpeta/archivo en zona de documentos de grupo"
#elif L==5	// fr
	"Unhide folder/file in documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Mostrar carpeta/archivo en zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Unhide folder/file in documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Unhide folder/file in documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide folder/file in documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Unhide folder/file in documents zone of group"			// eviri lazim!
#endif
	,
	[ActHidDocGrp] =
#if   L==1	// ca
	"Hide folder/file in documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Hide folder/file in documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Hide folder/file in documents zone of group"
#elif L==4	// es
	"Ocultar carpeta/archivo en zona de documentos de grupo"
#elif L==5	// fr
	"Hide folder/file in documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Ocultar carpeta/archivo en zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Hide folder/file in documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Hide folder/file in documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide folder/file in documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Hide folder/file in documents zone of group"			// eviri lazim!
#endif
	,
	[ActReqDatAdmDocGrp] =
#if   L==1	// ca
	"See file metadata in documents zone of group"			// Necessita traducci
#elif L==2	// de
	"See file metadata in documents zone of group"			// Need bersetzung
#elif L==3	// en
	"See file metadata in documents zone of group"
#elif L==4	// es
	"Ver metadatos de archivo en zona de documentos de grupo"
#elif L==5	// fr
	"See file metadata in documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in documents zone of group"			// eviri lazim!
#endif
	,
	[ActChgDatAdmDocGrp] =
#if   L==1	// ca
	"Change file metadata in documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Change file metadata in documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Change file metadata in documents zone of group"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de documentos de grupo"
#elif L==5	// fr
	"Change file metadata in documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in documents zone of group"		// eviri lazim!
#endif
	,
	[ActDowAdmDocGrp] =
#if   L==1	// ca
	"Download file from documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Download file from documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Download file from documents zone of group"
#elif L==4	// es
	"Descargar archivo de zona de documentos de grupo"
#elif L==5	// fr
	"Download file from documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de documentos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Download file from documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Download file from documents zone of group"		// eviri lazim!
#endif
	,
	[ActAdmTchCrsGrp] =
#if   L==1	// ca
	"Request management of teachers' documents zone of course/group"			// Necessita traducci
#elif L==2	// de
	"Request management of teachers' documents zone of course/group"			// Need bersetzung
#elif L==3	// en
	"Request management of teachers' documents zone of course/group"
#elif L==4	// es
	"Solicitar administraci&oacute;n de zona de archivos de profesores de asignatura/grupo"
#elif L==5	// fr
	"Request management of teachers' documents zone of course/group"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar administraci&oacute;n de zona de archivos de profesores de asignatura/grupo"	// Okoteve traduccin
#elif L==7	// it
	"Request management of teachers' documents zone of course/group"			// Bisogno di traduzione
#elif L==8	// pl
	"Request management of teachers' documents zone of course/group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request management of teachers' documents zone of course/group"			// Precisa de traduo
#elif L==10	// tr
	"Request management of teachers' documents zone of course/group"			// eviri lazim!
#endif
	,
	[ActChgToAdmTch] =
#if   L==1	// ca
	"Change teachers' documents zone of course/group to management mode"				// Necessita traducci
#elif L==2	// de
	"Change teachers' documents zone of course/group to management mode"				// Need bersetzung
#elif L==3	// en
	"Change teachers' documents zone of course/group to management mode"
#elif L==4	// es
	"Cambiar zona de documentos de profesores de asignatura/grupo a modo administraci&oacute;n"
#elif L==5	// fr
	"Change teachers' documents zone of course/group to management mode"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar zona de documentos de profesores de asignatura/grupo a modo administraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change teachers' documents zone of course/group to management mode"				// Bisogno di traduzione
#elif L==8	// pl
	"Change teachers' documents zone of course/group to management mode"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change teachers' documents zone of course/group to management mode"				// Precisa de traduo
#elif L==10	// tr
	"Change teachers' documents zone of course/group to management mode"				// eviri lazim!
#endif
	,
	[ActAdmTchCrs] =
#if   L==1	// ca
	"Manage teachers' documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Manage teachers' documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Manage teachers' documents zone of course"
#elif L==4	// es
	"Administrar zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Manage teachers' documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Manage teachers' documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Manage teachers' documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage teachers' documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Manage teachers' documents zone of course"			// eviri lazim!
#endif
	,
	[ActReqRemFilTchCrs] =
#if   L==1	// ca
	"Request removal of file from teachers' documents zone of course"				// Necessita traducci
#elif L==2	// de
	"Request removal of file from teachers' documents zone of course"				// Need bersetzung
#elif L==3	// en
	"Request removal of file from teachers' documents zone of course"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Request removal of file from teachers' documents zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from teachers' documents zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from teachers' documents zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from teachers' documents zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from teachers' documents zone of course"				// eviri lazim!
#endif
	,
	[ActRemFilTchCrs] =
#if   L==1	// ca
	"Remove file from teachers' documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Remove file from teachers' documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Remove file from teachers' documents zone of course"
#elif L==4	// es
	"Eliminar archivo de zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Remove file from teachers' documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from teachers' documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from teachers' documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from teachers' documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Remove file from teachers' documents zone of course"			// eviri lazim!
#endif
	,
	[ActRemFolTchCrs] =
#if   L==1	// ca
	"Remove empty folder from teachers' documents zone of course"				// Necessita traducci
#elif L==2	// de
	"Remove empty folder from teachers' documents zone of course"				// Need bersetzung
#elif L==3	// en
	"Remove empty folder from teachers' documents zone of course"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Remove empty folder from teachers' documents zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from teachers' documents zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from teachers' documents zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from teachers' documents zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from teachers' documents zone of course"				// eviri lazim!
#endif
	,
	[ActCopTchCrs] =
#if   L==1	// ca
	"Set source of copy in teachers' documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Set source of copy in teachers' documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Set source of copy in teachers' documents zone of course"
#elif L==4	// es
	"Establecer origen de copia en zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Set source of copy in teachers' documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in teachers' documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in teachers' documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in teachers' documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in teachers' documents zone of course"			// eviri lazim!
#endif
	,
	[ActPasTchCrs] =
#if   L==1	// ca
	"Paste folder/file in teachers' documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Paste folder/file in teachers' documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Paste folder/file in teachers' documents zone of course"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Paste folder/file in teachers' documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in teachers' documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in teachers' documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in teachers' documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in teachers' documents zone of course"			// eviri lazim!
#endif
	,
	[ActRemTreTchCrs] =
#if   L==1	// ca
	"Remove non-empty folder from teachers' documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from teachers' documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from teachers' documents zone of course"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Remove non-empty folder from teachers' documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from teachers' documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from teachers' documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from teachers' documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from teachers' documents zone of course"			// eviri lazim!
#endif
	,
	[ActFrmCreTchCrs] =
#if   L==1	// ca
	"Edit new folder/file/link in teachers' documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in teachers' documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in teachers' documents zone of course"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Edit new folder/file/link in teachers' documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in teachers' documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in teachers' documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in teachers' documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in teachers' documents zone of course"			// eviri lazim!
#endif
	,
	[ActCreFolTchCrs] =
#if   L==1	// ca
	"Create new folder in teachers' documents zone of course"		// Necessita traducci
#elif L==2	// de
	"Create new folder in teachers' documents zone of course"		// Need bersetzung
#elif L==3	// en
	"Create new folder in teachers' documents zone of course"
#elif L==4	// es
	"Crear nueva carpeta en zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Create new folder in teachers' documents zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in teachers' documents zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in teachers' documents zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in teachers' documents zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Create new folder in teachers' documents zone of course"		// eviri lazim!
#endif
	,
	[ActCreLnkTchCrs] =
#if   L==1	// ca
	"Create new link in teachers' documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Create new link in teachers' documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Create new link in teachers' documents zone of course"
#elif L==4	// es
	"Crear nuevo enlace en zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Create new link in teachers' documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in teachers' documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in teachers' documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in teachers' documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Create new link in teachers' documents zone of course"			// eviri lazim!
#endif
	,
	[ActRenFolTchCrs] =
#if   L==1	// ca
	"Rename folder in teachers' documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Rename folder in teachers' documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Rename folder in teachers' documents zone of course"
#elif L==4	// es
	"Renombrar carpeta en zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Rename folder in teachers' documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in teachers' documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in teachers' documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in teachers' documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Rename folder in teachers' documents zone of course"			// eviri lazim!
#endif
	,
	[ActRcvFilTchCrsDZ] =
#if   L==1	// ca
	"Send file to teachers' documents zone of course using Dropzone.js"			// Necessita traducci
#elif L==2	// de
	"Send file to teachers' documents zone of course using Dropzone.js"			// Need bersetzung
#elif L==3	// en
	"Send file to teachers' documents zone of course using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona de documentos de profesores de asignatura usando Dropzone.js"
#elif L==5	// fr
	"Send file to teachers' documents zone of course using Dropzone.js"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de documentos de profesores de asignatura usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to teachers' documents zone of course using Dropzone.js"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to teachers' documents zone of course using Dropzone.js"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to teachers' documents zone of course using Dropzone.js"			// Precisa de traduo
#elif L==10	// tr
	"Send file to teachers' documents zone of course using Dropzone.js"			// eviri lazim!
#endif
	,
	[ActRcvFilTchCrsCla] =
#if   L==1	// ca
	"Send file to teachers' documents zone of course using the classic way"			// Necessita traducci
#elif L==2	// de
	"Send file to teachers' documents zone of course using the classic way"			// Need bersetzung
#elif L==3	// en
	"Send file to teachers' documents zone of course using the classic way"
#elif L==4	// es
	"Enviar archivo a zona de documentos de profesores de asignatura de forma tradicional"
#elif L==5	// fr
	"Send file to teachers' documents zone of course using the classic way"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de documentos de profesores de asignatura de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file to teachers' documents zone of course using the classic way"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to teachers' documents zone of course using the classic way"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to teachers' documents zone of course using the classic way"			// Precisa de traduo
#elif L==10	// tr
	"Send file to teachers' documents zone of course using the classic way"			// eviri lazim!
#endif
	,
	[ActExpTchCrs] =
#if   L==1	// ca
	"Expand folder in teachers' documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Expand folder in teachers' documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Expand folder in teachers' documents zone of course"
#elif L==4	// es
	"Expandir carpeta en zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Expand folder in teachers' documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in teachers' documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in teachers' documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in teachers' documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Expand folder in teachers' documents zone of course"			// eviri lazim!
#endif
	,
	[ActConTchCrs] =
#if   L==1	// ca
	"Contract folder in teachers' documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Contract folder in teachers' documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Contract folder in teachers' documents zone of course"
#elif L==4	// es
	"Contraer carpeta en zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Contract folder in teachers' documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in teachers' documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in teachers' documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in teachers' documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Contract folder in teachers' documents zone of course"			// eviri lazim!
#endif
	,
	[ActZIPTchCrs] =
#if   L==1	// ca
	"Compress folder in teachers' documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Compress folder in teachers' documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Compress folder in teachers' documents zone of course"
#elif L==4	// es
	"Comprimir carpeta en zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Compress folder in teachers' documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in teachers' documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in teachers' documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in teachers' documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Compress folder in teachers' documents zone of course"			// eviri lazim!
#endif
	,
	[ActReqDatTchCrs] =
#if   L==1	// ca
	"See file metadata in teachers' documents zone of course"			// Necessita traducci
#elif L==2	// de
	"See file metadata in teachers' documents zone of course"			// Need bersetzung
#elif L==3	// en
	"See file metadata in teachers' documents zone of course"
#elif L==4	// es
	"Ver metadatos de archivo en zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"See file metadata in teachers' documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in teachers' documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in teachers' documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in teachers' documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in teachers' documents zone of course"			// eviri lazim!
#endif
	,
	[ActChgDatTchCrs] =
#if   L==1	// ca
	"Change file metadata in teachers' documents zone of course"				// Necessita traducci
#elif L==2	// de
	"Change file metadata in teachers' documents zone of course"				// Need bersetzung
#elif L==3	// en
	"Change file metadata in teachers' documents zone of course"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Change file metadata in teachers' documents zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in teachers' documents zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in teachers' documents zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in teachers' documents zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in teachers' documents zone of course"				// eviri lazim!
#endif
	,
	[ActDowTchCrs] =
#if   L==1	// ca
	"Download file from teachers' documents zone of course"			// Necessita traducci
#elif L==2	// de
	"Download file from teachers' documents zone of course"			// Need bersetzung
#elif L==3	// en
	"Download file from teachers' documents zone of course"
#elif L==4	// es
	"Descargar archivo de zona de documentos de profesores de asignatura"
#elif L==5	// fr
	"Download file from teachers' documents zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de documentos de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Download file from teachers' documents zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Download file from teachers' documents zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from teachers' documents zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Download file from teachers' documents zone of course"			// eviri lazim!
#endif
	,
	[ActAdmTchGrp] =
#if   L==1	// ca
	"Manage teachers' documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Manage teachers' documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Manage teachers' documents zone of group"
#elif L==4	// es
	"Administrar zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Manage teachers' documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Manage teachers' documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Manage teachers' documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage teachers' documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Manage teachers' documents zone of group"		// eviri lazim!
#endif
	,
	[ActReqRemFilTchGrp] =
#if   L==1	// ca
	"Request removal of file from teachers' documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Request removal of file from teachers' documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Request removal of file from teachers' documents zone of group"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Request removal of file from teachers' documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from teachers' documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from teachers' documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from teachers' documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from teachers' documents zone of group"			// eviri lazim!
#endif
	,
	[ActRemFilTchGrp] =
#if   L==1	// ca
	"Remove file from teachers' documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Remove file from teachers' documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Remove file from teachers' documents zone of group"
#elif L==4	// es
	"Eliminar archivo de zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Remove file from teachers' documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from teachers' documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from teachers' documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from teachers' documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Remove file from teachers' documents zone of group"		// eviri lazim!
#endif
	,
	[ActRemFolTchGrp] =
#if   L==1	// ca
	"Remove empty folder of teachers' documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Remove empty folder of teachers' documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Remove empty folder of teachers' documents zone of group"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Remove empty folder of teachers' documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder of teachers' documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder of teachers' documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder of teachers' documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder of teachers' documents zone of group"			// eviri lazim!
#endif
	,
	[ActCopTchGrp] =
#if   L==1	// ca
	"Set source of copy in teachers' documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Set source of copy in teachers' documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Set source of copy in teachers' documents zone of group"
#elif L==4	// es
	"Establecer origen de copia en zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Set source of copy in teachers' documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in teachers' documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in teachers' documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in teachers' documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in teachers' documents zone of group"			// eviri lazim!
#endif
	,
	[ActPasTchGrp] =
#if   L==1	// ca
	"Paste folder/file in teachers' documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Paste folder/file in teachers' documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Paste folder/file in teachers' documents zone of group"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Paste folder/file in teachers' documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in teachers' documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in teachers' documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in teachers' documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in teachers' documents zone of group"		// eviri lazim!
#endif
	,
	[ActRemTreTchGrp] =
#if   L==1	// ca
	"Remove non-empty folder of teachers' documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder of teachers' documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder of teachers' documents zone of group"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Remove non-empty folder of teachers' documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder of teachers' documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder of teachers' documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder of teachers' documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder of teachers' documents zone of group"			// eviri lazim!
#endif
	,
	[ActFrmCreTchGrp] =
#if   L==1	// ca
	"Edit new folder/file/link in teachers' documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in teachers' documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in teachers' documents zone of group"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Edit new folder/file/link in teachers' documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in teachers' documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in teachers' documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in teachers' documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in teachers' documents zone of group"			// eviri lazim!
#endif
	,
	[ActCreFolTchGrp] =
#if   L==1	// ca
	"Create new folder in teachers' documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Create new folder in teachers' documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Create new folder in teachers' documents zone of group"
#elif L==4	// es
	"Crear nueva carpeta en zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Create new folder in teachers' documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in teachers' documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in teachers' documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in teachers' documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Create new folder in teachers' documents zone of group"		// eviri lazim!
#endif
	,
	[ActCreLnkTchGrp] =
#if   L==1	// ca
	"Create new link in teachers' documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Create new link in teachers' documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Create new link in teachers' documents zone of group"
#elif L==4	// es
	"Crear nuevo enlace en zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Create new link in teachers' documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in teachers' documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in teachers' documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in teachers' documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Create new link in teachers' documents zone of group"			// eviri lazim!
#endif
	,
	[ActRenFolTchGrp] =
#if   L==1	// ca
	"Rename folder in teachers' documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Rename folder in teachers' documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Rename folder in teachers' documents zone of group"
#elif L==4	// es
	"Renombrar carpeta en zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Rename folder in teachers' documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in teachers' documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in teachers' documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in teachers' documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Rename folder in teachers' documents zone of group"			// eviri lazim!
#endif
	,
	[ActRcvFilTchGrpDZ] =
#if   L==1	// ca
	"Send file to teachers' documents zone of group using Dropzone.js"		// Necessita traducci
#elif L==2	// de
	"Send file to teachers' documents zone of group using Dropzone.js"		// Need bersetzung
#elif L==3	// en
	"Send file to teachers' documents zone of group using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona de documentos de profesores de grupo usando Dropzone.js"
#elif L==5	// fr
	"Send file to teachers' documents zone of group using Dropzone.js"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de documentos de profesores de grupo usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to teachers' documents zone of group using Dropzone.js"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to teachers' documents zone of group using Dropzone.js"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to teachers' documents zone of group using Dropzone.js"		// Precisa de traduo
#elif L==10	// tr
	"Send file to teachers' documents zone of group using Dropzone.js"		// eviri lazim!
#endif
	,
	[ActRcvFilTchGrpCla] =
#if   L==1	// ca
	"Send file in teachers' documents zone of group using the classic way"			// Necessita traducci
#elif L==2	// de
	"Send file in teachers' documents zone of group using the classic way"			// Need bersetzung
#elif L==3	// en
	"Send file in teachers' documents zone of group using the classic way"
#elif L==4	// es
	"Enviar archivo a zona de documentos de profesores de grupo de forma tradicional"
#elif L==5	// fr
	"Send file in teachers' documents zone of group using the classic way"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de documentos de profesores de grupo de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file in teachers' documents zone of group using the classic way"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file in teachers' documents zone of group using the classic way"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file in teachers' documents zone of group using the classic way"			// Precisa de traduo
#elif L==10	// tr
	"Send file in teachers' documents zone of group using the classic way"			// eviri lazim!
#endif
	,
	[ActExpTchGrp] =
#if   L==1	// ca
	"Expand folder in teachers' documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Expand folder in teachers' documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Expand folder in teachers' documents zone of group"
#elif L==4	// es
	"Expandir carpeta en zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Expand folder in teachers' documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in teachers' documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in teachers' documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in teachers' documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Expand folder in teachers' documents zone of group"		// eviri lazim!
#endif
	,
	[ActConTchGrp] =
#if   L==1	// ca
	"Contract folder in teachers' documents zone of group"		// Necessita traducci
#elif L==2	// de
	"Contract folder in teachers' documents zone of group"		// Need bersetzung
#elif L==3	// en
	"Contract folder in teachers' documents zone of group"
#elif L==4	// es
	"Contraer carpeta en zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Contract folder in teachers' documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in teachers' documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in teachers' documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in teachers' documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Contract folder in teachers' documents zone of group"		// eviri lazim!
#endif
	,
	[ActZIPTchGrp] =
#if   L==1	// ca
	"Compress folder in teachers' documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Compress folder in teachers' documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Compress folder in teachers' documents zone of group"
#elif L==4	// es
	"Comprimir carpeta en zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Compress folder in teachers' documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in teachers' documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in teachers' documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in teachers' documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Compress folder in teachers' documents zone of group"			// eviri lazim!
#endif
	,
	[ActReqDatTchGrp] =
#if   L==1	// ca
	"See file metadata in teachers' documents zone of group"		// Necessita traducci
#elif L==2	// de
	"See file metadata in teachers' documents zone of group"		// Need bersetzung
#elif L==3	// en
	"See file metadata in teachers' documents zone of group"
#elif L==4	// es
	"Ver metadatos de archivo en zona de documentos de profesores de grupo"
#elif L==5	// fr
	"See file metadata in teachers' documents zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in teachers' documents zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in teachers' documents zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in teachers' documents zone of group"		// Precisa de traduo
#elif L==10	// tr
	"See file metadata in teachers' documents zone of group"		// eviri lazim!
#endif
	,
	[ActChgDatTchGrp] =
#if   L==1	// ca
	"Change file metadata in teachers' documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Change file metadata in teachers' documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Change file metadata in teachers' documents zone of group"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Change file metadata in teachers' documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in teachers' documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in teachers' documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in teachers' documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in teachers' documents zone of group"			// eviri lazim!
#endif
	,
	[ActDowTchGrp] =
#if   L==1	// ca
	"Download file from teachers' documents zone of group"			// Necessita traducci
#elif L==2	// de
	"Download file from teachers' documents zone of group"			// Need bersetzung
#elif L==3	// en
	"Download file from teachers' documents zone of group"
#elif L==4	// es
	"Descargar archivo de zona de documentos de profesores de grupo"
#elif L==5	// fr
	"Download file from teachers' documents zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de documentos de profesores de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Download file from teachers' documents zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Download file from teachers' documents zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from teachers' documents zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Download file from teachers' documents zone of group"			// eviri lazim!
#endif
	,
	[ActAdmShaCrsGrp] =
#if   L==1	// ca
	"Request management of shared zone of course/group"					// Necessita traducci
#elif L==2	// de
	"Request management of shared zone of course/group"					// Need bersetzung
#elif L==3	// en
	"Request management of shared zone of course/group"
#elif L==4	// es
	"Solicitar administraci&oacute;n de zona de archivos compartidos de asignatura/grupo"
#elif L==5	// fr
	"Request management of shared zone of course/group"					// Besoin de traduction
#elif L==6	// gn
	"Solicitar administraci&oacute;n de zona de archivos compartidos de asignatura/grupo"	// Okoteve traduccin
#elif L==7	// it
	"Request management of shared zone of course/group"					// Bisogno di traduzione
#elif L==8	// pl
	"Request management of shared zone of course/group"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request management of shared zone of course/group"					// Precisa de traduo
#elif L==10	// tr
	"Request management of shared zone of course/group"					// eviri lazim!
#endif
	,
	[ActChgToAdmSha] =
#if   L==1	// ca
	"Change shared files zone of course/group to management mode"				// Necessita traducci
#elif L==2	// de
	"Change shared files zone of course/group to management mode"				// Need bersetzung
#elif L==3	// en
	"Change shared files zone of course/group to management mode"
#elif L==4	// es
	"Cambiar zona de archivos compartidos de asignatura/grupo a modo administraci&oacute;n"
#elif L==5	// fr
	"Change shared files zone of course/group to management mode"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar zona de archivos compartidos de asignatura/grupo a modo administraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change shared files zone of course/group to management mode"				// Bisogno di traduzione
#elif L==8	// pl
	"Change shared files zone of course/group to management mode"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change shared files zone of course/group to management mode"				// Precisa de traduo
#elif L==10	// tr
	"Change shared files zone of course/group to management mode"				// eviri lazim!
#endif
	,
	[ActAdmShaCrs] =
#if   L==1	// ca
	"Manage shared files zone of course"				// Necessita traducci
#elif L==2	// de
	"Manage shared files zone of course"				// Need bersetzung
#elif L==3	// en
	"Manage shared files zone of course"
#elif L==4	// es
	"Administrar zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"Manage shared files zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Manage shared files zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Manage shared files zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage shared files zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Manage shared files zone of course"				// eviri lazim!
#endif
	,
	[ActReqRemFilShaCrs] =
#if   L==1	// ca
	"Request removal of shared file of course"				// Necessita traducci
#elif L==2	// de
	"Request removal of shared file of course"				// Need bersetzung
#elif L==3	// en
	"Request removal of shared file of course"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo compartido de asignatura"
#elif L==5	// fr
	"Request removal of shared file of course"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo compartido de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of shared file of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of shared file of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of shared file of course"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of shared file of course"				// eviri lazim!
#endif
	,
	[ActRemFilShaCrs] =
#if   L==1	// ca
	"Remove file from shared files zone of course"				// Necessita traducci
#elif L==2	// de
	"Remove file from shared files zone of course"				// Need bersetzung
#elif L==3	// en
	"Remove file from shared files zone of course"
#elif L==4	// es
	"Eliminar archivo de zona de archivos compartidos una asignatura"
#elif L==5	// fr
	"Remove file from shared files zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de zona de archivos compartidos una asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from shared files zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from shared files zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from shared files zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Remove file from shared files zone of course"				// eviri lazim!
#endif
	,
	[ActRemFolShaCrs] =
#if   L==1	// ca
	"Remove empty folder from shared files zone of course"				// Necessita traducci
#elif L==2	// de
	"Remove empty folder from shared files zone of course"				// Need bersetzung
#elif L==3	// en
	"Remove empty folder from shared files zone of course"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"Remove empty folder from shared files zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from shared files zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from shared files zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from shared files zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from shared files zone of course"				// eviri lazim!
#endif
	,
	[ActCopShaCrs] =
#if   L==1	// ca
	"Set source of copy in shared files zone of course"				// Necessita traducci
#elif L==2	// de
	"Set source of copy in shared files zone of course"				// Need bersetzung
#elif L==3	// en
	"Set source of copy in shared files zone of course"
#elif L==4	// es
	"Establecer origen de copia en zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"Set source of copy in shared files zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in shared files zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in shared files zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in shared files zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in shared files zone of course"				// eviri lazim!
#endif
	,
	[ActPasShaCrs] =
#if   L==1	// ca
	"Paste folder/file in shared files zone of course"			// Necessita traducci
#elif L==2	// de
	"Paste folder/file in shared files zone of course"			// Need bersetzung
#elif L==3	// en
	"Paste folder/file in shared files zone of course"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"Paste folder/file in shared files zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in shared files zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in shared files zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in shared files zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in shared files zone of course"			// eviri lazim!
#endif
	,
	[ActRemTreShaCrs] =
#if   L==1	// ca
	"Remove non-empty folder from shared files zone of course"			// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from shared files zone of course"			// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from shared files zone of course"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"Remove non-empty folder from shared files zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from shared files zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from shared files zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from shared files zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from shared files zone of course"			// eviri lazim!
#endif
	,
	[ActFrmCreShaCrs] =
#if   L==1	// ca
	"Edit new folder/file/link in shared files zone of course"				// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in shared files zone of course"				// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in shared files zone of course"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"Edit new folder/file/link in shared files zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in shared files zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in shared files zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in shared files zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in shared files zone of course"				// eviri lazim!
#endif
	,
	[ActCreFolShaCrs] =
#if   L==1	// ca
	"Create new folder in shared files zone of course"			// Necessita traducci
#elif L==2	// de
	"Create new folder in shared files zone of course"			// Need bersetzung
#elif L==3	// en
	"Create new folder in shared files zone of course"
#elif L==4	// es
	"Crear nueva carpeta en zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"Create new folder in shared files zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in shared files zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in shared files zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in shared files zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Create new folder in shared files zone of course"			// eviri lazim!
#endif
	,
	[ActCreLnkShaCrs] =
#if   L==1	// ca
	"Create new link in shared files zone of course"			// Necessita traducci
#elif L==2	// de
	"Create new link in shared files zone of course"			// Need bersetzung
#elif L==3	// en
	"Create new link in shared files zone of course"
#elif L==4	// es
	"Crear nuevo enlace en zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"Create new link in shared files zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in shared files zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in shared files zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in shared files zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Create new link in shared files zone of course"			// eviri lazim!
#endif
	,
	[ActRenFolShaCrs] =
#if   L==1	// ca
	"Rename folder in shared files zone of course"				// Necessita traducci
#elif L==2	// de
	"Rename folder in shared files zone of course"				// Need bersetzung
#elif L==3	// en
	"Rename folder in shared files zone of course"
#elif L==4	// es
	"Renombrar carpeta en zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"Rename folder in shared files zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in shared files zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in shared files zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in shared files zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Rename folder in shared files zone of course"				// eviri lazim!
#endif
	,
	[ActRcvFilShaCrsDZ] =
#if   L==1	// ca
	"Send file to shared files zone of course using Dropzone.js"				// Necessita traducci
#elif L==2	// de
	"Send file to shared files zone of course using Dropzone.js"				// Need bersetzung
#elif L==3	// en
	"Send file to shared files zone of course using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona de archivos compartidos de asignatura usando Dropzone.js"
#elif L==5	// fr
	"Send file to shared files zone of course using Dropzone.js"				// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de archivos compartidos de asignatura usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to shared files zone of course using Dropzone.js"				// Bisogno di traduzione
#elif L==8	// pl
	"Send file to shared files zone of course using Dropzone.js"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to shared files zone of course using Dropzone.js"				// Precisa de traduo
#elif L==10	// tr
	"Send file to shared files zone of course using Dropzone.js"				// eviri lazim!
#endif
	,
	[ActRcvFilShaCrsCla] =
#if   L==1	// ca
	"Send file to shared files zone of course using the classic way"			// Necessita traducci
#elif L==2	// de
	"Send file to shared files zone of course using the classic way"			// Need bersetzung
#elif L==3	// en
	"Send file to shared files zone of course using the classic way"
#elif L==4	// es
	"Enviar archivo a zona de archivos compartidos de asignatura de forma tradicional"
#elif L==5	// fr
	"Send file to shared files zone of course using the classic way"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de archivos compartidos de asignatura de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file to shared files zone of course using the classic way"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to shared files zone of course using the classic way"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to shared files zone of course using the classic way"			// Precisa de traduo
#elif L==10	// tr
	"Send file to shared files zone of course using the classic way"			// eviri lazim!
#endif
	,
	[ActExpShaCrs] =
#if   L==1	// ca
	"Expand folder in shared files zone of course"				// Necessita traducci
#elif L==2	// de
	"Expand folder in shared files zone of course"				// Need bersetzung
#elif L==3	// en
	"Expand folder in shared files zone of course"
#elif L==4	// es
	"Expandir carpeta en zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"Expand folder in shared files zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in shared files zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in shared files zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in shared files zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Expand folder in shared files zone of course"				// eviri lazim!
#endif
	,
	[ActConShaCrs] =
#if   L==1	// ca
	"Contract folder in shared files zone of course"			// Necessita traducci
#elif L==2	// de
	"Contract folder in shared files zone of course"			// Need bersetzung
#elif L==3	// en
	"Contract folder in shared files zone of course"
#elif L==4	// es
	"Contract carpeta en zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"Contract folder in shared files zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Contract carpeta en zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in shared files zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in shared files zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in shared files zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Contract folder in shared files zone of course"			// eviri lazim!
#endif
	,
	[ActZIPShaCrs] =
#if   L==1	// ca
	"Compress folder in shared files zone of course"			// Necessita traducci
#elif L==2	// de
	"Compress folder in shared files zone of course"			// Need bersetzung
#elif L==3	// en
	"Compress folder in shared files zone of course"
#elif L==4	// es
	"Comprimir carpeta en zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"Compress folder in shared files zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in shared files zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in shared files zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in shared files zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Compress folder in shared files zone of course"			// eviri lazim!
#endif
	,
	[ActReqDatShaCrs] =
#if   L==1	// ca
	"See file metadata in shared files zone of course"				// Necessita traducci
#elif L==2	// de
	"See file metadata in shared files zone of course"				// Need bersetzung
#elif L==3	// en
	"See file metadata in shared files zone of course"
#elif L==4	// es
	"Ver metadatos de archivo en zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"See file metadata in shared files zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in shared files zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in shared files zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in shared files zone of course"				// Precisa de traduo
#elif L==10	// tr
	"See file metadata in shared files zone of course"				// eviri lazim!
#endif
	,
	[ActChgDatShaCrs] =
#if   L==1	// ca
	"Change file metadata in shared files zone of course"				// Necessita traducci
#elif L==2	// de
	"Change file metadata in shared files zone of course"				// Need bersetzung
#elif L==3	// en
	"Change file metadata in shared files zone of course"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"Change file metadata in shared files zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in shared files zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in shared files zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in shared files zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in shared files zone of course"				// eviri lazim!
#endif
	,
	[ActDowShaCrs] =
#if   L==1	// ca
	"Download file from shared files zone of course"			// Necessita traducci
#elif L==2	// de
	"Download file from shared files zone of course"			// Need bersetzung
#elif L==3	// en
	"Download file from shared files zone of course"
#elif L==4	// es
	"Descargar archivo de zona de archivos compartidos de asignatura"
#elif L==5	// fr
	"Download file from shared files zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de archivos compartidos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Download file from shared files zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Download file from shared files zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from shared files zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Download file from shared files zone of course"			// eviri lazim!
#endif
	,
	[ActAdmShaGrp] =
#if   L==1	// ca
	"Manage shared files zone of group"			// Necessita traducci
#elif L==2	// de
	"Manage shared files zone of group"			// Need bersetzung
#elif L==3	// en
	"Manage shared files zone of group"
#elif L==4	// es
	"Administrar zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Manage shared files zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Manage shared files zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Manage shared files zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage shared files zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Manage shared files zone of group"			// eviri lazim!
#endif
	,
	[ActReqRemFilShaGrp] =
#if   L==1	// ca
	"Request removal of file from shared files zone of group"				// Necessita traducci
#elif L==2	// de
	"Request removal of file from shared files zone of group"				// Need bersetzung
#elif L==3	// en
	"Request removal of file from shared files zone of group"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Request removal of file from shared files zone of group"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from shared files zone of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from shared files zone of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from shared files zone of group"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from shared files zone of group"				// eviri lazim!
#endif
	,
	[ActRemFilShaGrp] =
#if   L==1	// ca
	"Remove file from shared files zone of group"			// Necessita traducci
#elif L==2	// de
	"Remove file from shared files zone of group"			// Need bersetzung
#elif L==3	// en
	"Remove file from shared files zone of group"
#elif L==4	// es
	"Eliminar archivo de zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Remove file from shared files zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from shared files zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from shared files zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from shared files zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Remove file from shared files zone of group"			// eviri lazim!
#endif
	,
	[ActRemFolShaGrp] =
#if   L==1	// ca
	"Remove empty folder from shared files zone of group"				// Necessita traducci
#elif L==2	// de
	"Remove empty folder from shared files zone of group"				// Need bersetzung
#elif L==3	// en
	"Remove empty folder from shared files zone of group"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Remove empty folder from shared files zone of group"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from shared files zone of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from shared files zone of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from shared files zone of group"				// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from shared files zone of group"				// eviri lazim!
#endif
	,
	[ActCopShaGrp] =
#if   L==1	// ca
	"Set source of copy in shared files zone of group"			// Necessita traducci
#elif L==2	// de
	"Set source of copy in shared files zone of group"			// Need bersetzung
#elif L==3	// en
	"Set source of copy in shared files zone of group"
#elif L==4	// es
	"Establecer origen de copia en zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Set source of copy in shared files zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in shared files zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in shared files zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in shared files zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in shared files zone of group"			// eviri lazim!
#endif
	,
	[ActPasShaGrp] =
#if   L==1	// ca
	"Paste folder/file in shared files zone of group"			// Necessita traducci
#elif L==2	// de
	"Paste folder/file in shared files zone of group"			// Need bersetzung
#elif L==3	// en
	"Paste folder/file in shared files zone of group"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Paste folder/file in shared files zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in shared files zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in shared files zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in shared files zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in shared files zone of group"			// eviri lazim!
#endif
	,
	[ActRemTreShaGrp] =
#if   L==1	// ca
	"Remove non-empty folder from shared files zone of group"			// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from shared files zone of group"			// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from shared files zone of group"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Remove non-empty folder from shared files zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from shared files zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from shared files zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from shared files zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from shared files zone of group"			// eviri lazim!
#endif
	,
	[ActFrmCreShaGrp] =
#if   L==1	// ca
	"Edit new folder/file/link in shared zone of group"				// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in shared zone of group"				// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in shared zone of group"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Edit new folder/file/link in shared zone of group"				// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in shared zone of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in shared zone of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in shared zone of group"				// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in shared zone of group"				// eviri lazim!
#endif
	,
	[ActCreFolShaGrp] =
#if   L==1	// ca
	"Create new folder in shared files zone of group"		// Necessita traducci
#elif L==2	// de
	"Create new folder in shared files zone of group"		// Need bersetzung
#elif L==3	// en
	"Create new folder in shared files zone of group"
#elif L==4	// es
	"Crear nueva carpeta en zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Create new folder in shared files zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in shared files zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in shared files zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in shared files zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Create new folder in shared files zone of group"		// eviri lazim!
#endif
	,
	[ActCreLnkShaGrp] =
#if   L==1	// ca
	"Create new link in shared files zone of group"			// Necessita traducci
#elif L==2	// de
	"Create new link in shared files zone of group"			// Need bersetzung
#elif L==3	// en
	"Create new link in shared files zone of group"
#elif L==4	// es
	"Crear nuevo enlace en zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Create new link in shared files zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in shared files zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in shared files zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in shared files zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Create new link in shared files zone of group"			// eviri lazim!
#endif
	,
	[ActRenFolShaGrp] =
#if   L==1	// ca
	"Rename folder in shared zone of group"				// Necessita traducci
#elif L==2	// de
	"Rename folder in shared zone of group"				// Need bersetzung
#elif L==3	// en
	"Rename folder in shared zone of group"
#elif L==4	// es
	"Renombrar carpeta en zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Rename folder in shared zone of group"				// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in shared zone of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in shared zone of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in shared zone of group"				// Precisa de traduo
#elif L==10	// tr
	"Rename folder in shared zone of group"				// eviri lazim!
#endif
	,
	[ActRcvFilShaGrpDZ] =
#if   L==1	// ca
	"Send file to shared files zone of group using Dropzone.js"			// Necessita traducci
#elif L==2	// de
	"Send file to shared files zone of group using Dropzone.js"			// Need bersetzung
#elif L==3	// en
	"Send file to shared files zone of group using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona de archivos compartidos de grupo usando Dropzone.js"
#elif L==5	// fr
	"Send file to shared files zone of group using Dropzone.js"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de archivos compartidos de grupo usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to shared files zone of group using Dropzone.js"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to shared files zone of group using Dropzone.js"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to shared files zone of group using Dropzone.js"			// Precisa de traduo
#elif L==10	// tr
	"Send file to shared files zone of group using Dropzone.js"			// eviri lazim!
#endif
	,
	[ActRcvFilShaGrpCla] =
#if   L==1	// ca
	"Send file to shared files zone of group using the classic way"			// Necessita traducci
#elif L==2	// de
	"Send file to shared files zone of group using the classic way"			// Need bersetzung
#elif L==3	// en
	"Send file to shared files zone of group using the classic way"
#elif L==4	// es
	"Enviar archivo a zona de archivos compartidos de grupo de forma tradicional"
#elif L==5	// fr
	"Send file to shared files zone of group using the classic way"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de archivos compartidos de grupo de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file to shared files zone of group using the classic way"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to shared files zone of group using the classic way"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to shared files zone of group using the classic way"			// Precisa de traduo
#elif L==10	// tr
	"Send file to shared files zone of group using the classic way"			// eviri lazim!
#endif
	,
	[ActExpShaGrp] =
#if   L==1	// ca
	"Expand folder in shared files zone of group"			// Necessita traducci
#elif L==2	// de
	"Expand folder in shared files zone of group"			// Need bersetzung
#elif L==3	// en
	"Expand folder in shared files zone of group"
#elif L==4	// es
	"Expandir carpeta en zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Expand folder in shared files zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in shared files zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in shared files zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in shared files zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Expand folder in shared files zone of group"			// eviri lazim!
#endif
	,
	[ActConShaGrp] =
#if   L==1	// ca
	"Contract folder in shared files zone of group"			// Necessita traducci
#elif L==2	// de
	"Contract folder in shared files zone of group"			// Need bersetzung
#elif L==3	// en
	"Contract folder in shared files zone of group"
#elif L==4	// es
	"Contraer carpeta en zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Contract folder in shared files zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in shared files zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in shared files zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in shared files zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Contract folder in shared files zone of group"			// eviri lazim!
#endif
	,
	[ActZIPShaGrp] =
#if   L==1	// ca
	"Compress folder in shared files zone of group"			// Necessita traducci
#elif L==2	// de
	"Compress folder in shared files zone of group"			// Need bersetzung
#elif L==3	// en
	"Compress folder in shared files zone of group"
#elif L==4	// es
	"Comprimir carpeta en zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Compress folder in shared files zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in shared files zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in shared files zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in shared files zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Compress folder in shared files zone of group"			// eviri lazim!
#endif
	,
	[ActReqDatShaGrp] =
#if   L==1	// ca
	"See file metadata in shared files zone of group"			// Necessita traducci
#elif L==2	// de
	"See file metadata in shared files zone of group"			// Need bersetzung
#elif L==3	// en
	"See file metadata in shared files zone of group"
#elif L==4	// es
	"Ver metadatos de archivo en zona de archivos compartidos de grupo"
#elif L==5	// fr
	"See file metadata in shared files zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in shared files zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in shared files zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in shared files zone of group"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in shared files zone of group"			// eviri lazim!
#endif
	,
	[ActChgDatShaGrp] =
#if   L==1	// ca
	"Change file metadata in shared files zone of group"			// Necessita traducci
#elif L==2	// de
	"Change file metadata in shared files zone of group"			// Need bersetzung
#elif L==3	// en
	"Change file metadata in shared files zone of group"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Change file metadata in shared files zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in shared files zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in shared files zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in shared files zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in shared files zone of group"			// eviri lazim!
#endif
	,
	[ActDowShaGrp] =
#if   L==1	// ca
	"Download file from shared files zone of group"			// Necessita traducci
#elif L==2	// de
	"Download file from shared files zone of group"			// Need bersetzung
#elif L==3	// en
	"Download file from shared files zone of group"
#elif L==4	// es
	"Descargar archivo de zona de archivos compartidos de grupo"
#elif L==5	// fr
	"Download file from shared files zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de archivos compartidos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Download file from shared files zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Download file from shared files zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from shared files zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Download file from shared files zone of group"			// eviri lazim!
#endif
	,
	[ActReqAsgWrkCrs] =
#if   L==1	// ca
	"Manage assignments/works in course"			// Necessita traducci
#elif L==2	// de
	"Manage assignments/works in course"			// Need bersetzung
#elif L==3	// en
	"Manage assignments/works in course"
#elif L==4	// es
	"Administrar actividades/trabajos en asignatura"
#elif L==5	// fr
	"Manage assignments/works in course"			// Besoin de traduction
#elif L==6	// gn
	"Administrar actividades/trabajos en asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Manage assignments/works in course"			// Bisogno di traduzione
#elif L==8	// pl
	"Manage assignments/works in course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage assignments/works in course"			// Precisa de traduo
#elif L==10	// tr
	"Manage assignments/works in course"			// eviri lazim!
#endif
	,
	[ActAdmAsgWrkCrs] =
#if   L==1	// ca
	"Manage all assignments/works in course"			// Necessita traducci
#elif L==2	// de
	"Manage all assignments/works in course"			// Need bersetzung
#elif L==3	// en
	"Manage all assignments/works in course"
#elif L==4	// es
	"Administrar todas las actividades/trabajos de asignatura"
#elif L==5	// fr
	"Manage all assignments/works in course"			// Besoin de traduction
#elif L==6	// gn
	"Administrar todas las actividades/trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Manage all assignments/works in course"			// Bisogno di traduzione
#elif L==8	// pl
	"Manage all assignments/works in course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage all assignments/works in course"			// Precisa de traduo
#elif L==10	// tr
	"Manage all assignments/works in course"			// eviri lazim!
#endif
	,
	[ActAdmAsgWrkUsr] =
#if   L==1	// ca
	"Manage the assignments/works of user"			// Necessita traducci
#elif L==2	// de
	"Manage the assignments/works of user"			// Need bersetzung
#elif L==3	// en
	"Manage the assignments/works of user"
#elif L==4	// es
	"Administrar las actividades/trabajos de usuario"
#elif L==5	// fr
	"Manage the assignments/works of user"			// Besoin de traduction
#elif L==6	// gn
	"Administrar las actividades/trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Manage the assignments/works of user"			// Bisogno di traduzione
#elif L==8	// pl
	"Manage the assignments/works of user"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage the assignments/works of user"			// Precisa de traduo
#elif L==10	// tr
	"Manage the assignments/works of user"			// eviri lazim!
#endif
	,
	[ActReqRemFilAsgUsr] =
#if   L==1	// ca
	"Request removal of file from user's assignments"			// Necessita traducci
#elif L==2	// de
	"Request removal of file from user's assignments"			// Need bersetzung
#elif L==3	// en
	"Request removal of file from user's assignments"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de actividades de usuario"
#elif L==5	// fr
	"Request removal of file from user's assignments"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from user's assignments"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from user's assignments"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from user's assignments"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from user's assignments"			// eviri lazim!
#endif
	,
	[ActRemFilAsgUsr] =
#if   L==1	// ca
	"Remove file from user's assignments"		// Necessita traducci
#elif L==2	// de
	"Remove file from user's assignments"		// Need bersetzung
#elif L==3	// en
	"Remove file from user's assignments"
#elif L==4	// es
	"Eliminar archivo de actividades de usuario"
#elif L==5	// fr
	"Remove file from user's assignments"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from user's assignments"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from user's assignments"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from user's assignments"		// Precisa de traduo
#elif L==10	// tr
	"Remove file from user's assignments"		// eviri lazim!
#endif
	,
	[ActRemFolAsgUsr] =
#if   L==1	// ca
	"Remove empty folder from user's assignments"			// Necessita traducci
#elif L==2	// de
	"Remove empty folder from user's assignments"			// Need bersetzung
#elif L==3	// en
	"Remove empty folder from user's assignments"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de actividades de usuario"
#elif L==5	// fr
	"Remove empty folder from user's assignments"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from user's assignments"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from user's assignments"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from user's assignments"			// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from user's assignments"			// eviri lazim!
#endif
	,
	[ActCopAsgUsr] =
#if   L==1	// ca
	"Set origin of copy in user's assignments"		// Necessita traducci
#elif L==2	// de
	"Set origin of copy in user's assignments"		// Need bersetzung
#elif L==3	// en
	"Set origin of copy in user's assignments"
#elif L==4	// es
	"Establecer origen de copia en actividades de usuario"
#elif L==5	// fr
	"Set origin of copy in user's assignments"		// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Set origin of copy in user's assignments"		// Bisogno di traduzione
#elif L==8	// pl
	"Set origin of copy in user's assignments"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set origin of copy in user's assignments"		// Precisa de traduo
#elif L==10	// tr
	"Set origin of copy in user's assignments"		// eviri lazim!
#endif
	,
	[ActPasAsgUsr] =
#if   L==1	// ca
	"Paste folder/file in user's assignments"		// Necessita traducci
#elif L==2	// de
	"Paste folder/file in user's assignments"		// Need bersetzung
#elif L==3	// en
	"Paste folder/file in user's assignments"
#elif L==4	// es
	"Pegar carpeta/archivo en actividades de usuario"
#elif L==5	// fr
	"Paste folder/file in user's assignments"		// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in user's assignments"		// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in user's assignments"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in user's assignments"		// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in user's assignments"		// eviri lazim!
#endif
	,
	[ActRemTreAsgUsr] =
#if   L==1	// ca
	"Remove non-empty folder of user's assignments"			// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder of user's assignments"			// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder of user's assignments"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de actividades de usuario"
#elif L==5	// fr
	"Remove non-empty folder of user's assignments"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder of user's assignments"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder of user's assignments"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder of user's assignments"			// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder of user's assignments"			// eviri lazim!
#endif
	,
	[ActFrmCreAsgUsr] =
#if   L==1	// ca
	"Edit new folder/file/link in user's assignments"		// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in user's assignments"		// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in user's assignments"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en actividades de usuario"
#elif L==5	// fr
	"Edit new folder/file/link in user's assignments"		// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in user's assignments"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in user's assignments"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in user's assignments"		// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in user's assignments"		// eviri lazim!
#endif
	,
	[ActCreFolAsgUsr] =
#if   L==1	// ca
	"Create new folder in user's assignments"	// Necessita traducci
#elif L==2	// de
	"Create new folder in user's assignments"	// Need bersetzung
#elif L==3	// en
	"Create new folder in user's assignments"
#elif L==4	// es
	"Crear nueva carpeta en actividades de usuario"
#elif L==5	// fr
	"Create new folder in user's assignments"	// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in user's assignments"	// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in user's assignments"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in user's assignments"	// Precisa de traduo
#elif L==10	// tr
	"Create new folder in user's assignments"	// eviri lazim!
#endif
	,
	[ActCreLnkAsgUsr] =
#if   L==1	// ca
	"Create new link in user's assignments"		// Necessita traducci
#elif L==2	// de
	"Create new link in user's assignments"		// Need bersetzung
#elif L==3	// en
	"Create new link in user's assignments"
#elif L==4	// es
	"Crear nuevo enlace en actividades de usuario"
#elif L==5	// fr
	"Create new link in user's assignments"		// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in user's assignments"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in user's assignments"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in user's assignments"		// Precisa de traduo
#elif L==10	// tr
	"Create new link in user's assignments"		// eviri lazim!
#endif
	,
	[ActRenFolAsgUsr] =
#if   L==1	// ca
	"Rename folder in user's assignments"		// Necessita traducci
#elif L==2	// de
	"Rename folder in user's assignments"		// Need bersetzung
#elif L==3	// en
	"Rename folder in user's assignments"
#elif L==4	// es
	"Renombrar carpeta en actividades de usuario"
#elif L==5	// fr
	"Rename folder in user's assignments"		// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in user's assignments"		// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in user's assignments"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in user's assignments"		// Precisa de traduo
#elif L==10	// tr
	"Rename folder in user's assignments"		// eviri lazim!
#endif
	,
	[ActRcvFilAsgUsrDZ] =
#if   L==1	// ca
	"Send new file to user's assignments using Dropzone.js"			// Necessita traducci
#elif L==2	// de
	"Send new file to user's assignments using Dropzone.js"			// Need bersetzung
#elif L==3	// en
	"Send new file to user's assignments using Dropzone.js"
#elif L==4	// es
	"Enviar un nuevo archivo a actividades de usuario usando Dropzone.js"
#elif L==5	// fr
	"Send new file to user's assignments using Dropzone.js"			// Besoin de traduction
#elif L==6	// gn
	"Enviar un nuevo archivo a actividades de usuario usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send new file to user's assignments using Dropzone.js"			// Bisogno di traduzione
#elif L==8	// pl
	"Send new file to user's assignments using Dropzone.js"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send new file to user's assignments using Dropzone.js"			// Precisa de traduo
#elif L==10	// tr
	"Send new file to user's assignments using Dropzone.js"			// eviri lazim!
#endif
	,
	[ActRcvFilAsgUsrCla] =
#if   L==1	// ca
	"Send new file to user's assignments using the classic way"		// Necessita traducci
#elif L==2	// de
	"Send new file to user's assignments using the classic way"		// Need bersetzung
#elif L==3	// en
	"Send new file to user's assignments using the classic way"
#elif L==4	// es
	"Enviar nuevo archivo a actividades de usuario de forma tradicional"
#elif L==5	// fr
	"Send new file to user's assignments using the classic way"		// Besoin de traduction
#elif L==6	// gn
	"Enviar nuevo archivo a actividades de usuario de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send new file to user's assignments using the classic way"		// Bisogno di traduzione
#elif L==8	// pl
	"Send new file to user's assignments using the classic way"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send new file to user's assignments using the classic way"		// Precisa de traduo
#elif L==10	// tr
	"Send new file to user's assignments using the classic way"		// eviri lazim!
#endif
	,
	[ActExpAsgUsr] =
#if   L==1	// ca
	"Expand folder in user's assignments"		// Necessita traducci
#elif L==2	// de
	"Expand folder in user's assignments"		// Need bersetzung
#elif L==3	// en
	"Expand folder in user's assignments"
#elif L==4	// es
	"Expandir carpeta en actividades de usuario"
#elif L==5	// fr
	"Expand folder in user's assignments"		// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in user's assignments"		// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in user's assignments"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in user's assignments"		// Precisa de traduo
#elif L==10	// tr
	"Expand folder in user's assignments"		// eviri lazim!
#endif
	,
	[ActConAsgUsr] =
#if   L==1	// ca
	"Contract folder in user's assignments"		// Necessita traducci
#elif L==2	// de
	"Contract folder in user's assignments"		// Need bersetzung
#elif L==3	// en
	"Contract folder in user's assignments"
#elif L==4	// es
	"Contraer carpeta en actividades de usuario"
#elif L==5	// fr
	"Contract folder in user's assignments"		// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in user's assignments"		// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in user's assignments"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in user's assignments"		// Precisa de traduo
#elif L==10	// tr
	"Contract folder in user's assignments"		// eviri lazim!
#endif
	,
	[ActZIPAsgUsr] =
#if   L==1	// ca
	"Compress folder in user's assignments"		// Necessita traducci
#elif L==2	// de
	"Compress folder in user's assignments"		// Need bersetzung
#elif L==3	// en
	"Compress folder in user's assignments"
#elif L==4	// es
	"Comprimir carpeta en actividades de usuario"
#elif L==5	// fr
	"Compress folder in user's assignments"		// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in user's assignments"		// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in user's assignments"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in user's assignments"		// Precisa de traduo
#elif L==10	// tr
	"Compress folder in user's assignments"		// eviri lazim!
#endif
	,
	[ActReqDatAsgUsr] =
#if   L==1	// ca
	"See file metadata in user's assignments"		// Necessita traducci
#elif L==2	// de
	"See file metadata in user's assignments"		// Need bersetzung
#elif L==3	// en
	"See file metadata in user's assignments"
#elif L==4	// es
	"Ver metadatos de archivo en actividades de usuario"
#elif L==5	// fr
	"See file metadata in user's assignments"		// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in user's assignments"		// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in user's assignments"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in user's assignments"		// Precisa de traduo
#elif L==10	// tr
	"See file metadata in user's assignments"		// eviri lazim!
#endif
	,
	[ActChgDatAsgUsr] =
#if   L==1	// ca
	"Change file metadata in user's assignments"			// Necessita traducci
#elif L==2	// de
	"Change file metadata in user's assignments"			// Need bersetzung
#elif L==3	// en
	"Change file metadata in user's assignments"
#elif L==4	// es
	"Cambiar metadatos de archivo en actividades de usuario"
#elif L==5	// fr
	"Change file metadata in user's assignments"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in user's assignments"			// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in user's assignments"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in user's assignments"			// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in user's assignments"			// eviri lazim!
#endif
	,
	[ActDowAsgUsr] =
#if   L==1	// ca
	"Download file from user's assignments"		// Necessita traducci
#elif L==2	// de
	"Download file from user's assignments"		// Need bersetzung
#elif L==3	// en
	"Download file from user's assignments"
#elif L==4	// es
	"Descargar archivo de actividades de usuario"
#elif L==5	// fr
	"Download file from user's assignments"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de actividades de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Download file from user's assignments"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from user's assignments"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from user's assignments"		// Precisa de traduo
#elif L==10	// tr
	"Download file from user's assignments"		// eviri lazim!
#endif
	,
	[ActReqRemFilWrkUsr] =
#if   L==1	// ca
	"Request removal of file from user's works"				// Necessita traducci
#elif L==2	// de
	"Request removal of file from user's works"				// Need bersetzung
#elif L==3	// en
	"Request removal of file from user's works"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de trabajos de usuario"
#elif L==5	// fr
	"Request removal of file from user's works"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from user's works"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from user's works"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from user's works"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from user's works"				// eviri lazim!
#endif
	,
	[ActRemFilWrkUsr] =
#if   L==1	// ca
	"Remove file from user's works"			// Necessita traducci
#elif L==2	// de
	"Remove file from user's works"			// Need bersetzung
#elif L==3	// en
	"Remove file from user's works"
#elif L==4	// es
	"Eliminar archivo de trabajos de usuario"
#elif L==5	// fr
	"Remove file from user's works"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from user's works"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from user's works"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from user's works"			// Precisa de traduo
#elif L==10	// tr
	"Remove file from user's works"			// eviri lazim!
#endif
	,
	[ActRemFolWrkUsr] =
#if   L==1	// ca
	"Remove empty folder from user's works"			// Necessita traducci
#elif L==2	// de
	"Remove empty folder from user's works"			// Need bersetzung
#elif L==3	// en
	"Remove empty folder from user's works"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de trabajos de usuario"
#elif L==5	// fr
	"Remove empty folder from user's works"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from user's works"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from user's works"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from user's works"			// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from user's works"			// eviri lazim!
#endif
	,
	[ActCopWrkUsr] =
#if   L==1	// ca
	"Set origin of copy in user's works"			// Necessita traducci
#elif L==2	// de
	"Set origin of copy in user's works"			// Need bersetzung
#elif L==3	// en
	"Set origin of copy in user's works"
#elif L==4	// es
	"Establecer origen de copia en trabajos de usuario"
#elif L==5	// fr
	"Set origin of copy in user's works"			// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Set origin of copy in user's works"			// Bisogno di traduzione
#elif L==8	// pl
	"Set origin of copy in user's works"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set origin of copy in user's works"			// Precisa de traduo
#elif L==10	// tr
	"Set origin of copy in user's works"			// eviri lazim!
#endif
	,
	[ActPasWrkUsr] =
#if   L==1	// ca
	"Paste folder/file in user's works"			// Necessita traducci
#elif L==2	// de
	"Paste folder/file in user's works"			// Need bersetzung
#elif L==3	// en
	"Paste folder/file in user's works"
#elif L==4	// es
	"Pegar archivo or carpeta en trabajos de usuario"
#elif L==5	// fr
	"Paste folder/file in user's works"			// Besoin de traduction
#elif L==6	// gn
	"Pegar archivo or carpeta en trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in user's works"			// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in user's works"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in user's works"			// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in user's works"			// eviri lazim!
#endif
	,
	[ActRemTreWrkUsr] =
#if   L==1	// ca
	"Remove non-empty folder from user's works"			// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from user's works"			// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from user's works"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de trabajos de usuario"
#elif L==5	// fr
	"Remove non-empty folder from user's works"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from user's works"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from user's works"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from user's works"			// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from user's works"			// eviri lazim!
#endif
	,
	[ActFrmCreWrkUsr] =
#if   L==1	// ca
	"Edit new folder/file/link in user's works"			// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in user's works"			// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in user's works"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en trabajos de usuario"
#elif L==5	// fr
	"Edit new folder/file/link in user's works"			// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in user's works"			// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in user's works"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in user's works"			// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in user's works"			// eviri lazim!
#endif
	,
	[ActCreFolWrkUsr] =
#if   L==1	// ca
	"Create new folder in user's works"		// Necessita traducci
#elif L==2	// de
	"Create new folder in user's works"		// Need bersetzung
#elif L==3	// en
	"Create new folder in user's works"
#elif L==4	// es
	"Crear nueva carpeta en trabajos de usuario"
#elif L==5	// fr
	"Create new folder in user's works"		// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in user's works"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in user's works"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in user's works"		// Precisa de traduo
#elif L==10	// tr
	"Create new folder in user's works"		// eviri lazim!
#endif
	,
	[ActCreLnkWrkUsr] =
#if   L==1	// ca
	"Create new link in user's works"		// Necessita traducci
#elif L==2	// de
	"Create new link in user's works"		// Need bersetzung
#elif L==3	// en
	"Create new link in user's works"
#elif L==4	// es
	"Crear nuevo enlace en trabajos de usuario"
#elif L==5	// fr
	"Create new link in user's works"		// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in user's works"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in user's works"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in user's works"		// Precisa de traduo
#elif L==10	// tr
	"Create new link in user's works"		// eviri lazim!
#endif
	,
	[ActRenFolWrkUsr] =
#if   L==1	// ca
	"Rename folder in user's works"			// Necessita traducci
#elif L==2	// de
	"Rename folder in user's works"			// Need bersetzung
#elif L==3	// en
	"Rename folder in user's works"
#elif L==4	// es
	"Renombrar carpeta en trabajos de usuario"
#elif L==5	// fr
	"Rename folder in user's works"			// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in user's works"			// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in user's works"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in user's works"			// Precisa de traduo
#elif L==10	// tr
	"Rename folder in user's works"			// eviri lazim!
#endif
	,
	[ActRcvFilWrkUsrDZ] =
#if   L==1	// ca
	"Send file to user's works using Dropzone.js"			// Necessita traducci
#elif L==2	// de
	"Send file to user's works using Dropzone.js"			// Need bersetzung
#elif L==3	// en
	"Send file to user's works using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a trabajos de usuario usando Dropzone.js"
#elif L==5	// fr
	"Send file to user's works using Dropzone.js"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a trabajos de usuario usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to user's works using Dropzone.js"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to user's works using Dropzone.js"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to user's works using Dropzone.js"			// Precisa de traduo
#elif L==10	// tr
	"Send file to user's works using Dropzone.js"			// eviri lazim!
#endif
	,
	[ActRcvFilWrkUsrCla] =
#if   L==1	// ca
	"Send file to user's works using the classic way"		// Necessita traducci
#elif L==2	// de
	"Send file to user's works using the classic way"		// Need bersetzung
#elif L==3	// en
	"Send file to user's works using the classic way"
#elif L==4	// es
	"Enviar archivo a trabajos de usuario de forma tradicional"
#elif L==5	// fr
	"Send file to user's works using the classic way"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a trabajos de usuario de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file to user's works using the classic way"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to user's works using the classic way"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to user's works using the classic way"		// Precisa de traduo
#elif L==10	// tr
	"Send file to user's works using the classic way"		// eviri lazim!
#endif
	,
	[ActExpWrkUsr] =
#if   L==1	// ca
	"Expand folder in user's works"			// Necessita traducci
#elif L==2	// de
	"Expand folder in user's works"			// Need bersetzung
#elif L==3	// en
	"Expand folder in user's works"
#elif L==4	// es
	"Expandir carpeta en trabajos de usuario"
#elif L==5	// fr
	"Expand folder in user's works"			// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in user's works"			// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in user's works"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in user's works"			// Precisa de traduo
#elif L==10	// tr
	"Expand folder in user's works"			// eviri lazim!
#endif
	,
	[ActConWrkUsr] =
#if   L==1	// ca
	"Contract folder in user's works"		// Necessita traducci
#elif L==2	// de
	"Contract folder in user's works"		// Need bersetzung
#elif L==3	// en
	"Contract folder in user's works"
#elif L==4	// es
	"Contraer carpeta en trabajos de usuario"
#elif L==5	// fr
	"Contract folder in user's works"		// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in user's works"		// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in user's works"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in user's works"		// Precisa de traduo
#elif L==10	// tr
	"Contract folder in user's works"		// eviri lazim!
#endif
	,
	[ActZIPWrkUsr] =
#if   L==1	// ca
	"Compress folder in user's works"		// Necessita traducci
#elif L==2	// de
	"Compress folder in user's works"		// Need bersetzung
#elif L==3	// en
	"Compress folder in user's works"
#elif L==4	// es
	"Comprimir carpeta en trabajos de usuario"
#elif L==5	// fr
	"Compress folder in user's works"		// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in user's works"		// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in user's works"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in user's works"		// Precisa de traduo
#elif L==10	// tr
	"Compress folder in user's works"		// eviri lazim!
#endif
	,
	[ActReqDatWrkUsr] =
#if   L==1	// ca
	"See file metadata in user's works"			// Necessita traducci
#elif L==2	// de
	"See file metadata in user's works"			// Need bersetzung
#elif L==3	// en
	"See file metadata in user's works"
#elif L==4	// es
	"Ver metadatos de archivo en trabajos de usuario"
#elif L==5	// fr
	"See file metadata in user's works"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in user's works"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in user's works"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in user's works"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in user's works"			// eviri lazim!
#endif
	,
	[ActChgDatWrkUsr] =
#if   L==1	// ca
	"Change file metadata in user's works"			// Necessita traducci
#elif L==2	// de
	"Change file metadata in user's works"			// Need bersetzung
#elif L==3	// en
	"Change file metadata in user's works"
#elif L==4	// es
	"Cambiar metadatos de archivo en trabajos de usuario"
#elif L==5	// fr
	"Change file metadata in user's works"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in user's works"			// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in user's works"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in user's works"			// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in user's works"			// eviri lazim!
#endif
	,
	[ActDowWrkUsr] =
#if   L==1	// ca
	"Download file from user's works"		// Necessita traducci
#elif L==2	// de
	"Download file from user's works"		// Need bersetzung
#elif L==3	// en
	"Download file from user's works"
#elif L==4	// es
	"Descargar archivo de trabajos de usuario"
#elif L==5	// fr
	"Download file from user's works"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de trabajos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Download file from user's works"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from user's works"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from user's works"		// Precisa de traduo
#elif L==10	// tr
	"Download file from user's works"		// eviri lazim!
#endif
	,
	[ActReqRemFilAsgCrs] =
#if   L==1	// ca
	"Request removal of file from assignments zone of course"				// Necessita traducci
#elif L==2	// de
	"Request removal of file from assignments zone of course"				// Need bersetzung
#elif L==3	// en
	"Request removal of file from assignments zone of course"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de zona de actividades de asignatura"
#elif L==5	// fr
	"Request removal of file from assignments zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from assignments zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from assignments zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from assignments zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from assignments zone of course"				// eviri lazim!
#endif
	,
	[ActRemFilAsgCrs] =
#if   L==1	// ca
	"Remove file from assignments zone of course"		// Necessita traducci
#elif L==2	// de
	"Remove file from assignments zone of course"		// Need bersetzung
#elif L==3	// en
	"Remove file from assignments zone of course"
#elif L==4	// es
	"Eliminar archivo en zona de actividades de asignatura"
#elif L==5	// fr
	"Remove file from assignments zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo en zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from assignments zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from assignments zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from assignments zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Remove file from assignments zone of course"		// eviri lazim!
#endif
	,
	[ActRemFolAsgCrs] =
#if   L==1	// ca
	"Remove empty folder from assignments zone of course"			// Necessita traducci
#elif L==2	// de
	"Remove empty folder from assignments zone of course"			// Need bersetzung
#elif L==3	// en
	"Remove empty folder from assignments zone of course"
#elif L==4	// es
	"Eliminar carpeta vac&acute;a de zona de actividades de asignatura"
#elif L==5	// fr
	"Remove empty folder from assignments zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&acute;a de zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from assignments zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from assignments zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from assignments zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from assignments zone of course"			// eviri lazim!
#endif
	,
	[ActCopAsgCrs] =
#if   L==1	// ca
	"Set origin of copy in assignments zone of course"			// Necessita traducci
#elif L==2	// de
	"Set origin of copy in assignments zone of course"			// Need bersetzung
#elif L==3	// en
	"Set origin of copy in assignments zone of course"
#elif L==4	// es
	"Establecer origen de copia en zona de actividades de asignatura"
#elif L==5	// fr
	"Set origin of copy in assignments zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Set origin of copy in assignments zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Set origin of copy in assignments zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set origin of copy in assignments zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Set origin of copy in assignments zone of course"			// eviri lazim!
#endif
	,
	[ActPasAsgCrs] =
#if   L==1	// ca
	"Paste folder/file in assignments zone of course"		// Necessita traducci
#elif L==2	// de
	"Paste folder/file in assignments zone of course"		// Need bersetzung
#elif L==3	// en
	"Paste folder/file in assignments zone of course"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de actividades de asignatura"
#elif L==5	// fr
	"Paste folder/file in assignments zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in assignments zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in assignments zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in assignments zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in assignments zone of course"		// eviri lazim!
#endif
	,
	[ActRemTreAsgCrs] =
#if   L==1	// ca
	"Remove non-empty folder from assignments zone of course"		// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from assignments zone of course"		// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from assignments zone of course"
#elif L==4	// es
	"Eliminar carpeta no vac&acute;a de zona de actividades de asignatura"
#elif L==5	// fr
	"Remove non-empty folder from assignments zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&acute;a de zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from assignments zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from assignments zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from assignments zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from assignments zone of course"		// eviri lazim!
#endif
	,
	[ActFrmCreAsgCrs] =
#if   L==1	// ca
	"Edit new folder/file/link in assignments zone of course"			// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in assignments zone of course"			// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in assignments zone of course"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de actividades de asignatura"
#elif L==5	// fr
	"Edit new folder/file/link in assignments zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in assignments zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in assignments zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in assignments zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in assignments zone of course"			// eviri lazim!
#endif
	,
	[ActCreFolAsgCrs] =
#if   L==1	// ca
	"Create new folder in assignments zone of course"		// Necessita traducci
#elif L==2	// de
	"Create new folder in assignments zone of course"		// Need bersetzung
#elif L==3	// en
	"Create new folder in assignments zone of course"
#elif L==4	// es
	"Crear nueva carpeta en zona de actividades de asignatura"
#elif L==5	// fr
	"Create new folder in assignments zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in assignments zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in assignments zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in assignments zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Create new folder in assignments zone of course"		// eviri lazim!
#endif
	,
	[ActCreLnkAsgCrs] =
#if   L==1	// ca
	"Create new link in assignments zone of course"			// Necessita traducci
#elif L==2	// de
	"Create new link in assignments zone of course"			// Need bersetzung
#elif L==3	// en
	"Create new link in assignments zone of course"
#elif L==4	// es
	"Crear nuevo enlace en zona de actividades de asignatura"
#elif L==5	// fr
	"Create new link in assignments zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in assignments zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in assignments zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in assignments zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Create new link in assignments zone of course"			// eviri lazim!
#endif
	,
	[ActRenFolAsgCrs] =
#if   L==1	// ca
	"Rename folder in assignments zone of course"			// Necessita traducci
#elif L==2	// de
	"Rename folder in assignments zone of course"			// Need bersetzung
#elif L==3	// en
	"Rename folder in assignments zone of course"
#elif L==4	// es
	"Renombrar carpeta en zona de actividades de asignatura"
#elif L==5	// fr
	"Rename folder in assignments zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in assignments zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in assignments zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in assignments zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Rename folder in assignments zone of course"			// eviri lazim!
#endif
	,
	[ActRcvFilAsgCrsDZ] =
#if   L==1	// ca
	"Send file to assignments zone of course using Dropzone.js"		// Necessita traducci
#elif L==2	// de
	"Send file to assignments zone of course using Dropzone.js"		// Need bersetzung
#elif L==3	// en
	"Send file to assignments zone of course using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona de actividades de asignatura usando Dropzone.js"
#elif L==5	// fr
	"Send file to assignments zone of course using Dropzone.js"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de actividades de asignatura usando Dropzone.js" // Okoteve traduccin
#elif L==7	// it
	"Send file to assignments zone of course using Dropzone.js"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to assignments zone of course using Dropzone.js"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to assignments zone of course using Dropzone.js"		// Precisa de traduo
#elif L==10	// tr
	"Send file to assignments zone of course using Dropzone.js"		// eviri lazim!
#endif
	,
	[ActRcvFilAsgCrsCla] =
#if   L==1	// ca
	"Send file to assignments zone of course using the classic way"			// Necessita traducci
#elif L==2	// de
	"Send file to assignments zone of course using the classic way"			// Need bersetzung
#elif L==3	// en
	"Send file to assignments zone of course using the classic way"
#elif L==4	// es
	"Enviar archivo a zona de actividades de asignatura de forma tradicional"
#elif L==5	// fr
	"Send file to assignments zone of course using the classic way"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de actividades de asignatura de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file to assignments zone of course using the classic way"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to assignments zone of course using the classic way"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to assignments zone of course using the classic way"			// Precisa de traduo
#elif L==10	// tr
	"Send file to assignments zone of course using the classic way"			// eviri lazim!
#endif
	,
	[ActExpAsgCrs] =
#if   L==1	// ca
	"Expand folder in assignments zone of course"		// Necessita traducci
#elif L==2	// de
	"Expand folder in assignments zone of course"		// Need bersetzung
#elif L==3	// en
	"Expand folder in assignments zone of course"
#elif L==4	// es
	"Expandir carpeta en zona de actividades de asignatura"
#elif L==5	// fr
	"Expand folder in assignments zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in assignments zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in assignments zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in assignments zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Expand folder in assignments zone of course"		// eviri lazim!
#endif
	,
	[ActConAsgCrs] =
#if   L==1	// ca
	"Contract folder in assignments zone of course"		// Necessita traducci
#elif L==2	// de
	"Contract folder in assignments zone of course"		// Need bersetzung
#elif L==3	// en
	"Contract folder in assignments zone of course"
#elif L==4	// es
	"Contraer carpeta en zona de actividades de asignatura"
#elif L==5	// fr
	"Contract folder in assignments zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in assignments zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in assignments zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in assignments zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Contract folder in assignments zone of course"		// eviri lazim!
#endif
	,
	[ActZIPAsgCrs] =
#if   L==1	// ca
	"Compress folder in assignments zone of course"			// Necessita traducci
#elif L==2	// de
	"Compress folder in assignments zone of course"			// Need bersetzung
#elif L==3	// en
	"Compress folder in assignments zone of course"
#elif L==4	// es
	"Comprimir carpeta en zona de actividades de asignatura"
#elif L==5	// fr
	"Compress folder in assignments zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in assignments zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in assignments zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in assignments zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Compress folder in assignments zone of course"			// eviri lazim!
#endif
	,
	[ActReqDatAsgCrs] =
#if   L==1	// ca
	"See file metadata in assignments zone of course"		// Necessita traducci
#elif L==2	// de
	"See file metadata in assignments zone of course"		// Need bersetzung
#elif L==3	// en
	"See file metadata in assignments zone of course"
#elif L==4	// es
	"Ver metadatos de archivo en zona de actividades de asignatura"
#elif L==5	// fr
	"See file metadata in assignments zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in assignments zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in assignments zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in assignments zone of course"		// Precisa de traduo
#elif L==10	// tr
	"See file metadata in assignments zone of course"		// eviri lazim!
#endif
	,
	[ActChgDatAsgCrs] =
#if   L==1	// ca
	"Change file metadata in assignments zone of course"			// Necessita traducci
#elif L==2	// de
	"Change file metadata in assignments zone of course"			// Need bersetzung
#elif L==3	// en
	"Change file metadata in assignments zone of course"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de actividades de asignatura"
#elif L==5	// fr
	"Change file metadata in assignments zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in assignments zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in assignments zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in assignments zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in assignments zone of course"			// eviri lazim!
#endif
	,
	[ActDowAsgCrs] =
#if   L==1	// ca
	"Download file from assignments zone of course"			// Necessita traducci
#elif L==2	// de
	"Download file from assignments zone of course"			// Need bersetzung
#elif L==3	// en
	"Download file from assignments zone of course"
#elif L==4	// es
	"Descargar archivo de zona de actividades de asignatura"
#elif L==5	// fr
	"Download file from assignments zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de actividades de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Download file from assignments zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Download file from assignments zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from assignments zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Download file from assignments zone of course"			// eviri lazim!
#endif
	,
	[ActReqRemFilWrkCrs] =
#if   L==1	// ca
	"Request removal of file from works zone of course"				// Necessita traducci
#elif L==2	// de
	"Request removal of file from works zone of course"				// Need bersetzung
#elif L==3	// en
	"Request removal of file from works zone of course"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de zona de trabajos de asignatura"
#elif L==5	// fr
	"Request removal of file from works zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from works zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from works zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from works zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from works zone of course"				// eviri lazim!
#endif
	,
	[ActRemFilWrkCrs] =
#if   L==1	// ca
	"Remove file from works zone of course"			// Necessita traducci
#elif L==2	// de
	"Remove file from works zone of course"			// Need bersetzung
#elif L==3	// en
	"Remove file from works zone of course"
#elif L==4	// es
	"Eliminar archivo de zona de trabajos de asignatura"
#elif L==5	// fr
	"Remove file from works zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from works zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from works zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from works zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Remove file from works zone of course"			// eviri lazim!
#endif
	,
	[ActRemFolWrkCrs] =
#if   L==1	// ca
	"Remove empty folder from works zone of course"				// Necessita traducci
#elif L==2	// de
	"Remove empty folder from works zone of course"				// Need bersetzung
#elif L==3	// en
	"Remove empty folder from works zone of course"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona de trabajos de asignatura"
#elif L==5	// fr
	"Remove empty folder from works zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from works zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from works zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from works zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from works zone of course"				// eviri lazim!
#endif
	,
	[ActCopWrkCrs] =
#if   L==1	// ca
	"Set origin of copy in works zone of course"			// Necessita traducci
#elif L==2	// de
	"Set origin of copy in works zone of course"			// Need bersetzung
#elif L==3	// en
	"Set origin of copy in works zone of course"
#elif L==4	// es
	"Establecer origen de copia en zona de trabajos de asignatura"
#elif L==5	// fr
	"Set origin of copy in works zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Set origin of copy in works zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Set origin of copy in works zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set origin of copy in works zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Set origin of copy in works zone of course"			// eviri lazim!
#endif
	,
	[ActPasWrkCrs] =
#if   L==1	// ca
	"Paste folder/file in works zone of course"			// Necessita traducci
#elif L==2	// de
	"Paste folder/file in works zone of course"			// Need bersetzung
#elif L==3	// en
	"Paste folder/file in works zone of course"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de trabajos de asignatura"
#elif L==5	// fr
	"Paste folder/file in works zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in works zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in works zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in works zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in works zone of course"			// eviri lazim!
#endif
	,
	[ActRemTreWrkCrs] =
#if   L==1	// ca
	"Remove non-empty folder from works zone of course"			// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from works zone of course"			// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from works zone of course"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona de trabajos de asignatura"
#elif L==5	// fr
	"Remove non-empty folder from works zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from works zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from works zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from works zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from works zone of course"			// eviri lazim!
#endif
	,
	[ActFrmCreWrkCrs] =
#if   L==1	// ca
	"Edit new folder/file/link in works zone of course"			// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in works zone of course"			// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in works zone of course"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de trabajos de asignatura"
#elif L==5	// fr
	"Edit new folder/file/link in works zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in works zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in works zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in works zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in works zone of course"			// eviri lazim!
#endif
	,
	[ActCreFolWrkCrs] =
#if   L==1	// ca
	"Create new folder in works zone of course"		// Necessita traducci
#elif L==2	// de
	"Create new folder in works zone of course"		// Need bersetzung
#elif L==3	// en
	"Create new folder in works zone of course"
#elif L==4	// es
	"Crear nueva carpeta en zona de trabajos de asignatura"
#elif L==5	// fr
	"Create new folder in works zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in works zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in works zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in works zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Create new folder in works zone of course"		// eviri lazim!
#endif
	,
	[ActCreLnkWrkCrs] =
#if   L==1	// ca
	"Create new link in works zone of course"		// Necessita traducci
#elif L==2	// de
	"Create new link in works zone of course"		// Need bersetzung
#elif L==3	// en
	"Create new link in works zone of course"
#elif L==4	// es
	"Crear nuevo enlace en zona de trabajos de asignatura"
#elif L==5	// fr
	"Create new link in works zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in works zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in works zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in works zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Create new link in works zone of course"		// eviri lazim!
#endif
	,
	[ActRenFolWrkCrs] =
#if   L==1	// ca
	"Rename folder in works zone of course"			// Necessita traducci
#elif L==2	// de
	"Rename folder in works zone of course"			// Need bersetzung
#elif L==3	// en
	"Rename folder in works zone of course"
#elif L==4	// es
	"Renombrar carpeta en zona de trabajos de asignatura"
#elif L==5	// fr
	"Rename folder in works zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in works zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in works zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in works zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Rename folder in works zone of course"			// eviri lazim!
#endif
	,
	[ActRcvFilWrkCrsDZ] =
#if   L==1	// ca
	"Send file to works zone of course using Dropzone.js"			// Necessita traducci
#elif L==2	// de
	"Send file to works zone of course using Dropzone.js"			// Need bersetzung
#elif L==3	// en
	"Send file to works zone of course using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona de trabajos de asignatura usando Dropzone.js"
#elif L==5	// fr
	"Send file to works zone of course using Dropzone.js"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de trabajos de asignatura usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to works zone of course using Dropzone.js"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to works zone of course using Dropzone.js"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to works zone of course using Dropzone.js"			// Precisa de traduo
#elif L==10	// tr
	"Send file to works zone of course using Dropzone.js"			// eviri lazim!
#endif
	,
	[ActRcvFilWrkCrsCla] =
#if   L==1	// ca
	"Send file to works zone of course using the classic way"		// Necessita traducci
#elif L==2	// de
	"Send file to works zone of course using the classic way"		// Need bersetzung
#elif L==3	// en
	"Send file to works zone of course using the classic way"
#elif L==4	// es
	"Enviar archivo a zona de trabajos de asignatura de forma tradicional"
#elif L==5	// fr
	"Send file to works zone of course using the classic way"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de trabajos de asignatura de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file to works zone of course using the classic way"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to works zone of course using the classic way"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to works zone of course using the classic way"		// Precisa de traduo
#elif L==10	// tr
	"Send file to works zone of course using the classic way"		// eviri lazim!
#endif
	,
	[ActExpWrkCrs] =
#if   L==1	// ca
	"Expand folder in works zone of course"			// Necessita traducci
#elif L==2	// de
	"Expand folder in works zone of course"			// Need bersetzung
#elif L==3	// en
	"Expand folder in works zone of course"
#elif L==4	// es
	"Expandir carpeta en zona de trabajos de asignatura"
#elif L==5	// fr
	"Expand folder in works zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in works zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in works zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in works zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Expand folder in works zone of course"			// eviri lazim!
#endif
	,
	[ActConWrkCrs] =
#if   L==1	// ca
	"Contract folder in works zone of course"		// Necessita traducci
#elif L==2	// de
	"Contract folder in works zone of course"		// Need bersetzung
#elif L==3	// en
	"Contract folder in works zone of course"
#elif L==4	// es
	"Contraer carpeta en zona de trabajos de asignatura"
#elif L==5	// fr
	"Contract folder in works zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in works zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in works zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in works zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Contract folder in works zone of course"		// eviri lazim!
#endif
	,
	[ActZIPWrkCrs] =
#if   L==1	// ca
	"Compress folder in works zone of course"		// Necessita traducci
#elif L==2	// de
	"Compress folder in works zone of course"		// Need bersetzung
#elif L==3	// en
	"Compress folder in works zone of course"
#elif L==4	// es
	"Comprimir carpeta en zona de trabajos de asignatura"
#elif L==5	// fr
	"Compress folder in works zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in works zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in works zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in works zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Compress folder in works zone of course"		// eviri lazim!
#endif
	,
	[ActReqDatWrkCrs] =
#if   L==1	// ca
	"See file metadata in works zone of course"			// Necessita traducci
#elif L==2	// de
	"See file metadata in works zone of course"			// Need bersetzung
#elif L==3	// en
	"See file metadata in works zone of course"
#elif L==4	// es
	"Ver metadatos de archivo en zona de trabajos de asignatura"
#elif L==5	// fr
	"See file metadata in works zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in works zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in works zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in works zone of course"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in works zone of course"			// eviri lazim!
#endif
	,
	[ActChgDatWrkCrs] =
#if   L==1	// ca
	"Change file metadata in works zone of course"				// Necessita traducci
#elif L==2	// de
	"Change file metadata in works zone of course"				// Need bersetzung
#elif L==3	// en
	"Change file metadata in works zone of course"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de trabajos de asignatura"
#elif L==5	// fr
	"Change file metadata in works zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in works zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in works zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in works zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in works zone of course"				// eviri lazim!
#endif
	,
	[ActDowWrkCrs] =
#if   L==1	// ca
	"Download file from works zone of course"		// Necessita traducci
#elif L==2	// de
	"Download file from works zone of course"		// Need bersetzung
#elif L==3	// en
	"Download file from works zone of course"
#elif L==4	// es
	"Descargar archivo de zona de trabajos de asignatura"
#elif L==5	// fr
	"Download file from works zone of course"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de trabajos de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Download file from works zone of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from works zone of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from works zone of course"		// Precisa de traduo
#elif L==10	// tr
	"Download file from works zone of course"		// eviri lazim!
#endif
	,
	[ActSeeAdmMrk] =
#if   L==1	// ca
	"Marks zone (see or manage)"			// Necessita traducci
#elif L==2	// de
	"Marks zone (see or manage)"			// Need bersetzung
#elif L==3	// en
	"Marks zone (see or manage)"
#elif L==4	// es
	"Zona de calificaciones (ver o administrar)"
#elif L==5	// fr
	"Marks zone (see or manage)"			// Besoin de traduction
#elif L==6	// gn
	"Zona de calificaciones (ver o administrar)"	// Okoteve traduccin
#elif L==7	// it
	"Marks zone (see or manage)"			// Bisogno di traduzione
#elif L==8	// pl
	"Marks zone (see or manage)"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Marks zone (see or manage)"			// Precisa de traduo
#elif L==10	// tr
	"Marks zone (see or manage)"			// eviri lazim!
#endif
	,
	[ActChgToSeeMrk] =
#if   L==1	// ca
	"Change marks zone of course/group to view mode"			// Necessita traducci
#elif L==2	// de
	"Change marks zone of course/group to view mode"			// Need bersetzung
#elif L==3	// en
	"Change marks zone of course/group to view mode"
#elif L==4	// es
	"Cambiar zona de calificaciones de asignatura/grupo a modo vista"
#elif L==5	// fr
	"Change marks zone of course/group to view mode"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar zona de calificaciones de asignatura/grupo a modo vista"	// Okoteve traduccin
#elif L==7	// it
	"Change marks zone of course/group to view mode"			// Bisogno di traduzione
#elif L==8	// pl
	"Change marks zone of course/group to view mode"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change marks zone of course/group to view mode"			// Precisa de traduo
#elif L==10	// tr
	"Change marks zone of course/group to view mode"			// eviri lazim!
#endif
	,
	[ActSeeMrkCrs] =
#if   L==1	// ca
	"See marks zone of course"			// Necessita traducci
#elif L==2	// de
	"See marks zone of course"			// Need bersetzung
#elif L==3	// en
	"See marks zone of course"
#elif L==4	// es
	"Ver zona de calificaciones de asignatura"
#elif L==5	// fr
	"See marks zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Ver zona de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See marks zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"See marks zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See marks zone of course"			// Precisa de traduo
#elif L==10	// tr
	"See marks zone of course"			// eviri lazim!
#endif
	,
	[ActExpSeeMrkCrs] =
#if   L==1	// ca
	"Expand folder in marks zone of course"				// Necessita traducci
#elif L==2	// de
	"Expand folder in marks zone of course"				// Need bersetzung
#elif L==3	// en
	"Expand folder in marks zone of course"
#elif L==4	// es
	"Expandir carpeta en zona de calificaciones de asignatura"
#elif L==5	// fr
	"Expand folder in marks zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in marks zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in marks zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in marks zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Expand folder in marks zone of course"				// eviri lazim!
#endif
	,
	[ActConSeeMrkCrs] =
#if   L==1	// ca
	"Contract folder in marks zone of course"			// Necessita traducci
#elif L==2	// de
	"Contract folder in marks zone of course"			// Need bersetzung
#elif L==3	// en
	"Contract folder in marks zone of course"
#elif L==4	// es
	"Contraer carpeta en zona de calificaciones de asignatura"
#elif L==5	// fr
	"Contract folder in marks zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in marks zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in marks zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in marks zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Contract folder in marks zone of course"			// eviri lazim!
#endif
	,
	[ActReqDatSeeMrkCrs] =
#if   L==1	// ca
	"See file metadata in marks zone of course"				// Necessita traducci
#elif L==2	// de
	"See file metadata in marks zone of course"				// Need bersetzung
#elif L==3	// en
	"See file metadata in marks zone of course"
#elif L==4	// es
	"Ver metadatos de archivo en zona de calificaciones de asignatura"
#elif L==5	// fr
	"See file metadata in marks zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in marks zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in marks zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in marks zone of course"				// Precisa de traduo
#elif L==10	// tr
	"See file metadata in marks zone of course"				// eviri lazim!
#endif
	,
	[ActReqLnkSeeMrkCrs] =
#if   L==1	// ca
	"Copy link to file when showing course marks area"			// Necessita traducci
#elif L==2	// de
	"Copy link to file when showing course marks area"			// Need bersetzung
#elif L==3	// en
	"Copy link to file when showing course marks area"
#elif L==4	// es
	"Copiar enlace a archivo viendo zona de calificaciones de asignatura"
#elif L==5	// fr
	"Copy link to file when showing course marks area"			// Besoin de traduction
#elif L==6	// gn
	"Copiar enlace a archivo viendo zona de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Copy link to file when showing course marks area"			// Bisogno di traduzione
#elif L==8	// pl
	"Copy link to file when showing course marks area"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Copy link to file when showing course marks area"			// Precisa de traduo
#elif L==10	// tr
	"Copy link to file when showing course marks area"			// eviri lazim!
#endif
	,
	[ActSeeMyMrkCrs] =
#if   L==1	// ca
	"Individualized access to marks file in course"				// Necessita traducci
#elif L==2	// de
	"Individualized access to marks file in course"				// Need bersetzung
#elif L==3	// en
	"Individualized access to marks file in course"
#elif L==4	// es
	"Acceso individualizado a archivo de calificaciones en asignatura"
#elif L==5	// fr
	"Individualized access to marks file in course"				// Besoin de traduction
#elif L==6	// gn
	"Acceso individualizado a archivo de calificaciones en asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Individualized access to marks file in course"				// Bisogno di traduzione
#elif L==8	// pl
	"Individualized access to marks file in course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Individualized access to marks file in course"				// Precisa de traduo
#elif L==10	// tr
	"Individualized access to marks file in course"				// eviri lazim!
#endif
	,
	[ActSeeMrkGrp] =
#if   L==1	// ca
	"See marks zone of group"		// Necessita traducci
#elif L==2	// de
	"See marks zone of group"		// Need bersetzung
#elif L==3	// en
	"See marks zone of group"
#elif L==4	// es
	"Ver zona de calificaciones de grupo"
#elif L==5	// fr
	"See marks zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Ver zona de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"See marks zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"See marks zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See marks zone of group"		// Precisa de traduo
#elif L==10	// tr
	"See marks zone of group"		// eviri lazim!
#endif
	,
	[ActExpSeeMrkGrp] =
#if   L==1	// ca
	"Expand folder in marks zone of group"			// Necessita traducci
#elif L==2	// de
	"Expand folder in marks zone of group"			// Need bersetzung
#elif L==3	// en
	"Expand folder in marks zone of group"
#elif L==4	// es
	"Expandir carpeta en zona de calificaciones de grupo"
#elif L==5	// fr
	"Expand folder in marks zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in marks zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in marks zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in marks zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Expand folder in marks zone of group"			// eviri lazim!
#endif
	,
	[ActConSeeMrkGrp] =
#if   L==1	// ca
	"Contract folder in marks zone of group"		// Necessita traducci
#elif L==2	// de
	"Contract folder in marks zone of group"		// Need bersetzung
#elif L==3	// en
	"Contract folder in marks zone of group"
#elif L==4	// es
	"Contraer carpeta en zona de calificaciones de grupo"
#elif L==5	// fr
	"Contract folder in marks zone of group"		// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in marks zone of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in marks zone of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in marks zone of group"		// Precisa de traduo
#elif L==10	// tr
	"Contract folder in marks zone of group"		// eviri lazim!
#endif
	,
	[ActReqDatSeeMrkGrp] =
#if   L==1	// ca
	"See file metadata in marks zone of group"			// Necessita traducci
#elif L==2	// de
	"See file metadata in marks zone of group"			// Need bersetzung
#elif L==3	// en
	"See file metadata in marks zone of group"
#elif L==4	// es
	"Ver metadatos de archivo en zona de calificaciones de grupo"
#elif L==5	// fr
	"See file metadata in marks zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in marks zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in marks zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in marks zone of group"			// Precisa de traduo
#elif L==10	// tr
	"See file metadata in marks zone of group"			// eviri lazim!
#endif
	,
	[ActSeeMyMrkGrp] =
#if   L==1	// ca
	"Individualized access to marks file in group"			// Necessita traducci
#elif L==2	// de
	"Individualized access to marks file in group"			// Need bersetzung
#elif L==3	// en
	"Individualized access to marks file in group"
#elif L==4	// es
	"Acceso individualizado a archivo de calificaciones en grupo"
#elif L==5	// fr
	"Individualized access to marks file in group"			// Besoin de traduction
#elif L==6	// gn
	"Acceso individualizado a archivo de calificaciones en grupo"	// Okoteve traduccin
#elif L==7	// it
	"Individualized access to marks file in group"			// Bisogno di traduzione
#elif L==8	// pl
	"Individualized access to marks file in group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Individualized access to marks file in group"			// Precisa de traduo
#elif L==10	// tr
	"Individualized access to marks file in group"			// eviri lazim!
#endif
	,
	[ActChgToAdmMrk] =
#if   L==1	// ca
	"Change marks zone of course/group to management mode"					// Necessita traducci
#elif L==2	// de
	"Change marks zone of course/group to management mode"					// Need bersetzung
#elif L==3	// en
	"Change marks zone of course/group to management mode"
#elif L==4	// es
	"Cambiar zona de calificaciones de asignatura/grupo a modo administraci&oacute;n"
#elif L==5	// fr
	"Change marks zone of course/group to management mode"					// Besoin de traduction
#elif L==6	// gn
	"Cambiar zona de calificaciones de asignatura/grupo a modo administraci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change marks zone of course/group to management mode"					// Bisogno di traduzione
#elif L==8	// pl
	"Change marks zone of course/group to management mode"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change marks zone of course/group to management mode"					// Precisa de traduo
#elif L==10	// tr
	"Change marks zone of course/group to management mode"					// eviri lazim!
#endif
	,
	[ActAdmMrkCrs] =
#if   L==1	// ca
	"Manage marks zone of the course"			// Necessita traducci
#elif L==2	// de
	"Manage marks zone of the course"			// Need bersetzung
#elif L==3	// en
	"Manage marks zone of the course"
#elif L==4	// es
	"Administrar zona de calificaciones de la asignatura"
#elif L==5	// fr
	"Manage marks zone of the course"			// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de calificaciones de la asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Manage marks zone of the course"			// Bisogno di traduzione
#elif L==8	// pl
	"Manage marks zone of the course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage marks zone of the course"			// Precisa de traduo
#elif L==10	// tr
	"Manage marks zone of the course"			// eviri lazim!
#endif
	,
	[ActReqRemFilMrkCrs] =
#if   L==1	// ca
	"Request removal of file from marks in course"					// Necessita traducci
#elif L==2	// de
	"Request removal of file from marks in course"					// Need bersetzung
#elif L==3	// en
	"Request removal of file from marks in course"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de calificaciones de asignatura"
#elif L==5	// fr
	"Request removal of file from marks in course"					// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from marks in course"					// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from marks in course"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from marks in course"					// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from marks in course"					// eviri lazim!
#endif
	,
	[ActRemFilMrkCrs] =
#if   L==1	// ca
	"Remove file in marks from a course"			// Necessita traducci
#elif L==2	// de
	"Remove file in marks from a course"			// Need bersetzung
#elif L==3	// en
	"Remove file in marks from a course"
#elif L==4	// es
	"Eliminar archivo de calificaciones de asignatura"
#elif L==5	// fr
	"Remove file in marks from a course"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove file in marks from a course"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove file in marks from a course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file in marks from a course"			// Precisa de traduo
#elif L==10	// tr
	"Remove file in marks from a course"			// eviri lazim!
#endif
	,
	[ActRemFolMrkCrs] =
#if   L==1	// ca
	"Remove empty folder from marks zone of course"			// Necessita traducci
#elif L==2	// de
	"Remove empty folder from marks zone of course"			// Need bersetzung
#elif L==3	// en
	"Remove empty folder from marks zone of course"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de calificaciones de asignatura"
#elif L==5	// fr
	"Remove empty folder from marks zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from marks zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from marks zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from marks zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from marks zone of course"			// eviri lazim!
#endif
	,
	[ActCopMrkCrs] =
#if   L==1	// ca
	"Set source of copy in marks zone of course"			// Necessita traducci
#elif L==2	// de
	"Set source of copy in marks zone of course"			// Need bersetzung
#elif L==3	// en
	"Set source of copy in marks zone of course"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de calificaciones de asignatura"
#elif L==5	// fr
	"Set source of copy in marks zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in marks zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in marks zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in marks zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in marks zone of course"			// eviri lazim!
#endif
	,
	[ActPasMrkCrs] =
#if   L==1	// ca
	"Paste folder/file in marks zone of course"			// Necessita traducci
#elif L==2	// de
	"Paste folder/file in marks zone of course"			// Need bersetzung
#elif L==3	// en
	"Paste folder/file in marks zone of course"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de calificaciones de asignatura"
#elif L==5	// fr
	"Paste folder/file in marks zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in marks zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in marks zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in marks zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in marks zone of course"			// eviri lazim!
#endif
	,
	[ActRemTreMrkCrs] =
#if   L==1	// ca
	"Remove non-empty folder from marks zone of course"				// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from marks zone of course"				// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from marks zone of course"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona de calificaciones de asignatura"
#elif L==5	// fr
	"Remove non-empty folder from marks zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from marks zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from marks zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from marks zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from marks zone of course"				// eviri lazim!
#endif
	,
	[ActFrmCreMrkCrs] =
#if   L==1	// ca
	"Edit new folder/file/link in marks zone of course"				// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in marks zone of course"				// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in marks zone of course"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de calificaciones de asignatura"
#elif L==5	// fr
	"Edit new folder/file/link in marks zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in marks zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in marks zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in marks zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in marks zone of course"				// eviri lazim!
#endif
	,
	[ActCreFolMrkCrs] =
#if   L==1	// ca
	"Create new folder in marks zone of course"			// Necessita traducci
#elif L==2	// de
	"Create new folder in marks zone of course"			// Need bersetzung
#elif L==3	// en
	"Create new folder in marks zone of course"
#elif L==4	// es
	"Crear nueva carpeta en zona de calificaciones de asignatura"
#elif L==5	// fr
	"Create new folder in marks zone of course"			// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in marks zone of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in marks zone of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in marks zone of course"			// Precisa de traduo
#elif L==10	// tr
	"Create new folder in marks zone of course"			// eviri lazim!
#endif
	,
	[ActRenFolMrkCrs] =
#if   L==1	// ca
	"Rename folder in marks zone of course"				// Necessita traducci
#elif L==2	// de
	"Rename folder in marks zone of course"				// Need bersetzung
#elif L==3	// en
	"Rename folder in marks zone of course"
#elif L==4	// es
	"Renombrar carpeta en zona de calificaciones de asignatura"
#elif L==5	// fr
	"Rename folder in marks zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in marks zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in marks zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in marks zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Rename folder in marks zone of course"				// eviri lazim!
#endif
	,
	[ActRcvFilMrkCrsDZ] =
#if   L==1	// ca
	"Send file to marks zone of course using Dropzone.js"				// Necessita traducci
#elif L==2	// de
	"Send file to marks zone of course using Dropzone.js"				// Need bersetzung
#elif L==3	// en
	"Send file to marks zone of course using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona de calificaciones de asignatura usando Dropzone.js"
#elif L==5	// fr
	"Send file to marks zone of course using Dropzone.js"				// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de calificaciones de asignatura usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to marks zone of course using Dropzone.js"				// Bisogno di traduzione
#elif L==8	// pl
	"Send file to marks zone of course using Dropzone.js"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to marks zone of course using Dropzone.js"				// Precisa de traduo
#elif L==10	// tr
	"Send file to marks zone of course using Dropzone.js"				// eviri lazim!
#endif
	,
	[ActRcvFilMrkCrsCla] =
#if   L==1	// ca
	"Send file to marks zone of course using the classic way"			// Necessita traducci
#elif L==2	// de
	"Send file to marks zone of course using the classic way"			// Need bersetzung
#elif L==3	// en
	"Send file to marks zone of course using the classic way"
#elif L==4	// es
	"Enviar archivo a zona de calificaciones de asignatura de forma tradicional"
#elif L==5	// fr
	"Send file to marks zone of course using the classic way"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de calificaciones de asignatura de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file to marks zone of course using the classic way"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to marks zone of course using the classic way"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to marks zone of course using the classic way"			// Precisa de traduo
#elif L==10	// tr
	"Send file to marks zone of course using the classic way"			// eviri lazim!
#endif
	,
	[ActExpAdmMrkCrs] =
#if   L==1	// ca
	"Expand folder in marks management zone of course"				// Necessita traducci
#elif L==2	// de
	"Expand folder in marks management zone of course"				// Need bersetzung
#elif L==3	// en
	"Expand folder in marks management zone of course"
#elif L==4	// es
	"Expandir carpeta en zona de administracin de calificaciones de asignatura"
#elif L==5	// fr
	"Expand folder in marks management zone of course"				// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de administracin de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in marks management zone of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in marks management zone of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in marks management zone of course"				// Precisa de traduo
#elif L==10	// tr
	"Expand folder in marks management zone of course"				// eviri lazim!
#endif
	,
	[ActConAdmMrkCrs] =
#if   L==1	// ca
	"Contract folder in marks management zone of course"					// Necessita traducci
#elif L==2	// de
	"Contract folder in marks management zone of course"					// Need bersetzung
#elif L==3	// en
	"Contract folder in marks management zone of course"
#elif L==4	// es
	"Contraer carpeta en zona de administraci&oacute;n de calificaciones de asignatura"
#elif L==5	// fr
	"Contract folder in marks management zone of course"					// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de administraci&oacute;n de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in marks management zone of course"					// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in marks management zone of course"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in marks management zone of course"					// Precisa de traduo
#elif L==10	// tr
	"Contract folder in marks management zone of course"					// eviri lazim!
#endif
	,
	[ActZIPAdmMrkCrs] =
#if   L==1	// ca
	"Compress folder in marks management zone of course"					// Necessita traducci
#elif L==2	// de
	"Compress folder in marks management zone of course"					// Need bersetzung
#elif L==3	// en
	"Compress folder in marks management zone of course"
#elif L==4	// es
	"Comprimir carpeta en zona de administraci&oacute;n de calificaciones de asignatura"
#elif L==5	// fr
	"Compress folder in marks management zone of course"					// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de administraci&oacute;n de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in marks management zone of course"					// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in marks management zone of course"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in marks management zone of course"					// Precisa de traduo
#elif L==10	// tr
	"Compress folder in marks management zone of course"					// eviri lazim!
#endif
	,
	[ActUnhMrkCrs] =
#if   L==1	// ca
	"Unhide folder/file in marks management zone of course"						// Necessita traducci
#elif L==2	// de
	"Unhide folder/file in marks management zone of course"						// Need bersetzung
#elif L==3	// en
	"Unhide folder/file in marks management zone of course"
#elif L==4	// es
	"Mostrar carpeta/archivo en zona de administraci&oacute;n de calificaciones de asignatura"
#elif L==5	// fr
	"Unhide folder/file in marks management zone of course"						// Besoin de traduction
#elif L==6	// gn
	"Mostrar carpeta/archivo en zona de administraci&oacute;n de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Unhide folder/file in marks management zone of course"						// Bisogno di traduzione
#elif L==8	// pl
	"Unhide folder/file in marks management zone of course"						// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide folder/file in marks management zone of course"						// Precisa de traduo
#elif L==10	// tr
	"Unhide folder/file in marks management zone of course"						// eviri lazim!
#endif
	,
	[ActHidMrkCrs] =
#if   L==1	// ca
	"Hide folder/file in marks management zone of course"						// Necessita traducci
#elif L==2	// de
	"Hide folder/file in marks management zone of course"						// Need bersetzung
#elif L==3	// en
	"Hide folder/file in marks management zone of course"
#elif L==4	// es
	"Ocultar carpeta/archivo en zona de administraci&oacute;n de calificaciones de asignatura"
#elif L==5	// fr
	"Hide folder/file in marks management zone of course"						// Besoin de traduction
#elif L==6	// gn
	"Ocultar carpeta/archivo en zona de administraci&oacute;n de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Hide folder/file in marks management zone of course"						// Bisogno di traduzione
#elif L==8	// pl
	"Hide folder/file in marks management zone of course"						// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide folder/file in marks management zone of course"						// Precisa de traduo
#elif L==10	// tr
	"Hide folder/file in marks management zone of course"						// eviri lazim!
#endif
	,
	[ActReqDatAdmMrkCrs] =
#if   L==1	// ca
	"See file metadata in marks management zone of course"						// Necessita traducci
#elif L==2	// de
	"See file metadata in marks management zone of course"						// Need bersetzung
#elif L==3	// en
	"See file metadata in marks management zone of course"
#elif L==4	// es
	"Ver metadatos de archivo en zona de administraci&oacute;n de calificaciones de asignatura"
#elif L==5	// fr
	"See file metadata in marks management zone of course"						// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de administraci&oacute;n de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in marks management zone of course"						// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in marks management zone of course"						// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in marks management zone of course"						// Precisa de traduo
#elif L==10	// tr
	"See file metadata in marks management zone of course"						// eviri lazim!
#endif
	,
	[ActChgDatAdmMrkCrs] =
#if   L==1	// ca
	"Change file metadata in marks management zone of course"					// Necessita traducci
#elif L==2	// de
	"Change file metadata in marks management zone of course"					// Need bersetzung
#elif L==3	// en
	"Change file metadata in marks management zone of course"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de administraci&oacute;n de calificaciones de asignatura"
#elif L==5	// fr
	"Change file metadata in marks management zone of course"					// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de administraci&oacute;n de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in marks management zone of course"					// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in marks management zone of course"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in marks management zone of course"					// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in marks management zone of course"					// eviri lazim!
#endif
	,
	[ActReqLnkAdmMrkCrs] =
#if   L==1	// ca
	"Copy link to file when managing course marks area"				// Necessita traducci
#elif L==2	// de
	"Copy link to file when managing course marks area"				// Need bersetzung
#elif L==3	// en
	"Copy link to file when managing course marks area"
#elif L==4	// es
	"Copiar enlace a archivo administrando zona de calificaciones de asignatura"
#elif L==5	// fr
	"Copy link to file when managing course marks area"				// Besoin de traduction
#elif L==6	// gn
	"Copiar enlace a archivo administrando zona de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Copy link to file when managing course marks area"				// Bisogno di traduzione
#elif L==8	// pl
	"Copy link to file when managing course marks area"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Copy link to file when managing course marks area"				// Precisa de traduo
#elif L==10	// tr
	"Copy link to file when managing course marks area"				// eviri lazim!
#endif
	,
	[ActDowAdmMrkCrs] =
#if   L==1	// ca
	"Download file from marks management zone of course"					// Necessita traducci
#elif L==2	// de
	"Download file from marks management zone of course"					// Need bersetzung
#elif L==3	// en
	"Download file from marks management zone of course"
#elif L==4	// es
	"Descargar archivo de zona de administraci&oacute;n de calificaciones de asignatura"
#elif L==5	// fr
	"Download file from marks management zone of course"					// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de administraci&oacute;n de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Download file from marks management zone of course"					// Bisogno di traduzione
#elif L==8	// pl
	"Download file from marks management zone of course"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from marks management zone of course"					// Precisa de traduo
#elif L==10	// tr
	"Download file from marks management zone of course"					// eviri lazim!
#endif
	,
	[ActChgNumRowHeaCrs] =
#if   L==1	// ca
	"Change number of head rows of a file in marks of course"				// Necessita traducci
#elif L==2	// de
	"Change number of head rows of a file in marks of course"				// Need bersetzung
#elif L==3	// en
	"Change number of head rows of a file in marks of course"
#elif L==4	// es
	"Cambiar n&uacute;mero de filas de cabecera de archivo de calificaciones de asignatura"
#elif L==5	// fr
	"Change number of head rows of a file in marks of course"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar n&uacute;mero de filas de cabecera de archivo de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change number of head rows of a file in marks of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Change number of head rows of a file in marks of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change number of head rows of a file in marks of course"				// Precisa de traduo
#elif L==10	// tr
	"Change number of head rows of a file in marks of course"				// eviri lazim!
#endif
	,
	[ActChgNumRowFooCrs] =
#if   L==1	// ca
	"Change number of foot rows of a file in marks in course"				// Necessita traducci
#elif L==2	// de
	"Change number of foot rows of a file in marks in course"				// Need bersetzung
#elif L==3	// en
	"Change number of foot rows of a file in marks in course"
#elif L==4	// es
	"Cambiar n&uacute;mero de filas de pie de archivo de calificaciones de asignatura"
#elif L==5	// fr
	"Change number of foot rows of a file in marks in course"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar n&uacute;mero de filas de pie de archivo de calificaciones de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Change number of foot rows of a file in marks in course"				// Bisogno di traduzione
#elif L==8	// pl
	"Change number of foot rows of a file in marks in course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change number of foot rows of a file in marks in course"				// Precisa de traduo
#elif L==10	// tr
	"Change number of foot rows of a file in marks in course"				// eviri lazim!
#endif
	,
	[ActAdmMrkGrp] =
#if   L==1	// ca
	"Manage marks zone of group"			// Necessita traducci
#elif L==2	// de
	"Manage marks zone of group"			// Need bersetzung
#elif L==3	// en
	"Manage marks zone of group"
#elif L==4	// es
	"Administrar zona de calificaciones de grupo"
#elif L==5	// fr
	"Manage marks zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Administrar zona de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Manage marks zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Manage marks zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage marks zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Manage marks zone of group"			// eviri lazim!
#endif
	,
	[ActReqRemFilMrkGrp] =
#if   L==1	// ca
	"Request removal of file from marks zone of group"				// Necessita traducci
#elif L==2	// de
	"Request removal of file from marks zone of group"				// Need bersetzung
#elif L==3	// en
	"Request removal of file from marks zone of group"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de zona de calificaciones de grupo"
#elif L==5	// fr
	"Request removal of file from marks zone of group"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de zona de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from marks zone of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from marks zone of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from marks zone of group"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from marks zone of group"				// eviri lazim!
#endif
	,
	[ActRemFilMrkGrp] =
#if   L==1	// ca
	"Remove file from marks zone of group"			// Necessita traducci
#elif L==2	// de
	"Remove file from marks zone of group"			// Need bersetzung
#elif L==3	// en
	"Remove file from marks zone of group"
#elif L==4	// es
	"Eliminar archivo de zona de calificaciones de grupo"
#elif L==5	// fr
	"Remove file from marks zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de zona de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from marks zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from marks zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from marks zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Remove file from marks zone of group"			// eviri lazim!
#endif
	,
	[ActRemFolMrkGrp] =
#if   L==1	// ca
	"Remove empty folder from marks zone of group"				// Necessita traducci
#elif L==2	// de
	"Remove empty folder from marks zone of group"				// Need bersetzung
#elif L==3	// en
	"Remove empty folder from marks zone of group"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de zona de calificaciones de grupo"
#elif L==5	// fr
	"Remove empty folder from marks zone of group"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de zona de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from marks zone of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from marks zone of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from marks zone of group"				// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from marks zone of group"				// eviri lazim!
#endif
	,
	[ActCopMrkGrp] =
#if   L==1	// ca
	"Set the source of copy in marks zone of group"			// Necessita traducci
#elif L==2	// de
	"Set the source of copy in marks zone of group"			// Need bersetzung
#elif L==3	// en
	"Set the source of copy in marks zone of group"
#elif L==4	// es
	"Establecer origen de copia en zona de calificaciones de grupo"
#elif L==5	// fr
	"Set the source of copy in marks zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en zona de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Set the source of copy in marks zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Set the source of copy in marks zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set the source of copy in marks zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Set the source of copy in marks zone of group"			// eviri lazim!
#endif
	,
	[ActPasMrkGrp] =
#if   L==1	// ca
	"Paste folder/file in marks zone of group"			// Necessita traducci
#elif L==2	// de
	"Paste folder/file in marks zone of group"			// Need bersetzung
#elif L==3	// en
	"Paste folder/file in marks zone of group"
#elif L==4	// es
	"Pegar carpeta/archivo en zona de calificaciones de grupo"
#elif L==5	// fr
	"Paste folder/file in marks zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en zona de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in marks zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in marks zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in marks zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in marks zone of group"			// eviri lazim!
#endif
	,
	[ActRemTreMrkGrp] =
#if   L==1	// ca
	"Remove non-empty folder from marks zone of group"			// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from marks zone of group"			// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from marks zone of group"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de zona de calificaciones de grupo"
#elif L==5	// fr
	"Remove non-empty folder from marks zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de zona de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from marks zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from marks zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from marks zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from marks zone of group"			// eviri lazim!
#endif
	,
	[ActFrmCreMrkGrp] =
#if   L==1	// ca
	"Edit new folder/file/link in marks zone of group"				// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in marks zone of group"				// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in marks zone of group"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en zona de calificaciones de grupo"
#elif L==5	// fr
	"Edit new folder/file/link in marks zone of group"				// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en zona de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in marks zone of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in marks zone of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in marks zone of group"				// Precisa de traduo
#elif L==10	// tr
	"Edit new folder/file/link in marks zone of group"				// eviri lazim!
#endif
	,
	[ActCreFolMrkGrp] =
#if   L==1	// ca
	"Create new folder in marks zone of group"			// Necessita traducci
#elif L==2	// de
	"Create new folder in marks zone of group"			// Need bersetzung
#elif L==3	// en
	"Create new folder in marks zone of group"
#elif L==4	// es
	"Crear nueva carpeta en zona de calificaciones de grupo"
#elif L==5	// fr
	"Create new folder in marks zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en zona de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in marks zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in marks zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in marks zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Create new folder in marks zone of group"			// eviri lazim!
#endif
	,
	[ActRenFolMrkGrp] =
#if   L==1	// ca
	"Rename folder in marks zone of group"			// Necessita traducci
#elif L==2	// de
	"Rename folder in marks zone of group"			// Need bersetzung
#elif L==3	// en
	"Rename folder in marks zone of group"
#elif L==4	// es
	"Renombrar carpeta en zona de calificaciones de grupo"
#elif L==5	// fr
	"Rename folder in marks zone of group"			// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en zona de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder in marks zone of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder in marks zone of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder in marks zone of group"			// Precisa de traduo
#elif L==10	// tr
	"Rename folder in marks zone of group"			// eviri lazim!
#endif
	,
	[ActRcvFilMrkGrpDZ] =
#if   L==1	// ca
	"Send file to marks zone of group using Dropzone.js"			// Necessita traducci
#elif L==2	// de
	"Send file to marks zone of group using Dropzone.js"			// Need bersetzung
#elif L==3	// en
	"Send file to marks zone of group using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a zona de calificaciones de grupo usando Dropzone.js"
#elif L==5	// fr
	"Send file to marks zone of group using Dropzone.js"			// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de calificaciones de grupo usando Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to marks zone of group using Dropzone.js"			// Bisogno di traduzione
#elif L==8	// pl
	"Send file to marks zone of group using Dropzone.js"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to marks zone of group using Dropzone.js"			// Precisa de traduo
#elif L==10	// tr
	"Send file to marks zone of group using Dropzone.js"			// eviri lazim!
#endif
	,
	[ActRcvFilMrkGrpCla] =
#if   L==1	// ca
	"Send file to marks zone of group using the classic way"		// Necessita traducci
#elif L==2	// de
	"Send file to marks zone of group using the classic way"		// Need bersetzung
#elif L==3	// en
	"Send file to marks zone of group using the classic way"
#elif L==4	// es
	"Enviar archivo a zona de calificaciones de grupo de forma tradicional"
#elif L==5	// fr
	"Send file to marks zone of group using the classic way"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a zona de calificaciones de grupo de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file to marks zone of group using the classic way"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to marks zone of group using the classic way"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to marks zone of group using the classic way"		// Precisa de traduo
#elif L==10	// tr
	"Send file to marks zone of group using the classic way"		// eviri lazim!
#endif
	,
	[ActExpAdmMrkGrp] =
#if   L==1	// ca
	"Expand folder in marks management zone of group"				// Necessita traducci
#elif L==2	// de
	"Expand folder in marks management zone of group"				// Need bersetzung
#elif L==3	// en
	"Expand folder in marks management zone of group"
#elif L==4	// es
	"Expandir carpeta en zona de administraci&oacute;n de calificaciones de grupo"
#elif L==5	// fr
	"Expand folder in marks management zone of group"				// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en zona de administraci&oacute;n de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in marks management zone of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in marks management zone of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in marks management zone of group"				// Precisa de traduo
#elif L==10	// tr
	"Expand folder in marks management zone of group"				// eviri lazim!
#endif
	,
	[ActConAdmMrkGrp] =
#if   L==1	// ca
	"Contract folder in marks management zone of group"				// Necessita traducci
#elif L==2	// de
	"Contract folder in marks management zone of group"				// Need bersetzung
#elif L==3	// en
	"Contract folder in marks management zone of group"
#elif L==4	// es
	"Contraer carpeta en zona de administraci&oacute;n de calificaciones de grupo"
#elif L==5	// fr
	"Contract folder in marks management zone of group"				// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en zona de administraci&oacute;n de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in marks management zone of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in marks management zone of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in marks management zone of group"				// Precisa de traduo
#elif L==10	// tr
	"Contract folder in marks management zone of group"				// eviri lazim!
#endif
	,
	[ActZIPAdmMrkGrp] =
#if   L==1	// ca
	"Compress folder in marks management zone of group"				// Necessita traducci
#elif L==2	// de
	"Compress folder in marks management zone of group"				// Need bersetzung
#elif L==3	// en
	"Compress folder in marks management zone of group"
#elif L==4	// es
	"Comprimir carpeta en zona de administraci&oacute;n de calificaciones de grupo"
#elif L==5	// fr
	"Compress folder in marks management zone of group"				// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en zona de administraci&oacute;n de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in marks management zone of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in marks management zone of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in marks management zone of group"				// Precisa de traduo
#elif L==10	// tr
	"Compress folder in marks management zone of group"				// eviri lazim!
#endif
	,
	[ActUnhMrkGrp] =
#if   L==1	// ca
	"Unhide folder/file of marks management zone of group"				// Necessita traducci
#elif L==2	// de
	"Unhide folder/file of marks management zone of group"				// Need bersetzung
#elif L==3	// en
	"Unhide folder/file of marks management zone of group"
#elif L==4	// es
	"Mostrar carpeta de zona de administraci&oacute;n de calificaciones de grupo"
#elif L==5	// fr
	"Unhide folder/file of marks management zone of group"				// Besoin de traduction
#elif L==6	// gn
	"Mostrar carpeta de zona de administraci&oacute;n de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Unhide folder/file of marks management zone of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Unhide folder/file of marks management zone of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide folder/file of marks management zone of group"				// Precisa de traduo
#elif L==10	// tr
	"Unhide folder/file of marks management zone of group"				// eviri lazim!
#endif
	,
	[ActHidMrkGrp] =
#if   L==1	// ca
	"Hide folder/file of marks management zone of group"				// Necessita traducci
#elif L==2	// de
	"Hide folder/file of marks management zone of group"				// Need bersetzung
#elif L==3	// en
	"Hide folder/file of marks management zone of group"
#elif L==4	// es
	"Ocultar carpeta de zona de administraci&oacute;n de calificaciones de grupo"
#elif L==5	// fr
	"Hide folder/file of marks management zone of group"				// Besoin de traduction
#elif L==6	// gn
	"Ocultar carpeta de zona de administraci&oacute;n de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Hide folder/file of marks management zone of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Hide folder/file of marks management zone of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide folder/file of marks management zone of group"				// Precisa de traduo
#elif L==10	// tr
	"Hide folder/file of marks management zone of group"				// eviri lazim!
#endif
	,
	[ActReqDatAdmMrkGrp] =
#if   L==1	// ca
	"See file metadata in marks management zone of group"					// Necessita traducci
#elif L==2	// de
	"See file metadata in marks management zone of group"					// Need bersetzung
#elif L==3	// en
	"See file metadata in marks management zone of group"
#elif L==4	// es
	"Ver metadatos de archivo en zona de administraci&oacute;n de calificaciones de grupo"
#elif L==5	// fr
	"See file metadata in marks management zone of group"					// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en zona de administraci&oacute;n de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in marks management zone of group"					// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in marks management zone of group"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in marks management zone of group"					// Precisa de traduo
#elif L==10	// tr
	"See file metadata in marks management zone of group"					// eviri lazim!
#endif
	,
	[ActChgDatAdmMrkGrp] =
#if   L==1	// ca
	"Change file metadata in marks management zone of group"					// Necessita traducci
#elif L==2	// de
	"Change file metadata in marks management zone of group"					// Need bersetzung
#elif L==3	// en
	"Change file metadata in marks management zone of group"
#elif L==4	// es
	"Cambiar metadatos de archivo en zona de administraci&oacute;n de calificaciones de grupo"
#elif L==5	// fr
	"Change file metadata in marks management zone of group"					// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en zona de administraci&oacute;n de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in marks management zone of group"					// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in marks management zone of group"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in marks management zone of group"					// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in marks management zone of group"					// eviri lazim!
#endif
	,
	[ActDowAdmMrkGrp] =
#if   L==1	// ca
	"Download file from marks management zone of group"				// Necessita traducci
#elif L==2	// de
	"Download file from marks management zone of group"				// Need bersetzung
#elif L==3	// en
	"Download file from marks management zone of group"
#elif L==4	// es
	"Descargar archivo de zona de administraci&oacute;n de calificaciones de grupo"
#elif L==5	// fr
	"Download file from marks management zone of group"				// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de zona de administraci&oacute;n de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Download file from marks management zone of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Download file from marks management zone of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from marks management zone of group"				// Precisa de traduo
#elif L==10	// tr
	"Download file from marks management zone of group"				// eviri lazim!
#endif
	,
	[ActChgNumRowHeaGrp] =
#if   L==1	// ca
	"Change number of head rows of a file in marks of group"				// Necessita traducci
#elif L==2	// de
	"Change number of head rows of a file in marks of group"				// Need bersetzung
#elif L==3	// en
	"Change number of head rows of a file in marks of group"
#elif L==4	// es
	"Cambiar n&uacute;mero de filas de cabecera de archivo de calificaciones de grupo"
#elif L==5	// fr
	"Change number of head rows of a file in marks of group"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar n&uacute;mero de filas de cabecera de archivo de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Change number of head rows of a file in marks of group"				// Bisogno di traduzione
#elif L==8	// pl
	"Change number of head rows of a file in marks of group"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change number of head rows of a file in marks of group"				// Precisa de traduo
#elif L==10	// tr
	"Change number of head rows of a file in marks of group"				// eviri lazim!
#endif
	,
	[ActChgNumRowFooGrp] =
#if   L==1	// ca
	"Change number of foot rows of a file in marks of group"			// Necessita traducci
#elif L==2	// de
	"Change number of foot rows of a file in marks of group"			// Need bersetzung
#elif L==3	// en
	"Change number of foot rows of a file in marks of group"
#elif L==4	// es
	"Cambiar n&uacute;mero de filas de pie de archivo de calificaciones de grupo"
#elif L==5	// fr
	"Change number of foot rows of a file in marks of group"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar n&uacute;mero de filas de pie de archivo de calificaciones de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Change number of foot rows of a file in marks of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Change number of foot rows of a file in marks of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change number of foot rows of a file in marks of group"			// Precisa de traduo
#elif L==10	// tr
	"Change number of foot rows of a file in marks of group"			// eviri lazim!
#endif
	,
	[ActAdmBrf] =
#if   L==1	// ca
	"Manage briefcase"		// Necessita traducci
#elif L==2	// de
	"Manage briefcase"		// Need bersetzung
#elif L==3	// en
	"Manage briefcase"
#elif L==4	// es
	"Administrar malet&iacute;n"
#elif L==5	// fr
	"Manage briefcase"		// Besoin de traduction
#elif L==6	// gn
	"Administrar malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Manage briefcase"		// Bisogno di traduzione
#elif L==8	// pl
	"Manage briefcase"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Manage briefcase"		// Precisa de traduo
#elif L==10	// tr
	"Manage briefcase"		// eviri lazim!
#endif
	,
	[ActReqRemFilBrf] =
#if   L==1	// ca
	"Request removal of file from briefcase"			// Necessita traducci
#elif L==2	// de
	"Request removal of file from briefcase"			// Need bersetzung
#elif L==3	// en
	"Request removal of file from briefcase"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivo de malet&iacute;n"
#elif L==5	// fr
	"Request removal of file from briefcase"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivo de malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of file from briefcase"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of file from briefcase"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of file from briefcase"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of file from briefcase"			// eviri lazim!
#endif
	,
	[ActRemFilBrf] =
#if   L==1	// ca
	"Remove file from briefcase"		// Necessita traducci
#elif L==2	// de
	"Remove file from briefcase"		// Need bersetzung
#elif L==3	// en
	"Remove file from briefcase"
#elif L==4	// es
	"Eliminar archivo de malet&iacute;n"
#elif L==5	// fr
	"Remove file from briefcase"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivo de malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove file from briefcase"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove file from briefcase"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove file from briefcase"		// Precisa de traduo
#elif L==10	// tr
	"Remove file from briefcase"		// eviri lazim!
#endif
	,
	[ActRemFolBrf] =
#if   L==1	// ca
	"Remove empty folder from briefcase"			// Necessita traducci
#elif L==2	// de
	"Remove empty folder from briefcase"			// Need bersetzung
#elif L==3	// en
	"Remove empty folder from briefcase"
#elif L==4	// es
	"Eliminar carpeta vac&iacute;a de malet&iacute;n"
#elif L==5	// fr
	"Remove empty folder from briefcase"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta vac&iacute;a de malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove empty folder from briefcase"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove empty folder from briefcase"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove empty folder from briefcase"			// Precisa de traduo
#elif L==10	// tr
	"Remove empty folder from briefcase"			// eviri lazim!
#endif
	,
	[ActCopBrf] =
#if   L==1	// ca
	"Set source of copy in briefcase"		// Necessita traducci
#elif L==2	// de
	"Set source of copy in briefcase"		// Need bersetzung
#elif L==3	// en
	"Set source of copy in briefcase"
#elif L==4	// es
	"Establecer origen de copia en malet&iacute;n"
#elif L==5	// fr
	"Set source of copy in briefcase"		// Besoin de traduction
#elif L==6	// gn
	"Establecer origen de copia en malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Set source of copy in briefcase"		// Bisogno di traduzione
#elif L==8	// pl
	"Set source of copy in briefcase"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Set source of copy in briefcase"		// Precisa de traduo
#elif L==10	// tr
	"Set source of copy in briefcase"		// eviri lazim!
#endif
	,
	[ActPasBrf] =
#if   L==1	// ca
	"Paste folder/file in briefcase"		// Necessita traducci
#elif L==2	// de
	"Paste folder/file in briefcase"		// Need bersetzung
#elif L==3	// en
	"Paste folder/file in briefcase"
#elif L==4	// es
	"Pegar carpeta/archivo en malet&iacute;n"
#elif L==5	// fr
	"Paste folder/file in briefcase"		// Besoin de traduction
#elif L==6	// gn
	"Pegar carpeta/archivo en malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Paste folder/file in briefcase"		// Bisogno di traduzione
#elif L==8	// pl
	"Paste folder/file in briefcase"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste folder/file in briefcase"		// Precisa de traduo
#elif L==10	// tr
	"Paste folder/file in briefcase"		// eviri lazim!
#endif
	,
	[ActRemTreBrf] =
#if   L==1	// ca
	"Remove non-empty folder from briefcase"		// Necessita traducci
#elif L==2	// de
	"Remove non-empty folder from briefcase"		// Need bersetzung
#elif L==3	// en
	"Remove non-empty folder from briefcase"
#elif L==4	// es
	"Eliminar carpeta no vac&iacute;a de malet&iacute;n"
#elif L==5	// fr
	"Remove non-empty folder from briefcase"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar carpeta no vac&iacute;a de malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-empty folder from briefcase"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-empty folder from briefcase"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-empty folder from briefcase"		// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from briefcase"		// eviri lazim!
#endif
	,
	[ActFrmCreBrf] =
#if   L==1	// ca
	"Edit new folder/file/link in briefcase"		// Necessita traducci
#elif L==2	// de
	"Edit new folder/file/link in briefcase"		// Need bersetzung
#elif L==3	// en
	"Edit new folder/file/link in briefcase"
#elif L==4	// es
	"Editar nueva carpeta/archivo/enlace en malet&iacute;n"
#elif L==5	// fr
	"Edit new folder/file/link in briefcase"		// Besoin de traduction
#elif L==6	// gn
	"Editar nueva carpeta/archivo/enlace en malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Edit new folder/file/link in briefcase"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit new folder/file/link in briefcase"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new folder/file/link in briefcase"		// Precisa de traduo
#elif L==10	// tr
	"Remove non-empty folder from briefcase"		// eviri lazim!
#endif
	,
	[ActCreFolBrf] =
#if   L==1	// ca
	"Create new folder in briefcase"	// Necessita traducci
#elif L==2	// de
	"Create new folder in briefcase"	// Need bersetzung
#elif L==3	// en
	"Create new folder in briefcase"
#elif L==4	// es
	"Crear nueva carpeta en malet&iacute;n"
#elif L==5	// fr
	"Create new folder in briefcase"	// Besoin de traduction
#elif L==6	// gn
	"Crear nueva carpeta en malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Create new folder in briefcase"	// Bisogno di traduzione
#elif L==8	// pl
	"Create new folder in briefcase"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new folder in briefcase"	// Precisa de traduo
#elif L==10	// tr
	"Create new folder in briefcase"	// eviri lazim!
#endif
	,
	[ActCreLnkBrf] =
#if   L==1	// ca
	"Create new link in briefcase"		// Necessita traducci
#elif L==2	// de
	"Create new link in briefcase"		// Need bersetzung
#elif L==3	// en
	"Create new link in briefcase"
#elif L==4	// es
	"Crear nuevo enlace en malet&iacute;n"
#elif L==5	// fr
	"Create new link in briefcase"		// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo enlace en malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Create new link in briefcase"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new link in briefcase"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new link in briefcase"		// Precisa de traduo
#elif L==10	// tr
	"Create new link in briefcase"		// eviri lazim!
#endif
	,
	[ActRenFolBrf] =
#if   L==1	// ca
	"Rename folder of briefcase"		// Necessita traducci
#elif L==2	// de
	"Rename folder of briefcase"		// Need bersetzung
#elif L==3	// en
	"Rename folder of briefcase"
#elif L==4	// es
	"Renombrar carpeta en malet&iacute;n"
#elif L==5	// fr
	"Rename folder of briefcase"		// Besoin de traduction
#elif L==6	// gn
	"Renombrar carpeta en malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Rename folder of briefcase"		// Bisogno di traduzione
#elif L==8	// pl
	"Rename folder of briefcase"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename folder of briefcase"		// Precisa de traduo
#elif L==10	// tr
	"Rename folder of briefcase"		// eviri lazim!
#endif
	,
	[ActRcvFilBrfDZ] =
#if   L==1	// ca
	"Send file to briefcase using Dropzone.js"		// Necessita traducci
#elif L==2	// de
	"Send file to briefcase using Dropzone.js"		// Need bersetzung
#elif L==3	// en
	"Send file to briefcase using Dropzone.js"
#elif L==4	// es
	"Enviar archivo a malet&iacute;n using Dropzone.js"
#elif L==5	// fr
	"Send file to briefcase using Dropzone.js"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a malet&iacute;n using Dropzone.js"	// Okoteve traduccin
#elif L==7	// it
	"Send file to briefcase using Dropzone.js"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to briefcase using Dropzone.js"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to briefcase using Dropzone.js"		// Precisa de traduo
#elif L==10	// tr
	"Send file to briefcase using Dropzone.js"		// eviri lazim!
#endif
	,
	[ActRcvFilBrfCla] =
#if   L==1	// ca
	"Send file to briefcase using the classic way"		// Necessita traducci
#elif L==2	// de
	"Send file to briefcase using the classic way"		// Need bersetzung
#elif L==3	// en
	"Send file to briefcase using the classic way"
#elif L==4	// es
	"Enviar archivo a malet&iacute;n de forma tradicional"
#elif L==5	// fr
	"Send file to briefcase using the classic way"		// Besoin de traduction
#elif L==6	// gn
	"Enviar archivo a malet&iacute;n de forma tradicional"	// Okoteve traduccin
#elif L==7	// it
	"Send file to briefcase using the classic way"		// Bisogno di traduzione
#elif L==8	// pl
	"Send file to briefcase using the classic way"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send file to briefcase using the classic way"		// Precisa de traduo
#elif L==10	// tr
	"Send file to briefcase using the classic way"		// eviri lazim!
#endif
	,
	[ActExpBrf] =
#if   L==1	// ca
	"Expand folder in briefcase"		// Necessita traducci
#elif L==2	// de
	"Expand folder in briefcase"		// Need bersetzung
#elif L==3	// en
	"Expand folder in briefcase"
#elif L==4	// es
	"Expandir carpeta en malet&iacute;n"
#elif L==5	// fr
	"Expand folder in briefcase"		// Besoin de traduction
#elif L==6	// gn
	"Expandir carpeta en malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Expand folder in briefcase"		// Bisogno di traduzione
#elif L==8	// pl
	"Expand folder in briefcase"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Expand folder in briefcase"		// Precisa de traduo
#elif L==10	// tr
	"Expand folder in briefcase"		// eviri lazim!
#endif
	,
	[ActConBrf] =
#if   L==1	// ca
	"Contract folder in briefcase"		// Necessita traducci
#elif L==2	// de
	"Contract folder in briefcase"		// Need bersetzung
#elif L==3	// en
	"Contract folder in briefcase"
#elif L==4	// es
	"Contraer carpeta en malet&iacute;n"
#elif L==5	// fr
	"Contract folder in briefcase"		// Besoin de traduction
#elif L==6	// gn
	"Contraer carpeta en malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Contract folder in briefcase"		// Bisogno di traduzione
#elif L==8	// pl
	"Contract folder in briefcase"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Contract folder in briefcase"		// Precisa de traduo
#elif L==10	// tr
	"Contract folder in briefcase"		// eviri lazim!
#endif
	,
	[ActZIPBrf] =
#if   L==1	// ca
	"Compress folder in briefcase"		// Necessita traducci
#elif L==2	// de
	"Compress folder in briefcase"		// Need bersetzung
#elif L==3	// en
	"Compress folder in briefcase"
#elif L==4	// es
	"Comprimir carpeta en malet&iacute;n"
#elif L==5	// fr
	"Compress folder in briefcase"		// Besoin de traduction
#elif L==6	// gn
	"Comprimir carpeta en malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Compress folder in briefcase"		// Bisogno di traduzione
#elif L==8	// pl
	"Compress folder in briefcase"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compress folder in briefcase"		// Precisa de traduo
#elif L==10	// tr
	"Compress folder in briefcase"		// eviri lazim!
#endif
	,
	[ActReqDatBrf] =
#if   L==1	// ca
	"See file metadata in briefcase"		// Necessita traducci
#elif L==2	// de
	"See file metadata in briefcase"		// Need bersetzung
#elif L==3	// en
	"See file metadata in briefcase"
#elif L==4	// es
	"Ver metadatos de archivo en malet&iacute;n"
#elif L==5	// fr
	"See file metadata in briefcase"		// Besoin de traduction
#elif L==6	// gn
	"Ver metadatos de archivo en malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See file metadata in briefcase"		// Bisogno di traduzione
#elif L==8	// pl
	"See file metadata in briefcase"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See file metadata in briefcase"		// Precisa de traduo
#elif L==10	// tr
	"See file metadata in briefcase"		// eviri lazim!
#endif
	,
	[ActChgDatBrf] =
#if   L==1	// ca
	"Change file metadata in briefcase"			// Necessita traducci
#elif L==2	// de
	"Change file metadata in briefcase"			// Need bersetzung
#elif L==3	// en
	"Change file metadata in briefcase"
#elif L==4	// es
	"Cambiar metadatos de archivo en malet&iacute;n"
#elif L==5	// fr
	"Change file metadata in briefcase"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar metadatos de archivo en malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change file metadata in briefcase"			// Bisogno di traduzione
#elif L==8	// pl
	"Change file metadata in briefcase"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change file metadata in briefcase"			// Precisa de traduo
#elif L==10	// tr
	"Change file metadata in briefcase"			// eviri lazim!
#endif
	,
	[ActDowBrf] =
#if   L==1	// ca
	"Download file from briefcase"		// Necessita traducci
#elif L==2	// de
	"Download file from briefcase"		// Need bersetzung
#elif L==3	// en
	"Download file from briefcase"
#elif L==4	// es
	"Descargar archivo de malet&iacute;n"
#elif L==5	// fr
	"Download file from briefcase"		// Besoin de traduction
#elif L==6	// gn
	"Descargar archivo de malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Download file from briefcase"		// Bisogno di traduzione
#elif L==8	// pl
	"Download file from briefcase"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Download file from briefcase"		// Precisa de traduo
#elif L==10	// tr
	"Download file from briefcase"		// eviri lazim!
#endif
	,
	[ActReqRemOldBrf] =
#if   L==1	// ca
	"Request removal of old files from briefcase"				// Necessita traducci
#elif L==2	// de
	"Request removal of old files from briefcase"				// Need bersetzung
#elif L==3	// en
	"Request removal of old files from briefcase"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de archivos antiguos de malet&iacute;n"
#elif L==5	// fr
	"Request removal of old files from briefcase"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de archivos antiguos de malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of old files from briefcase"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of old files from briefcase"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of old files from briefcase"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of old files from briefcase"				// eviri lazim!
#endif
	,
	[ActRemOldBrf] =
#if   L==1	// ca
	"Remove old files in briefcase"			// Necessita traducci
#elif L==2	// de
	"Remove old files in briefcase"			// Need bersetzung
#elif L==3	// en
	"Remove old files in briefcase"
#elif L==4	// es
	"Eliminar archivos antiguos de malet&iacute;n"
#elif L==5	// fr
	"Remove old files in briefcase"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar archivos antiguos de malet&iacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove old files in briefcase"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove old files in briefcase"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove old files in briefcase"			// Precisa de traduo
#elif L==10	// tr
	"Remove old files in briefcase"			// eviri lazim!
#endif
	,
	[ActReqSelGrp] =
#if   L==1	// ca
	"Request selection of groups of students"		// Necessita traducci
#elif L==2	// de
	"Request selection of groups of students"		// Need bersetzung
#elif L==3	// en
	"Request selection of groups of students"
#elif L==4	// es
	"Solicitar selecci&oacute;n de grupos de estudiantes"
#elif L==5	// fr
	"Request selection of groups of students"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar selecci&oacute;n de grupos de estudiantes"	// Okoteve traduccin
#elif L==7	// it
	"Request selection of groups of students"		// Bisogno di traduzione
#elif L==8	// pl
	"Request selection of groups of students"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request selection of groups of students"		// Precisa de traduo
#elif L==10	// tr
	"Request selection of groups of students"		// eviri lazim!
#endif
	,
	[ActChgGrp] =
#if   L==1	// ca
	"Change my groups"	// Necessita traducci
#elif L==2	// de
	"Change my groups"	// Need bersetzung
#elif L==3	// en
	"Change my groups"
#elif L==4	// es
	"Cambiar mis grupos"
#elif L==5	// fr
	"Change my groups"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar mis grupos"	// Okoteve traduccin
#elif L==7	// it
	"Change my groups"	// Bisogno di traduzione
#elif L==8	// pl
	"Change my groups"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change my groups"	// Precisa de traduo
#elif L==10	// tr
	"Change my groups"	// eviri lazim!
#endif
	,
	[ActReqEdiGrp] =
#if   L==1	// ca
	"Request edition of groups"		// Necessita traducci
#elif L==2	// de
	"Request edition of groups"		// Need bersetzung
#elif L==3	// en
	"Request edition of groups"
#elif L==4	// es
	"Solicitar edici&oacute;n de grupos"
#elif L==5	// fr
	"Request edition of groups"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar edici&oacute;n de grupos"	// Okoteve traduccin
#elif L==7	// it
	"Request edition of groups"		// Bisogno di traduzione
#elif L==8	// pl
	"Request edition of groups"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request edition of groups"		// Precisa de traduo
#elif L==10	// tr
	"Request edition of groups"		// eviri lazim!
#endif
	,
	[ActNewGrpTyp] =
#if   L==1	// ca
	"Crear tipus de grup"
#elif L==2	// de
	"Gruppen-Typ definieren"
#elif L==3	// en
	"Create type of group"
#elif L==4	// es
	"Crear tipo de grupo"
#elif L==5	// fr
	"Cr&eacute;er type de groupe"
#elif L==6	// gn
	"Crear tipo de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Creare tipo di gruppo"
#elif L==8	// pl
	"Utw&oacute;rz typu grupy"
#elif L==9	// pt
	"Criar tipo de grupo"
#elif L==10	// tr
	"Create type of group"	// eviri lazim!
#endif
	,
	[ActReqRemGrpTyp] =
#if   L==1	// ca
	"Request removal of type of group"		// Necessita traducci
#elif L==2	// de
	"Request removal of type of group"		// Need bersetzung
#elif L==3	// en
	"Request removal of type of group"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de tipo de grupo"
#elif L==5	// fr
	"Request removal of type of group"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de tipo de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of type of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of type of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of type of group"		// Precisa de traduo
#elif L==10	// tr
	"Request removal of type of group"		// eviri lazim!
#endif
	,
	[ActRemGrpTyp] =
#if   L==1	// ca
	"Eliminar tipus de grup"
#elif L==2	// de
	"Entfernen Art der Gruppe"
#elif L==3	// en
	"Remove type of group"
#elif L==4	// es
	"Eliminar tipo de grupo"
#elif L==5	// fr
	"Supprimer type de groupe"
#elif L==6	// gn
	"Eliminar tipo de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Rimuovere tipo di gruppo"
#elif L==8	// pl
	"Usu&nacute; typ grupy"
#elif L==9	// pt
	"Remover tipo de grupo"
#elif L==10	// tr
	"Grup t&uuml;r&uuml;n&uuml; kald&inodot;r"
#endif
	,
	[ActRenGrpTyp] =
#if   L==1	// ca
	"Rename type of group"		// Necessita traducci
#elif L==2	// de
	"Rename type of group"		// Need bersetzung
#elif L==3	// en
	"Rename type of group"
#elif L==4	// es
	"Renombrar tipo de grupo"
#elif L==5	// fr
	"Rename type of group"		// Besoin de traduction
#elif L==6	// gn
	"Renombrar tipo de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Rename type of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Rename type of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename type of group"		// Precisa de traduo
#elif L==10	// tr
	"Rename type of group"		// eviri lazim!
#endif
	,
	[ActChgMdtGrpTyp] =
#if   L==1	// ca
	"Change if it is mandatory to register in groups of a type"	// Necessita traducci
#elif L==2	// de
	"Change if it is mandatory to register in groups of a type"	// Need bersetzung
#elif L==3	// en
	"Change if it is mandatory to register in groups of a type"
#elif L==4	// es
	"Cambiar si es obligatorio registrarse en grupos de un tipo"
#elif L==5	// fr
	"Change if it is mandatory to register in groups of a type"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar si es obligatorio registrarse en grupos de un tipo"	// Okoteve traduccin
#elif L==7	// it
	"Change if it is mandatory to register in groups of a type"	// Bisogno di traduzione
#elif L==8	// pl
	"Change if it is mandatory to register in groups of a type"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change if it is mandatory to register in groups of a type"	// Precisa de traduo
#elif L==10	// tr
	"Change if it is mandatory to register in groups of a type"	// eviri lazim!
#endif
	,
	[ActChgMulGrpTyp] =
#if   L==1	// ca
	"Change if it is possible to register in multiple groups of a type"	// Necessita traducci
#elif L==2	// de
	"Change if it is possible to register in multiple groups of a type"	// Need bersetzung
#elif L==3	// en
	"Change if it is possible to register in multiple groups of a type"
#elif L==4	// es
	"Cambiar si es posible registrarse en varios grupos de un tipo"
#elif L==5	// fr
	"Change if it is possible to register in multiple groups of a type"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar si es posible registrarse en varios grupos de un tipo"		// Okoteve traduccin
#elif L==7	// it
	"Change if it is possible to register in multiple groups of a type"	// Bisogno di traduzione
#elif L==8	// pl
	"Change if it is possible to register in multiple groups of a type"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change if it is possible to register in multiple groups of a type"	// Precisa de traduo
#elif L==10	// tr
	"Change if it is possible to register in multiple groups of a type"	// eviri lazim!
#endif
	,
	[ActChgTimGrpTyp] =
#if   L==1	// ca
	"Change date when groups of a type will open"				// Necessita traducci
#elif L==2	// de
	"Change date when groups of a type will open"				// Need bersetzung
#elif L==3	// en
	"Change date when groups of a type will open"
#elif L==4	// es
	"Cambiar fecha en la que los grupos de un tipo se abrir&aacute;n"
#elif L==5	// fr
	"Change date when groups of a type will open"				// Besoin de traduction
#elif L==6	// gn
	"Cambiar fecha en la que los grupos de un tipo se abrir&aacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change date when groups of a type will open"				// Bisogno di traduzione
#elif L==8	// pl
	"Change date when groups of a type will open"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change date when groups of a type will open"				// Precisa de traduo
#elif L==10	// tr
	"Change date when groups of a type will open"				// eviri lazim!
#endif
	,
	[ActNewGrp] =
#if   L==1	// ca
	"Crear grup"
#elif L==2	// de
	"Gruppe erstellen"
#elif L==3	// en
	"Create group"
#elif L==4	// es
	"Crear grupo"
#elif L==5	// fr
	"Cr&eacute;er groupe"
#elif L==6	// gn
	"Crear grupo"		// Okoteve traduccin
#elif L==7	// it
	"Creare gruppo"
#elif L==8	// pl
	"Utw&oacute;rz grup&eogon;"
#elif L==9	// pt
	"Criar grupo"
#elif L==10	// tr
	"Create group"		// eviri lazim!
#endif
	,
	[ActReqRemGrp] =
#if   L==1	// ca
	"Request removal of group"		// Necessita traducci
#elif L==2	// de
	"Request removal of group"		// Need bersetzung
#elif L==3	// en
	"Request removal of group"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de grupo"
#elif L==5	// fr
	"Request removal of group"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of group"		// Precisa de traduo
#elif L==10	// tr
	"Request removal of group"		// eviri lazim!
#endif
	,
	[ActRemGrp] =
#if   L==1	// ca
	"Eliminar grup"
#elif L==2	// de
	"Gruppe entfernen"
#elif L==3	// en
	"Remove group"
#elif L==4	// es
	"Eliminar grupo"
#elif L==5	// fr
	"Supprimer groupe"
#elif L==6	// gn
	"Eliminar grupo"	// Okoteve traduccin
#elif L==7	// it
	"Rimuovere gruppo"
#elif L==8	// pl
	"Usu&nacute; gruper"
#elif L==9	// pt
	"Remover grupo"
#elif L==10	// tr
	"Grubu kald&inodot;r"
#endif
	,
	[ActOpeGrp] =
#if   L==1	// ca
	"Open group"		// Necessita traducci
#elif L==2	// de
	"Open group"		// Need bersetzung
#elif L==3	// en
	"Open group"
#elif L==4	// es
	"Abrir grupo"
#elif L==5	// fr
	"Open group"		// Besoin de traduction
#elif L==6	// gn
	"Abrir grupo"	// Okoteve traduccin
#elif L==7	// it
	"Open group"		// Bisogno di traduzione
#elif L==8	// pl
	"Open group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Open group"		// Precisa de traduo
#elif L==10	// tr
	"Open group"		// eviri lazim!
#endif
	,
	[ActCloGrp] =
#if   L==1	// ca
	"Close group"		// Necessita traducci
#elif L==2	// de
	"Close group"		// Need bersetzung
#elif L==3	// en
	"Close group"
#elif L==4	// es
	"Cerrar grupo"
#elif L==5	// fr
	"Close group"		// Besoin de traduction
#elif L==6	// gn
	"Cerrar grupo"	// Okoteve traduccin
#elif L==7	// it
	"Close group"		// Bisogno di traduzione
#elif L==8	// pl
	"Close group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Close group"		// Precisa de traduo
#elif L==10	// tr
	"Close group"		// eviri lazim!
#endif
	,
	[ActEnaFilZonGrp] =
#if   L==1	// ca
	"Enable filezones of group"		// Necessita traducci
#elif L==2	// de
	"Enable filezones of group"		// Need bersetzung
#elif L==3	// en
	"Enable filezones of group"
#elif L==4	// es
	"Habilitar zonas de archivos de grupo"
#elif L==5	// fr
	"Enable filezones of group"		// Besoin de traduction
#elif L==6	// gn
	"Habilitar zonas de archivos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Enable filezones of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Enable filezones of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enable filezones of group"		// Precisa de traduo
#elif L==10	// tr
	"Enable filezones of group"		// eviri lazim!
#endif
	,
	[ActDisFilZonGrp] =
#if   L==1	// ca
	"Disable filezones of group"			// Necessita traducci
#elif L==2	// de
	"Disable filezones of group"			// Need bersetzung
#elif L==3	// en
	"Disable filezones of group"
#elif L==4	// es
	"Inhabilitar zonas de archivos de grupo"
#elif L==5	// fr
	"Disable filezones of group"			// Besoin de traduction
#elif L==6	// gn
	"Inhabilitar zonas de archivos de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Disable filezones of group"			// Bisogno di traduzione
#elif L==8	// pl
	"Disable filezones of group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Disable filezones of group"			// Precisa de traduo
#elif L==10	// tr
	"Disable filezones of group"			// eviri lazim!
#endif
	,
	[ActChgGrpTyp] =
#if   L==1	// ca
	"Change type of group of group"		// Necessita traducci
#elif L==2	// de
	"Change type of group of group"		// Need bersetzung
#elif L==3	// en
	"Change type of group of group"
#elif L==4	// es
	"Cambiar tipo de grupo de grupo"
#elif L==5	// fr
	"Change type of group of group"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar tipo de grupo de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Change type of group of group"		// Bisogno di traduzione
#elif L==8	// pl
	"Change type of group of group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change type of group of group"		// Precisa de traduo
#elif L==10	// tr
	"Change type of group of group"		// eviri lazim!
#endif
	,
	[ActRenGrp] =
#if   L==1	// ca
	"Rename group"		// Necessita traducci
#elif L==2	// de
	"Rename group"		// Need bersetzung
#elif L==3	// en
	"Rename group"
#elif L==4	// es
	"Renombrar grupo"
#elif L==5	// fr
	"Rename group"		// Besoin de traduction
#elif L==6	// gn
	"Renombrar grupo"	// Okoteve traduccin
#elif L==7	// it
	"Rename group"		// Bisogno di traduzione
#elif L==8	// pl
	"Rename group"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename group"		// Precisa de traduo
#elif L==10	// tr
	"Rename group"		// eviri lazim!
#endif
	,
	[ActChgGrpRoo] =
#if   L==1	// ca
	"Change room of group"	// Necessita traducci
#elif L==2	// de
	"Change room of group"	// Need bersetzung
#elif L==3	// en
	"Change room of group"
#elif L==4	// es
	"Cambiar sala de grupo"
#elif L==5	// fr
	"Change room of group"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar sala de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Change room of group"	// Bisogno di traduzione
#elif L==8	// pl
	"Change room of group"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change room of group"	// Precisa de traduo
#elif L==10	// tr
	"Change room of group"	// eviri lazim!
#endif
	,
	[ActChgMaxStdGrp] =
#if   L==1	// ca
	"Change maximum number of students in group"			// Necessita traducci
#elif L==2	// de
	"Change maximum number of students in group"			// Need bersetzung
#elif L==3	// en
	"Change maximum number of students in group"
#elif L==4	// es
	"Cambiar n&uacute;mero m&aacute;ximo de estudiantes de grupo"
#elif L==5	// fr
	"Change maximum number of students in group"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar n&uacute;mero m&aacute;ximo de estudiantes de grupo"	// Okoteve traduccin
#elif L==7	// it
	"Change maximum number of students in group"			// Bisogno di traduzione
#elif L==8	// pl
	"Change maximum number of students in group"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change maximum number of students in group"			// Precisa de traduo
#elif L==10	// tr
	"Change maximum number of students in group"			// eviri lazim!
#endif
	,
	[ActLstStd] =
#if   L==1	// ca
	"Show class photo or list of students"		// Necessita traducci
#elif L==2	// de
	"Show class photo or list of students"		// Need bersetzung
#elif L==3	// en
	"Show class photo or list of students"
#elif L==4	// es
	"Mostrar foto de clase o lista de estudiantes"
#elif L==5	// fr
	"Show class photo or list of students"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar foto de clase o lista de estudiantes"	// Okoteve traduccin
#elif L==7	// it
	"Show class photo or list of students"		// Bisogno di traduzione
#elif L==8	// pl
	"Show class photo or list of students"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show class photo or list of students"		// Precisa de traduo
#elif L==10	// tr
	"Show class photo or list of students"		// eviri lazim!
#endif
	,
	[ActLstStdAll] =
#if   L==1	// ca
	"List the full data of students"		// Necessita traducci
#elif L==2	// de
	"List the full data of students"		// Need bersetzung
#elif L==3	// en
	"List the full data of students"
#elif L==4	// es
	"Listar los datos completos de los estudiantes"
#elif L==5	// fr
	"List the full data of students"		// Besoin de traduction
#elif L==6	// gn
	"Listar los datos completos de los estudiantes"	// Okoteve traduccin
#elif L==7	// it
	"List the full data of students"		// Bisogno di traduzione
#elif L==8	// pl
	"List the full data of students"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List the full data of students"		// Precisa de traduo
#elif L==10	// tr
	"List the full data of students"		// eviri lazim!
#endif
	,
	[ActPrnStdPho] =
#if   L==1	// ca
	"Show class photo of students ready to be printed"		// Necessita traducci
#elif L==2	// de
	"Show class photo of students ready to be printed"		// Need bersetzung
#elif L==3	// en
	"Show class photo of students ready to be printed"
#elif L==4	// es
	"Mostrar foto de clase de estudiantes lista para imprimir"
#elif L==5	// fr
	"Show class photo of students ready to be printed"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar foto de clase de estudiantes lista para imprimir"	// Okoteve traduccin
#elif L==7	// it
	"Show class photo of students ready to be printed"		// Bisogno di traduzione
#elif L==8	// pl
	"Show class photo of students ready to be printed"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show class photo of students ready to be printed"		// Precisa de traduo
#elif L==10	// tr
	"Show class photo of students ready to be printed"		// eviri lazim!
#endif
	,
	[Act_DoAct_OnSevStd] =
#if   L==1	// ca
	"Do an action on several selected students"				// Necessita traducci
#elif L==2	// de
	"Do an action on several selected students"				// Need bersetzung
#elif L==3	// en
	"Do an action on several selected students"
#elif L==4	// es
	"Realizar una acci&oacute;n sobre varios estudiantes seleccionados"
#elif L==5	// fr
	"Do an action on several selected students"				// Besoin de traduction
#elif L==6	// gn
	"Realizar una acci&oacute;n sobre varios estudiantes seleccionados"	// Okoteve traduccin
#elif L==7	// it
	"Do an action on several selected students"				// Bisogno di traduzione
#elif L==8	// pl
	"Do an action on several selected students"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Do an action on several selected students"				// Precisa de traduo
#elif L==10	// tr
	"Do an action on several selected students"				// eviri lazim!
#endif
	,
	[ActSeeRecSevStd] =
#if   L==1	// ca
	"See records of several selected students"		// Necessita traducci
#elif L==2	// de
	"See records of several selected students"		// Need bersetzung
#elif L==3	// en
	"See records of several selected students"
#elif L==4	// es
	"Ver fichas de varios estudiantes seleccionados"
#elif L==5	// fr
	"See records of several selected students"		// Besoin de traduction
#elif L==6	// gn
	"Ver fichas de varios estudiantes seleccionados"	// Okoteve traduccin
#elif L==7	// it
	"See records of several selected students"		// Bisogno di traduzione
#elif L==8	// pl
	"See records of several selected students"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See records of several selected students"		// Precisa de traduo
#elif L==10	// tr
	"See records of several selected students"		// eviri lazim!
#endif
	,
	[ActPrnRecSevStd] =
#if   L==1	// ca
	"See records of several selected students ready to print"		// Necessita traducci
#elif L==2	// de
	"See records of several selected students ready to print"		// Need bersetzung
#elif L==3	// en
	"See records of several selected students ready to print"
#elif L==4	// es
	"Ver fichas de varios estudiantes seleccionados lista para imprimir"
#elif L==5	// fr
	"See records of several selected students ready to print"		// Besoin de traduction
#elif L==6	// gn
	"Ver fichas de varios estudiantes seleccionados lista para imprimir"	// Okoteve traduccin
#elif L==7	// it
	"See records of several selected students ready to print"		// Bisogno di traduzione
#elif L==8	// pl
	"See records of several selected students ready to print"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See records of several selected students ready to print"		// Precisa de traduo
#elif L==10	// tr
	"See records of several selected students ready to print"		// eviri lazim!
#endif
	,
	[ActReqMdfOneStd] =
#if   L==1	// ca
	"Request a student's ID for enrolment/removal"					// Necessita traducci
#elif L==2	// de
	"Request a student's ID for enrolment/removal"					// Need bersetzung
#elif L==3	// en
	"Request a student's ID for enrolment/removal"
#elif L==4	// es
	"Solicitar el ID de estudiante para inscripci&oacute;n/eliminaci&oacute;n"
#elif L==5	// fr
	"Request a student's ID for enrolment/removal"					// Besoin de traduction
#elif L==6	// gn
	"Solicitar el ID de estudiante para inscripci&oacute;n/eliminaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request a student's ID for enrolment/removal"					// Bisogno di traduzione
#elif L==8	// pl
	"Request a student's ID for enrolment/removal"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request a student's ID for enrolment/removal"					// Precisa de traduo
#elif L==10	// tr
	"Request a student's ID for enrolment/removal"					// eviri lazim!
#endif
	,
	[ActReqMdfStd] =
#if   L==1	// ca
	"Request enrolment/removal of a student"			// Necessita traducci
#elif L==2	// de
	"Request enrolment/removal of a student"			// Need bersetzung
#elif L==3	// en
	"Request enrolment/removal of a student"
#elif L==4	// es
	"Solicitar inscripci&oacute;n/eliminaci&oacute;n de estudiante"
#elif L==5	// fr
	"Request enrolment/removal of a student"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar inscripci&oacute;n/eliminaci&oacute;n de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Request enrolment/removal of a student"			// Bisogno di traduzione
#elif L==8	// pl
	"Request enrolment/removal of a student"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request enrolment/removal of a student"			// Precisa de traduo
#elif L==10	// tr
	"Request enrolment/removal of a student"			// eviri lazim!
#endif
	,
	[ActReqStdPho] =
#if   L==1	// ca
	"Edit a student's photo"	// Necessita traducci
#elif L==2	// de
	"Edit a student's photo"	// Need bersetzung
#elif L==3	// en
	"Edit a student's photo"
#elif L==4	// es
	"Editar la foto de estudiante"
#elif L==5	// fr
	"Edit a student's photo"	// Besoin de traduction
#elif L==6	// gn
	"Editar la foto de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Edit a student's photo"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit a student's photo"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit a student's photo"	// Precisa de traduo
#elif L==10	// tr
	"Edit a student's photo"	// eviri lazim!
#endif
	,
	[ActDetStdPho] =
#if   L==1	// ca
	"Send student's photo and detect faces on it"			// Necessita traducci
#elif L==2	// de
	"Send student's photo and detect faces on it"			// Need bersetzung
#elif L==3	// en
	"Send student's photo and detect faces on it"
#elif L==4	// es
	"Enviar la foto de estudiante y detectar rostros en ella"
#elif L==5	// fr
	"Send student's photo and detect faces on it"			// Besoin de traduction
#elif L==6	// gn
	"Enviar la foto de estudiante y detectar rostros en ella"	// Okoteve traduccin
#elif L==7	// it
	"Send student's photo and detect faces on it"			// Bisogno di traduzione
#elif L==8	// pl
	"Send student's photo and detect faces on it"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send student's photo and detect faces on it"			// Precisa de traduo
#elif L==10	// tr
	"Send student's photo and detect faces on it"			// eviri lazim!
#endif
	,
	[ActChgStdPho] =
#if   L==1	// ca
	"Update a student's photo"		// Necessita traducci
#elif L==2	// de
	"Update a student's photo"		// Need bersetzung
#elif L==3	// en
	"Update a student's photo"
#elif L==4	// es
	"Actualizar la foto de estudiante"
#elif L==5	// fr
	"Update a student's photo"		// Besoin de traduction
#elif L==6	// gn
	"Actualizar la foto de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Update a student's photo"		// Bisogno di traduzione
#elif L==8	// pl
	"Update a student's photo"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Update a student's photo"		// Precisa de traduo
#elif L==10	// tr
	"Update a student's photo"		// eviri lazim!
#endif
	,
	[ActReqRemStdPho] =
#if   L==1	// ca
	"Request removal of student's photo"			// Necessita traducci
#elif L==2	// de
	"Request removal of student's photo"			// Need bersetzung
#elif L==3	// en
	"Request removal of student's photo"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de foto de estudiante"
#elif L==5	// fr
	"Request removal of student's photo"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de foto de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of student's photo"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of student's photo"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of student's photo"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of student's photo"			// eviri lazim!
#endif
	,
	[ActRemStdPho] =
#if   L==1	// ca
	"Remove student's photo"		// Necessita traducci
#elif L==2	// de
	"Remove student's photo"		// Need bersetzung
#elif L==3	// en
	"Remove student's photo"
#elif L==4	// es
	"Eliminar la foto de estudiante"
#elif L==5	// fr
	"Remove student's photo"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar la foto de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Remove student's photo"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove student's photo"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove student's photo"		// Precisa de traduo
#elif L==10	// tr
	"Remove student's photo"		// eviri lazim!
#endif
	,
	[ActCreStd] =
#if   L==1	// ca
	"Create new student"		// Necessita traducci
#elif L==2	// de
	"Create new student"		// Need bersetzung
#elif L==3	// en
	"Create new student"
#elif L==4	// es
	"Crear nuevo estudiante"
#elif L==5	// fr
	"Create new student"		// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Create new student"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new student"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new student"		// Precisa de traduo
#elif L==10	// tr
	"Create new student"		// eviri lazim!
#endif
	,
	[ActUpdStd] =
#if   L==1	// ca
	"Update a student's data and groups"		// Necessita traducci
#elif L==2	// de
	"Update a student's data and groups"		// Need bersetzung
#elif L==3	// en
	"Update a student's data and groups"
#elif L==4	// es
	"Actualizar los datos y grupos de estudiante"
#elif L==5	// fr
	"Update a student's data and groups"		// Besoin de traduction
#elif L==6	// gn
	"Actualizar los datos y grupos de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Update a student's data and groups"		// Bisogno di traduzione
#elif L==8	// pl
	"Update a student's data and groups"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Update a student's data and groups"		// Precisa de traduo
#elif L==10	// tr
	"Update a student's data and groups"		// eviri lazim!
#endif
	,
	[ActCnfID_Std] =
#if   L==1	// ca
	"Confirm a student's ID"	// Necessita traducci
#elif L==2	// de
	"Confirm a student's ID"	// Need bersetzung
#elif L==3	// en
	"Confirm a student's ID"
#elif L==4	// es
	"Confirmar el ID de estudiante"
#elif L==5	// fr
	"Confirm a student's ID"	// Besoin de traduction
#elif L==6	// gn
	"Confirmar el ID de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Confirm a student's ID"	// Bisogno di traduzione
#elif L==8	// pl
	"Confirm a student's ID"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Confirm a student's ID"	// Precisa de traduo
#elif L==10	// tr
	"Confirm a student's ID"	// eviri lazim!
#endif
	,
	[ActFrmAccStd] =
#if   L==1	// ca
	"Forms to the change a student's account"		// Necessita traducci
#elif L==2	// de
	"Forms to the change a student's account"		// Need bersetzung
#elif L==3	// en
	"Forms to the change a student's account"
#elif L==4	// es
	"Formularios para cambiar la cuenta de estudiante"
#elif L==5	// fr
	"Forms to the change a student's account"		// Besoin de traduction
#elif L==6	// gn
	"Formularios para cambiar la cuenta de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Forms to the change a student's account"		// Bisogno di traduzione
#elif L==8	// pl
	"Forms to the change a student's account"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Forms to the change a student's account"		// Precisa de traduo
#elif L==10	// tr
	"Forms to the change a student's account"		// eviri lazim!
#endif
	,
	[ActRemNicStd] =
#if   L==1	// ca
	"Remove student's nickname"	// Necessita traducci
#elif L==2	// de
	"Remove student's nickname"	// Need bersetzung
#elif L==3	// en
	"Remove student's nickname"
#elif L==4	// es
	"Eliminar apodo de estudiante"
#elif L==5	// fr
	"Remove student's nickname"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar apodo de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Remove student's nickname"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove student's nickname"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove student's nickname"	// Precisa de traduo
#elif L==10	// tr
	"Remove student's nickname"	// eviri lazim!
#endif
	,
	[ActChgNicStd] =
#if   L==1	// ca
	"Change student's nickname"	// Necessita traducci
#elif L==2	// de
	"Change student's nickname"	// Need bersetzung
#elif L==3	// en
	"Change student's nickname"
#elif L==4	// es
	"Cambiar apodo de estudiante"
#elif L==5	// fr
	"Change student's nickname"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar apodo de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Change student's nickname"	// Bisogno di traduzione
#elif L==8	// pl
	"Change student's nickname"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change student's nickname"	// Precisa de traduo
#elif L==10	// tr
	"Change student's nickname"	// eviri lazim!
#endif
	,
	[ActRemID_Std] =
#if   L==1	// ca
	"Remove student's ID"		// Necessita traducci
#elif L==2	// de
	"Remove student's ID"		// Need bersetzung
#elif L==3	// en
	"Remove student's ID"
#elif L==4	// es
	"Eliminar ID de estudiante"
#elif L==5	// fr
	"Remove student's ID"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar ID de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Remove student's ID"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove student's ID"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove student's ID"		// Precisa de traduo
#elif L==10	// tr
	"Remove student's ID"		// eviri lazim!
#endif
	,
	[ActChgID_Std] =
#if   L==1	// ca
	"Create new student's ID"	// Necessita traducci
#elif L==2	// de
	"Create new student's ID"	// Need bersetzung
#elif L==3	// en
	"Create new student's ID"
#elif L==4	// es
	"Crear nuevo ID de estudiante"
#elif L==5	// fr
	"Create new student's ID"	// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo ID de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Create new student's ID"	// Bisogno di traduzione
#elif L==8	// pl
	"Create new student's ID"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new student's ID"	// Precisa de traduo
#elif L==10	// tr
	"Create new student's ID"	// eviri lazim!
#endif
	,
	[ActChgPwdStd] =
#if   L==1	// ca
	"Change student's password"			// Necessita traducci
#elif L==2	// de
	"Change student's password"			// Need bersetzung
#elif L==3	// en
	"Change student's password"
#elif L==4	// es
	"Cambiar contrase&ntilde;a de estudiante"
#elif L==5	// fr
	"Change student's password"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar contrase&ntilde;a de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Change student's password"			// Bisogno di traduzione
#elif L==8	// pl
	"Change student's password"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change student's password"			// Precisa de traduo
#elif L==10	// tr
	"Change student's password"			// eviri lazim!
#endif
	,
	[ActRemMaiStd] =
#if   L==1	// ca
	"Remove student's email"				// Necessita traducci
#elif L==2	// de
	"Remove student's email"				// Need bersetzung
#elif L==3	// en
	"Remove student's email"
#elif L==4	// es
	"Eliminar correo electr&oacute;nico de estudiante"
#elif L==5	// fr
	"Remove student's email"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar correo electr&oacute;nico de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Remove student's email"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove student's email"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove student's email"				// Precisa de traduo
#elif L==10	// tr
	"Remove student's email"				// eviri lazim!
#endif
	,
	[ActChgMaiStd] =
#if   L==1	// ca
	"Create new student's email"				// Necessita traducci
#elif L==2	// de
	"Create new student's email"				// Need bersetzung
#elif L==3	// en
	"Create new student's email"
#elif L==4	// es
	"Crear nuevo correo electr&oacute;nico de estudiante"
#elif L==5	// fr
	"Create new student's email"				// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo correo electr&oacute;nico de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Create new student's email"				// Bisogno di traduzione
#elif L==8	// pl
	"Create new student's email"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new student's email"				// Precisa de traduo
#elif L==10	// tr
	"Create new student's email"				// eviri lazim!
#endif
	,
	[ActRemStdCrs] =
#if   L==1	// ca
	"Remove student from a course"		// Necessita traducci
#elif L==2	// de
	"Remove student from a course"		// Need bersetzung
#elif L==3	// en
	"Remove student from a course"
#elif L==4	// es
	"Eliminar estudiante de asignatura"
#elif L==5	// fr
	"Remove student from a course"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar estudiante de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove student from a course"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove student from a course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove student from a course"		// Precisa de traduo
#elif L==10	// tr
	"Remove student from a course"		// eviri lazim!
#endif
	,
	[ActReqRemAllStdCrs] =
#if   L==1	// ca
	"Request removal of all students from a course"				// Necessita traducci
#elif L==2	// de
	"Request removal of all students from a course"				// Need bersetzung
#elif L==3	// en
	"Request removal of all students from a course"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de todos los estudiantes de asignatura"
#elif L==5	// fr
	"Request removal of all students from a course"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de todos los estudiantes de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of all students from a course"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of all students from a course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of all students from a course"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of all students from a course"				// eviri lazim!
#endif
	,
	[ActRemAllStdCrs] =
#if   L==1	// ca
	"Remove all students from a course"		// Necessita traducci
#elif L==2	// de
	"Remove all students from a course"		// Need bersetzung
#elif L==3	// en
	"Remove all students from a course"
#elif L==4	// es
	"Eliminar todos los estudiantes de asignatura"
#elif L==5	// fr
	"Remove all students from a course"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar todos los estudiantes de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove all students from a course"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove all students from a course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove all students from a course"		// Precisa de traduo
#elif L==10	// tr
	"Remove all students from a course"		// eviri lazim!
#endif
	,
	[ActReqAccEnrStd] =
#if   L==1	// ca
	"See whether to accept or reject my enrolment as student"		// Necessita traducci
#elif L==2	// de
	"See whether to accept or reject my enrolment as student"		// Need bersetzung
#elif L==3	// en
	"See whether to accept or reject my enrolment as student"
#elif L==4	// es
	"Ver si aceptar o rechazar mi inscripci&oacute;n como estudiante"
#elif L==5	// fr
	"See whether to accept or reject my enrolment as student"		// Besoin de traduction
#elif L==6	// gn
	"Ver si aceptar o rechazar mi inscripci&oacute;n como estudiante"	// Okoteve traduccin
#elif L==7	// it
	"See whether to accept or reject my enrolment as student"		// Bisogno di traduzione
#elif L==8	// pl
	"See whether to accept or reject my enrolment as student"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See whether to accept or reject my enrolment as student"		// Precisa de traduo
#elif L==10	// tr
	"See whether to accept or reject my enrolment as student"		// eviri lazim!
#endif
	,
	[ActAccEnrStd] =
#if   L==1	// ca
	"Accept my enrolment as student"		// Necessita traducci
#elif L==2	// de
	"Accept my enrolment as student"		// Need bersetzung
#elif L==3	// en
	"Accept my enrolment as student"
#elif L==4	// es
	"Aceptar mi inscripci&oacute;n como estudiante"
#elif L==5	// fr
	"Accept my enrolment as student"		// Besoin de traduction
#elif L==6	// gn
	"Aceptar mi inscripci&oacute;n como estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Accept my enrolment as student"		// Bisogno di traduzione
#elif L==8	// pl
	"Accept my enrolment as student"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Accept my enrolment as student"		// Precisa de traduo
#elif L==10	// tr
	"Accept my enrolment as student"		// eviri lazim!
#endif
	,
	[ActRemMe_Std] =
#if   L==1	// ca
	"Reject my enrolment as student"			// Necessita traducci
#elif L==2	// de
	"Reject my enrolment as student"			// Need bersetzung
#elif L==3	// en
	"Reject my enrolment as student"
#elif L==4	// es
	"Rechazar mi inscripci&oacute;n como estudiante"
#elif L==5	// fr
	"Reject my enrolment as student"			// Besoin de traduction
#elif L==6	// gn
	"Rechazar mi inscripci&oacute;n como estudiante"	// Okoteve traduccin
#elif L==7	// it
	"Reject my enrolment as student"			// Bisogno di traduzione
#elif L==8	// pl
	"Reject my enrolment as student"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Reject my enrolment as student"			// Precisa de traduo
#elif L==10	// tr
	"Reject my enrolment as student"			// eviri lazim!
#endif
	,
	[ActReqFolSevStd] =
#if   L==1	// ca
	"Request follow several students"	// Necessita traducci
#elif L==2	// de
	"Request follow several students"	// Need bersetzung
#elif L==3	// en
	"Request follow several students"
#elif L==4	// es
	"Solicitar seguir a varios estudiantes"
#elif L==5	// fr
	"Request follow several students"	// Besoin de traduction
#elif L==6	// gn
	"Solicitar seguir a varios estudiantes"	// Okoteve traduccin
#elif L==7	// it
	"Request follow several students"	// Bisogno di traduzione
#elif L==8	// pl
	"Request follow several students"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request follow several students"	// Precisa de traduo
#elif L==10	// tr
	"Request follow several students"	// eviri lazim!
#endif
	,
	[ActReqUnfSevStd] =
#if   L==1	// ca
	"Request unfollow several students"			// Necessita traducci
#elif L==2	// de
	"Request unfollow several students"			// Need bersetzung
#elif L==3	// en
	"Request unfollow several students"
#elif L==4	// es
	"Solicitar dejar de seguir a varios estudiantes"
#elif L==5	// fr
	"Request unfollow several students"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar dejar de seguir a varios estudiantes"	// Okoteve traduccin
#elif L==7	// it
	"Request unfollow several students"			// Bisogno di traduzione
#elif L==8	// pl
	"Request unfollow several students"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request unfollow several students"			// Precisa de traduo
#elif L==10	// tr
	"Request unfollow several students"			// eviri lazim!
#endif
	,
	[ActFolSevStd] =
#if   L==1	// ca
	"Follow several students"	// Necessita traducci
#elif L==2	// de
	"Follow several students"	// Need bersetzung
#elif L==3	// en
	"Follow several students"
#elif L==4	// es
	"Seguir a varios estudiantes"
#elif L==5	// fr
	"Follow several students"	// Besoin de traduction
#elif L==6	// gn
	"Seguir a varios estudiantes"	// Okoteve traduccin
#elif L==7	// it
	"Follow several students"	// Bisogno di traduzione
#elif L==8	// pl
	"Follow several students"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Follow several students"	// Precisa de traduo
#elif L==10	// tr
	"Follow several students"	// eviri lazim!
#endif
	,
	[ActUnfSevStd] =
#if   L==1	// ca
	"Unfollow several students"		// Necessita traducci
#elif L==2	// de
	"Unfollow several students"		// Need bersetzung
#elif L==3	// en
	"Unfollow several students"
#elif L==4	// es
	"Dejar de seguir a varios estudiantes"
#elif L==5	// fr
	"Unfollow several students"		// Besoin de traduction
#elif L==6	// gn
	"Dejar de seguir a varios estudiantes"	// Okoteve traduccin
#elif L==7	// it
	"Unfollow several students"		// Bisogno di traduzione
#elif L==8	// pl
	"Unfollow several students"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unfollow several students"		// Precisa de traduo
#elif L==10	// tr
	"Unfollow several students"		// eviri lazim!
#endif
	,
	[ActSeeRecOneStd] =
#if   L==1	// ca
	"See the record of a student"	// Necessita traducci
#elif L==2	// de
	"See the record of a student"	// Need bersetzung
#elif L==3	// en
	"See the record of a student"
#elif L==4	// es
	"Ver la ficha de estudiante"
#elif L==5	// fr
	"See the record of a student"	// Besoin de traduction
#elif L==6	// gn
	"Ver la ficha de estudiante"	// Okoteve traduccin
#elif L==7	// it
	"See the record of a student"	// Bisogno di traduzione
#elif L==8	// pl
	"See the record of a student"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the record of a student"	// Precisa de traduo
#elif L==10	// tr
	"See the record of a student"	// eviri lazim!
#endif
	,
	[ActReqEnrSevStd] =
#if   L==1	// ca
	"Request enrolment/removing of several students to/from a course"				// Necessita traducci
#elif L==2	// de
	"Request enrolment/removing of several students to/from a course"				// Need bersetzung
#elif L==3	// en
	"Request enrolment/removing of several students to/from a course"
#elif L==4	// es
	"Solicitar inscripci&oacute;n/eliminaci&oacute;n de varios estudiantes a/de un asignatura"
#elif L==5	// fr
	"Request enrolment/removing of several students to/from a course"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar inscripci&oacute;n/eliminaci&oacute;n de varios estudiantes a/de un asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Request enrolment/removing of several students to/from a course"				// Bisogno di traduzione
#elif L==8	// pl
	"Request enrolment/removing of several students to/from a course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request enrolment/removing of several students to/from a course"				// Precisa de traduo
#elif L==10	// tr
	"Request enrolment/removing of several students to/from a course"				// eviri lazim!
#endif
	,
	[ActRcvFrmEnrSevStd] =
#if   L==1	// ca
	"Register/remove several students in/from a course"		// Necessita traducci
#elif L==2	// de
	"Register/remove several students in/from a course"		// Need bersetzung
#elif L==3	// en
	"Register/remove several students in/from a course"
#elif L==4	// es
	"Inscribir/eliminar varios estudiantes en/de asignatura"
#elif L==5	// fr
	"Register/remove several students in/from a course"		// Besoin de traduction
#elif L==6	// gn
	"Inscribir/eliminar varios estudiantes en/de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Register/remove several students in/from a course"		// Bisogno di traduzione
#elif L==8	// pl
	"Register/remove several students in/from a course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Register/remove several students in/from a course"		// Precisa de traduo
#elif L==10	// tr
	"Register/remove several students in/from a course"		// eviri lazim!
#endif
	,
	[ActRcvRecOthUsr] =
#if   L==1	// ca
	"Update record fields of student in course"			// Necessita traducci
#elif L==2	// de
	"Update record fields of student in course"			// Need bersetzung
#elif L==3	// en
	"Update record fields of student in course"
#elif L==4	// es
	"Actualizar los campos de la ficha de estudiante en asignatura"
#elif L==5	// fr
	"Update record fields of student in course"			// Besoin de traduction
#elif L==6	// gn
	"Actualizar los campos de la ficha de estudiante en asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Update record fields of student in course"			// Bisogno di traduzione
#elif L==8	// pl
	"Update record fields of student in course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Update record fields of student in course"			// Precisa de traduo
#elif L==10	// tr
	"Update record fields of student in course"			// eviri lazim!
#endif
	,
	[ActEdiRecFie] =
#if   L==1	// ca
	"Edit record fields of students"		// Necessita traducci
#elif L==2	// de
	"Edit record fields of students"		// Need bersetzung
#elif L==3	// en
	"Edit record fields of students"
#elif L==4	// es
	"Editar los campos de fichas de estudiantes"
#elif L==5	// fr
	"Edit record fields of students"		// Besoin de traduction
#elif L==6	// gn
	"Editar los campos de fichas de estudiantes"	// Okoteve traduccin
#elif L==7	// it
	"Edit record fields of students"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit record fields of students"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit record fields of students"		// Precisa de traduo
#elif L==10	// tr
	"Edit record fields of students"		// eviri lazim!
#endif
	,
	[ActNewFie] =
#if   L==1	// ca
	"Crear camp de fitxa"
#elif L==2	// de
	"Datenfeld erstellen"
#elif L==3	// en
	"Create record field"
#elif L==4	// es
	"Crear campo de ficha"
#elif L==5	// fr
	"Cr&eacute;er champ de carte"
#elif L==6	// gn
	"Crear campo de ficha"	// Okoteve traduccin
#elif L==7	// it
	"Creare campo di scheda"
#elif L==8	// pl
	"Utw&oacute;rz rekord pola"
#elif L==9	// pt
	"Criar campo de cart&atilde;o"
#elif L==10	// tr
	"Create record field"	// eviri lazim!
#endif
	,
	[ActReqRemFie] =
#if   L==1	// ca
	"Request removal of record field"			// Necessita traducci
#elif L==2	// de
	"Request removal of record field"			// Need bersetzung
#elif L==3	// en
	"Request removal of record field"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de campo de ficha"
#elif L==5	// fr
	"Request removal of record field"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de campo de ficha"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of record field"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of record field"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of record field"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of record field"			// eviri lazim!
#endif
	,
	[ActRemFie] =
#if   L==1	// ca
	"Eliminar camp de fitxa"
#elif L==2	// de
	"Datenfeld entfernen"
#elif L==3	// en
	"Remove record field"
#elif L==4	// es
	"Eliminar campo de ficha"
#elif L==5	// fr
	"Supprimer champ de carte"
#elif L==6	// gn
	"Eliminar campo de ficha"	// Okoteve traduccin
#elif L==7	// it
	"Rimuovere campo di scheda"
#elif L==8	// pl
	"Usu&nacute; pola rekordu"
#elif L==9	// pt
	"Remover campo de cart&atilde;o"
#elif L==10	// tr
	"Kay&inodot;t alan&inodot;n&inodot; kald&inodot;r"
#endif
	,
	[ActRenFie] =
#if   L==1	// ca
	"Rename record field"		// Necessita traducci
#elif L==2	// de
	"Rename record field"		// Need bersetzung
#elif L==3	// en
	"Rename record field"
#elif L==4	// es
	"Renombrar campo de ficha"
#elif L==5	// fr
	"Rename record field"		// Besoin de traduction
#elif L==6	// gn
	"Renombrar campo de ficha"	// Okoteve traduccin
#elif L==7	// it
	"Rename record field"		// Bisogno di traduzione
#elif L==8	// pl
	"Rename record field"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Rename record field"		// Precisa de traduo
#elif L==10	// tr
	"Rename record field"		// eviri lazim!
#endif
	,
	[ActChgRowFie] =
#if   L==1	// ca
	"Change number of form lines in record field"					// Necessita traducci
#elif L==2	// de
	"Change number of form lines in record field"					// Need bersetzung
#elif L==3	// en
	"Change number of form lines in record field"
#elif L==4	// es
	"Cambiar n&uacute;mero de l&iacute;neas del formulario de campo de ficha"
#elif L==5	// fr
	"Change number of form lines in record field"					// Besoin de traduction
#elif L==6	// gn
	"Cambiar n&uacute;mero de l&iacute;neas del formulario de campo de ficha"	// Okoteve traduccin
#elif L==7	// it
	"Change number of form lines in record field"					// Bisogno di traduzione
#elif L==8	// pl
	"Change number of form lines in record field"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change number of form lines in record field"					// Precisa de traduo
#elif L==10	// tr
	"Change number of form lines in record field"					// eviri lazim!
#endif
	,
	[ActChgVisFie] =
#if   L==1	// ca
	"Change visibility of a record field"	// Necessita traducci
#elif L==2	// de
	"Change visibility of a record field"	// Need bersetzung
#elif L==3	// en
	"Change visibility of a record field"
#elif L==4	// es
	"Cambiar visibilidad de campo de ficha"
#elif L==5	// fr
	"Change visibility of a record field"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar visibilidad de campo de ficha"	// Okoteve traduccin
#elif L==7	// it
	"Change visibility of a record field"	// Bisogno di traduzione
#elif L==8	// pl
	"Change visibility of a record field"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change visibility of a record field"	// Precisa de traduo
#elif L==10	// tr
	"Change visibility of a record field"	// eviri lazim!
#endif
	,
	[ActRcvRecCrs] =
#if   L==1	// ca
	"Update fields of my record in a course"		// Necessita traducci
#elif L==2	// de
	"Update fields of my record in a course"		// Need bersetzung
#elif L==3	// en
	"Update fields of my record in a course"
#elif L==4	// es
	"Actualizar campos de mi ficha en una asignatura"
#elif L==5	// fr
	"Update fields of my record in a course"		// Besoin de traduction
#elif L==6	// gn
	"Actualizar campos de mi ficha en una asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Update fields of my record in a course"		// Bisogno di traduzione
#elif L==8	// pl
	"Update fields of my record in a course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Update fields of my record in a course"		// Precisa de traduo
#elif L==10	// tr
	"Update fields of my record in a course"		// eviri lazim!
#endif
	,
	[ActLstTch] =
#if   L==1	// ca
	"Show class photo or list of teachers"		// Necessita traducci
#elif L==2	// de
	"Show class photo or list of teachers"		// Need bersetzung
#elif L==3	// en
	"Show class photo or list of teachers"
#elif L==4	// es
	"Mostrar foto de clase o lista de profesores"
#elif L==5	// fr
	"Show class photo or list of teachers"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar foto de clase o lista de profesores"	// Okoteve traduccin
#elif L==7	// it
	"Show class photo or list of teachers"		// Bisogno di traduzione
#elif L==8	// pl
	"Show class photo or list of teachers"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show class photo or list of teachers"		// Precisa de traduo
#elif L==10	// tr
	"Show class photo or list of teachers"		// eviri lazim!
#endif
	,
	[ActLstTchAll] =
#if   L==1	// ca
	"List the full data of the teachers"		// Necessita traducci
#elif L==2	// de
	"List the full data of the teachers"		// Need bersetzung
#elif L==3	// en
	"List the full data of the teachers"
#elif L==4	// es
	"Listar los datos completos de los profesores"
#elif L==5	// fr
	"List the full data of the teachers"		// Besoin de traduction
#elif L==6	// gn
	"Listar los datos completos de los profesores"	// Okoteve traduccin
#elif L==7	// it
	"List the full data of the teachers"		// Bisogno di traduzione
#elif L==8	// pl
	"List the full data of the teachers"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List the full data of the teachers"		// Precisa de traduo
#elif L==10	// tr
	"List the full data of the teachers"		// eviri lazim!
#endif
	,
	[ActPrnTchPho] =
#if   L==1	// ca
	"Show class photo of teachers ready to be printed"		// Necessita traducci
#elif L==2	// de
	"Show class photo of teachers ready to be printed"		// Need bersetzung
#elif L==3	// en
	"Show class photo of teachers ready to be printed"
#elif L==4	// es
	"Mostrar foto de clase de profesores lista para imprimir"
#elif L==5	// fr
	"Show class photo of teachers ready to be printed"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar foto de clase de profesores lista para imprimir"	// Okoteve traduccin
#elif L==7	// it
	"Show class photo of teachers ready to be printed"		// Bisogno di traduzione
#elif L==8	// pl
	"Show class photo of teachers ready to be printed"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show class photo of teachers ready to be printed"		// Precisa de traduo
#elif L==10	// tr
	"Show class photo of teachers ready to be printed"		// eviri lazim!
#endif
	,
	[Act_DoAct_OnSevTch] =
#if   L==1	// ca
	"Do an action on several selected teachers"				// Necessita traducci
#elif L==2	// de
	"Do an action on several selected teachers"				// Need bersetzung
#elif L==3	// en
	"Do an action on several selected teachers"
#elif L==4	// es
	"Realizar una acci&oacute;n sobre varios profesores seleccionados"
#elif L==5	// fr
	"Do an action on several selected teachers"				// Besoin de traduction
#elif L==6	// gn
	"Realizar una acci&oacute;n sobre varios profesores seleccionados"	// Okoteve traduccin
#elif L==7	// it
	"Do an action on several selected teachers"				// Bisogno di traduzione
#elif L==8	// pl
	"Do an action on several selected teachers"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Do an action on several selected teachers"				// Precisa de traduo
#elif L==10	// tr
	"Do an action on several selected teachers"				// eviri lazim!
#endif
	,
	[ActSeeRecSevTch] =
#if   L==1	// ca
	"See records of several selected teachers"	// Necessita traducci
#elif L==2	// de
	"See records of several selected teachers"	// Need bersetzung
#elif L==3	// en
	"See records of several selected teachers"
#elif L==4	// es
	"Ver fichas de varios profesores seleccionados"
#elif L==5	// fr
	"See records of several selected teachers"	// Besoin de traduction
#elif L==6	// gn
	"Ver fichas de varios profesores seleccionados"	// Okoteve traduccin
#elif L==7	// it
	"See records of several selected teachers"	// Bisogno di traduzione
#elif L==8	// pl
	"See records of several selected teachers"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See records of several selected teachers"	// Precisa de traduo
#elif L==10	// tr
	"See records of several selected teachers"	// eviri lazim!
#endif
	,
	[ActPrnRecSevTch] =
#if   L==1	// ca
	"See records of several selected teachers ready to print"		// Necessita traducci
#elif L==2	// de
	"See records of several selected teachers ready to print"		// Need bersetzung
#elif L==3	// en
	"See records of several selected teachers ready to print"
#elif L==4	// es
	"Ver fichas de varios profesores seleccionados lista para imprimir"
#elif L==5	// fr
	"See records of several selected teachers ready to print"		// Besoin de traduction
#elif L==6	// gn
	"Ver fichas de varios profesores seleccionados lista para imprimir"	// Okoteve traduccin
#elif L==7	// it
	"See records of several selected teachers ready to print"		// Bisogno di traduzione
#elif L==8	// pl
	"See records of several selected teachers ready to print"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See records of several selected teachers ready to print"		// Precisa de traduo
#elif L==10	// tr
	"See records of several selected teachers ready to print"		// eviri lazim!
#endif
	,
	[ActReqMdfOneTch] =
#if   L==1	// ca
	"Request a teacher's ID for enrolment/removal"					// Necessita traducci
#elif L==2	// de
	"Request a teacher's ID for enrolment/removal"					// Need bersetzung
#elif L==3	// en
	"Request a teacher's ID for enrolment/removal"
#elif L==4	// es
	"Solicitar el ID de profesor para inscripci&oacute;n/eliminaci&oacute;n"
#elif L==5	// fr
	"Request a teacher's ID for enrolment/removal"					// Besoin de traduction
#elif L==6	// gn
	"Solicitar el ID de profesor para inscripci&oacute;n/eliminaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request a teacher's ID for enrolment/removal"					// Bisogno di traduzione
#elif L==8	// pl
	"Request a teacher's ID for enrolment/removal"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request a teacher's ID for enrolment/removal"					// Precisa de traduo
#elif L==10	// tr
	"Request a teacher's ID for enrolment/removal"					// eviri lazim!
#endif
	,
	[ActReqMdfNET] =
#if   L==1	// ca
	"Request enrolment/removal of a non-editing teacher"			// Necessita traducci
#elif L==2	// de
	"Request enrolment/removal of a non-editing teacher"			// Need bersetzung
#elif L==3	// en
	"Request enrolment/removal of a non-editing teacher"
#elif L==4	// es
	"Solicitar inscripci&oacute;n/eliminaci&oacute;n de profesor no editor"
#elif L==5	// fr
	"Request enrolment/removal of a non-editing teacher"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar inscripci&oacute;n/eliminaci&oacute;n de profesor no editor"	// Okoteve traduccin
#elif L==7	// it
	"Request enrolment/removal of a non-editing teacher"			// Bisogno di traduzione
#elif L==8	// pl
	"Request enrolment/removal of a non-editing teacher"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request enrolment/removal of a non-editing teacher"			// Precisa de traduo
#elif L==10	// tr
	"Request enrolment/removal of a non-editing teacher"			// eviri lazim!
#endif
	,
	[ActReqMdfTch] =
#if   L==1	// ca
	"Request enrolment/removal of a teacher"			// Necessita traducci
#elif L==2	// de
	"Request enrolment/removal of a teacher"			// Need bersetzung
#elif L==3	// en
	"Request enrolment/removal of a teacher"
#elif L==4	// es
	"Solicitar inscripci&oacute;n/eliminaci&oacute;n de profesor"
#elif L==5	// fr
	"Request enrolment/removal of a teacher"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar inscripci&oacute;n/eliminaci&oacute;n de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Request enrolment/removal of a teacher"			// Bisogno di traduzione
#elif L==8	// pl
	"Request enrolment/removal of a teacher"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request enrolment/removal of a teacher"			// Precisa de traduo
#elif L==10	// tr
	"Request enrolment/removal of a teacher"			// eviri lazim!
#endif
	,
	[ActReqTchPho] =
#if   L==1	// ca
	"Edit a teacher's photo"	// Necessita traducci
#elif L==2	// de
	"Edit a teacher's photo"	// Need bersetzung
#elif L==3	// en
	"Edit a teacher's photo"
#elif L==4	// es
	"Editar la foto de profesor"
#elif L==5	// fr
	"Edit a teacher's photo"	// Besoin de traduction
#elif L==6	// gn
	"Editar la foto de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Edit a teacher's photo"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit a teacher's photo"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit a teacher's photo"	// Precisa de traduo
#elif L==10	// tr
	"Edit a teacher's photo"	// eviri lazim!
#endif
	,
	[ActDetTchPho] =
#if   L==1	// ca
	"Send teacher's photo and detect faces on it"		// Necessita traducci
#elif L==2	// de
	"Send teacher's photo and detect faces on it"		// Need bersetzung
#elif L==3	// en
	"Send teacher's photo and detect faces on it"
#elif L==4	// es
	"Enviar la foto de profesor y detectar rostros en ella"
#elif L==5	// fr
	"Send teacher's photo and detect faces on it"		// Besoin de traduction
#elif L==6	// gn
	"Enviar la foto de profesor y detectar rostros en ella"	// Okoteve traduccin
#elif L==7	// it
	"Send teacher's photo and detect faces on it"		// Bisogno di traduzione
#elif L==8	// pl
	"Send teacher's photo and detect faces on it"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send teacher's photo and detect faces on it"		// Precisa de traduo
#elif L==10	// tr
	"Send teacher's photo and detect faces on it"		// eviri lazim!
#endif
	,
	[ActChgTchPho] =
#if   L==1	// ca
	"Update a teacher's photo"		// Necessita traducci
#elif L==2	// de
	"Update a teacher's photo"		// Need bersetzung
#elif L==3	// en
	"Update a teacher's photo"
#elif L==4	// es
	"Actualizar la foto de profesor"
#elif L==5	// fr
	"Update a teacher's photo"		// Besoin de traduction
#elif L==6	// gn
	"Actualizar la foto de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Update a teacher's photo"		// Bisogno di traduzione
#elif L==8	// pl
	"Update a teacher's photo"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Update a teacher's photo"		// Precisa de traduo
#elif L==10	// tr
	"Update a teacher's photo"		// eviri lazim!
#endif
	,
	[ActReqRemTchPho] =
#if   L==1	// ca
	"Request removal of teacher's photo"			// Necessita traducci
#elif L==2	// de
	"Request removal of teacher's photo"			// Need bersetzung
#elif L==3	// en
	"Request removal of teacher's photo"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de foto de profesor"
#elif L==5	// fr
	"Request removal of teacher's photo"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de foto de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of teacher's photo"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of teacher's photo"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of teacher's photo"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of teacher's photo"			// eviri lazim!
#endif
	,
	[ActRemTchPho] =
#if   L==1	// ca
	"Remove teacher's photo"	// Necessita traducci
#elif L==2	// de
	"Remove teacher's photo"	// Need bersetzung
#elif L==3	// en
	"Remove teacher's photo"
#elif L==4	// es
	"Eliminar la foto de profesor"
#elif L==5	// fr
	"Remove teacher's photo"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar la foto de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Remove teacher's photo"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove teacher's photo"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove teacher's photo"	// Precisa de traduo
#elif L==10	// tr
	"Remove teacher's photo"	// eviri lazim!
#endif
	,
	[ActCreNET] =
#if   L==1	// ca
	"Create new non-editing teacher"	// Necessita traducci
#elif L==2	// de
	"Create new non-editing teacher"	// Need bersetzung
#elif L==3	// en
	"Create new non-editing teacher"
#elif L==4	// es
	"Crear nuevo profesor no editor"
#elif L==5	// fr
	"Create new non-editing teacher"	// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo profesor no editor"	// Okoteve traduccin
#elif L==7	// it
	"Create new non-editing teacher"	// Bisogno di traduzione
#elif L==8	// pl
	"Create new non-editing teacher"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new non-editing teacher"	// Precisa de traduo
#elif L==10	// tr
	"Create new non-editing teacher"	// eviri lazim!
#endif
	,
	[ActCreTch] =
#if   L==1	// ca
	"Create new teacher"	// Necessita traducci
#elif L==2	// de
	"Create new teacher"	// Need bersetzung
#elif L==3	// en
	"Create new teacher"
#elif L==4	// es
	"Crear nuevo profesor"
#elif L==5	// fr
	"Create new teacher"	// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo profesor"	// Okoteve traduccin
#elif L==7	// it
	"Create new teacher"	// Bisogno di traduzione
#elif L==8	// pl
	"Create new teacher"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new teacher"	// Precisa de traduo
#elif L==10	// tr
	"Create new teacher"	// eviri lazim!
#endif
	,
	[ActUpdNET] =
#if   L==1	// ca
	"Update a non-editing teacher's data and groups"	// Necessita traducci
#elif L==2	// de
	"Update a non-editing teacher's data and groups"	// Need bersetzung
#elif L==3	// en
	"Update a non-editing teacher's data and groups"
#elif L==4	// es
	"Actualizar los datos y grupos de profesor no editor"
#elif L==5	// fr
	"Update a non-editing teacher's data and groups"	// Besoin de traduction
#elif L==6	// gn
	"Actualizar los datos y grupos de profesor no editor"	// Okoteve traduccin
#elif L==7	// it
	"Update a non-editing teacher's data and groups"	// Bisogno di traduzione
#elif L==8	// pl
	"Update a non-editing teacher's data and groups"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Update a non-editing teacher's data and groups"	// Precisa de traduo
#elif L==10	// tr
	"Update a non-editing teacher's data and groups"	// eviri lazim!
#endif
	,
	[ActUpdTch] =
#if   L==1	// ca
	"Update a teacher's data and groups"		// Necessita traducci
#elif L==2	// de
	"Update a teacher's data and groups"		// Need bersetzung
#elif L==3	// en
	"Update a teacher's data and groups"
#elif L==4	// es
	"Actualizar los datos y grupos de profesor"
#elif L==5	// fr
	"Update a teacher's data and groups"		// Besoin de traduction
#elif L==6	// gn
	"Actualizar los datos y grupos de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Update a teacher's data and groups"		// Bisogno di traduzione
#elif L==8	// pl
	"Update a teacher's data and groups"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Update a teacher's data and groups"		// Precisa de traduo
#elif L==10	// tr
	"Update a teacher's data and groups"		// eviri lazim!
#endif
	,
	[ActCnfID_Tch] =
#if   L==1	// ca
	"Confirm a teacher's ID"	// Necessita traducci
#elif L==2	// de
	"Confirm a teacher's ID"	// Need bersetzung
#elif L==3	// en
	"Confirm a teacher's ID"
#elif L==4	// es
	"Confirmar el ID de profesor"
#elif L==5	// fr
	"Confirm a teacher's ID"	// Besoin de traduction
#elif L==6	// gn
	"Confirmar el ID de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Confirm a teacher's ID"	// Bisogno di traduzione
#elif L==8	// pl
	"Confirm a teacher's ID"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Confirm a teacher's ID"	// Precisa de traduo
#elif L==10	// tr
	"Confirm a teacher's ID"	// eviri lazim!
#endif
	,
	[ActFrmAccTch] =
#if   L==1	// ca
	"Forms to the change a teacher's account"		// Necessita traducci
#elif L==2	// de
	"Forms to the change a teacher's account"		// Need bersetzung
#elif L==3	// en
	"Forms to the change a teacher's account"
#elif L==4	// es
	"Formularios para cambiar la cuenta de profesor"
#elif L==5	// fr
	"Forms to the change a teacher's account"		// Besoin de traduction
#elif L==6	// gn
	"Formularios para cambiar la cuenta de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Forms to the change a teacher's account"		// Bisogno di traduzione
#elif L==8	// pl
	"Forms to the change a teacher's account"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Forms to the change a teacher's account"		// Precisa de traduo
#elif L==10	// tr
	"Forms to the change a teacher's account"		// eviri lazim!
#endif
	,
	[ActRemNicTch] =
#if   L==1	// ca
	"Remove teacher's nickname"	// Necessita traducci
#elif L==2	// de
	"Remove teacher's nickname"	// Need bersetzung
#elif L==3	// en
	"Remove teacher's nickname"
#elif L==4	// es
	"Eliminar apodo de profesor"
#elif L==5	// fr
	"Remove teacher's nickname"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar apodo de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Remove teacher's nickname"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove teacher's nickname"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove teacher's nickname"	// Precisa de traduo
#elif L==10	// tr
	"Remove teacher's nickname"	// eviri lazim!
#endif
	,
	[ActChgNicTch] =
#if   L==1	// ca
	"Change teacher's nickname"	// Necessita traducci
#elif L==2	// de
	"Change teacher's nickname"	// Need bersetzung
#elif L==3	// en
	"Change teacher's nickname"
#elif L==4	// es
	"Cambiar apodo de profesor"
#elif L==5	// fr
	"Change teacher's nickname"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar apodo de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Change teacher's nickname"	// Bisogno di traduzione
#elif L==8	// pl
	"Change teacher's nickname"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change teacher's nickname"	// Precisa de traduo
#elif L==10	// tr
	"Change teacher's nickname"	// eviri lazim!
#endif
	,
	[ActRemID_Tch] =
#if   L==1	// ca
	"Remove teacher's ID"		// Necessita traducci
#elif L==2	// de
	"Remove teacher's ID"		// Need bersetzung
#elif L==3	// en
	"Remove teacher's ID"
#elif L==4	// es
	"Eliminar ID de profesor"
#elif L==5	// fr
	"Remove teacher's ID"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar ID de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Remove teacher's ID"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove teacher's ID"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove teacher's ID"		// Precisa de traduo
#elif L==10	// tr
	"Remove teacher's ID"		// eviri lazim!
#endif
	,
	[ActChgID_Tch] =
#if   L==1	// ca
	"Create new teacher's ID"	// Necessita traducci
#elif L==2	// de
	"Create new teacher's ID"	// Need bersetzung
#elif L==3	// en
	"Create new teacher's ID"
#elif L==4	// es
	"Crear nuevo ID de profesor"
#elif L==5	// fr
	"Create new teacher's ID"	// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo ID de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Create new teacher's ID"	// Bisogno di traduzione
#elif L==8	// pl
	"Create new teacher's ID"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new teacher's ID"	// Precisa de traduo
#elif L==10	// tr
	"Create new teacher's ID"	// eviri lazim!
#endif
	,
	[ActChgPwdTch] =
#if   L==1	// ca
	"Change teacher's password"		// Necessita traducci
#elif L==2	// de
	"Change teacher's password"		// Need bersetzung
#elif L==3	// en
	"Change teacher's password"
#elif L==4	// es
	"Cambiar contrase&ntilde;a de profesor"
#elif L==5	// fr
	"Change teacher's password"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar contrase&ntilde;a de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Change teacher's password"		// Bisogno di traduzione
#elif L==8	// pl
	"Change teacher's password"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change teacher's password"		// Precisa de traduo
#elif L==10	// tr
	"Change teacher's password"		// eviri lazim!
#endif
	,
	[ActRemMaiTch] =
#if   L==1	// ca
	"Remove teacher's email"				// Necessita traducci
#elif L==2	// de
	"Remove teacher's email"				// Need bersetzung
#elif L==3	// en
	"Remove teacher's email"
#elif L==4	// es
	"Eliminar correo electr&oacute;nico de profesor"
#elif L==5	// fr
	"Remove teacher's email"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar correo electr&oacute;nico de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Remove teacher's email"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove teacher's email"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove teacher's email"				// Precisa de traduo
#elif L==10	// tr
	"Remove teacher's email"				// eviri lazim!
#endif
	,
	[ActChgMaiTch] =
#if   L==1	// ca
	"Create new teacher's email"				// Necessita traducci
#elif L==2	// de
	"Create new teacher's email"				// Need bersetzung
#elif L==3	// en
	"Create new teacher's email"
#elif L==4	// es
	"Crear nuevo correo electr&oacute;nico de profesor"
#elif L==5	// fr
	"Create new teacher's email"				// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo correo electr&oacute;nico de profesor"	// Okoteve traduccin
#elif L==7	// it
	"Create new teacher's email"				// Bisogno di traduzione
#elif L==8	// pl
	"Create new teacher's email"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new teacher's email"				// Precisa de traduo
#elif L==10	// tr
	"Create new teacher's email"				// eviri lazim!
#endif
	,
	[ActRemNETCrs] =
#if   L==1	// ca
	"Remove non-editing teacher from a course"	// Necessita traducci
#elif L==2	// de
	"Remove non-editing teacher from a course"	// Need bersetzung
#elif L==3	// en
	"Remove non-editing teacher from a course"
#elif L==4	// es
	"Eliminar profesor no editor de asignatura"
#elif L==5	// fr
	"Remove non-editing teacher from a course"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar profesor no editor de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove non-editing teacher from a course"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove non-editing teacher from a course"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove non-editing teacher from a course"	// Precisa de traduo
#elif L==10	// tr
	"Remove non-editing teacher from a course"	// eviri lazim!
#endif
	,
	[ActRemTchCrs] =
#if   L==1	// ca
	"Remove teacher from a course"		// Necessita traducci
#elif L==2	// de
	"Remove teacher from a course"		// Need bersetzung
#elif L==3	// en
	"Remove teacher from a course"
#elif L==4	// es
	"Eliminar profesor de asignatura"
#elif L==5	// fr
	"Remove teacher from a course"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar profesor de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove teacher from a course"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove teacher from a course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove teacher from a course"		// Precisa de traduo
#elif L==10	// tr
	"Remove teacher from a course"		// eviri lazim!
#endif
	,
	[ActReqAccEnrNET] =
#if   L==1	// ca
	"See whether to accept or reject my enrolment as non-editing teacher"		// Necessita traducci
#elif L==2	// de
	"See whether to accept or reject my enrolment as non-editing teacher"		// Need bersetzung
#elif L==3	// en
	"See whether to accept or reject my enrolment as non-editing teacher"
#elif L==4	// es
	"Ver si aceptar o rechazar mi inscripci&oacute;n como profesor no editor"
#elif L==5	// fr
	"See whether to accept or reject my enrolment as non-editing teacher"		// Besoin de traduction
#elif L==6	// gn
	"Ver si aceptar o rechazar mi inscripci&oacute;n como profesor no editor"	// Okoteve traduccin
#elif L==7	// it
	"See whether to accept or reject my enrolment as non-editing teacher"		// Bisogno di traduzione
#elif L==8	// pl
	"See whether to accept or reject my enrolment as non-editing teacher"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See whether to accept or reject my enrolment as non-editing teacher"		// Precisa de traduo
#elif L==10	// tr
	"See whether to accept or reject my enrolment as non-editing teacher"		// eviri lazim!
#endif
	,
	[ActReqAccEnrTch] =
#if   L==1	// ca
	"See whether to accept or reject my enrolment as teacher"	// Necessita traducci
#elif L==2	// de
	"See whether to accept or reject my enrolment as teacher"	// Need bersetzung
#elif L==3	// en
	"See whether to accept or reject my enrolment as teacher"
#elif L==4	// es
	"Ver si aceptar o rechazar mi inscripci&oacute;n como profesor"
#elif L==5	// fr
	"See whether to accept or reject my enrolment as teacher"	// Besoin de traduction
#elif L==6	// gn
	"Ver si aceptar o rechazar mi inscripci&oacute;n como profesor"	// Okoteve traduccin
#elif L==7	// it
	"See whether to accept or reject my enrolment as teacher"	// Bisogno di traduzione
#elif L==8	// pl
	"See whether to accept or reject my enrolment as teacher"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See whether to accept or reject my enrolment as teacher"	// Precisa de traduo
#elif L==10	// tr
	"See whether to accept or reject my enrolment as teacher"	// eviri lazim!
#endif
	,
	[ActAccEnrNET] =
#if   L==1	// ca
	"Accept my enrolment as non-editing teacher"		// Necessita traducci
#elif L==2	// de
	"Accept my enrolment as non-editing teacher"		// Need bersetzung
#elif L==3	// en
	"Accept my enrolment as non-editing teacher"
#elif L==4	// es
	"Aceptar mi inscripci&oacute;n como profesor no editor"
#elif L==5	// fr
	"Accept my enrolment as non-editing teacher"		// Besoin de traduction
#elif L==6	// gn
	"Aceptar mi inscripci&oacute;n como profesor no editor"	// Okoteve traduccin
#elif L==7	// it
	"Accept my enrolment as non-editing teacher"		// Bisogno di traduzione
#elif L==8	// pl
	"Accept my enrolment as non-editing teacher"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Accept my enrolment as non-editing teacher"		// Precisa de traduo
#elif L==10	// tr
	"Accept my enrolment as non-editing teacher"		// eviri lazim!
#endif
	,
	[ActAccEnrTch] =
#if   L==1	// ca
	"Accept my enrolment as teacher"		// Necessita traducci
#elif L==2	// de
	"Accept my enrolment as teacher"		// Need bersetzung
#elif L==3	// en
	"Accept my enrolment as teacher"
#elif L==4	// es
	"Aceptar mi inscripci&oacute;n como profesor"
#elif L==5	// fr
	"Accept my enrolment as teacher"		// Besoin de traduction
#elif L==6	// gn
	"Aceptar mi inscripci&oacute;n como profesor"	// Okoteve traduccin
#elif L==7	// it
	"Accept my enrolment as teacher"		// Bisogno di traduzione
#elif L==8	// pl
	"Accept my enrolment as teacher"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Accept my enrolment as teacher"		// Precisa de traduo
#elif L==10	// tr
	"Accept my enrolment as teacher"		// eviri lazim!
#endif
	,
	[ActRemMe_NET] =
#if   L==1	// ca
	"Reject my enrolment as non-editing teacher"			// Necessita traducci
#elif L==2	// de
	"Reject my enrolment as non-editing teacher"			// Need bersetzung
#elif L==3	// en
	"Reject my enrolment as non-editing teacher"
#elif L==4	// es
	"Rechazar mi inscripci&oacute;n como profesor no editor"
#elif L==5	// fr
	"Reject my enrolment as non-editing teacher"			// Besoin de traduction
#elif L==6	// gn
	"Rechazar mi inscripci&oacute;n como profesor no editor"	// Okoteve traduccin
#elif L==7	// it
	"Reject my enrolment as non-editing teacher"			// Bisogno di traduzione
#elif L==8	// pl
	"Reject my enrolment as non-editing teacher"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Reject my enrolment as non-editing teacher"			// Precisa de traduo
#elif L==10	// tr
	"Reject my enrolment as non-editing teacher"			// eviri lazim!
#endif
	,
	[ActRemMe_Tch] =
#if   L==1	// ca
	"Reject my enrolment as teacher"		// Necessita traducci
#elif L==2	// de
	"Reject my enrolment as teacher"		// Need bersetzung
#elif L==3	// en
	"Reject my enrolment as teacher"
#elif L==4	// es
	"Rechazar mi inscripci&oacute;n como profesor"
#elif L==5	// fr
	"Reject my enrolment as teacher"		// Besoin de traduction
#elif L==6	// gn
	"Rechazar mi inscripci&oacute;n como profesor"	// Okoteve traduccin
#elif L==7	// it
	"Reject my enrolment as teacher"		// Bisogno di traduzione
#elif L==8	// pl
	"Reject my enrolment as teacher"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Reject my enrolment as teacher"		// Precisa de traduo
#elif L==10	// tr
	"Reject my enrolment as teacher"		// eviri lazim!
#endif
	,
	[ActReqFolSevTch] =
#if   L==1	// ca
	"Request follow several teachers"	// Necessita traducci
#elif L==2	// de
	"Request follow several teachers"	// Need bersetzung
#elif L==3	// en
	"Request follow several teachers"
#elif L==4	// es
	"Solicitar seguir a varios profesores"
#elif L==5	// fr
	"Request follow several teachers"	// Besoin de traduction
#elif L==6	// gn
	"Solicitar seguir a varios profesores"	// Okoteve traduccin
#elif L==7	// it
	"Request follow several teachers"	// Bisogno di traduzione
#elif L==8	// pl
	"Request follow several teachers"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request follow several teachers"	// Precisa de traduo
#elif L==10	// tr
	"Request follow several teachers"	// eviri lazim!
#endif
	,
	[ActReqUnfSevTch] =
#if   L==1	// ca
	"Request unfollow several teachers"		// Necessita traducci
#elif L==2	// de
	"Request unfollow several teachers"		// Need bersetzung
#elif L==3	// en
	"Request unfollow several teachers"
#elif L==4	// es
	"Solicitar dejar de seguir a varios profesores"
#elif L==5	// fr
	"Request unfollow several teachers"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar dejar de seguir a varios profesores"	// Okoteve traduccin
#elif L==7	// it
	"Request unfollow several teachers"		// Bisogno di traduzione
#elif L==8	// pl
	"Request unfollow several teachers"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request unfollow several teachers"		// Precisa de traduo
#elif L==10	// tr
	"Request unfollow several teachers"		// eviri lazim!
#endif
	,
	[ActFolSevTch] =
#if   L==1	// ca
	"Follow several teachers"	// Necessita traducci
#elif L==2	// de
	"Follow several teachers"	// Need bersetzung
#elif L==3	// en
	"Follow several teachers"
#elif L==4	// es
	"Seguir a varios profesores"
#elif L==5	// fr
	"Follow several teachers"	// Besoin de traduction
#elif L==6	// gn
	"Seguir a varios profesores"	// Okoteve traduccin
#elif L==7	// it
	"Follow several teachers"	// Bisogno di traduzione
#elif L==8	// pl
	"Follow several teachers"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Follow several teachers"	// Precisa de traduo
#elif L==10	// tr
	"Follow several teachers"	// eviri lazim!
#endif
	,
	[ActUnfSevTch] =
#if   L==1	// ca
	"Unfollow several teachers"		// Necessita traducci
#elif L==2	// de
	"Unfollow several teachers"		// Need bersetzung
#elif L==3	// en
	"Unfollow several teachers"
#elif L==4	// es
	"Dejar de seguir a varios profesores"
#elif L==5	// fr
	"Unfollow several teachers"		// Besoin de traduction
#elif L==6	// gn
	"Dejar de seguir a varios profesores"	// Okoteve traduccin
#elif L==7	// it
	"Unfollow several teachers"		// Bisogno di traduzione
#elif L==8	// pl
	"Unfollow several teachers"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unfollow several teachers"		// Precisa de traduo
#elif L==10	// tr
	"Unfollow several teachers"		// eviri lazim!
#endif
	,
	[ActSeeRecOneTch] =
#if   L==1	// ca
	"See the record of a teacher"	// Necessita traducci
#elif L==2	// de
	"See the record of a teacher"	// Need bersetzung
#elif L==3	// en
	"See the record of a teacher"
#elif L==4	// es
	"Ver la ficha de profesor"
#elif L==5	// fr
	"See the record of a teacher"	// Besoin de traduction
#elif L==6	// gn
	"Ver la ficha de profesor"	// Okoteve traduccin
#elif L==7	// it
	"See the record of a teacher"	// Bisogno di traduzione
#elif L==8	// pl
	"See the record of a teacher"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the record of a teacher"	// Precisa de traduo
#elif L==10	// tr
	"See the record of a teacher"	// eviri lazim!
#endif
	,
	[ActReqEnrSevNET] =
#if   L==1	// ca
	"Request enrolment/removing of several non-editing teachers to/from a course"				// Necessita traducci
#elif L==2	// de
	"Request enrolment/removing of several non-editing teachers to/from a course"				// Need bersetzung
#elif L==3	// en
	"Request enrolment/removing of several non-editing teachers to/from a course"
#elif L==4	// es
	"Solicitar inscripci&oacute;n/eliminaci&oacute;n de varios profesores no editores a/de un asignatura"
#elif L==5	// fr
	"Request enrolment/removing of several non-editing teachers to/from a course"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar inscripci&oacute;n/eliminaci&oacute;n de varios profesores no editores a/de un asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Request enrolment/removing of several non-editing teachers to/from a course"				// Bisogno di traduzione
#elif L==8	// pl
	"Request enrolment/removing of several non-editing teachers to/from a course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request enrolment/removing of several non-editing teachers to/from a course"				// Precisa de traduo
#elif L==10	// tr
	"Request enrolment/removing of several non-editing teachers to/from a course"				// eviri lazim!
#endif
	,
	[ActRcvFrmEnrSevNET] =
#if   L==1	// ca
	"Register/remove several non-editing teachers in/from a course"		// Necessita traducci
#elif L==2	// de
	"Register/remove several non-editing teachers in/from a course"		// Need bersetzung
#elif L==3	// en
	"Register/remove several non-editing teachers in/from a course"
#elif L==4	// es
	"Inscribir/eliminar varios profesores no editores en/de asignatura"
#elif L==5	// fr
	"Register/remove several non-editing teachers in/from a course"		// Besoin de traduction
#elif L==6	// gn
	"Inscribir/eliminar varios profesores no editores en/de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Register/remove several non-editing teachers in/from a course"		// Bisogno di traduzione
#elif L==8	// pl
	"Register/remove several non-editing teachers in/from a course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Register/remove several non-editing teachers in/from a course"		// Precisa de traduo
#elif L==10	// tr
	"Register/remove several non-editing teachers in/from a course"		// eviri lazim!
#endif
	,
	[ActReqEnrSevTch] =
#if   L==1	// ca
	"Request enrolment/removing of several teachers to/from a course"				// Necessita traducci
#elif L==2	// de
	"Request enrolment/removing of several teachers to/from a course"				// Need bersetzung
#elif L==3	// en
	"Request enrolment/removing of several teachers to/from a course"
#elif L==4	// es
	"Solicitar inscripci&oacute;n/eliminaci&oacute;n de varios profesores a/de un asignatura"
#elif L==5	// fr
	"Request enrolment/removing of several teachers to/from a course"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar inscripci&oacute;n/eliminaci&oacute;n de varios profesores a/de un asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Request enrolment/removing of several teachers to/from a course"				// Bisogno di traduzione
#elif L==8	// pl
	"Request enrolment/removing of several teachers to/from a course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request enrolment/removing of several teachers to/from a course"				// Precisa de traduo
#elif L==10	// tr
	"Request enrolment/removing of several teachers to/from a course"				// eviri lazim!
#endif
	,
	[ActRcvFrmEnrSevTch] =
#if   L==1	// ca
	"Register/remove several teachers in/from a course"	// Necessita traducci
#elif L==2	// de
	"Register/remove several teachers in/from a course"	// Need bersetzung
#elif L==3	// en
	"Register/remove several teachers in/from a course"
#elif L==4	// es
	"Inscribir/eliminar varios profesores en/de asignatura"
#elif L==5	// fr
	"Register/remove several teachers in/from a course"	// Besoin de traduction
#elif L==6	// gn
	"Inscribir/eliminar varios profesores en/de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Register/remove several teachers in/from a course"	// Bisogno di traduzione
#elif L==8	// pl
	"Register/remove several teachers in/from a course"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Register/remove several teachers in/from a course"	// Precisa de traduo
#elif L==10	// tr
	"Register/remove several teachers in/from a course"	// eviri lazim!
#endif
	,
	[ActFrmLogInUsrAgd] =
#if   L==1	// ca
	"See form to log in and see a user's public agenda"					// Necessita traducci
#elif L==2	// de
	"See form to log in and see a user's public agenda"					// Need bersetzung
#elif L==3	// en
	"See form to log in and see a user's public agenda"
#elif L==4	// es
	"Ver formulario para iniciar sesi&oacute;n y ver la agenda p&uacute;blica de usuario"
#elif L==5	// fr
	"See form to log in and see a user's public agenda"					// Besoin de traduction
#elif L==6	// gn
	"Ver formulario para iniciar sesi&oacute;n y ver la agenda p&uacute;blica de usuario"	// Okoteve traduccin
#elif L==7	// it
	"See form to log in and see a user's public agenda"					// Bisogno di traduzione
#elif L==8	// pl
	"See form to log in and see a user's public agenda"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See form to log in and see a user's public agenda"					// Precisa de traduo
#elif L==10	// tr
	"See form to log in and see a user's public agenda"					// eviri lazim!
#endif
	,
	[ActLogInUsrAgd] =
#if   L==1	// ca
	"See a user's public agenda after log in"				// Necessita traducci
#elif L==2	// de
	"See a user's public agenda after log in"				// Need bersetzung
#elif L==3	// en
	"See a user's public agenda after log in"
#elif L==4	// es
	"Ver la agenda p&uacute;blica de usuario tras iniciar sesi&oacute;n"
#elif L==5	// fr
	"See a user's public agenda after log in"				// Besoin de traduction
#elif L==6	// gn
	"Ver la agenda p&uacute;blica de usuario tras iniciar sesi&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See a user's public agenda after log in"				// Bisogno di traduzione
#elif L==8	// pl
	"See a user's public agenda after log in"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See a user's public agenda after log in"				// Precisa de traduo
#elif L==10	// tr
	"See a user's public agenda after log in"				// eviri lazim!
#endif
	,
	[ActLogInUsrAgdLan] =
#if   L==1	// ca
	"See a user's public agenda after change language"		// Necessita traducci
#elif L==2	// de
	"See a user's public agenda after change language"		// Need bersetzung
#elif L==3	// en
	"See a user's public agenda after change language"
#elif L==4	// es
	"Ver la agenda p&uacute;blica de usuario tras cambiar idioma"
#elif L==5	// fr
	"See a user's public agenda after change language"		// Besoin de traduction
#elif L==6	// gn
	"Ver la agenda p&uacute;blica de usuario tras cambiar idioma"	// Okoteve traduccin
#elif L==7	// it
	"See a user's public agenda after change language"		// Bisogno di traduzione
#elif L==8	// pl
	"See a user's public agenda after change language"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See a user's public agenda after change language"		// Precisa de traduo
#elif L==10	// tr
	"See a user's public agenda after change language"		// eviri lazim!
#endif
	,
	[ActLstOth] =
#if   L==1	// ca
	"Show class photo or list of guests"		// Necessita traducci
#elif L==2	// de
	"Show class photo or list of guests"		// Need bersetzung
#elif L==3	// en
	"Show class photo or list of guests"
#elif L==4	// es
	"Mostrar foto de clase o lista de invitados"
#elif L==5	// fr
	"Show class photo or list of guests"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar foto de clase o lista de invitados"	// Okoteve traduccin
#elif L==7	// it
	"Show class photo or list of guests"		// Bisogno di traduzione
#elif L==8	// pl
	"Show class photo or list of guests"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show class photo or list of guests"		// Precisa de traduo
#elif L==10	// tr
	"Show class photo or list of guests"		// eviri lazim!
#endif
	,
	[ActNewAdmIns] =
#if   L==1	// ca
	"Register an administrador in an institution"		// Necessita traducci
#elif L==2	// de
	"Register an administrador in an institution"		// Need bersetzung
#elif L==3	// en
	"Register an administrador in an institution"
#elif L==4	// es
	"Inscribir un administrador en una instituci&oacute;n"
#elif L==5	// fr
	"Register an administrador in an institution"		// Besoin de traduction
#elif L==6	// gn
	"Inscribir un administrador en una instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Register an administrador in an institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Register an administrador in an institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Register an administrador in an institution"		// Precisa de traduo
#elif L==10	// tr
	"Register an administrador in an institution"		// eviri lazim!
#endif
	,
	[ActRemAdmIns] =
#if   L==1	// ca
	"Remove administrador from an institution"	// Necessita traducci
#elif L==2	// de
	"Remove administrador from an institution"	// Need bersetzung
#elif L==3	// en
	"Remove administrador from an institution"
#elif L==4	// es
	"Eliminar administrador de instituci&oacute;n"
#elif L==5	// fr
	"Remove administrador from an institution"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar administrador de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove administrador from an institution"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove administrador from an institution"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove administrador from an institution"	// Precisa de traduo
#elif L==10	// tr
	"Remove administrador from an institution"	// eviri lazim!
#endif
	,
	[ActNewAdmCtr] =
#if   L==1	// ca
	"Register an administrador in a center"		// Necessita traducci
#elif L==2	// de
	"Register an administrador in a center"		// Need bersetzung
#elif L==3	// en
	"Register an administrador in a center"
#elif L==4	// es
	"Inscribir un administrador en un centro"
#elif L==5	// fr
	"Register an administrador in a center"		// Besoin de traduction
#elif L==6	// gn
	"Inscribir un administrador en un centro"	// Okoteve traduccin
#elif L==7	// it
	"Register an administrador in a center"		// Bisogno di traduzione
#elif L==8	// pl
	"Register an administrador in a center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Register an administrador in a center"		// Precisa de traduo
#elif L==10	// tr
	"Register an administrador in a center"		// eviri lazim!
#endif
	,
	[ActRemAdmCtr] =
#if   L==1	// ca
	"Remove administrador from a center"	// Necessita traducci
#elif L==2	// de
	"Remove administrador from a center"	// Need bersetzung
#elif L==3	// en
	"Remove administrador from a center"
#elif L==4	// es
	"Eliminar administrador de centro"
#elif L==5	// fr
	"Remove administrador from a center"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar administrador de centro"	// Okoteve traduccin
#elif L==7	// it
	"Remove administrador from a center"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove administrador from a center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove administrador from a center"	// Precisa de traduo
#elif L==10	// tr
	"Remove administrador from a center"	// eviri lazim!
#endif
	,
	[ActNewAdmDeg] =
#if   L==1	// ca
	"Register an administrador in a degree"			// Necessita traducci
#elif L==2	// de
	"Register an administrador in a degree"			// Need bersetzung
#elif L==3	// en
	"Register an administrador in a degree"
#elif L==4	// es
	"Inscribir un administrador en una titulaci&oacute;n"
#elif L==5	// fr
	"Register an administrador in a degree"			// Besoin de traduction
#elif L==6	// gn
	"Inscribir un administrador en una titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Register an administrador in a degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Register an administrador in a degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Register an administrador in a degree"			// Precisa de traduo
#elif L==10	// tr
	"Register an administrador in a degree"			// eviri lazim!
#endif
	,
	[ActRemAdmDeg] =
#if   L==1	// ca
	"Remove administrador from a degree"			// Necessita traducci
#elif L==2	// de
	"Remove administrador from a degree"			// Need bersetzung
#elif L==3	// en
	"Remove administrador from a degree"
#elif L==4	// es
	"Eliminar administrador en una titulaci&oacute;n"
#elif L==5	// fr
	"Remove administrador from a degree"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar administrador en una titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove administrador from a degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove administrador from a degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove administrador from a degree"			// Precisa de traduo
#elif L==10	// tr
	"Remove administrador from a degree"			// eviri lazim!
#endif
	,
	[ActLstGst] =
#if   L==1	// ca
	"List main data of administrators"		// Necessita traducci
#elif L==2	// de
	"List main data of administrators"		// Need bersetzung
#elif L==3	// en
	"List main data of administrators"
#elif L==4	// es
	"Listar datos principales de administradores"
#elif L==5	// fr
	"List main data of administrators"		// Besoin de traduction
#elif L==6	// gn
	"Listar datos principales de administradores"	// Okoteve traduccin
#elif L==7	// it
	"List main data of administrators"		// Bisogno di traduzione
#elif L==8	// pl
	"List main data of administrators"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List main data of administrators"		// Precisa de traduo
#elif L==10	// tr
	"List main data of administrators"		// eviri lazim!
#endif
	,
	[ActLstGstAll] =
#if   L==1	// ca
	"List the full data of the guests"		// Necessita traducci
#elif L==2	// de
	"List the full data of the guests"		// Need bersetzung
#elif L==3	// en
	"List the full data of the guests"
#elif L==4	// es
	"Listar los datos completos de los invitados"
#elif L==5	// fr
	"List the full data of the guests"		// Besoin de traduction
#elif L==6	// gn
	"Listar los datos completos de los invitados"	// Okoteve traduccin
#elif L==7	// it
	"List the full data of the guests"		// Bisogno di traduzione
#elif L==8	// pl
	"List the full data of the guests"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List the full data of the guests"		// Precisa de traduo
#elif L==10	// tr
	"List the full data of the guests"		// eviri lazim!
#endif
	,
	[ActPrnGstPho] =
#if   L==1	// ca
	"Show class photo of guests ready to be printed"		// Necessita traducci
#elif L==2	// de
	"Show class photo of guests ready to be printed"		// Need bersetzung
#elif L==3	// en
	"Show class photo of guests ready to be printed"
#elif L==4	// es
	"Mostrar foto de clase de invitados lista para imprimir"
#elif L==5	// fr
	"Show class photo of guests ready to be printed"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar foto de clase de invitados lista para imprimir"	// Okoteve traduccin
#elif L==7	// it
	"Show class photo of guests ready to be printed"		// Bisogno di traduzione
#elif L==8	// pl
	"Show class photo of guests ready to be printed"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show class photo of guests ready to be printed"		// Precisa de traduo
#elif L==10	// tr
	"Show class photo of guests ready to be printed"		// eviri lazim!
#endif
	,
	[Act_DoAct_OnSevGst] =
#if   L==1	// ca
	"Do an action on several selected guests"				// Necessita traducci
#elif L==2	// de
	"Do an action on several selected guests"				// Need bersetzung
#elif L==3	// en
	"Do an action on several selected guests"
#elif L==4	// es
	"Realizar una acci&oacute;n sobre varios invitados seleccionados"
#elif L==5	// fr
	"Do an action on several selected guests"				// Besoin de traduction
#elif L==6	// gn
	"Realizar una acci&oacute;n sobre varios invitados seleccionados"	// Okoteve traduccin
#elif L==7	// it
	"Do an action on several selected guests"				// Bisogno di traduzione
#elif L==8	// pl
	"Do an action on several selected guests"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Do an action on several selected guests"				// Precisa de traduo
#elif L==10	// tr
	"Do an action on several selected guests"				// eviri lazim!
#endif
	,
	[ActSeeRecSevGst] =
#if   L==1	// ca
	"See records of several selected guests"	// Necessita traducci
#elif L==2	// de
	"See records of several selected guests"	// Need bersetzung
#elif L==3	// en
	"See records of several selected guests"
#elif L==4	// es
	"Ver fichas de varios invitados seleccionados"
#elif L==5	// fr
	"See records of several selected guests"	// Besoin de traduction
#elif L==6	// gn
	"Ver fichas de varios invitados seleccionados"	// Okoteve traduccin
#elif L==7	// it
	"See records of several selected guests"	// Bisogno di traduzione
#elif L==8	// pl
	"See records of several selected guests"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See records of several selected guests"	// Precisa de traduo
#elif L==10	// tr
	"See records of several selected guests"	// eviri lazim!
#endif
	,
	[ActPrnRecSevGst] =
#if   L==1	// ca
	"See records of several selected guests ready to print"			// Necessita traducci
#elif L==2	// de
	"See records of several selected guests ready to print"			// Need bersetzung
#elif L==3	// en
	"See records of several selected guests ready to print"
#elif L==4	// es
	"Ver fichas de varios invitados seleccionados lista para imprimir"
#elif L==5	// fr
	"See records of several selected guests ready to print"			// Besoin de traduction
#elif L==6	// gn
	"Ver fichas de varios invitados seleccionados lista para imprimir"	// Okoteve traduccin
#elif L==7	// it
	"See records of several selected guests ready to print"			// Bisogno di traduzione
#elif L==8	// pl
	"See records of several selected guests ready to print"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See records of several selected guests ready to print"			// Precisa de traduo
#elif L==10	// tr
	"See records of several selected guests ready to print"			// eviri lazim!
#endif
	,
	[ActReqMdfOneOth] =
#if   L==1	// ca
	"Request a user's ID for enrolment/removal"				// Necessita traducci
#elif L==2	// de
	"Request a user's ID for enrolment/removal"				// Need bersetzung
#elif L==3	// en
	"Request a user's ID for enrolment/removal"
#elif L==4	// es
	"Solicitar el ID de usuario para inscripci&oacute;n/eliminaci&oacute;n"
#elif L==5	// fr
	"Request a user's ID for enrolment/removal"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar el ID de usuario para inscripci&oacute;n/eliminaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request a user's ID for enrolment/removal"				// Bisogno di traduzione
#elif L==8	// pl
	"Request a user's ID for enrolment/removal"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request a user's ID for enrolment/removal"				// Precisa de traduo
#elif L==10	// tr
	"Request a user's ID for enrolment/removal"				// eviri lazim!
#endif
	,
	[ActReqMdfOth] =
#if   L==1	// ca
	"Request enrolment/removal of a user"			// Necessita traducci
#elif L==2	// de
	"Request enrolment/removal of a user"			// Need bersetzung
#elif L==3	// en
	"Request enrolment/removal of a user"
#elif L==4	// es
	"Solicitar inscripcion/eliminaci&oacute;n de usuario"
#elif L==5	// fr
	"Request enrolment/removal of a user"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar inscripcion/eliminaci&oacute;n de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Request enrolment/removal of a user"			// Bisogno di traduzione
#elif L==8	// pl
	"Request enrolment/removal of a user"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request enrolment/removal of a user"			// Precisa de traduo
#elif L==10	// tr
	"Request enrolment/removal of a user"			// eviri lazim!
#endif
	,
	[ActReqOthPho] =
#if   L==1	// ca
	"Edit a user's photo"		// Necessita traducci
#elif L==2	// de
	"Edit a user's photo"		// Need bersetzung
#elif L==3	// en
	"Edit a user's photo"
#elif L==4	// es
	"Editar la foto de usuario"
#elif L==5	// fr
	"Edit a user's photo"		// Besoin de traduction
#elif L==6	// gn
	"Editar la foto de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Edit a user's photo"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit a user's photo"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit a user's photo"		// Precisa de traduo
#elif L==10	// tr
	"Edit a user's photo"		// eviri lazim!
#endif
	,
	[ActDetOthPho] =
#if   L==1	// ca
	"Send user's photo and detect faces on it"		// Necessita traducci
#elif L==2	// de
	"Send user's photo and detect faces on it"		// Need bersetzung
#elif L==3	// en
	"Send user's photo and detect faces on it"
#elif L==4	// es
	"Enviar la foto de usuario y detectar rostros en ella"
#elif L==5	// fr
	"Send user's photo and detect faces on it"		// Besoin de traduction
#elif L==6	// gn
	"Enviar la foto de usuario y detectar rostros en ella"	// Okoteve traduccin
#elif L==7	// it
	"Send user's photo and detect faces on it"		// Bisogno di traduzione
#elif L==8	// pl
	"Send user's photo and detect faces on it"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send user's photo and detect faces on it"		// Precisa de traduo
#elif L==10	// tr
	"Send user's photo and detect faces on it"		// eviri lazim!
#endif
	,
	[ActChgOthPho] =
#if   L==1	// ca
	"Update a user's photo"		// Necessita traducci
#elif L==2	// de
	"Update a user's photo"		// Need bersetzung
#elif L==3	// en
	"Update a user's photo"
#elif L==4	// es
	"Actualizar la foto de usuario"
#elif L==5	// fr
	"Update a user's photo"		// Besoin de traduction
#elif L==6	// gn
	"Actualizar la foto de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Update a user's photo"		// Bisogno di traduzione
#elif L==8	// pl
	"Update a user's photo"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Update a user's photo"		// Precisa de traduo
#elif L==10	// tr
	"Update a user's photo"		// eviri lazim!
#endif
	,
	[ActReqRemOthPho] =
#if   L==1	// ca
	"Request removal of user's photo"			// Necessita traducci
#elif L==2	// de
	"Request removal of user's photo"			// Need bersetzung
#elif L==3	// en
	"Request removal of user's photo"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de foto de usuario"
#elif L==5	// fr
	"Request removal of user's photo"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de foto de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of user's photo"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of user's photo"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of user's photo"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of user's photo"			// eviri lazim!
#endif
	,
	[ActRemOthPho] =
#if   L==1	// ca
	"Remove user's photo"		// Necessita traducci
#elif L==2	// de
	"Remove user's photo"		// Need bersetzung
#elif L==3	// en
	"Remove user's photo"
#elif L==4	// es
	"Eliminar la foto de usuario"
#elif L==5	// fr
	"Remove user's photo"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar la foto de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Remove user's photo"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove user's photo"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove user's photo"		// Precisa de traduo
#elif L==10	// tr
	"Remove user's photo"		// eviri lazim!
#endif
	,
	[ActCreOth] =
#if   L==1	// ca
	"Create new guest"	// Necessita traducci
#elif L==2	// de
	"Create new guest"	// Need bersetzung
#elif L==3	// en
	"Create new guest"
#elif L==4	// es
	"Crear nuevo invitado"
#elif L==5	// fr
	"Create new guest"	// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo invitado"	// Okoteve traduccin
#elif L==7	// it
	"Create new guest"	// Bisogno di traduzione
#elif L==8	// pl
	"Create new guest"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new guest"	// Precisa de traduo
#elif L==10	// tr
	"Create new guest"	// eviri lazim!
#endif
	,
	[ActUpdOth] =
#if   L==1	// ca
	"Update a user's data and groups"		// Necessita traducci
#elif L==2	// de
	"Update a user's data and groups"		// Need bersetzung
#elif L==3	// en
	"Update a user's data and groups"
#elif L==4	// es
	"Actualizar los datos y grupos de usuario"
#elif L==5	// fr
	"Update a user's data and groups"		// Besoin de traduction
#elif L==6	// gn
	"Actualizar los datos y grupos de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Update a user's data and groups"		// Bisogno di traduzione
#elif L==8	// pl
	"Update a user's data and groups"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Update a user's data and groups"		// Precisa de traduo
#elif L==10	// tr
	"Update a user's data and groups"		// eviri lazim!
#endif
	,
	[ActCnfID_Oth] =
#if   L==1	// ca
	"Confirm a user's ID"		// Necessita traducci
#elif L==2	// de
	"Confirm a user's ID"		// Need bersetzung
#elif L==3	// en
	"Confirm a user's ID"
#elif L==4	// es
	"Confirmar el ID de usuario"
#elif L==5	// fr
	"Confirm a user's ID"		// Besoin de traduction
#elif L==6	// gn
	"Confirmar el ID de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Confirm a user's ID"		// Bisogno di traduzione
#elif L==8	// pl
	"Confirm a user's ID"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Confirm a user's ID"		// Precisa de traduo
#elif L==10	// tr
	"Confirm a user's ID"		// eviri lazim!
#endif
	,
	[ActFrmAccOth] =
#if   L==1	// ca
	"Forms to the change a user's account"		// Necessita traducci
#elif L==2	// de
	"Forms to the change a user's account"		// Need bersetzung
#elif L==3	// en
	"Forms to the change a user's account"
#elif L==4	// es
	"Formularios para cambiar la cuenta de usuario"
#elif L==5	// fr
	"Forms to the change a user's account"		// Besoin de traduction
#elif L==6	// gn
	"Formularios para cambiar la cuenta de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Forms to the change a user's account"		// Bisogno di traduzione
#elif L==8	// pl
	"Forms to the change a user's account"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Forms to the change a user's account"		// Precisa de traduo
#elif L==10	// tr
	"Forms to the change a user's account"		// eviri lazim!
#endif
	,
	[ActRemNicOth] =
#if   L==1	// ca
	"Remove user's nickname"	// Necessita traducci
#elif L==2	// de
	"Remove user's nickname"	// Need bersetzung
#elif L==3	// en
	"Remove user's nickname"
#elif L==4	// es
	"Eliminar apodo de usuario"
#elif L==5	// fr
	"Remove user's nickname"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar apodo de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Remove user's nickname"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove user's nickname"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove user's nickname"	// Precisa de traduo
#elif L==10	// tr
	"Remove user's nickname"	// eviri lazim!
#endif
	,
	[ActChgNicOth] =
#if   L==1	// ca
	"Change user's nickname"	// Necessita traducci
#elif L==2	// de
	"Change user's nickname"	// Need bersetzung
#elif L==3	// en
	"Change user's nickname"
#elif L==4	// es
	"Cambiar apodo de usuario"
#elif L==5	// fr
	"Change user's nickname"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar apodo de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Change user's nickname"	// Bisogno di traduzione
#elif L==8	// pl
	"Change user's nickname"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change user's nickname"	// Precisa de traduo
#elif L==10	// tr
	"Change user's nickname"	// eviri lazim!
#endif
	,
	[ActRemID_Oth] =
#if   L==1	// ca
	"Remove user's ID"		// Necessita traducci
#elif L==2	// de
	"Remove user's ID"		// Need bersetzung
#elif L==3	// en
	"Remove user's ID"
#elif L==4	// es
	"Eliminar ID de usuario"
#elif L==5	// fr
	"Remove user's ID"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar ID de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Remove user's ID"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove user's ID"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove user's ID"		// Precisa de traduo
#elif L==10	// tr
	"Remove user's ID"		// eviri lazim!
#endif
	,
	[ActChgID_Oth] =
#if   L==1	// ca
	"Create new user's ID"		// Necessita traducci
#elif L==2	// de
	"Create new user's ID"		// Need bersetzung
#elif L==3	// en
	"Create new user's ID"
#elif L==4	// es
	"Crear nuevo ID de usuario"
#elif L==5	// fr
	"Create new user's ID"		// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo ID de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Create new user's ID"		// Bisogno di traduzione
#elif L==8	// pl
	"Create new user's ID"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new user's ID"		// Precisa de traduo
#elif L==10	// tr
	"Create new user's ID"		// eviri lazim!
#endif
	,
	[ActChgPwdOth] =
#if   L==1	// ca
	"Change user's password"		// Necessita traducci
#elif L==2	// de
	"Change user's password"		// Need bersetzung
#elif L==3	// en
	"Change user's password"
#elif L==4	// es
	"Cambiar contrase&ntilde;a de usuario"
#elif L==5	// fr
	"Change user's password"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar contrase&ntilde;a de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Change user's password"		// Bisogno di traduzione
#elif L==8	// pl
	"Change user's password"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change user's password"		// Precisa de traduo
#elif L==10	// tr
	"Change user's password"		// eviri lazim!
#endif
	,
	[ActRemMaiOth] =
#if   L==1	// ca
	"Remove user's email"				// Necessita traducci
#elif L==2	// de
	"Remove user's email"				// Need bersetzung
#elif L==3	// en
	"Remove user's email"
#elif L==4	// es
	"Eliminar correo electr&oacute;nico de usuario"
#elif L==5	// fr
	"Remove user's email"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar correo electr&oacute;nico de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Remove user's email"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove user's email"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove user's email"				// Precisa de traduo
#elif L==10	// tr
	"Remove user's email"				// eviri lazim!
#endif
	,
	[ActChgMaiOth] =
#if   L==1	// ca
	"Create new user's email"				// Necessita traducci
#elif L==2	// de
	"Create new user's email"				// Need bersetzung
#elif L==3	// en
	"Create new user's email"
#elif L==4	// es
	"Crear nuevo correo electr&oacute;nico de usuario"
#elif L==5	// fr
	"Create new user's email"				// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo correo electr&oacute;nico de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Create new user's email"				// Bisogno di traduzione
#elif L==8	// pl
	"Create new user's email"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new user's email"				// Precisa de traduo
#elif L==10	// tr
	"Create new user's email"				// eviri lazim!
#endif
	,
	[ActRemUsrGbl] =
#if   L==1	// ca
	"Eliminate completely a user from the platform"		// Necessita traducci
#elif L==2	// de
	"Eliminate completely a user from the platform"		// Need bersetzung
#elif L==3	// en
	"Eliminate completely a user from the platform"
#elif L==4	// es
	"Eliminar usuario completamente de la plataforma"
#elif L==5	// fr
	"Eliminate completely a user from the platform"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar usuario completamente de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Eliminate completely a user from the platform"		// Bisogno di traduzione
#elif L==8	// pl
	"Eliminate completely a user from the platform"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Eliminate completely a user from the platform"		// Precisa de traduo
#elif L==10	// tr
	"Eliminate completely a user from the platform"		// eviri lazim!
#endif
	,
	[ActReqRemOldUsr] =
#if   L==1	// ca
	"Request complete elimination of old users"			// Necessita traducci
#elif L==2	// de
	"Request complete elimination of old users"			// Need bersetzung
#elif L==3	// en
	"Request complete elimination of old users"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n completa de usuarios antiguos"
#elif L==5	// fr
	"Request complete elimination of old users"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n completa de usuarios antiguos"	// Okoteve traduccin
#elif L==7	// it
	"Request complete elimination of old users"			// Bisogno di traduzione
#elif L==8	// pl
	"Request complete elimination of old users"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request complete elimination of old users"			// Precisa de traduo
#elif L==10	// tr
	"Request complete elimination of old users"			// eviri lazim!
#endif
	,
	[ActRemOldUsr] =
#if   L==1	// ca
	"Eliminate completely old users"		// Necessita traducci
#elif L==2	// de
	"Eliminate completely old users"		// Need bersetzung
#elif L==3	// en
	"Eliminate completely old users"
#elif L==4	// es
	"Eliminar completamente usuarios antiguos"
#elif L==5	// fr
	"Eliminate completely old users"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar completamente usuarios antiguos"	// Okoteve traduccin
#elif L==7	// it
	"Eliminate completely old users"		// Bisogno di traduzione
#elif L==8	// pl
	"Eliminate completely old users"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Eliminate completely old users"		// Precisa de traduo
#elif L==10	// tr
	"Eliminate completely old users"		// eviri lazim!
#endif
	,
	[ActLstDupUsr] =
#if   L==1	// ca
	"List possible duplicate users"		// Necessita traducci
#elif L==2	// de
	"List possible duplicate users"		// Need bersetzung
#elif L==3	// en
	"List possible duplicate users"
#elif L==4	// es
	"Listar posibles usuarios duplicados"
#elif L==5	// fr
	"List possible duplicate users"		// Besoin de traduction
#elif L==6	// gn
	"Listar posibles usuarios duplicados"	// Okoteve traduccin
#elif L==7	// it
	"List possible duplicate users"		// Bisogno di traduzione
#elif L==8	// pl
	"List possible duplicate users"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List possible duplicate users"		// Precisa de traduo
#elif L==10	// tr
	"List possible duplicate users"		// eviri lazim!
#endif
	,
	[ActLstSimUsr] =
#if   L==1	// ca
	"List users similar to a given one (possible duplicates)"	// Necessita traducci
#elif L==2	// de
	"List users similar to a given one (possible duplicates)"	// Need bersetzung
#elif L==3	// en
	"List users similar to a given one (possible duplicates)"
#elif L==4	// es
	"Listar usuarios similares a uno dado (posibles duplicados)"
#elif L==5	// fr
	"List users similar to a given one (possible duplicates)"	// Besoin de traduction
#elif L==6	// gn
	"Listar usuarios similares a uno dado (posibles duplicados)"	// Okoteve traduccin
#elif L==7	// it
	"List users similar to a given one (possible duplicates)"	// Bisogno di traduzione
#elif L==8	// pl
	"List users similar to a given one (possible duplicates)"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List users similar to a given one (possible duplicates)"	// Precisa de traduo
#elif L==10	// tr
	"List users similar to a given one (possible duplicates)"	// eviri lazim!
#endif
	,
	[ActRemDupUsr] =
#if   L==1	// ca
	"Remove user from a list of possible duplicate users"			// Necessita traducci
#elif L==2	// de
	"Remove user from a list of possible duplicate users"			// Need bersetzung
#elif L==3	// en
	"Remove user from a list of possible duplicate users"
#elif L==4	// es
	"Eliminar a un usuario de una lista de posibles usuarios duplicados"
#elif L==5	// fr
	"Remove user from a list of possible duplicate users"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar a un usuario de una lista de posibles usuarios duplicados"	// Okoteve traduccin
#elif L==7	// it
	"Remove user from a list of possible duplicate users"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove user from a list of possible duplicate users"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove user from a list of possible duplicate users"			// Precisa de traduo
#elif L==10	// tr
	"Remove user from a list of possible duplicate users"			// eviri lazim!
#endif
	,
	[ActSeeAllAtt] =
#if   L==1	// ca
	"Show attendance events"	// Necessita traducci
#elif L==2	// de
	"Show attendance events"	// Need bersetzung
#elif L==3	// en
	"Show attendance events"
#elif L==4	// es
	"Mostrar eventos de asistencia"
#elif L==5	// fr
	"Show attendance events"	// Besoin de traduction
#elif L==6	// gn
	"Mostrar eventos de asistencia"	// Okoteve traduccin
#elif L==7	// it
	"Show attendance events"	// Bisogno di traduzione
#elif L==8	// pl
	"Show attendance events"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show attendance events"	// Precisa de traduo
#elif L==10	// tr
	"Show attendance events"	// eviri lazim!
#endif
	,
	[ActReqLstUsrAtt] =
#if   L==1	// ca
	"Request listing of attendance of several students to several events"		// Necessita traducci
#elif L==2	// de
	"Request listing of attendance of several students to several events"		// Need bersetzung
#elif L==3	// en
	"Request listing of attendance of several students to several events"
#elif L==4	// es
	"Solicitar el listado de asistencia de varios estudiantes a varios eventos"
#elif L==5	// fr
	"Request listing of attendance of several students to several events"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar el listado de asistencia de varios estudiantes a varios eventos"	// Okoteve traduccin
#elif L==7	// it
	"Request listing of attendance of several students to several events"		// Bisogno di traduzione
#elif L==8	// pl
	"Request listing of attendance of several students to several events"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request listing of attendance of several students to several events"		// Precisa de traduo
#elif L==10	// tr
	"Request listing of attendance of several students to several events"		// eviri lazim!
#endif
	,
	[ActSeeLstMyAtt] =
#if   L==1	// ca
	"List my attendance as student to several events"	// Necessita traducci
#elif L==2	// de
	"List my attendance as student to several events"	// Need bersetzung
#elif L==3	// en
	"List my attendance as student to several events"
#elif L==4	// es
	"Listar mi asistencia como estudiante a varios eventos"
#elif L==5	// fr
	"List my attendance as student to several events"	// Besoin de traduction
#elif L==6	// gn
	"Listar mi asistencia como estudiante a varios eventos"	// Okoteve traduccin
#elif L==7	// it
	"List my attendance as student to several events"	// Bisogno di traduzione
#elif L==8	// pl
	"List my attendance as student to several events"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List my attendance as student to several events"	// Precisa de traduo
#elif L==10	// tr
	"List my attendance as student to several events"	// eviri lazim!
#endif
	,
	[ActPrnLstMyAtt] =
#if   L==1	// ca
	"Print my attendance as student to several events"		// Necessita traducci
#elif L==2	// de
	"Print my attendance as student to several events"		// Need bersetzung
#elif L==3	// en
	"Print my attendance as student to several events"
#elif L==4	// es
	"Imprimir mi asistencia como estudiante a varios eventos"
#elif L==5	// fr
	"Print my attendance as student to several events"		// Besoin de traduction
#elif L==6	// gn
	"Imprimir mi asistencia como estudiante a varios eventos"	// Okoteve traduccin
#elif L==7	// it
	"Print my attendance as student to several events"		// Bisogno di traduzione
#elif L==8	// pl
	"Print my attendance as student to several events"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Print my attendance as student to several events"		// Precisa de traduo
#elif L==10	// tr
	"Print my attendance as student to several events"		// eviri lazim!
#endif
	,
	[ActSeeLstUsrAtt] =
#if   L==1	// ca
	"List the attendance of several students to several events"	// Necessita traducci
#elif L==2	// de
	"List the attendance of several students to several events"	// Need bersetzung
#elif L==3	// en
	"List the attendance of several students to several events"
#elif L==4	// es
	"Listar la asistencia de varios estudiantes a varios eventos"
#elif L==5	// fr
	"List the attendance of several students to several events"	// Besoin de traduction
#elif L==6	// gn
	"Listar la asistencia de varios estudiantes a varios eventos"	// Okoteve traduccin
#elif L==7	// it
	"List the attendance of several students to several events"	// Bisogno di traduzione
#elif L==8	// pl
	"List the attendance of several students to several events"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List the attendance of several students to several events"	// Precisa de traduo
#elif L==10	// tr
	"List the attendance of several students to several events"	// eviri lazim!
#endif
	,
	[ActPrnLstUsrAtt] =
#if   L==1	// ca
	"Print attendance of several students to several events"	// Necessita traducci
#elif L==2	// de
	"Print attendance of several students to several events"	// Need bersetzung
#elif L==3	// en
	"Print attendance of several students to several events"
#elif L==4	// es
	"Imprimir la asistencia de varios estudiantes a varios eventos"
#elif L==5	// fr
	"Print attendance of several students to several events"	// Besoin de traduction
#elif L==6	// gn
	"Imprimir la asistencia de varios estudiantes a varios eventos"	// Okoteve traduccin
#elif L==7	// it
	"Print attendance of several students to several events"	// Bisogno di traduzione
#elif L==8	// pl
	"Print attendance of several students to several events"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Print attendance of several students to several events"	// Precisa de traduo
#elif L==10	// tr
	"Print attendance of several students to several events"	// eviri lazim!
#endif
	,
	[ActFrmNewAtt] =
#if   L==1	// ca
	"Edit new attendance event"		// Necessita traducci
#elif L==2	// de
	"Edit new attendance event"		// Need bersetzung
#elif L==3	// en
	"Edit new attendance event"
#elif L==4	// es
	"Editar nuevo evento de asistencia"
#elif L==5	// fr
	"Edit new attendance event"		// Besoin de traduction
#elif L==6	// gn
	"Editar nuevo evento de asistencia"	// Okoteve traduccin
#elif L==7	// it
	"Edit new attendance event"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit new attendance event"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new attendance event"		// Precisa de traduo
#elif L==10	// tr
	"Edit new attendance event"		// eviri lazim!
#endif
	,
	[ActEdiOneAtt] =
#if   L==1	// ca
	"Edit one attendance event"	// Necessita traducci
#elif L==2	// de
	"Edit one attendance event"	// Need bersetzung
#elif L==3	// en
	"Edit one attendance event"
#elif L==4	// es
	"Editar evento de asistencia"
#elif L==5	// fr
	"Edit one attendance event"	// Besoin de traduction
#elif L==6	// gn
	"Editar evento de asistencia"	// Okoteve traduccin
#elif L==7	// it
	"Edit one attendance event"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit one attendance event"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit one attendance event"	// Precisa de traduo
#elif L==10	// tr
	"Edit one attendance event"	// eviri lazim!
#endif
	,
	[ActNewAtt] =
#if   L==1	// ca
	"Crear esdeveniment d'assist&egrave;ncia"
#elif L==2	// de
	"Pr&auml;senzveranstaltung erstellen"
#elif L==3	// en
	"Create attendance event"
#elif L==4	// es
	"Crear evento de asistencia"
#elif L==5	// fr
	"Cr&eacute;er &eacute;v&eacute;nement de pr&eacute;sence"
#elif L==6	// gn
	"Omohe&ntilde;&oacute;i evento de asistencia"
#elif L==7	// it
	"Creare evento di partecipazione"
#elif L==8	// pl
	"Utw&oacute;rz wydarzenie obecno&sacute;ci"
#elif L==9	// pt
	"Criar evento de participa&ccedil;&atilde;o"
#elif L==10	// tr
	"Kat&inodot;l&inodot;m etkinli&gbreve;i olu&scedil;tur"
#endif
	,
	[ActChgAtt] =
#if   L==1	// ca
	"Change an attendance event"		// Necessita traducci
#elif L==2	// de
	"Change an attendance event"		// Need bersetzung
#elif L==3	// en
	"Change an attendance event"
#elif L==4	// es
	"Cambiar un evento de asistencia"
#elif L==5	// fr
	"Change an attendance event"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar un evento de asistencia"	// Okoteve traduccin
#elif L==7	// it
	"Change an attendance event"		// Bisogno di traduzione
#elif L==8	// pl
	"Change an attendance event"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change an attendance event"		// Precisa de traduo
#elif L==10	// tr
	"Change an attendance event"		// eviri lazim!
#endif
	,
	[ActReqRemAtt] =
#if   L==1	// ca
	"Request removal of attendance event"			// Necessita traducci
#elif L==2	// de
	"Request removal of attendance event"			// Need bersetzung
#elif L==3	// en
	"Request removal of attendance event"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de evento de asistencia"
#elif L==5	// fr
	"Request removal of attendance event"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de evento de asistencia"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of attendance event"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of attendance event"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of attendance event"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of attendance event"			// eviri lazim!
#endif
	,
	[ActRemAtt] =
#if   L==1	// ca
	"Remove attendance event"	// Necessita traducci
#elif L==2	// de
	"Remove attendance event"	// Need bersetzung
#elif L==3	// en
	"Remove attendance event"
#elif L==4	// es
	"Eliminar evento de asistencia"
#elif L==5	// fr
	"Remove attendance event"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar evento de asistencia"	// Okoteve traduccin
#elif L==7	// it
	"Remove attendance event"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove attendance event"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove attendance event"	// Precisa de traduo
#elif L==10	// tr
	"Remove attendance event"	// eviri lazim!
#endif
	,
	[ActHidAtt] =
#if   L==1	// ca
	"Hide attendance event"			// Necessita traducci
#elif L==2	// de
	"Hide attendance event"			// Need bersetzung
#elif L==3	// en
	"Hide attendance event"
#elif L==4	// es
	"Ocultar un evento de asistencia"
#elif L==5	// fr
	"Hide attendance event"			// Besoin de traduction
#elif L==6	// gn
	"Ocultar un evento de asistencia"	// Okoteve traduccin
#elif L==7	// it
	"Hide attendance event"			// Bisogno di traduzione
#elif L==8	// pl
	"Hide attendance event"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide attendance event"			// Precisa de traduo
#elif L==10	// tr
	"Hide attendance event"			// eviri lazim!
#endif
	,
	[ActUnhAtt] =
#if   L==1	// ca
	"Unhide attendance event"	// Necessita traducci
#elif L==2	// de
	"Unhide attendance event"	// Need bersetzung
#elif L==3	// en
	"Unhide attendance event"
#elif L==4	// es
	"Mostrar evento de asistencia"
#elif L==5	// fr
	"Unhide attendance event"	// Besoin de traduction
#elif L==6	// gn
	"Mostrar evento de asistencia"	// Okoteve traduccin
#elif L==7	// it
	"Unhide attendance event"	// Bisogno di traduzione
#elif L==8	// pl
	"Unhide attendance event"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide attendance event"	// Precisa de traduo
#elif L==10	// tr
	"Unhide attendance event"	// eviri lazim!
#endif
	,
	[ActSeeOneAtt] =
#if   L==1	// ca
	"List students who attended to an event"	// Necessita traducci
#elif L==2	// de
	"List students who attended to an event"	// Need bersetzung
#elif L==3	// en
	"List students who attended to an event"
#elif L==4	// es
	"Listar estudiantes que asistieron a un evento"
#elif L==5	// fr
	"List students who attended to an event"	// Besoin de traduction
#elif L==6	// gn
	"Listar estudiantes que asistieron a un evento"	// Okoteve traduccin
#elif L==7	// it
	"List students who attended to an event"	// Bisogno di traduzione
#elif L==8	// pl
	"List students who attended to an event"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List students who attended to an event"	// Precisa de traduo
#elif L==10	// tr
	"List students who attended to an event"	// eviri lazim!
#endif
	,
	[ActReqLnkAtt] =
#if   L==1	// ca
	"Copy link to attendance event"		// Necessita traducci
#elif L==2	// de
	"Copy link to attendance event"		// Need bersetzung
#elif L==3	// en
	"Copy link to attendance event"
#elif L==4	// es
	"Copiar enlace a evento de asistencia"
#elif L==5	// fr
	"Copy link to attendance event"		// Besoin de traduction
#elif L==6	// gn
	"Copiar enlace a evento de asistencia"	// Okoteve traduccin
#elif L==7	// it
	"Copy link to attendance event"		// Bisogno di traduzione
#elif L==8	// pl
	"Copy link to attendance event"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Copy link to attendance event"		// Precisa de traduo
#elif L==10	// tr
	"Copy link to attendance event"		// eviri lazim!
#endif
	,
	[ActRecAttStd] =
#if   L==1	// ca
	"Save students who attended to an event and comments"		// Necessita traducci
#elif L==2	// de
	"Save students who attended to an event and comments"		// Need bersetzung
#elif L==3	// en
	"Save students who attended to an event and comments"
#elif L==4	// es
	"Guardar estudiantes que asistieron a un evento y comentarios"
#elif L==5	// fr
	"Save students who attended to an event and comments"		// Besoin de traduction
#elif L==6	// gn
	"Guardar estudiantes que asistieron a un evento y comentarios"	// Okoteve traduccin
#elif L==7	// it
	"Save students who attended to an event and comments"		// Bisogno di traduzione
#elif L==8	// pl
	"Save students who attended to an event and comments"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Save students who attended to an event and comments"		// Precisa de traduo
#elif L==10	// tr
	"Save students who attended to an event and comments"		// eviri lazim!
#endif
	,
	[ActRecAttMe] =
#if   L==1	// ca
	"Save my comments as student in an attendance event"			// Necessita traducci
#elif L==2	// de
	"Save my comments as student in an attendance event"			// Need bersetzung
#elif L==3	// en
	"Save my comments as student in an attendance event"
#elif L==4	// es
	"Guardar mis comentarios como estudiante en un evento de asistencia"
#elif L==5	// fr
	"Save my comments as student in an attendance event"			// Besoin de traduction
#elif L==6	// gn
	"Guardar mis comentarios como estudiante en un evento de asistencia"	// Okoteve traduccin
#elif L==7	// it
	"Save my comments as student in an attendance event"			// Bisogno di traduzione
#elif L==8	// pl
	"Save my comments as student in an attendance event"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Save my comments as student in an attendance event"			// Precisa de traduo
#elif L==10	// tr
	"Save my comments as student in an attendance event"			// eviri lazim!
#endif
	,
	[ActReqSignUp] =
#if   L==1	// ca
	"Request applying for my enrolment"		// Necessita traducci
#elif L==2	// de
	"Request applying for my enrolment"		// Need bersetzung
#elif L==3	// en
	"Request applying for my enrolment"
#elif L==4	// es
	"Formulario para solicitar mi inscripci&oacute;n"
#elif L==5	// fr
	"Request applying for my enrolment"		// Besoin de traduction
#elif L==6	// gn
	"Formulario para solicitar mi inscripci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request applying for my enrolment"		// Bisogno di traduzione
#elif L==8	// pl
	"Request applying for my enrolment"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request applying for my enrolment"		// Precisa de traduo
#elif L==10	// tr
	"Request applying for my enrolment"		// eviri lazim!
#endif
	,
	[ActSignUp] =
#if   L==1	// ca
	"Apply for my enrolment"		// Necessita traducci
#elif L==2	// de
	"Apply for my enrolment"		// Need bersetzung
#elif L==3	// en
	"Apply for my enrolment"
#elif L==4	// es
	"Solicitar mi inscripci&oacute;n"
#elif L==5	// fr
	"Apply for my enrolment"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar mi inscripci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Apply for my enrolment"		// Bisogno di traduzione
#elif L==8	// pl
	"Apply for my enrolment"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Apply for my enrolment"		// Precisa de traduo
#elif L==10	// tr
	"Apply for my enrolment"		// eviri lazim!
#endif
	,
	[ActSeeSignUpReq] =
#if   L==1	// ca
	"Show pending requests for inscription in the current course"			// Necessita traducci
#elif L==2	// de
	"Show pending requests for inscription in the current course"			// Need bersetzung
#elif L==3	// en
	"Show pending requests for inscription in the current course"
#elif L==4	// es
	"Mostrar solicitudes de inscripci&oacute;n pendientes en la asignatura actual"
#elif L==5	// fr
	"Show pending requests for inscription in the current course"			// Besoin de traduction
#elif L==6	// gn
	"Mostrar solicitudes de inscripci&oacute;n pendientes en la asignatura actual"	// Okoteve traduccin
#elif L==7	// it
	"Show pending requests for inscription in the current course"			// Bisogno di traduzione
#elif L==8	// pl
	"Show pending requests for inscription in the current course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show pending requests for inscription in the current course"			// Precisa de traduo
#elif L==10	// tr
	"Show pending requests for inscription in the current course"			// eviri lazim!
#endif
	,
	[ActUpdSignUpReq] =
#if   L==1	// ca
	"Update pending requests for inscription"			// Necessita traducci
#elif L==2	// de
	"Update pending requests for inscription"			// Need bersetzung
#elif L==3	// en
	"Update pending requests for inscription"
#elif L==4	// es
	"Actualizar solicitudes de inscripci&oacute;n pendientes"
#elif L==5	// fr
	"Update pending requests for inscription"			// Besoin de traduction
#elif L==6	// gn
	"Actualizar solicitudes de inscripci&oacute;n pendientes"	// Okoteve traduccin
#elif L==7	// it
	"Update pending requests for inscription"			// Bisogno di traduzione
#elif L==8	// pl
	"Update pending requests for inscription"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Update pending requests for inscription"			// Precisa de traduo
#elif L==10	// tr
	"Update pending requests for inscription"			// eviri lazim!
#endif
	,
	[ActReqRejSignUp] =
#if   L==1	// ca
	"Request rejection of a user's enrolment"			// Necessita traducci
#elif L==2	// de
	"Request rejection of a user's enrolment"			// Need bersetzung
#elif L==3	// en
	"Request rejection of a user's enrolment"
#elif L==4	// es
	"Solicitar el rechazo a la inscripci&oacute;n de usuario"
#elif L==5	// fr
	"Request rejection of a user's enrolment"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar el rechazo a la inscripci&oacute;n de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Request rejection of a user's enrolment"			// Bisogno di traduzione
#elif L==8	// pl
	"Request rejection of a user's enrolment"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request rejection of a user's enrolment"			// Precisa de traduo
#elif L==10	// tr
	"Request rejection of a user's enrolment"			// eviri lazim!
#endif
	,
	[ActRejSignUp] =
#if   L==1	// ca
	"Reject the enrolment"			// Necessita traducci
#elif L==2	// de
	"Reject the enrolment"			// Need bersetzung
#elif L==3	// en
	"Reject the enrolment"
#elif L==4	// es
	"Rechazar la inscripci&oacute;n"
#elif L==5	// fr
	"Reject the enrolment"			// Besoin de traduction
#elif L==6	// gn
	"Rechazar la inscripci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Reject the enrolment"			// Bisogno di traduzione
#elif L==8	// pl
	"Reject the enrolment"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Reject the enrolment"			// Precisa de traduo
#elif L==10	// tr
	"Reject the enrolment"			// eviri lazim!
#endif
	,
	[ActLstCon] =
#if   L==1	// ca
	"List connected users"		// Necessita traducci
#elif L==2	// de
	"List connected users"		// Need bersetzung
#elif L==3	// en
	"List connected users"
#elif L==4	// es
	"Listar usuarios conectados"
#elif L==5	// fr
	"List connected users"		// Besoin de traduction
#elif L==6	// gn
	"Listar usuarios conectados"	// Okoteve traduccin
#elif L==7	// it
	"List connected users"		// Bisogno di traduzione
#elif L==8	// pl
	"List connected users"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List connected users"		// Precisa de traduo
#elif L==10	// tr
	"List connected users"		// eviri lazim!
#endif
	,
	[ActSeeAnn] =
#if   L==1	// ca
	"Show global announcements"	// Necessita traducci
#elif L==2	// de
	"Show global announcements"	// Need bersetzung
#elif L==3	// en
	"Show global announcements"
#elif L==4	// es
	"Mostrar anuncios globales"
#elif L==5	// fr
	"Show global announcements"	// Besoin de traduction
#elif L==6	// gn
	"Mostrar anuncios globales"	// Okoteve traduccin
#elif L==7	// it
	"Show global announcements"	// Bisogno di traduzione
#elif L==8	// pl
	"Show global announcements"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show global announcements"	// Precisa de traduo
#elif L==10	// tr
	"Show global announcements"	// eviri lazim!
#endif
	,
	[ActWriAnn] =
#if   L==1	// ca
	"See form to create a new global announcement"		// Necessita traducci
#elif L==2	// de
	"See form to create a new global announcement"		// Need bersetzung
#elif L==3	// en
	"See form to create a new global announcement"
#elif L==4	// es
	"Ver formulario para crear un nuevo anuncio global"
#elif L==5	// fr
	"See form to create a new global announcement"		// Besoin de traduction
#elif L==6	// gn
	"Ver formulario para crear un nuevo anuncio global"	// Okoteve traduccin
#elif L==7	// it
	"See form to create a new global announcement"		// Bisogno di traduzione
#elif L==8	// pl
	"See form to create a new global announcement"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See form to create a new global announcement"		// Precisa de traduo
#elif L==10	// tr
	"See form to create a new global announcement"		// eviri lazim!
#endif
	,
	[ActNewAnn] =
#if   L==1	// ca
	"Crear anunci"
#elif L==2	// de
	"Erstelle Bekanntmachung"
#elif L==3	// en
	"Create announcement"
#elif L==4	// es
	"Crear anuncio"
#elif L==5	// fr
	"Cr&eacute;er annonce"
#elif L==6	// gn
	"Omohe&ntilde;&oacute;i anuncio"
#elif L==7	// it
	"Creare annuncio"
#elif L==8	// pl
	"Stw&oacute;rz og&lstrok;oszenia"
#elif L==9	// pt
	"Criar an&uacute;ncio"
#elif L==10	// tr
	"Duyuru olu&scedil;tur"
#endif
	,
	[ActHidAnn] =
#if   L==1	// ca
	"Hide global announcement"	// Necessita traducci
#elif L==2	// de
	"Hide global announcement"	// Need bersetzung
#elif L==3	// en
	"Hide global announcement"
#elif L==4	// es
	"Ocultar un anuncio global"
#elif L==5	// fr
	"Hide global announcement"	// Besoin de traduction
#elif L==6	// gn
	"Ocultar un anuncio global"	// Okoteve traduccin
#elif L==7	// it
	"Hide global announcement"	// Bisogno di traduzione
#elif L==8	// pl
	"Hide global announcement"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide global announcement"	// Precisa de traduo
#elif L==10	// tr
	"Hide global announcement"	// eviri lazim!
#endif
	,
	[ActUnhAnn] =
#if   L==1	// ca
	"Unhide global announcement"	// Necessita traducci
#elif L==2	// de
	"Unhide global announcement"	// Need bersetzung
#elif L==3	// en
	"Unhide global announcement"
#elif L==4	// es
	"Mostrar anuncio global"
#elif L==5	// fr
	"Unhide global announcement"	// Besoin de traduction
#elif L==6	// gn
	"Mostrar anuncio global"	// Okoteve traduccin
#elif L==7	// it
	"Unhide global announcement"	// Bisogno di traduzione
#elif L==8	// pl
	"Unhide global announcement"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide global announcement"	// Precisa de traduo
#elif L==10	// tr
	"Unhide global announcement"	// eviri lazim!
#endif
	,
	[ActRemAnn] =
#if   L==1	// ca
	"Remove global announcement"	// Necessita traducci
#elif L==2	// de
	"Remove global announcement"	// Need bersetzung
#elif L==3	// en
	"Remove global announcement"
#elif L==4	// es
	"Eliminar anuncio global"
#elif L==5	// fr
	"Remove global announcement"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar anuncio global"	// Okoteve traduccin
#elif L==7	// it
	"Remove global announcement"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove global announcement"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove global announcement"	// Precisa de traduo
#elif L==10	// tr
	"Remove global announcement"	// eviri lazim!
#endif
	,
	[ActSeeAllNot] =
#if   L==1	// ca
	"See notices"	// Necessita traducci
#elif L==2	// de
	"See notices"	// Need bersetzung
#elif L==3	// en
	"See notices"
#elif L==4	// es
	"Ver avisos"
#elif L==5	// fr
	"See notices"	// Besoin de traduction
#elif L==6	// gn
	"Ver avisos"	// Okoteve traduccin
#elif L==7	// it
	"See notices"	// Bisogno di traduzione
#elif L==8	// pl
	"See notices"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See notices"	// Precisa de traduo
#elif L==10	// tr
	"See notices"	// eviri lazim!
#endif
	,
	[ActSeeOneNot] =
#if   L==1	// ca
	"Show (expand) a notice"	// Necessita traducci
#elif L==2	// de
	"Show (expand) a notice"	// Need bersetzung
#elif L==3	// en
	"Show (expand) a notice"
#elif L==4	// es
	"Mostrar (expandir) un aviso"
#elif L==5	// fr
	"Show (expand) a notice"	// Besoin de traduction
#elif L==6	// gn
	"Mostrar (expandir) un aviso"	// Okoteve traduccin
#elif L==7	// it
	"Show (expand) a notice"	// Bisogno di traduzione
#elif L==8	// pl
	"Show (expand) a notice"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show (expand) a notice"	// Precisa de traduo
#elif L==10	// tr
	"Show (expand) a notice"	// eviri lazim!
#endif
	,
	[ActWriNot] =
#if   L==1	// ca
	"Write a new notice"		// Necessita traducci
#elif L==2	// de
	"Write a new notice"		// Need bersetzung
#elif L==3	// en
	"Write a new notice"
#elif L==4	// es
	"Escribir un nuevo aviso"
#elif L==5	// fr
	"Write a new notice"		// Besoin de traduction
#elif L==6	// gn
	"Escribir un nuevo aviso"	// Okoteve traduccin
#elif L==7	// it
	"Write a new notice"		// Bisogno di traduzione
#elif L==8	// pl
	"Write a new notice"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Write a new notice"		// Precisa de traduo
#elif L==10	// tr
	"Write a new notice"		// eviri lazim!
#endif
	,
	[ActNewNot] =
#if   L==1	// ca
	"Crear av&iacute;s"
#elif L==2	// de
	"Erstelle Ank&uuml;ndigung"
#elif L==3	// en
	"Create notice"
#elif L==4	// es
	"Crear aviso"
#elif L==5	// fr
	"Cr&eacute;er avis"
#elif L==6	// gn
	"Crear aviso"	// Okoteve traduccin
#elif L==7	// it
	"Creare avviso"
#elif L==8	// pl
	"Utw&oacute;rz powiadomienie"
#elif L==9	// pt
	"Criar aviso"
#elif L==10	// tr
	"Create notice"	// eviri lazim!
#endif
	,
	[ActHidNot] =
#if   L==1	// ca
	"Hide notice"		// Necessita traducci
#elif L==2	// de
	"Hide notice"		// Need bersetzung
#elif L==3	// en
	"Hide notice"
#elif L==4	// es
	"Ocultar un aviso"
#elif L==5	// fr
	"Hide notice"		// Besoin de traduction
#elif L==6	// gn
	"Ocultar un aviso"	// Okoteve traduccin
#elif L==7	// it
	"Hide notice"		// Bisogno di traduzione
#elif L==8	// pl
	"Hide notice"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide notice"		// Precisa de traduo
#elif L==10	// tr
	"Hide notice"		// eviri lazim!
#endif
	,
	[ActUnhNot] =
#if   L==1	// ca
	"Unhide notice"	// Necessita traducci
#elif L==2	// de
	"Unhide notice"	// Need bersetzung
#elif L==3	// en
	"Unhide notice"
#elif L==4	// es
	"Mostrar aviso"
#elif L==5	// fr
	"Unhide notice"	// Besoin de traduction
#elif L==6	// gn
	"Mostrar aviso"	// Okoteve traduccin
#elif L==7	// it
	"Unhide notice"	// Bisogno di traduzione
#elif L==8	// pl
	"Unhide notice"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide notice"	// Precisa de traduo
#elif L==10	// tr
	"Unhide notice"	// eviri lazim!
#endif
	,
	[ActReqRemNot] =
#if   L==1	// ca
	"Request removal of notice"		// Necessita traducci
#elif L==2	// de
	"Request removal of notice"		// Need bersetzung
#elif L==3	// en
	"Request removal of notice"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de aviso"
#elif L==5	// fr
	"Request removal of notice"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de aviso"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of notice"		// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of notice"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of notice"		// Precisa de traduo
#elif L==10	// tr
	"Request removal of notice"		// eviri lazim!
#endif
	,
	[ActRemNot] =
#if   L==1	// ca
	"Remove notice"		// Necessita traducci
#elif L==2	// de
	"Remove notice"		// Need bersetzung
#elif L==3	// en
	"Remove notice"
#elif L==4	// es
	"Eliminar aviso"
#elif L==5	// fr
	"Remove notice"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar aviso"	// Okoteve traduccin
#elif L==7	// it
	"Remove notice"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove notice"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove notice"		// Precisa de traduo
#elif L==10	// tr
	"Remove notice"		// eviri lazim!
#endif
	,
	[ActSeeFor] =
#if   L==1	// ca
	"See the top level of the forums"	// Necessita traducci
#elif L==2	// de
	"See the top level of the forums"	// Need bersetzung
#elif L==3	// en
	"See the top level of the forums"
#elif L==4	// es
	"Ver el nivel superior de los foros"
#elif L==5	// fr
	"See the top level of the forums"	// Besoin de traduction
#elif L==6	// gn
	"Ver el nivel superior de los foros"	// Okoteve traduccin
#elif L==7	// it
	"See the top level of the forums"	// Bisogno di traduzione
#elif L==8	// pl
	"See the top level of the forums"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the top level of the forums"	// Precisa de traduo
#elif L==10	// tr
	"See the top level of the forums"	// eviri lazim!
#endif
	,
	[ActSeeForCrsUsr] =
#if   L==1	// ca
	"See top level of forum of users of course"			// Necessita traducci
#elif L==2	// de
	"See top level of forum of users of course"			// Need bersetzung
#elif L==3	// en
	"See top level of forum of users of course"
#elif L==4	// es
	"Ver el nivel superior del foro de usuarios de asignatura"
#elif L==5	// fr
	"See top level of forum of users of course"			// Besoin de traduction
#elif L==6	// gn
	"Ver el nivel superior del foro de usuarios de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See top level of forum of users of course"			// Bisogno di traduzione
#elif L==8	// pl
	"See top level of forum of users of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See top level of forum of users of course"			// Precisa de traduo
#elif L==10	// tr
	"See top level of forum of users of course"			// eviri lazim!
#endif
	,
	[ActSeeForCrsTch] =
#if   L==1	// ca
	"See top level of forum of teachers of course"			// Necessita traducci
#elif L==2	// de
	"See top level of forum of teachers of course"			// Need bersetzung
#elif L==3	// en
	"See top level of forum of teachers of course"
#elif L==4	// es
	"Ver el nivel superior del foro de profesores de asignatura"
#elif L==5	// fr
	"See top level of forum of teachers of course"			// Besoin de traduction
#elif L==6	// gn
	"Ver el nivel superior del foro de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See top level of forum of teachers of course"			// Bisogno di traduzione
#elif L==8	// pl
	"See top level of forum of teachers of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See top level of forum of teachers of course"			// Precisa de traduo
#elif L==10	// tr
	"See top level of forum of teachers of course"			// eviri lazim!
#endif
	,
	[ActSeeForDegUsr] =
#if   L==1	// ca
	"See top level of forum of users of degree"				// Necessita traducci
#elif L==2	// de
	"See top level of forum of users of degree"				// Need bersetzung
#elif L==3	// en
	"See top level of forum of users of degree"
#elif L==4	// es
	"Ver el nivel superior del foro de usuarios de titulaci&oacute;n"
#elif L==5	// fr
	"See top level of forum of users of degree"				// Besoin de traduction
#elif L==6	// gn
	"Ver el nivel superior del foro de usuarios de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See top level of forum of users of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"See top level of forum of users of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See top level of forum of users of degree"				// Precisa de traduo
#elif L==10	// tr
	"See top level of forum of users of degree"				// eviri lazim!
#endif
	,
	[ActSeeForDegTch] =
#if   L==1	// ca
	"See top level of forum of teachers of degree"				// Necessita traducci
#elif L==2	// de
	"See top level of forum of teachers of degree"				// Need bersetzung
#elif L==3	// en
	"See top level of forum of teachers of degree"
#elif L==4	// es
	"Ver el nivel superior del foro de profesores de titulaci&oacute;n"
#elif L==5	// fr
	"See top level of forum of teachers of degree"				// Besoin de traduction
#elif L==6	// gn
	"Ver el nivel superior del foro de profesores de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See top level of forum of teachers of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"See top level of forum of teachers of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See top level of forum of teachers of degree"				// Precisa de traduo
#elif L==10	// tr
	"See top level of forum of teachers of degree"				// eviri lazim!
#endif
	,
	[ActSeeForCtrUsr] =
#if   L==1	// ca
	"See top level of forum of users of center"		// Necessita traducci
#elif L==2	// de
	"See top level of forum of users of center"		// Need bersetzung
#elif L==3	// en
	"See top level of forum of users of center"
#elif L==4	// es
	"Ver el nivel superior del foro de usuarios de centro"
#elif L==5	// fr
	"See top level of forum of users of center"		// Besoin de traduction
#elif L==6	// gn
	"Ver el nivel superior del foro de usuarios de centro"	// Okoteve traduccin
#elif L==7	// it
	"See top level of forum of users of center"		// Bisogno di traduzione
#elif L==8	// pl
	"See top level of forum of users of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See top level of forum of users of center"		// Precisa de traduo
#elif L==10	// tr
	"See top level of forum of users of center"		// eviri lazim!
#endif
	,
	[ActSeeForCtrTch] =
#if   L==1	// ca
	"See top level of forum of teachers of center"			// Necessita traducci
#elif L==2	// de
	"See top level of forum of teachers of center"			// Need bersetzung
#elif L==3	// en
	"See top level of forum of teachers of center"
#elif L==4	// es
	"Ver el nivel superior del foro de profesores de centro"
#elif L==5	// fr
	"See top level of forum of teachers of center"			// Besoin de traduction
#elif L==6	// gn
	"Ver el nivel superior del foro de profesores de centro"	// Okoteve traduccin
#elif L==7	// it
	"See top level of forum of teachers of center"			// Bisogno di traduzione
#elif L==8	// pl
	"See top level of forum of teachers of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See top level of forum of teachers of center"			// Precisa de traduo
#elif L==10	// tr
	"See top level of forum of teachers of center"			// eviri lazim!
#endif
	,
	[ActSeeForInsUsr] =
#if   L==1	// ca
	"See top level of forum of users of institution"			// Necessita traducci
#elif L==2	// de
	"See top level of forum of users of institution"			// Need bersetzung
#elif L==3	// en
	"See top level of forum of users of institution"
#elif L==4	// es
	"Ver el nivel superior del foro de usuarios de instituci&oacute;n"
#elif L==5	// fr
	"See top level of forum of users of institution"			// Besoin de traduction
#elif L==6	// gn
	"Ver el nivel superior del foro de usuarios de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See top level of forum of users of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"See top level of forum of users of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See top level of forum of users of institution"			// Precisa de traduo
#elif L==10	// tr
	"See top level of forum of users of institution"			// eviri lazim!
#endif
	,
	[ActSeeForInsTch] =
#if   L==1	// ca
	"See top level of forum of teachers of institution"			// Necessita traducci
#elif L==2	// de
	"See top level of forum of teachers of institution"			// Need bersetzung
#elif L==3	// en
	"See top level of forum of teachers of institution"
#elif L==4	// es
	"Ver el nivel superior del foro de profesores de instituci&oacute;n"
#elif L==5	// fr
	"See top level of forum of teachers of institution"			// Besoin de traduction
#elif L==6	// gn
	"Ver el nivel superior del foro de profesores de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See top level of forum of teachers of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"See top level of forum of teachers of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See top level of forum of teachers of institution"			// Precisa de traduo
#elif L==10	// tr
	"See top level of forum of teachers of institution"			// eviri lazim!
#endif
	,
	[ActSeeForGenUsr] =
#if   L==1	// ca
	"See top level of general forum of users"		// Necessita traducci
#elif L==2	// de
	"See top level of general forum of users"		// Need bersetzung
#elif L==3	// en
	"See top level of general forum of users"
#elif L==4	// es
	"Ver el nivel superior del foro de usuarios general"
#elif L==5	// fr
	"See top level of general forum of users"		// Besoin de traduction
#elif L==6	// gn
	"Ver el nivel superior del foro de usuarios general"	// Okoteve traduccin
#elif L==7	// it
	"See top level of general forum of users"		// Bisogno di traduzione
#elif L==8	// pl
	"See top level of general forum of users"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See top level of general forum of users"		// Precisa de traduo
#elif L==10	// tr
	"See top level of general forum of users"		// eviri lazim!
#endif
	,
	[ActSeeForGenTch] =
#if   L==1	// ca
	"See top level of general forum of teachers"		// Necessita traducci
#elif L==2	// de
	"See top level of general forum of teachers"		// Need bersetzung
#elif L==3	// en
	"See top level of general forum of teachers"
#elif L==4	// es
	"Ver el nivel superior del foro de profesores general"
#elif L==5	// fr
	"See top level of general forum of teachers"		// Besoin de traduction
#elif L==6	// gn
	"Ver el nivel superior del foro de profesores general"	// Okoteve traduccin
#elif L==7	// it
	"See top level of general forum of teachers"		// Bisogno di traduzione
#elif L==8	// pl
	"See top level of general forum of teachers"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See top level of general forum of teachers"		// Precisa de traduo
#elif L==10	// tr
	"See top level of general forum of teachers"		// eviri lazim!
#endif
	,
	[ActSeeForSWAUsr] =
#if   L==1	// ca
	"See top level of forum of users of the platform"		// Necessita traducci
#elif L==2	// de
	"See top level of forum of users of the platform"		// Need bersetzung
#elif L==3	// en
	"See top level of forum of users of the platform"
#elif L==4	// es
	"Ver el nivel superior del foro de usuarios de la plataforma"
#elif L==5	// fr
	"See top level of forum of users of the platform"		// Besoin de traduction
#elif L==6	// gn
	"Ver el nivel superior del foro de usuarios de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"See top level of forum of users of the platform"		// Bisogno di traduzione
#elif L==8	// pl
	"See top level of forum of users of the platform"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See top level of forum of users of the platform"		// Precisa de traduo
#elif L==10	// tr
	"See top level of forum of users of the platform"		// eviri lazim!
#endif
	,
	[ActSeeForSWATch] =
#if   L==1	// ca
	"See top level of forum of teachers of the platform"		// Necessita traducci
#elif L==2	// de
	"See top level of forum of teachers of the platform"		// Need bersetzung
#elif L==3	// en
	"See top level of forum of teachers of the platform"
#elif L==4	// es
	"Ver el nivel superior del foro de profesores de la plataforma"
#elif L==5	// fr
	"See top level of forum of teachers of the platform"		// Besoin de traduction
#elif L==6	// gn
	"Ver el nivel superior del foro de profesores de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"See top level of forum of teachers of the platform"		// Bisogno di traduzione
#elif L==8	// pl
	"See top level of forum of teachers of the platform"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See top level of forum of teachers of the platform"		// Precisa de traduo
#elif L==10	// tr
	"See top level of forum of teachers of the platform"		// eviri lazim!
#endif
	,
	[ActSeePstForCrsUsr] =
#if   L==1	// ca
	"See the posts of a thread of the forum of users of course"		// Necessita traducci
#elif L==2	// de
	"See the posts of a thread of the forum of users of course"		// Need bersetzung
#elif L==3	// en
	"See the posts of a thread of the forum of users of course"
#elif L==4	// es
	"Ver los mensajes de un hilo del foro de usuarios de asignatura"
#elif L==5	// fr
	"See the posts of a thread of the forum of users of course"		// Besoin de traduction
#elif L==6	// gn
	"Ver los mensajes de un hilo del foro de usuarios de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See the posts of a thread of the forum of users of course"		// Bisogno di traduzione
#elif L==8	// pl
	"See the posts of a thread of the forum of users of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the posts of a thread of the forum of users of course"		// Precisa de traduo
#elif L==10	// tr
	"See the posts of a thread of the forum of users of course"		// eviri lazim!
#endif
	,
	[ActSeePstForCrsTch] =
#if   L==1	// ca
	"See the posts of a thread of the forum of teachers of course"		// Necessita traducci
#elif L==2	// de
	"See the posts of a thread of the forum of teachers of course"		// Need bersetzung
#elif L==3	// en
	"See the posts of a thread of the forum of teachers of course"
#elif L==4	// es
	"Ver los mensajes de un hilo del foro de profesores de asignatura"
#elif L==5	// fr
	"See the posts of a thread of the forum of teachers of course"		// Besoin de traduction
#elif L==6	// gn
	"Ver los mensajes de un hilo del foro de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"See the posts of a thread of the forum of teachers of course"		// Bisogno di traduzione
#elif L==8	// pl
	"See the posts of a thread of the forum of teachers of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the posts of a thread of the forum of teachers of course"		// Precisa de traduo
#elif L==10	// tr
	"See the posts of a thread of the forum of teachers of course"		// eviri lazim!
#endif
	,
	[ActSeePstForDegUsr] =
#if   L==1	// ca
	"See the posts of a thread of the forum of users of degree"		// Necessita traducci
#elif L==2	// de
	"See the posts of a thread of the forum of users of degree"		// Need bersetzung
#elif L==3	// en
	"See the posts of a thread of the forum of users of degree"
#elif L==4	// es
	"Ver los mensajes de un hilo del foro de usuarios de titulaci&oacute;n"
#elif L==5	// fr
	"See the posts of a thread of the forum of users of degree"		// Besoin de traduction
#elif L==6	// gn
	"Ver los mensajes de un hilo del foro de usuarios de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See the posts of a thread of the forum of users of degree"		// Bisogno di traduzione
#elif L==8	// pl
	"See the posts of a thread of the forum of users of degree"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the posts of a thread of the forum of users of degree"		// Precisa de traduo
#elif L==10	// tr
	"See the posts of a thread of the forum of users of degree"		// eviri lazim!
#endif
	,
	[ActSeePstForDegTch] =
#if   L==1	// ca
	"See the posts of a thread of the forum of teachers of degree"			// Necessita traducci
#elif L==2	// de
	"See the posts of a thread of the forum of teachers of degree"			// Need bersetzung
#elif L==3	// en
	"See the posts of a thread of the forum of teachers of degree"
#elif L==4	// es
	"Ver los mensajes de un hilo del foro de profesores de titulaci&oacute;n"
#elif L==5	// fr
	"See the posts of a thread of the forum of teachers of degree"			// Besoin de traduction
#elif L==6	// gn
	"Ver los mensajes de un hilo del foro de profesores de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See the posts of a thread of the forum of teachers of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"See the posts of a thread of the forum of teachers of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the posts of a thread of the forum of teachers of degree"			// Precisa de traduo
#elif L==10	// tr
	"See the posts of a thread of the forum of teachers of degree"			// eviri lazim!
#endif
	,
	[ActSeePstForCtrUsr] =
#if   L==1	// ca
	"See the posts of a thread of the forum of users of center"	// Necessita traducci
#elif L==2	// de
	"See the posts of a thread of the forum of users of center"	// Need bersetzung
#elif L==3	// en
	"See the posts of a thread of the forum of users of center"
#elif L==4	// es
	"Ver los mensajes de un hilo del foro de usuarios de centro"
#elif L==5	// fr
	"See the posts of a thread of the forum of users of center"	// Besoin de traduction
#elif L==6	// gn
	"Ver los mensajes de un hilo del foro de usuarios de centro"	// Okoteve traduccin
#elif L==7	// it
	"See the posts of a thread of the forum of users of center"	// Bisogno di traduzione
#elif L==8	// pl
	"See the posts of a thread of the forum of users of center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the posts of a thread of the forum of users of center"	// Precisa de traduo
#elif L==10	// tr
	"See the posts of a thread of the forum of users of center"	// eviri lazim!
#endif
	,
	[ActSeePstForCtrTch] =
#if   L==1	// ca
	"See the posts of a thread of the forum of teachers of center"	// Necessita traducci
#elif L==2	// de
	"See the posts of a thread of the forum of teachers of center"	// Need bersetzung
#elif L==3	// en
	"See the posts of a thread of the forum of teachers of center"
#elif L==4	// es
	"Ver los mensajes de un hilo del foro de profesores de centro"
#elif L==5	// fr
	"See the posts of a thread of the forum of teachers of center"	// Besoin de traduction
#elif L==6	// gn
	"Ver los mensajes de un hilo del foro de profesores de centro"	// Okoteve traduccin
#elif L==7	// it
	"See the posts of a thread of the forum of teachers of center"	// Bisogno di traduzione
#elif L==8	// pl
	"See the posts of a thread of the forum of teachers of center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the posts of a thread of the forum of teachers of center"	// Precisa de traduo
#elif L==10	// tr
	"See the posts of a thread of the forum of teachers of center"	// eviri lazim!
#endif
	,
	[ActSeePstForInsUsr] =
#if   L==1	// ca
	"See the posts of a thread of the forum of users of institution"		// Necessita traducci
#elif L==2	// de
	"See the posts of a thread of the forum of users of institution"		// Need bersetzung
#elif L==3	// en
	"See the posts of a thread of the forum of users of institution"
#elif L==4	// es
	"Ver los mensajes de un hilo del foro de usuarios de instituci&oacute;n"
#elif L==5	// fr
	"See the posts of a thread of the forum of users of institution"		// Besoin de traduction
#elif L==6	// gn
	"Ver los mensajes de un hilo del foro de usuarios de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See the posts of a thread of the forum of users of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"See the posts of a thread of the forum of users of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the posts of a thread of the forum of users of institution"		// Precisa de traduo
#elif L==10	// tr
	"See the posts of a thread of the forum of users of institution"		// eviri lazim!
#endif
	,
	[ActSeePstForInsTch] =
#if   L==1	// ca
	"See the posts of a thread of the forum of teachers of institution"		// Necessita traducci
#elif L==2	// de
	"See the posts of a thread of the forum of teachers of institution"		// Need bersetzung
#elif L==3	// en
	"See the posts of a thread of the forum of teachers of institution"
#elif L==4	// es
	"Ver los mensajes de un hilo del foro de profesores de instituci&oacute;n"
#elif L==5	// fr
	"See the posts of a thread of the forum of teachers of institution"		// Besoin de traduction
#elif L==6	// gn
	"Ver los mensajes de un hilo del foro de profesores de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See the posts of a thread of the forum of teachers of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"See the posts of a thread of the forum of teachers of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the posts of a thread of the forum of teachers of institution"		// Precisa de traduo
#elif L==10	// tr
	"See the posts of a thread of the forum of teachers of institution"		// eviri lazim!
#endif
	,
	[ActSeePstForGenUsr] =
#if   L==1	// ca
	"See the posts of a thread of the general forum of users"	// Necessita traducci
#elif L==2	// de
	"See the posts of a thread of the general forum of users"	// Need bersetzung
#elif L==3	// en
	"See the posts of a thread of the general forum of users"
#elif L==4	// es
	"Ver los mensajes de un hilo del foro de usuarios general"
#elif L==5	// fr
	"See the posts of a thread of the general forum of users"	// Besoin de traduction
#elif L==6	// gn
	"Ver los mensajes de un hilo del foro de usuarios general"	// Okoteve traduccin
#elif L==7	// it
	"See the posts of a thread of the general forum of users"	// Bisogno di traduzione
#elif L==8	// pl
	"See the posts of a thread of the general forum of users"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the posts of a thread of the general forum of users"	// Precisa de traduo
#elif L==10	// tr
	"See the posts of a thread of the general forum of users"	// eviri lazim!
#endif
	,
	[ActSeePstForGenTch] =
#if   L==1	// ca
	"See the posts of a thread of the forum of teachers general"	// Necessita traducci
#elif L==2	// de
	"See the posts of a thread of the forum of teachers general"	// Need bersetzung
#elif L==3	// en
	"See the posts of a thread of the forum of teachers general"
#elif L==4	// es
	"Ver los mensajes de un hilo del foro de profesores general"
#elif L==5	// fr
	"See the posts of a thread of the forum of teachers general"	// Besoin de traduction
#elif L==6	// gn
	"Ver los mensajes de un hilo del foro de profesores general"	// Okoteve traduccin
#elif L==7	// it
	"See the posts of a thread of the forum of teachers general"	// Bisogno di traduzione
#elif L==8	// pl
	"See the posts of a thread of the forum of teachers general"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the posts of a thread of the forum of teachers general"	// Precisa de traduo
#elif L==10	// tr
	"See the posts of a thread of the forum of teachers general"	// eviri lazim!
#endif
	,
	[ActSeePstForSWAUsr] =
#if   L==1	// ca
	"See the posts of a thread of the forum of users of the platform"	// Necessita traducci
#elif L==2	// de
	"See the posts of a thread of the forum of users of the platform"	// Need bersetzung
#elif L==3	// en
	"See the posts of a thread of the forum of users of the platform"
#elif L==4	// es
	"Ver los mensajes de un hilo del foro de usuarios de la plataforma"
#elif L==5	// fr
	"See the posts of a thread of the forum of users of the platform"	// Besoin de traduction
#elif L==6	// gn
	"Ver los mensajes de un hilo del foro de usuarios de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"See the posts of a thread of the forum of users of the platform"	// Bisogno di traduzione
#elif L==8	// pl
	"See the posts of a thread of the forum of users of the platform"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the posts of a thread of the forum of users of the platform"	// Precisa de traduo
#elif L==10	// tr
	"See the posts of a thread of the forum of users of the platform"	// eviri lazim!
#endif
	,
	[ActSeePstForSWATch] =
#if   L==1	// ca
	"See the posts of a thread of the forum of teachers of the platform"	// Necessita traducci
#elif L==2	// de
	"See the posts of a thread of the forum of teachers of the platform"	// Need bersetzung
#elif L==3	// en
	"See the posts of a thread of the forum of teachers of the platform"
#elif L==4	// es
	"Ver los mensajes de un hilo del foro de profesores de la plataforma"
#elif L==5	// fr
	"See the posts of a thread of the forum of teachers of the platform"	// Besoin de traduction
#elif L==6	// gn
	"Ver los mensajes de un hilo del foro de profesores de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"See the posts of a thread of the forum of teachers of the platform"	// Bisogno di traduzione
#elif L==8	// pl
	"See the posts of a thread of the forum of teachers of the platform"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the posts of a thread of the forum of teachers of the platform"	// Precisa de traduo
#elif L==10	// tr
	"See the posts of a thread of the forum of teachers of the platform"	// eviri lazim!
#endif
	,
	[ActRcvThrForCrsUsr] =
#if   L==1	// ca
	"Send the first post of a new thread of forum of users of course"		// Necessita traducci
#elif L==2	// de
	"Send the first post of a new thread of forum of users of course"		// Need bersetzung
#elif L==3	// en
	"Send the first post of a new thread of forum of users of course"
#elif L==4	// es
	"Enviar el primer mensaje de un nuevo hilo del foro de usuarios de asignatura"
#elif L==5	// fr
	"Send the first post of a new thread of forum of users of course"		// Besoin de traduction
#elif L==6	// gn
	"Enviar el primer mensaje de un nuevo hilo del foro de usuarios de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Send the first post of a new thread of forum of users of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Send the first post of a new thread of forum of users of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send the first post of a new thread of forum of users of course"		// Precisa de traduo
#elif L==10	// tr
	"Send the first post of a new thread of forum of users of course"		// eviri lazim!
#endif
	,
	[ActRcvThrForCrsTch] =
#if   L==1	// ca
	"Send the first post of a new thread of forum of teachers of course"			// Necessita traducci
#elif L==2	// de
	"Send the first post of a new thread of forum of teachers of course"			// Need bersetzung
#elif L==3	// en
	"Send the first post of a new thread of forum of teachers of course"
#elif L==4	// es
	"Enviar el primer mensaje de un nuevo hilo del foro de profesores de asignatura"
#elif L==5	// fr
	"Send the first post of a new thread of forum of teachers of course"			// Besoin de traduction
#elif L==6	// gn
	"Enviar el primer mensaje de un nuevo hilo del foro de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Send the first post of a new thread of forum of teachers of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Send the first post of a new thread of forum of teachers of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send the first post of a new thread of forum of teachers of course"			// Precisa de traduo
#elif L==10	// tr
	"Send the first post of a new thread of forum of teachers of course"			// eviri lazim!
#endif
	,
	[ActRcvThrForDegUsr] =
#if   L==1	// ca
	"Send the first post of a new thread of forum of users of degree"			// Necessita traducci
#elif L==2	// de
	"Send the first post of a new thread of forum of users of degree"			// Need bersetzung
#elif L==3	// en
	"Send the first post of a new thread of forum of users of degree"
#elif L==4	// es
	"Enviar el primer mensaje de un nuevo hilo del foro de usuarios de titulaci&oacute;n"
#elif L==5	// fr
	"Send the first post of a new thread of forum of users of degree"			// Besoin de traduction
#elif L==6	// gn
	"Enviar el primer mensaje de un nuevo hilo del foro de usuarios de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Send the first post of a new thread of forum of users of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Send the first post of a new thread of forum of users of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send the first post of a new thread of forum of users of degree"			// Precisa de traduo
#elif L==10	// tr
	"Send the first post of a new thread of forum of users of degree"			// eviri lazim!
#endif
	,
	[ActRcvThrForDegTch] =
#if   L==1	// ca
	"Send the first post of a new thread of forum of teachers of degree"			// Necessita traducci
#elif L==2	// de
	"Send the first post of a new thread of forum of teachers of degree"			// Need bersetzung
#elif L==3	// en
	"Send the first post of a new thread of forum of teachers of degree"
#elif L==4	// es
	"Enviar el primer mensaje de un nuevo hilo del foro de profesores de titulaci&oacute;n"
#elif L==5	// fr
	"Send the first post of a new thread of forum of teachers of degree"			// Besoin de traduction
#elif L==6	// gn
	"Enviar el primer mensaje de un nuevo hilo del foro de profesores de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Send the first post of a new thread of forum of teachers of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Send the first post of a new thread of forum of teachers of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send the first post of a new thread of forum of teachers of degree"			// Precisa de traduo
#elif L==10	// tr
	"Send the first post of a new thread of forum of teachers of degree"			// eviri lazim!
#endif
	,
	[ActRcvThrForCtrUsr] =
#if   L==1	// ca
	"Send the first post of a new thread of forum of users of center"		// Necessita traducci
#elif L==2	// de
	"Send the first post of a new thread of forum of users of center"		// Need bersetzung
#elif L==3	// en
	"Send the first post of a new thread of forum of users of center"
#elif L==4	// es
	"Enviar el primer mensaje de un nuevo hilo del foro de usuarios de centro"
#elif L==5	// fr
	"Send the first post of a new thread of forum of users of center"		// Besoin de traduction
#elif L==6	// gn
	"Enviar el primer mensaje de un nuevo hilo del foro de usuarios de centro"	// Okoteve traduccin
#elif L==7	// it
	"Send the first post of a new thread of forum of users of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Send the first post of a new thread of forum of users of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send the first post of a new thread of forum of users of center"		// Precisa de traduo
#elif L==10	// tr
	"Send the first post of a new thread of forum of users of center"		// eviri lazim!
#endif
	,
	[ActRcvThrForCtrTch] =
#if   L==1	// ca
	"Send the first post of a new thread of forum of teachers of center"		// Necessita traducci
#elif L==2	// de
	"Send the first post of a new thread of forum of teachers of center"		// Need bersetzung
#elif L==3	// en
	"Send the first post of a new thread of forum of teachers of center"
#elif L==4	// es
	"Enviar el primer mensaje de un nuevo hilo del foro de profesores de centro"
#elif L==5	// fr
	"Send the first post of a new thread of forum of teachers of center"		// Besoin de traduction
#elif L==6	// gn
	"Enviar el primer mensaje de un nuevo hilo del foro de profesores de centro"	// Okoteve traduccin
#elif L==7	// it
	"Send the first post of a new thread of forum of teachers of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Send the first post of a new thread of forum of teachers of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send the first post of a new thread of forum of teachers of center"		// Precisa de traduo
#elif L==10	// tr
	"Send the first post of a new thread of forum of teachers of center"		// eviri lazim!
#endif
	,
	[ActRcvThrForInsUsr] =
#if   L==1	// ca
	"Send the first post of a new thread of forum of users of institution"			// Necessita traducci
#elif L==2	// de
	"Send the first post of a new thread of forum of users of institution"			// Need bersetzung
#elif L==3	// en
	"Send the first post of a new thread of forum of users of institution"
#elif L==4	// es
	"Enviar el primer mensaje de un nuevo hilo del foro de usuarios de instituci&oacute;n"
#elif L==5	// fr
	"Send the first post of a new thread of forum of users of institution"			// Besoin de traduction
#elif L==6	// gn
	"Enviar el primer mensaje de un nuevo hilo del foro de usuarios de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Send the first post of a new thread of forum of users of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Send the first post of a new thread of forum of users of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send the first post of a new thread of forum of users of institution"			// Precisa de traduo
#elif L==10	// tr
	"Send the first post of a new thread of forum of users of institution"			// eviri lazim!
#endif
	,
	[ActRcvThrForInsTch] =
#if   L==1	// ca
	"Send the first post of a new thread of forum of teachers of institution"			// Necessita traducci
#elif L==2	// de
	"Send the first post of a new thread of forum of teachers of institution"			// Need bersetzung
#elif L==3	// en
	"Send the first post of a new thread of forum of teachers of institution"
#elif L==4	// es
	"Enviar el primer mensaje de un nuevo hilo del foro de profesores de instituci&oacute;n"
#elif L==5	// fr
	"Send the first post of a new thread of forum of teachers of institution"			// Besoin de traduction
#elif L==6	// gn
	"Enviar el primer mensaje de un nuevo hilo del foro de profesores de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Send the first post of a new thread of forum of teachers of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Send the first post of a new thread of forum of teachers of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send the first post of a new thread of forum of teachers of institution"			// Precisa de traduo
#elif L==10	// tr
	"Send the first post of a new thread of forum of teachers of institution"			// eviri lazim!
#endif
	,
	[ActRcvThrForGenUsr] =
#if   L==1	// ca
	"Send the first post of a new thread of general forum of users"			// Necessita traducci
#elif L==2	// de
	"Send the first post of a new thread of general forum of users"			// Need bersetzung
#elif L==3	// en
	"Send the first post of a new thread of general forum of users"
#elif L==4	// es
	"Enviar el primer mensaje de un nuevo hilo del foro de usuarios general"
#elif L==5	// fr
	"Send the first post of a new thread of general forum of users"			// Besoin de traduction
#elif L==6	// gn
	"Enviar el primer mensaje de un nuevo hilo del foro de usuarios general"	// Okoteve traduccin
#elif L==7	// it
	"Send the first post of a new thread of general forum of users"			// Bisogno di traduzione
#elif L==8	// pl
	"Send the first post of a new thread of general forum of users"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send the first post of a new thread of general forum of users"			// Precisa de traduo
#elif L==10	// tr
	"Send the first post of a new thread of general forum of users"			// eviri lazim!
#endif
	,
	[ActRcvThrForGenTch] =
#if   L==1	// ca
	"Send the first post of a new thread of general forum of teachers"		// Necessita traducci
#elif L==2	// de
	"Send the first post of a new thread of general forum of teachers"		// Need bersetzung
#elif L==3	// en
	"Send the first post of a new thread of general forum of teachers"
#elif L==4	// es
	"Enviar el primer mensaje de un nuevo hilo del foro de profesores general"
#elif L==5	// fr
	"Send the first post of a new thread of general forum of teachers"		// Besoin de traduction
#elif L==6	// gn
	"Enviar el primer mensaje de un nuevo hilo del foro de profesores general"	// Okoteve traduccin
#elif L==7	// it
	"Send the first post of a new thread of general forum of teachers"		// Bisogno di traduzione
#elif L==8	// pl
	"Send the first post of a new thread of general forum of teachers"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send the first post of a new thread of general forum of teachers"		// Precisa de traduo
#elif L==10	// tr
	"Send the first post of a new thread of general forum of teachers"		// eviri lazim!
#endif
	,
	[ActRcvThrForSWAUsr] =
#if   L==1	// ca
	"Send the first post of a new thread of forum of users of the platform"			// Necessita traducci
#elif L==2	// de
	"Send the first post of a new thread of forum of users of the platform"			// Need bersetzung
#elif L==3	// en
	"Send the first post of a new thread of forum of users of the platform"
#elif L==4	// es
	"Enviar el primer mensaje de un nuevo hilo del foro de usuarios de la plataforma"
#elif L==5	// fr
	"Send the first post of a new thread of forum of users of the platform"			// Besoin de traduction
#elif L==6	// gn
	"Enviar el primer mensaje de un nuevo hilo del foro de usuarios de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Send the first post of a new thread of forum of users of the platform"			// Bisogno di traduzione
#elif L==8	// pl
	"Send the first post of a new thread of forum of users of the platform"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send the first post of a new thread of forum of users of the platform"			// Precisa de traduo
#elif L==10	// tr
	"Send the first post of a new thread of forum of users of the platform"			// eviri lazim!
#endif
	,
	[ActRcvThrForSWATch] =
#if   L==1	// ca
	"Send the first post of a new thread of forum of teachers of the platform"		// Necessita traducci
#elif L==2	// de
	"Send the first post of a new thread of forum of teachers of the platform"		// Need bersetzung
#elif L==3	// en
	"Send the first post of a new thread of forum of teachers of the platform"
#elif L==4	// es
	"Enviar el primer mensaje de un nuevo hilo del foro de profesores de la plataforma"
#elif L==5	// fr
	"Send the first post of a new thread of forum of teachers of the platform"		// Besoin de traduction
#elif L==6	// gn
	"Enviar el primer mensaje de un nuevo hilo del foro de profesores de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Send the first post of a new thread of forum of teachers of the platform"		// Bisogno di traduzione
#elif L==8	// pl
	"Send the first post of a new thread of forum of teachers of the platform"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send the first post of a new thread of forum of teachers of the platform"		// Precisa de traduo
#elif L==10	// tr
	"Send the first post of a new thread of forum of teachers of the platform"		// eviri lazim!
#endif
	,
	[ActRcvRepForCrsUsr] =
#if   L==1	// ca
	"Send reply post in a thread of the forum of users of course"			// Necessita traducci
#elif L==2	// de
	"Send reply post in a thread of the forum of users of course"			// Need bersetzung
#elif L==3	// en
	"Send reply post in a thread of the forum of users of course"
#elif L==4	// es
	"Enviar un mensaje de respuesta en un hilo del foro de usuarios de asignatura"
#elif L==5	// fr
	"Send reply post in a thread of the forum of users of course"			// Besoin de traduction
#elif L==6	// gn
	"Enviar un mensaje de respuesta en un hilo del foro de usuarios de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Send reply post in a thread of the forum of users of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Send reply post in a thread of the forum of users of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send reply post in a thread of the forum of users of course"			// Precisa de traduo
#elif L==10	// tr
	"Send reply post in a thread of the forum of users of course"			// eviri lazim!
#endif
	,
	[ActRcvRepForCrsTch] =
#if   L==1	// ca
	"Send reply post in a thread of the forum of teachers of course"			// Necessita traducci
#elif L==2	// de
	"Send reply post in a thread of the forum of teachers of course"			// Need bersetzung
#elif L==3	// en
	"Send reply post in a thread of the forum of teachers of course"
#elif L==4	// es
	"Enviar un mensaje de respuesta en un hilo del foro de profesores de asignatura"
#elif L==5	// fr
	"Send reply post in a thread of the forum of teachers of course"			// Besoin de traduction
#elif L==6	// gn
	"Enviar un mensaje de respuesta en un hilo del foro de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Send reply post in a thread of the forum of teachers of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Send reply post in a thread of the forum of teachers of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send reply post in a thread of the forum of teachers of course"			// Precisa de traduo
#elif L==10	// tr
	"Send reply post in a thread of the forum of teachers of course"			// eviri lazim!
#endif
	,
	[ActRcvRepForDegUsr] =
#if   L==1	// ca
	"Send reply post in a thread of the forum of users of degree"				// Necessita traducci
#elif L==2	// de
	"Send reply post in a thread of the forum of users of degree"				// Need bersetzung
#elif L==3	// en
	"Send reply post in a thread of the forum of users of degree"
#elif L==4	// es
	"Enviar un mensaje de respuesta en un hilo del foro de usuarios de titulaci&oacute;n"
#elif L==5	// fr
	"Send reply post in a thread of the forum of users of degree"				// Besoin de traduction
#elif L==6	// gn
	"Enviar un mensaje de respuesta en un hilo del foro de usuarios de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Send reply post in a thread of the forum of users of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Send reply post in a thread of the forum of users of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send reply post in a thread of the forum of users of degree"				// Precisa de traduo
#elif L==10	// tr
	"Send reply post in a thread of the forum of users of degree"				// eviri lazim!
#endif
	,
	[ActRcvRepForDegTch] =
#if   L==1	// ca
	"Send reply post in a thread of the forum of teachers of degree"			// Necessita traducci
#elif L==2	// de
	"Send reply post in a thread of the forum of teachers of degree"			// Need bersetzung
#elif L==3	// en
	"Send reply post in a thread of the forum of teachers of degree"
#elif L==4	// es
	"Enviar un mensaje de respuesta en un hilo del foro de profesores de titulaci&oacute;n"
#elif L==5	// fr
	"Send reply post in a thread of the forum of teachers of degree"			// Besoin de traduction
#elif L==6	// gn
	"Enviar un mensaje de respuesta en un hilo del foro de profesores de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Send reply post in a thread of the forum of teachers of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Send reply post in a thread of the forum of teachers of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send reply post in a thread of the forum of teachers of degree"			// Precisa de traduo
#elif L==10	// tr
	"Send reply post in a thread of the forum of teachers of degree"			// eviri lazim!
#endif
	,
	[ActRcvRepForCtrUsr] =
#if   L==1	// ca
	"Send reply post in a thread of the forum of users of center"			// Necessita traducci
#elif L==2	// de
	"Send reply post in a thread of the forum of users of center"			// Need bersetzung
#elif L==3	// en
	"Send reply post in a thread of the forum of users of center"
#elif L==4	// es
	"Enviar un mensaje de respuesta en un hilo del foro de usuarios de centro"
#elif L==5	// fr
	"Send reply post in a thread of the forum of users of center"			// Besoin de traduction
#elif L==6	// gn
	"Enviar un mensaje de respuesta en un hilo del foro de usuarios de centro"	// Okoteve traduccin
#elif L==7	// it
	"Send reply post in a thread of the forum of users of center"			// Bisogno di traduzione
#elif L==8	// pl
	"Send reply post in a thread of the forum of users of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send reply post in a thread of the forum of users of center"			// Precisa de traduo
#elif L==10	// tr
	"Send reply post in a thread of the forum of users of center"			// eviri lazim!
#endif
	,
	[ActRcvRepForCtrTch] =
#if   L==1	// ca
	"Send reply post in a thread of the forum of teachers of center"		// Necessita traducci
#elif L==2	// de
	"Send reply post in a thread of the forum of teachers of center"		// Need bersetzung
#elif L==3	// en
	"Send reply post in a thread of the forum of teachers of center"
#elif L==4	// es
	"Enviar un mensaje de respuesta en un hilo del foro de profesores de centro"
#elif L==5	// fr
	"Send reply post in a thread of the forum of teachers of center"		// Besoin de traduction
#elif L==6	// gn
	"Enviar un mensaje de respuesta en un hilo del foro de profesores de centro"	// Okoteve traduccin
#elif L==7	// it
	"Send reply post in a thread of the forum of teachers of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Send reply post in a thread of the forum of teachers of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send reply post in a thread of the forum of teachers of center"		// Precisa de traduo
#elif L==10	// tr
	"Send reply post in a thread of the forum of teachers of center"		// eviri lazim!
#endif
	,
	[ActRcvRepForInsUsr] =
#if   L==1	// ca
	"Send reply post in a thread of the forum of users of institution"			// Necessita traducci
#elif L==2	// de
	"Send reply post in a thread of the forum of users of institution"			// Need bersetzung
#elif L==3	// en
	"Send reply post in a thread of the forum of users of institution"
#elif L==4	// es
	"Enviar un mensaje de respuesta en un hilo del foro de usuarios de instituci&oacute;n"
#elif L==5	// fr
	"Send reply post in a thread of the forum of users of institution"			// Besoin de traduction
#elif L==6	// gn
	"Enviar un mensaje de respuesta en un hilo del foro de usuarios de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Send reply post in a thread of the forum of users of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Send reply post in a thread of the forum of users of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send reply post in a thread of the forum of users of institution"			// Precisa de traduo
#elif L==10	// tr
	"Send reply post in a thread of the forum of users of institution"			// eviri lazim!
#endif
	,
	[ActRcvRepForInsTch] =
#if   L==1	// ca
	"Send reply post in a thread of the forum of teachers of institution"				// Necessita traducci
#elif L==2	// de
	"Send reply post in a thread of the forum of teachers of institution"				// Need bersetzung
#elif L==3	// en
	"Send reply post in a thread of the forum of teachers of institution"
#elif L==4	// es
	"Enviar un mensaje de respuesta en un hilo del foro de profesores de instituci&oacute;n"
#elif L==5	// fr
	"Send reply post in a thread of the forum of teachers of institution"				// Besoin de traduction
#elif L==6	// gn
	"Enviar un mensaje de respuesta en un hilo del foro de profesores de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Send reply post in a thread of the forum of teachers of institution"				// Bisogno di traduzione
#elif L==8	// pl
	"Send reply post in a thread of the forum of teachers of institution"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send reply post in a thread of the forum of teachers of institution"				// Precisa de traduo
#elif L==10	// tr
	"Send reply post in a thread of the forum of teachers of institution"				// eviri lazim!
#endif
	,
	[ActRcvRepForGenUsr] =
#if   L==1	// ca
	"Send reply post in a thread of the general forum of users"			// Necessita traducci
#elif L==2	// de
	"Send reply post in a thread of the general forum of users"			// Need bersetzung
#elif L==3	// en
	"Send reply post in a thread of the general forum of users"
#elif L==4	// es
	"Enviar un mensaje de respuesta en un hilo del foro de usuarios general"
#elif L==5	// fr
	"Send reply post in a thread of the general forum of users"			// Besoin de traduction
#elif L==6	// gn
	"Enviar un mensaje de respuesta en un hilo del foro de usuarios general"	// Okoteve traduccin
#elif L==7	// it
	"Send reply post in a thread of the general forum of users"			// Bisogno di traduzione
#elif L==8	// pl
	"Send reply post in a thread of the general forum of users"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send reply post in a thread of the general forum of users"			// Precisa de traduo
#elif L==10	// tr
	"Send reply post in a thread of the general forum of users"			// eviri lazim!
#endif
	,
	[ActRcvRepForGenTch] =
#if   L==1	// ca
	"Send reply post in a thread of the general forum of teachers"			// Necessita traducci
#elif L==2	// de
	"Send reply post in a thread of the general forum of teachers"			// Need bersetzung
#elif L==3	// en
	"Send reply post in a thread of the general forum of teachers"
#elif L==4	// es
	"Enviar un mensaje de respuesta en un hilo del foro de profesores general"
#elif L==5	// fr
	"Send reply post in a thread of the general forum of teachers"			// Besoin de traduction
#elif L==6	// gn
	"Enviar un mensaje de respuesta en un hilo del foro de profesores general"	// Okoteve traduccin
#elif L==7	// it
	"Send reply post in a thread of the general forum of teachers"			// Bisogno di traduzione
#elif L==8	// pl
	"Send reply post in a thread of the general forum of teachers"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send reply post in a thread of the general forum of teachers"			// Precisa de traduo
#elif L==10	// tr
	"Send reply post in a thread of the general forum of teachers"			// eviri lazim!
#endif
	,
	[ActRcvRepForSWAUsr] =
#if   L==1	// ca
	"Send reply post in a thread of the forum of users of the platform"			// Necessita traducci
#elif L==2	// de
	"Send reply post in a thread of the forum of users of the platform"			// Need bersetzung
#elif L==3	// en
	"Send reply post in a thread of the forum of users of the platform"
#elif L==4	// es
	"Enviar un mensaje de respuesta en un hilo del foro de usuarios de la plataforma"
#elif L==5	// fr
	"Send reply post in a thread of the forum of users of the platform"			// Besoin de traduction
#elif L==6	// gn
	"Enviar un mensaje de respuesta en un hilo del foro de usuarios de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Send reply post in a thread of the forum of users of the platform"			// Bisogno di traduzione
#elif L==8	// pl
	"Send reply post in a thread of the forum of users of the platform"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send reply post in a thread of the forum of users of the platform"			// Precisa de traduo
#elif L==10	// tr
	"Send reply post in a thread of the forum of users of the platform"			// eviri lazim!
#endif
	,
	[ActRcvRepForSWATch] =
#if   L==1	// ca
	"Send reply post in a thread of the forum of teachers of the platform"			// Necessita traducci
#elif L==2	// de
	"Send reply post in a thread of the forum of teachers of the platform"			// Need bersetzung
#elif L==3	// en
	"Send reply post in a thread of the forum of teachers of the platform"
#elif L==4	// es
	"Enviar un mensaje de respuesta en un hilo del foro de profesores de la plataforma"
#elif L==5	// fr
	"Send reply post in a thread of the forum of teachers of the platform"			// Besoin de traduction
#elif L==6	// gn
	"Enviar un mensaje de respuesta en un hilo del foro de profesores de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Send reply post in a thread of the forum of teachers of the platform"			// Bisogno di traduzione
#elif L==8	// pl
	"Send reply post in a thread of the forum of teachers of the platform"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send reply post in a thread of the forum of teachers of the platform"			// Precisa de traduo
#elif L==10	// tr
	"Send reply post in a thread of the forum of teachers of the platform"		// eviri lazim!
#endif
	,
	[ActReqDelThrCrsUsr] =
#if   L==1	// ca
	"Request removal of thread of forum of users of course"				// Necessita traducci
#elif L==2	// de
	"Request removal of thread of forum of users of course"				// Need bersetzung
#elif L==3	// en
	"Request removal of thread of forum of users of course"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de hilo del foro de usuarios de asignatura"
#elif L==5	// fr
	"Request removal of thread of forum of users of course"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de hilo del foro de usuarios de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of thread of forum of users of course"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of thread of forum of users of course"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of thread of forum of users of course"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of thread of forum of users of course"				// eviri lazim!
#endif
	,
	[ActReqDelThrCrsTch] =
#if   L==1	// ca
	"Request removal of thread of forum of teachers of course"			// Necessita traducci
#elif L==2	// de
	"Request removal of thread of forum of teachers of course"			// Need bersetzung
#elif L==3	// en
	"Request removal of thread of forum of teachers of course"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de hilo del foro de profesores de asignatura"
#elif L==5	// fr
	"Request removal of thread of forum of teachers of course"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de hilo del foro de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of thread of forum of teachers of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of thread of forum of teachers of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of thread of forum of teachers of course"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of thread of forum of teachers of course"			// eviri lazim!
#endif
	,
	[ActReqDelThrDegUsr] =
#if   L==1	// ca
	"Request removal of thread of forum of users of degree"					// Necessita traducci
#elif L==2	// de
	"Request removal of thread of forum of users of degree"					// Need bersetzung
#elif L==3	// en
	"Request removal of thread of forum of users of degree"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de hilo del foro de usuarios de titulaci&oacute;n"
#elif L==5	// fr
	"Request removal of thread of forum of users of degree"					// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de hilo del foro de usuarios de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of thread of forum of users of degree"					// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of thread of forum of users of degree"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of thread of forum of users of degree"					// Precisa de traduo
#elif L==10	// tr
	"Request removal of thread of forum of users of degree"					// eviri lazim!
#endif
	,
	[ActReqDelThrDegTch] =
#if   L==1	// ca
	"Request removal of thread of forum of teachers of degree"				// Necessita traducci
#elif L==2	// de
	"Request removal of thread of forum of teachers of degree"				// Need bersetzung
#elif L==3	// en
	"Request removal of thread of forum of teachers of degree"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de hilo del foro de profesores de titulaci&oacute;n"
#elif L==5	// fr
	"Request removal of thread of forum of teachers of degree"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de hilo del foro de profesores de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of thread of forum of teachers of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of thread of forum of teachers of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of thread of forum of teachers of degree"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of thread of forum of teachers of degree"				// eviri lazim!
#endif
	,
	[ActReqDelThrCtrUsr] =
#if   L==1	// ca
	"Request removal of thread of forum of users of center"			// Necessita traducci
#elif L==2	// de
	"Request removal of thread of forum of users of center"			// Need bersetzung
#elif L==3	// en
	"Request removal of thread of forum of users of center"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de hilo del foro de usuarios de centro"
#elif L==5	// fr
	"Request removal of thread of forum of users of center"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de hilo del foro de usuarios de centro"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of thread of forum of users of center"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of thread of forum of users of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of thread of forum of users of center"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of thread of forum of users of center"			// eviri lazim!
#endif
	,
	[ActReqDelThrCtrTch] =
#if   L==1	// ca
	"Request removal of thread of forum of teachers of center"			// Necessita traducci
#elif L==2	// de
	"Request removal of thread of forum of teachers of center"			// Need bersetzung
#elif L==3	// en
	"Request removal of thread of forum of teachers of center"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de hilo del foro de profesores de centro"
#elif L==5	// fr
	"Request removal of thread of forum of teachers of center"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de hilo del foro de profesores de centro"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of thread of forum of teachers of center"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of thread of forum of teachers of center"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of thread of forum of teachers of center"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of thread of forum of teachers of center"			// eviri lazim!
#endif
	,
	[ActReqDelThrInsUsr] =
#if   L==1	// ca
	"Request removal of thread of forum of users of institution"				// Necessita traducci
#elif L==2	// de
	"Request removal of thread of forum of users of institution"				// Need bersetzung
#elif L==3	// en
	"Request removal of thread of forum of users of institution"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de hilo del foro de usuarios de instituci&oacute;n"
#elif L==5	// fr
	"Request removal of thread of forum of users of institution"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de hilo del foro de usuarios de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of thread of forum of users of institution"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of thread of forum of users of institution"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of thread of forum of users of institution"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of thread of forum of users of institution"				// eviri lazim!
#endif
	,
	[ActReqDelThrInsTch] =
#if   L==1	// ca
	"Request removal of thread of forum of teachers of institution"			// Necessita traducci
#elif L==2	// de
	"Request removal of thread of forum of teachers of institution"			// Need bersetzung
#elif L==3	// en
	"Request removal of thread of forum of teachers of institution"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de hilo del foro de profesores de instituci&oacute;n"
#elif L==5	// fr
	"Request removal of thread of forum of teachers of institution"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de hilo del foro de profesores de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of thread of forum of teachers of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of thread of forum of teachers of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of thread of forum of teachers of institution"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of thread of forum of teachers of institution"			// eviri lazim!
#endif
	,
	[ActReqDelThrGenUsr] =
#if   L==1	// ca
	"Request removal of thread of general forum of users"			// Necessita traducci
#elif L==2	// de
	"Request removal of thread of general forum of users"			// Need bersetzung
#elif L==3	// en
	"Request removal of thread of general forum of users"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de hilo del foro de usuarios general"
#elif L==5	// fr
	"Request removal of thread of general forum of users"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de hilo del foro de usuarios general"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of thread of general forum of users"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of thread of general forum of users"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of thread of general forum of users"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of thread of general forum of users"			// eviri lazim!
#endif
	,
	[ActReqDelThrGenTch] =
#if   L==1	// ca
	"Request removal of thread of general forum of teachers"			// Necessita traducci
#elif L==2	// de
	"Request removal of thread of general forum of teachers"			// Need bersetzung
#elif L==3	// en
	"Request removal of thread of general forum of teachers"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de hilo del foro de profesores general"
#elif L==5	// fr
	"Request removal of thread of general forum of teachers"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de hilo del foro de profesores general"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of thread of general forum of teachers"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of thread of general forum of teachers"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of thread of general forum of teachers"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of thread of general forum of teachers"			// eviri lazim!
#endif
	,
	[ActReqDelThrSWAUsr] =
#if   L==1	// ca
	"Request removal of thread of forum of users of the platform"			// Necessita traducci
#elif L==2	// de
	"Request removal of thread of forum of users of the platform"			// Need bersetzung
#elif L==3	// en
	"Request removal of thread of forum of users of the platform"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de hilo del foro de usuarios de la plataforma"
#elif L==5	// fr
	"Request removal of thread of forum of users of the platform"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de hilo del foro de usuarios de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of thread of forum of users of the platform"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of thread of forum of users of the platform"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of thread of forum of users of the platform"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of thread of forum of users of the platform"			// eviri lazim!
#endif
	,
	[ActReqDelThrSWATch] =
#if   L==1	// ca
	"Request removal of thread of forum of teachers of the platform"			// Necessita traducci
#elif L==2	// de
	"Request removal of thread of forum of teachers of the platform"			// Need bersetzung
#elif L==3	// en
	"Request removal of thread of forum of teachers of the platform"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de hilo del foro de profesores de la plataforma"
#elif L==5	// fr
	"Request removal of thread of forum of teachers of the platform"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de hilo del foro de profesores de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of thread of forum of teachers of the platform"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of thread of forum of teachers of the platform"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of thread of forum of teachers of the platform"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of thread of forum of teachers of the platform"			// eviri lazim!
#endif
	,
	[ActDelThrForCrsUsr] =
#if   L==1	// ca
	"Remove thread of forum of users of course"		// Necessita traducci
#elif L==2	// de
	"Remove thread of forum of users of course"		// Need bersetzung
#elif L==3	// en
	"Remove thread of forum of users of course"
#elif L==4	// es
	"Eliminar hilo del foro de usuarios de asignatura"
#elif L==5	// fr
	"Remove thread of forum of users of course"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar hilo del foro de usuarios de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove thread of forum of users of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove thread of forum of users of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove thread of forum of users of course"		// Precisa de traduo
#elif L==10	// tr
	"Remove thread of forum of users of course"		// eviri lazim!
#endif
	,
	[ActDelThrForCrsTch] =
#if   L==1	// ca
	"Remove thread of forum of teachers of course"		// Necessita traducci
#elif L==2	// de
	"Remove thread of forum of teachers of course"		// Need bersetzung
#elif L==3	// en
	"Remove thread of forum of teachers of course"
#elif L==4	// es
	"Eliminar hilo del foro de profesores de asignatura"
#elif L==5	// fr
	"Remove thread of forum of teachers of course"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar hilo del foro de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove thread of forum of teachers of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove thread of forum of teachers of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove thread of forum of teachers of course"		// Precisa de traduo
#elif L==10	// tr
	"Remove thread of forum of teachers of course"		// eviri lazim!
#endif
	,
	[ActDelThrForDegUsr] =
#if   L==1	// ca
	"Remove thread of forum of users of degree"			// Necessita traducci
#elif L==2	// de
	"Remove thread of forum of users of degree"			// Need bersetzung
#elif L==3	// en
	"Remove thread of forum of users of degree"
#elif L==4	// es
	"Eliminar hilo del foro de usuarios de titulaci&oacute;n"
#elif L==5	// fr
	"Remove thread of forum of users of degree"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar hilo del foro de usuarios de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove thread of forum of users of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove thread of forum of users of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove thread of forum of users of degree"			// Precisa de traduo
#elif L==10	// tr
	"Remove thread of forum of users of degree"			// eviri lazim!
#endif
	,
	[ActDelThrForDegTch] =
#if   L==1	// ca
	"Remove thread of forum of teachers of degree"			// Necessita traducci
#elif L==2	// de
	"Remove thread of forum of teachers of degree"			// Need bersetzung
#elif L==3	// en
	"Remove thread of forum of teachers of degree"
#elif L==4	// es
	"Eliminar hilo del foro de profesores de titulaci&oacute;n"
#elif L==5	// fr
	"Remove thread of forum of teachers of degree"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar hilo del foro de profesores de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove thread of forum of teachers of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove thread of forum of teachers of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove thread of forum of teachers of degree"			// Precisa de traduo
#elif L==10	// tr
	"Remove thread of forum of teachers of degree"			// eviri lazim!
#endif
	,
	[ActDelThrForCtrUsr] =
#if   L==1	// ca
	"Remove thread of forum of users of center"	// Necessita traducci
#elif L==2	// de
	"Remove thread of forum of users of center"	// Need bersetzung
#elif L==3	// en
	"Remove thread of forum of users of center"
#elif L==4	// es
	"Eliminar hilo del foro de usuarios de centro"
#elif L==5	// fr
	"Remove thread of forum of users of center"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar hilo del foro de usuarios de centro"	// Okoteve traduccin
#elif L==7	// it
	"Remove thread of forum of users of center"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove thread of forum of users of center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove thread of forum of users of center"	// Precisa de traduo
#elif L==10	// tr
	"Remove thread of forum of users of center"	// eviri lazim!
#endif
	,
	[ActDelThrForCtrTch] =
#if   L==1	// ca
	"Remove thread of forum of teachers of center"		// Necessita traducci
#elif L==2	// de
	"Remove thread of forum of teachers of center"		// Need bersetzung
#elif L==3	// en
	"Remove thread of forum of teachers of center"
#elif L==4	// es
	"Eliminar hilo del foro de profesores de centro"
#elif L==5	// fr
	"Remove thread of forum of teachers of center"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar hilo del foro de profesores de centro"	// Okoteve traduccin
#elif L==7	// it
	"Remove thread of forum of teachers of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove thread of forum of teachers of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove thread of forum of teachers of center"		// Precisa de traduo
#elif L==10	// tr
	"Remove thread of forum of teachers of center"		// eviri lazim!
#endif
	,
	[ActDelThrForInsUsr] =
#if   L==1	// ca
	"Remove thread of forum of users of institution"		// Necessita traducci
#elif L==2	// de
	"Remove thread of forum of users of institution"		// Need bersetzung
#elif L==3	// en
	"Remove thread of forum of users of institution"
#elif L==4	// es
	"Eliminar hilo del foro de usuarios de instituci&oacute;n"
#elif L==5	// fr
	"Remove thread of forum of users of institution"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar hilo del foro de usuarios de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove thread of forum of users of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove thread of forum of users of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove thread of forum of users of institution"		// Precisa de traduo
#elif L==10	// tr
	"Remove thread of forum of users of institution"		// eviri lazim!
#endif
	,
	[ActDelThrForInsTch] =
#if   L==1	// ca
	"Remove thread of forum of teachers of institution"		// Necessita traducci
#elif L==2	// de
	"Remove thread of forum of teachers of institution"		// Need bersetzung
#elif L==3	// en
	"Remove thread of forum of teachers of institution"
#elif L==4	// es
	"Eliminar hilo del foro de profesores de instituci&oacute;n"
#elif L==5	// fr
	"Remove thread of forum of teachers of institution"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar hilo del foro de profesores de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove thread of forum of teachers of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove thread of forum of teachers of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove thread of forum of teachers of institution"		// Precisa de traduo
#elif L==10	// tr
	"Remove thread of forum of teachers of institution"		// eviri lazim!
#endif
	,
	[ActDelThrForGenUsr] =
#if   L==1	// ca
	"Remove thread of general forum of users"	// Necessita traducci
#elif L==2	// de
	"Remove thread of general forum of users"	// Need bersetzung
#elif L==3	// en
	"Remove thread of general forum of users"
#elif L==4	// es
	"Eliminar hilo del foro de usuarios general"
#elif L==5	// fr
	"Remove thread of general forum of users"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar hilo del foro de usuarios general"	// Okoteve traduccin
#elif L==7	// it
	"Remove thread of general forum of users"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove thread of general forum of users"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove thread of general forum of users"	// Precisa de traduo
#elif L==10	// tr
	"Remove thread of general forum of users"	// eviri lazim!
#endif
	,
	[ActDelThrForGenTch] =
#if   L==1	// ca
	"Remove thread of general forum of teachers"	// Necessita traducci
#elif L==2	// de
	"Remove thread of general forum of teachers"	// Need bersetzung
#elif L==3	// en
	"Remove thread of general forum of teachers"
#elif L==4	// es
	"Eliminar hilo del foro de profesores general"
#elif L==5	// fr
	"Remove thread of general forum of teachers"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar hilo del foro de profesores general"	// Okoteve traduccin
#elif L==7	// it
	"Remove thread of general forum of teachers"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove thread of general forum of teachers"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove thread of general forum of teachers"	// Precisa de traduo
#elif L==10	// tr
	"Remove thread of general forum of teachers"	// eviri lazim!
#endif
	,
	[ActDelThrForSWAUsr] =
#if   L==1	// ca
	"Remove thread of forum of users of the platform"	// Necessita traducci
#elif L==2	// de
	"Remove thread of forum of users of the platform"	// Need bersetzung
#elif L==3	// en
	"Remove thread of forum of users of the platform"
#elif L==4	// es
	"Eliminar hilo del foro de usuarios de la plataforma"
#elif L==5	// fr
	"Remove thread of forum of users of the platform"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar hilo del foro de usuarios de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Remove thread of forum of users of the platform"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove thread of forum of users of the platform"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove thread of forum of users of the platform"	// Precisa de traduo
#elif L==10	// tr
	"Remove thread of forum of users of the platform"	// eviri lazim!
#endif
	,
	[ActDelThrForSWATch] =
#if   L==1	// ca
	"Remove thread of forum of teachers of the platform"	// Necessita traducci
#elif L==2	// de
	"Remove thread of forum of teachers of the platform"	// Need bersetzung
#elif L==3	// en
	"Remove thread of forum of teachers of the platform"
#elif L==4	// es
	"Eliminar hilo del foro de profesores de la plataforma"
#elif L==5	// fr
	"Remove thread of forum of teachers of the platform"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar hilo del foro de profesores de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Remove thread of forum of teachers of the platform"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove thread of forum of teachers of the platform"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove thread of forum of teachers of the platform"	// Precisa de traduo
#elif L==10	// tr
	"Remove thread of forum of teachers of the platform"	// eviri lazim!
#endif
	,
	[ActCutThrForCrsUsr] =
#if   L==1	// ca
	"Cut thread of forum of users of course"		// Necessita traducci
#elif L==2	// de
	"Cut thread of forum of users of course"		// Need bersetzung
#elif L==3	// en
	"Cut thread of forum of users of course"
#elif L==4	// es
	"Cortar hilo del foro de usuarios de asignatura"
#elif L==5	// fr
	"Cut thread of forum of users of course"		// Besoin de traduction
#elif L==6	// gn
	"Cortar hilo del foro de usuarios de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Cut thread of forum of users of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Cut thread of forum of users of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Cut thread of forum of users of course"		// Precisa de traduo
#elif L==10	// tr
	"Cut thread of forum of users of course"		// eviri lazim!
#endif
	,
	[ActCutThrForCrsTch] =
#if   L==1	// ca
	"Cut thread of forum of teachers of course"		// Necessita traducci
#elif L==2	// de
	"Cut thread of forum of teachers of course"		// Need bersetzung
#elif L==3	// en
	"Cut thread of forum of teachers of course"
#elif L==4	// es
	"Cortar hilo del foro de profesores de asignatura"
#elif L==5	// fr
	"Cut thread of forum of teachers of course"		// Besoin de traduction
#elif L==6	// gn
	"Cortar hilo del foro de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Cut thread of forum of teachers of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Cut thread of forum of teachers of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Cut thread of forum of teachers of course"		// Precisa de traduo
#elif L==10	// tr
	"Cut thread of forum of teachers of course"		// eviri lazim!
#endif
	,
	[ActCutThrForDegUsr] =
#if   L==1	// ca
	"Cut thread of forum of users of degree"		// Necessita traducci
#elif L==2	// de
	"Cut thread of forum of users of degree"		// Need bersetzung
#elif L==3	// en
	"Cut thread of forum of users of degree"
#elif L==4	// es
	"Cortar hilo del foro de usuarios de titulaci&oacute;n"
#elif L==5	// fr
	"Cut thread of forum of users of degree"		// Besoin de traduction
#elif L==6	// gn
	"Cortar hilo del foro de usuarios de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Cut thread of forum of users of degree"		// Bisogno di traduzione
#elif L==8	// pl
	"Cut thread of forum of users of degree"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Cut thread of forum of users of degree"		// Precisa de traduo
#elif L==10	// tr
	"Cut thread of forum of users of degree"		// eviri lazim!
#endif
	,
	[ActCutThrForDegTch] =
#if   L==1	// ca
	"Cut thread of forum of teachers of degree"			// Necessita traducci
#elif L==2	// de
	"Cut thread of forum of teachers of degree"			// Need bersetzung
#elif L==3	// en
	"Cut thread of forum of teachers of degree"
#elif L==4	// es
	"Cortar hilo del foro de profesores de titulaci&oacute;n"
#elif L==5	// fr
	"Cut thread of forum of teachers of degree"			// Besoin de traduction
#elif L==6	// gn
	"Cortar hilo del foro de profesores de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Cut thread of forum of teachers of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Cut thread of forum of teachers of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Cut thread of forum of teachers of degree"			// Precisa de traduo
#elif L==10	// tr
	"Cut thread of forum of teachers of degree"			// eviri lazim!
#endif
	,
	[ActCutThrForCtrUsr] =
#if   L==1	// ca
	"Cut thread of forum of users of center"	// Necessita traducci
#elif L==2	// de
	"Cut thread of forum of users of center"	// Need bersetzung
#elif L==3	// en
	"Cut thread of forum of users of center"
#elif L==4	// es
	"Cortar hilo del foro de usuarios de centro"
#elif L==5	// fr
	"Cut thread of forum of users of center"	// Besoin de traduction
#elif L==6	// gn
	"Cortar hilo del foro de usuarios de centro"	// Okoteve traduccin
#elif L==7	// it
	"Cut thread of forum of users of center"	// Bisogno di traduzione
#elif L==8	// pl
	"Cut thread of forum of users of center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Cut thread of forum of users of center"	// Precisa de traduo
#elif L==10	// tr
	"Cut thread of forum of users of center"	// eviri lazim!
#endif
	,
	[ActCutThrForCtrTch] =
#if   L==1	// ca
	"Cut thread of forum of teachers of center"	// Necessita traducci
#elif L==2	// de
	"Cut thread of forum of teachers of center"	// Need bersetzung
#elif L==3	// en
	"Cut thread of forum of teachers of center"
#elif L==4	// es
	"Cortar hilo del foro de profesores de centro"
#elif L==5	// fr
	"Cut thread of forum of teachers of center"	// Besoin de traduction
#elif L==6	// gn
	"Cortar hilo del foro de profesores de centro"	// Okoteve traduccin
#elif L==7	// it
	"Cut thread of forum of teachers of center"	// Bisogno di traduzione
#elif L==8	// pl
	"Cut thread of forum of teachers of center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Cut thread of forum of teachers of center"	// Precisa de traduo
#elif L==10	// tr
	"Cut thread of forum of teachers of center"	// eviri lazim!
#endif
	,
	[ActCutThrForInsUsr] =
#if   L==1	// ca
	"Cut thread of forum of users of institution"			// Necessita traducci
#elif L==2	// de
	"Cut thread of forum of users of institution"			// Need bersetzung
#elif L==3	// en
	"Cut thread of forum of users of institution"
#elif L==4	// es
	"Cortar hilo del foro de usuarios de instituci&oacute;n"
#elif L==5	// fr
	"Cut thread of forum of users of institution"			// Besoin de traduction
#elif L==6	// gn
	"Cortar hilo del foro de usuarios de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Cut thread of forum of users of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Cut thread of forum of users of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Cut thread of forum of users of institution"			// Precisa de traduo
#elif L==10	// tr
	"Cut thread of forum of users of institution"			// eviri lazim!
#endif
	,
	[ActCutThrForInsTch] =
#if   L==1	// ca
	"Cut thread of forum of teachers of institution"		// Necessita traducci
#elif L==2	// de
	"Cut thread of forum of teachers of institution"		// Need bersetzung
#elif L==3	// en
	"Cut thread of forum of teachers of institution"
#elif L==4	// es
	"Cortar hilo del foro de profesores de instituci&oacute;n"
#elif L==5	// fr
	"Cut thread of forum of teachers of institution"		// Besoin de traduction
#elif L==6	// gn
	"Cortar hilo del foro de profesores de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Cut thread of forum of teachers of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Cut thread of forum of teachers of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Cut thread of forum of teachers of institution"		// Precisa de traduo
#elif L==10	// tr
	"Cut thread of forum of teachers of institution"		// eviri lazim!
#endif
	,
	[ActCutThrForGenUsr] =
#if   L==1	// ca
	"Cut thread of general forum of users"		// Necessita traducci
#elif L==2	// de
	"Cut thread of general forum of users"		// Need bersetzung
#elif L==3	// en
	"Cut thread of general forum of users"
#elif L==4	// es
	"Cortar hilo del foro de usuarios general"
#elif L==5	// fr
	"Cut thread of general forum of users"		// Besoin de traduction
#elif L==6	// gn
	"Cortar hilo del foro de usuarios general"	// Okoteve traduccin
#elif L==7	// it
	"Cut thread of general forum of users"		// Bisogno di traduzione
#elif L==8	// pl
	"Cut thread of general forum of users"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Cut thread of general forum of users"		// Precisa de traduo
#elif L==10	// tr
	"Cut thread of general forum of users"		// eviri lazim!
#endif
	,
	[ActCutThrForGenTch] =
#if   L==1	// ca
	"Cut thread of general forum of teachers"	// Necessita traducci
#elif L==2	// de
	"Cut thread of general forum of teachers"	// Need bersetzung
#elif L==3	// en
	"Cut thread of general forum of teachers"
#elif L==4	// es
	"Cortar hilo del foro de profesores general"
#elif L==5	// fr
	"Cut thread of general forum of teachers"	// Besoin de traduction
#elif L==6	// gn
	"Cortar hilo del foro de profesores general"	// Okoteve traduccin
#elif L==7	// it
	"Cut thread of general forum of teachers"	// Bisogno di traduzione
#elif L==8	// pl
	"Cut thread of general forum of teachers"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Cut thread of general forum of teachers"	// Precisa de traduo
#elif L==10	// tr
	"Cut thread of general forum of teachers"	// eviri lazim!
#endif
	,
	[ActCutThrForSWAUsr] =
#if   L==1	// ca
	"Cut thread of forum of users of the platform"		// Necessita traducci
#elif L==2	// de
	"Cut thread of forum of users of the platform"		// Need bersetzung
#elif L==3	// en
	"Cut thread of forum of users of the platform"
#elif L==4	// es
	"Cortar hilo del foro de usuarios de la plataforma"
#elif L==5	// fr
	"Cut thread of forum of users of the platform"		// Besoin de traduction
#elif L==6	// gn
	"Cortar hilo del foro de usuarios de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Cut thread of forum of users of the platform"		// Bisogno di traduzione
#elif L==8	// pl
	"Cut thread of forum of users of the platform"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Cut thread of forum of users of the platform"		// Precisa de traduo
#elif L==10	// tr
	"Cut thread of forum of users of the platform"		// eviri lazim!
#endif
	,
	[ActCutThrForSWATch] =
#if   L==1	// ca
	"Cut thread of forum of teachers of the platform"	// Necessita traducci
#elif L==2	// de
	"Cut thread of forum of teachers of the platform"	// Need bersetzung
#elif L==3	// en
	"Cut thread of forum of teachers of the platform"
#elif L==4	// es
	"Cortar hilo del foro de profesores de la plataforma"
#elif L==5	// fr
	"Cut thread of forum of teachers of the platform"	// Besoin de traduction
#elif L==6	// gn
	"Cortar hilo del foro de profesores de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Cut thread of forum of teachers of the platform"	// Bisogno di traduzione
#elif L==8	// pl
	"Cut thread of forum of teachers of the platform"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Cut thread of forum of teachers of the platform"	// Precisa de traduo
#elif L==10	// tr
	"Cut thread of forum of teachers of the platform"	// eviri lazim!
#endif
	,
	[ActPasThrForCrsUsr] =
#if   L==1	// ca
	"Paste thread of forum of users of course"	// Necessita traducci
#elif L==2	// de
	"Paste thread of forum of users of course"	// Need bersetzung
#elif L==3	// en
	"Paste thread of forum of users of course"
#elif L==4	// es
	"Pegar hilo del foro de usuarios de asignatura"
#elif L==5	// fr
	"Paste thread of forum of users of course"	// Besoin de traduction
#elif L==6	// gn
	"Pegar hilo del foro de usuarios de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Paste thread of forum of users of course"	// Bisogno di traduzione
#elif L==8	// pl
	"Paste thread of forum of users of course"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste thread of forum of users of course"	// Precisa de traduo
#elif L==10	// tr
	"Paste thread of forum of users of course"	// eviri lazim!
#endif
	,
	[ActPasThrForCrsTch] =
#if   L==1	// ca
	"Paste thread of forum of teachers of course"		// Necessita traducci
#elif L==2	// de
	"Paste thread of forum of teachers of course"		// Need bersetzung
#elif L==3	// en
	"Paste thread of forum of teachers of course"
#elif L==4	// es
	"Pegar hilo del foro de profesores de asignatura"
#elif L==5	// fr
	"Paste thread of forum of teachers of course"		// Besoin de traduction
#elif L==6	// gn
	"Pegar hilo del foro de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Paste thread of forum of teachers of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Paste thread of forum of teachers of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste thread of forum of teachers of course"		// Precisa de traduo
#elif L==10	// tr
	"Paste thread of forum of teachers of course"		// eviri lazim!
#endif
	,
	[ActPasThrForDegUsr] =
#if   L==1	// ca
	"Paste thread of forum of users of degree"		// Necessita traducci
#elif L==2	// de
	"Paste thread of forum of users of degree"		// Need bersetzung
#elif L==3	// en
	"Paste thread of forum of users of degree"
#elif L==4	// es
	"Pegar hilo del foro de usuarios de titulaci&oacute;n"
#elif L==5	// fr
	"Paste thread of forum of users of degree"		// Besoin de traduction
#elif L==6	// gn
	"Pegar hilo del foro de usuarios de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Paste thread of forum of users of degree"		// Bisogno di traduzione
#elif L==8	// pl
	"Paste thread of forum of users of degree"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste thread of forum of users of degree"		// Precisa de traduo
#elif L==10	// tr
	"Paste thread of forum of users of degree"		// eviri lazim!
#endif
	,
	[ActPasThrForDegTch] =
#if   L==1	// ca
	"Paste thread of forum of teachers of degree"			// Necessita traducci
#elif L==2	// de
	"Paste thread of forum of teachers of degree"			// Need bersetzung
#elif L==3	// en
	"Paste thread of forum of teachers of degree"
#elif L==4	// es
	"Pegar hilo del foro de profesores de titulaci&oacute;n"
#elif L==5	// fr
	"Paste thread of forum of teachers of degree"			// Besoin de traduction
#elif L==6	// gn
	"Pegar hilo del foro de profesores de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Paste thread of forum of teachers of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Paste thread of forum of teachers of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste thread of forum of teachers of degree"			// Precisa de traduo
#elif L==10	// tr
	"Paste thread of forum of teachers of degree"			// eviri lazim!
#endif
	,
	[ActPasThrForCtrUsr] =
#if   L==1	// ca
	"Paste thread of forum of users of center"	// Necessita traducci
#elif L==2	// de
	"Paste thread of forum of users of center"	// Need bersetzung
#elif L==3	// en
	"Paste thread of forum of users of center"
#elif L==4	// es
	"Pegar hilo del foro de usuarios de centro"
#elif L==5	// fr
	"Paste thread of forum of users of center"	// Besoin de traduction
#elif L==6	// gn
	"Pegar hilo del foro de usuarios de centro"	// Okoteve traduccin
#elif L==7	// it
	"Paste thread of forum of users of center"	// Bisogno di traduzione
#elif L==8	// pl
	"Paste thread of forum of users of center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste thread of forum of users of center"	// Precisa de traduo
#elif L==10	// tr
	"Paste thread of forum of users of center"	// eviri lazim!
#endif
	,
	[ActPasThrForCtrTch] =
#if   L==1	// ca
	"Paste thread of forum of teachers of center"	// Necessita traducci
#elif L==2	// de
	"Paste thread of forum of teachers of center"	// Need bersetzung
#elif L==3	// en
	"Paste thread of forum of teachers of center"
#elif L==4	// es
	"Pegar hilo del foro de profesores de centro"
#elif L==5	// fr
	"Paste thread of forum of teachers of center"	// Besoin de traduction
#elif L==6	// gn
	"Pegar hilo del foro de profesores de centro"	// Okoteve traduccin
#elif L==7	// it
	"Paste thread of forum of teachers of center"	// Bisogno di traduzione
#elif L==8	// pl
	"Paste thread of forum of teachers of center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste thread of forum of teachers of center"	// Precisa de traduo
#elif L==10	// tr
	"Paste thread of forum of teachers of center"	// eviri lazim!
#endif
	,
	[ActPasThrForInsUsr] =
#if   L==1	// ca
	"Paste thread of forum of users of institution"		// Necessita traducci
#elif L==2	// de
	"Paste thread of forum of users of institution"		// Need bersetzung
#elif L==3	// en
	"Paste thread of forum of users of institution"
#elif L==4	// es
	"Pegar hilo del foro de usuarios de instituci&oacute;n"
#elif L==5	// fr
	"Paste thread of forum of users of institution"		// Besoin de traduction
#elif L==6	// gn
	"Pegar hilo del foro de usuarios de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Paste thread of forum of users of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Paste thread of forum of users of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste thread of forum of users of institution"		// Precisa de traduo
#elif L==10	// tr
	"Paste thread of forum of users of institution"		// eviri lazim!
#endif
	,
	[ActPasThrForInsTch] =
#if   L==1	// ca
	"Paste thread of forum of teachers of institution"		// Necessita traducci
#elif L==2	// de
	"Paste thread of forum of teachers of institution"		// Need bersetzung
#elif L==3	// en
	"Paste thread of forum of teachers of institution"
#elif L==4	// es
	"Pegar hilo del foro de profesores de instituci&oacute;n"
#elif L==5	// fr
	"Paste thread of forum of teachers of institution"		// Besoin de traduction
#elif L==6	// gn
	"Pegar hilo del foro de profesores de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Paste thread of forum of teachers of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Paste thread of forum of teachers of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste thread of forum of teachers of institution"		// Precisa de traduo
#elif L==10	// tr
	"Paste thread of forum of teachers of institution"		// eviri lazim!
#endif
	,
	[ActPasThrForGenUsr] =
#if   L==1	// ca
	"Paste thread of general forum of users"	// Necessita traducci
#elif L==2	// de
	"Paste thread of general forum of users"	// Need bersetzung
#elif L==3	// en
	"Paste thread of general forum of users"
#elif L==4	// es
	"Pegar hilo del foro de usuarios general"
#elif L==5	// fr
	"Paste thread of general forum of users"	// Besoin de traduction
#elif L==6	// gn
	"Pegar hilo del foro de usuarios general"	// Okoteve traduccin
#elif L==7	// it
	"Paste thread of general forum of users"	// Bisogno di traduzione
#elif L==8	// pl
	"Paste thread of general forum of users"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste thread of general forum of users"	// Precisa de traduo
#elif L==10	// tr
	"Paste thread of general forum of users"	// eviri lazim!
#endif
	,
	[ActPasThrForGenTch] =
#if   L==1	// ca
	"Paste thread of general forum of teachers"	// Necessita traducci
#elif L==2	// de
	"Paste thread of general forum of teachers"	// Need bersetzung
#elif L==3	// en
	"Paste thread of general forum of teachers"
#elif L==4	// es
	"Pegar hilo del foro de profesores general"
#elif L==5	// fr
	"Paste thread of general forum of teachers"	// Besoin de traduction
#elif L==6	// gn
	"Pegar hilo del foro de profesores general"	// Okoteve traduccin
#elif L==7	// it
	"Paste thread of general forum of teachers"	// Bisogno di traduzione
#elif L==8	// pl
	"Paste thread of general forum of teachers"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste thread of general forum of teachers"	// Precisa de traduo
#elif L==10	// tr
	"Paste thread of general forum of teachers"	// eviri lazim!
#endif
	,
	[ActPasThrForSWAUsr] =
#if   L==1	// ca
	"Paste thread of forum of users of the platform"	// Necessita traducci
#elif L==2	// de
	"Paste thread of forum of users of the platform"	// Need bersetzung
#elif L==3	// en
	"Paste thread of forum of users of the platform"
#elif L==4	// es
	"Pegar hilo del foro de usuarios de la plataforma"
#elif L==5	// fr
	"Paste thread of forum of users of the platform"	// Besoin de traduction
#elif L==6	// gn
	"Pegar hilo del foro de usuarios de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Paste thread of forum of users of the platform"	// Bisogno di traduzione
#elif L==8	// pl
	"Paste thread of forum of users of the platform"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste thread of forum of users of the platform"	// Precisa de traduo
#elif L==10	// tr
	"Paste thread of forum of users of the platform"	// eviri lazim!
#endif
	,
	[ActPasThrForSWATch] =
#if   L==1	// ca
	"Paste thread of forum of teachers of the platform"	// Necessita traducci
#elif L==2	// de
	"Paste thread of forum of teachers of the platform"	// Need bersetzung
#elif L==3	// en
	"Paste thread of forum of teachers of the platform"
#elif L==4	// es
	"Pegar hilo del foro de profesores de la plataforma"
#elif L==5	// fr
	"Paste thread of forum of teachers of the platform"	// Besoin de traduction
#elif L==6	// gn
	"Pegar hilo del foro de profesores de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Paste thread of forum of teachers of the platform"	// Bisogno di traduzione
#elif L==8	// pl
	"Paste thread of forum of teachers of the platform"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Paste thread of forum of teachers of the platform"	// Precisa de traduo
#elif L==10	// tr
	"Paste thread of forum of teachers of the platform"	// eviri lazim!
#endif
	,
	[ActDelPstForCrsUsr] =
#if   L==1	// ca
	"Remove post of forum of users of course"		// Necessita traducci
#elif L==2	// de
	"Remove post of forum of users of course"		// Need bersetzung
#elif L==3	// en
	"Remove post of forum of users of course"
#elif L==4	// es
	"Eliminar mensaje del foro de usuarios de asignatura"
#elif L==5	// fr
	"Remove post of forum of users of course"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar mensaje del foro de usuarios de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove post of forum of users of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove post of forum of users of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove post of forum of users of course"		// Precisa de traduo
#elif L==10	// tr
	"Remove post of forum of users of course"		// eviri lazim!
#endif
	,
	[ActDelPstForCrsTch] =
#if   L==1	// ca
	"Remove post of forum of teachers of course"		// Necessita traducci
#elif L==2	// de
	"Remove post of forum of teachers of course"		// Need bersetzung
#elif L==3	// en
	"Remove post of forum of teachers of course"
#elif L==4	// es
	"Eliminar mensaje del foro de profesores de asignatura"
#elif L==5	// fr
	"Remove post of forum of teachers of course"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar mensaje del foro de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Remove post of forum of teachers of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove post of forum of teachers of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove post of forum of teachers of course"		// Precisa de traduo
#elif L==10	// tr
	"Remove post of forum of teachers of course"		// eviri lazim!
#endif
	,
	[ActDelPstForDegUsr] =
#if   L==1	// ca
	"Remove post of forum of users of degree"			// Necessita traducci
#elif L==2	// de
	"Remove post of forum of users of degree"			// Need bersetzung
#elif L==3	// en
	"Remove post of forum of users of degree"
#elif L==4	// es
	"Eliminar mensaje del foro de usuarios de titulaci&oacute;n"
#elif L==5	// fr
	"Remove post of forum of users of degree"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar mensaje del foro de usuarios de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove post of forum of users of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove post of forum of users of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove post of forum of users of degree"			// Precisa de traduo
#elif L==10	// tr
	"Remove post of forum of users of degree"			// eviri lazim!
#endif
	,
	[ActDelPstForDegTch] =
#if   L==1	// ca
	"Remove post of forum of teachers of degree"			// Necessita traducci
#elif L==2	// de
	"Remove post of forum of teachers of degree"			// Need bersetzung
#elif L==3	// en
	"Remove post of forum of teachers of degree"
#elif L==4	// es
	"Eliminar mensaje del foro de profesores de titulaci&oacute;n"
#elif L==5	// fr
	"Remove post of forum of teachers of degree"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar mensaje del foro de profesores de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove post of forum of teachers of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove post of forum of teachers of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove post of forum of teachers of degree"			// Precisa de traduo
#elif L==10	// tr
	"Remove post of forum of teachers of degree"			// eviri lazim!
#endif
	,
	[ActDelPstForCtrUsr] =
#if   L==1	// ca
	"Remove post of forum of users of center"		// Necessita traducci
#elif L==2	// de
	"Remove post of forum of users of center"		// Need bersetzung
#elif L==3	// en
	"Remove post of forum of users of center"
#elif L==4	// es
	"Eliminar mensaje del foro de usuarios de centro"
#elif L==5	// fr
	"Remove post of forum of users of center"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar mensaje del foro de usuarios de centro"	// Okoteve traduccin
#elif L==7	// it
	"Remove post of forum of users of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove post of forum of users of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove post of forum of users of center"		// Precisa de traduo
#elif L==10	// tr
	"Remove post of forum of users of center"		// eviri lazim!
#endif
	,
	[ActDelPstForCtrTch] =
#if   L==1	// ca
	"Remove post of forum of teachers of center"		// Necessita traducci
#elif L==2	// de
	"Remove post of forum of teachers of center"		// Need bersetzung
#elif L==3	// en
	"Remove post of forum of teachers of center"
#elif L==4	// es
	"Eliminar mensaje del foro de profesores de centro"
#elif L==5	// fr
	"Remove post of forum of teachers of center"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar mensaje del foro de profesores de centro"	// Okoteve traduccin
#elif L==7	// it
	"Remove post of forum of teachers of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove post of forum of teachers of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove post of forum of teachers of center"		// Precisa de traduo
#elif L==10	// tr
	"Remove post of forum of teachers of center"		// eviri lazim!
#endif
	,
	[ActDelPstForInsUsr] =
#if   L==1	// ca
	"Remove post of forum of users of institution"			// Necessita traducci
#elif L==2	// de
	"Remove post of forum of users of institution"			// Need bersetzung
#elif L==3	// en
	"Remove post of forum of users of institution"
#elif L==4	// es
	"Eliminar mensaje del foro de usuarios de instituci&oacute;n"
#elif L==5	// fr
	"Remove post of forum of users of institution"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar mensaje del foro de usuarios de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove post of forum of users of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove post of forum of users of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove post of forum of users of institution"			// Precisa de traduo
#elif L==10	// tr
	"Remove post of forum of users of institution"			// eviri lazim!
#endif
	,
	[ActDelPstForInsTch] =
#if   L==1	// ca
	"Remove post of forum of teachers of institution"		// Necessita traducci
#elif L==2	// de
	"Remove post of forum of teachers of institution"		// Need bersetzung
#elif L==3	// en
	"Remove post of forum of teachers of institution"
#elif L==4	// es
	"Eliminar mensaje del foro de profesores de instituci&oacute;n"
#elif L==5	// fr
	"Remove post of forum of teachers of institution"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar mensaje del foro de profesores de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Remove post of forum of teachers of institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove post of forum of teachers of institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove post of forum of teachers of institution"		// Precisa de traduo
#elif L==10	// tr
	"Remove post of forum of teachers of institution"		// eviri lazim!
#endif
	,
	[ActDelPstForGenUsr] =
#if   L==1	// ca
	"Remove post of general forum of users"		// Necessita traducci
#elif L==2	// de
	"Remove post of general forum of users"		// Need bersetzung
#elif L==3	// en
	"Remove post of general forum of users"
#elif L==4	// es
	"Eliminar mensaje del foro de usuarios general"
#elif L==5	// fr
	"Remove post of general forum of users"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar mensaje del foro de usuarios general"	// Okoteve traduccin
#elif L==7	// it
	"Remove post of general forum of users"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove post of general forum of users"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove post of general forum of users"		// Precisa de traduo
#elif L==10	// tr
	"Remove post of general forum of users"		// eviri lazim!
#endif
	,
	[ActDelPstForGenTch] =
#if   L==1	// ca
	"Remove post of general forum of teachers"		// Necessita traducci
#elif L==2	// de
	"Remove post of general forum of teachers"		// Need bersetzung
#elif L==3	// en
	"Remove post of general forum of teachers"
#elif L==4	// es
	"Eliminar mensaje del foro de profesores general"
#elif L==5	// fr
	"Remove post of general forum of teachers"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar mensaje del foro de profesores general"	// Okoteve traduccin
#elif L==7	// it
	"Remove post of general forum of teachers"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove post of general forum of teachers"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove post of general forum of teachers"		// Precisa de traduo
#elif L==10	// tr
	"Remove post of general forum of teachers"		// eviri lazim!
#endif
	,
	[ActDelPstForSWAUsr] =
#if   L==1	// ca
	"Remove post of forum of users of the platform"			// Necessita traducci
#elif L==2	// de
	"Remove post of forum of users of the platform"			// Need bersetzung
#elif L==3	// en
	"Remove post of forum of users of the platform"
#elif L==4	// es
	"Eliminar mensaje del foro de usuarios de la plataforma"
#elif L==5	// fr
	"Remove post of forum of users of the platform"			// Besoin de traduction
#elif L==6	// gn
	"Eliminar mensaje del foro de usuarios de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Remove post of forum of users of the platform"			// Bisogno di traduzione
#elif L==8	// pl
	"Remove post of forum of users of the platform"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove post of forum of users of the platform"			// Precisa de traduo
#elif L==10	// tr
	"Remove post of forum of users of the platform"			// eviri lazim!
#endif
	,
	[ActDelPstForSWATch] =
#if   L==1	// ca
	"Remove post of forum of teachers of the platform"		// Necessita traducci
#elif L==2	// de
	"Remove post of forum of teachers of the platform"		// Need bersetzung
#elif L==3	// en
	"Remove post of forum of teachers of the platform"
#elif L==4	// es
	"Eliminar mensaje del foro de profesores de la plataforma"
#elif L==5	// fr
	"Remove post of forum of teachers of the platform"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar mensaje del foro de profesores de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Remove post of forum of teachers of the platform"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove post of forum of teachers of the platform"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove post of forum of teachers of the platform"		// Precisa de traduo
#elif L==10	// tr
	"Remove post of forum of teachers of the platform"		// eviri lazim!
#endif
	,
	[ActEnbPstForCrsUsr] =
#if   L==1	// ca
	"Enable post of forum of users of course"		// Necessita traducci
#elif L==2	// de
	"Enable post of forum of users of course"		// Need bersetzung
#elif L==3	// en
	"Enable post of forum of users of course"
#elif L==4	// es
	"Habilitar mensaje del foro de usuarios de asignatura"
#elif L==5	// fr
	"Enable post of forum of users of course"		// Besoin de traduction
#elif L==6	// gn
	"Habilitar mensaje del foro de usuarios de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Enable post of forum of users of course"		// Bisogno di traduzione
#elif L==8	// pl
	"Enable post of forum of users of course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enable post of forum of users of course"		// Precisa de traduo
#elif L==10	// tr
	"Enable post of forum of users of course"		// eviri lazim!
#endif
	,
	[ActEnbPstForCrsTch] =
#if   L==1	// ca
	"Enable post of forum of teachers of course"			// Necessita traducci
#elif L==2	// de
	"Enable post of forum of teachers of course"			// Need bersetzung
#elif L==3	// en
	"Enable post of forum of teachers of course"
#elif L==4	// es
	"Habilitar mensaje del foro de profesores de asignatura"
#elif L==5	// fr
	"Enable post of forum of teachers of course"			// Besoin de traduction
#elif L==6	// gn
	"Habilitar mensaje del foro de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Enable post of forum of teachers of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Enable post of forum of teachers of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enable post of forum of teachers of course"			// Precisa de traduo
#elif L==10	// tr
	"Enable post of forum of teachers of course"			// eviri lazim!
#endif
	,
	[ActEnbPstForDegUsr] =
#if   L==1	// ca
	"Enable post of forum of users of degree"			// Necessita traducci
#elif L==2	// de
	"Enable post of forum of users of degree"			// Need bersetzung
#elif L==3	// en
	"Enable post of forum of users of degree"
#elif L==4	// es
	"Habilitar mensaje del foro de usuarios de titulaci&oacute;n"
#elif L==5	// fr
	"Enable post of forum of users of degree"			// Besoin de traduction
#elif L==6	// gn
	"Habilitar mensaje del foro de usuarios de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Enable post of forum of users of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Enable post of forum of users of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enable post of forum of users of degree"			// Precisa de traduo
#elif L==10	// tr
	"Enable post of forum of users of degree"			// eviri lazim!
#endif
	,
	[ActEnbPstForDegTch] =
#if   L==1	// ca
	"Enable post of forum of teachers of degree"			// Necessita traducci
#elif L==2	// de
	"Enable post of forum of teachers of degree"			// Need bersetzung
#elif L==3	// en
	"Enable post of forum of teachers of degree"
#elif L==4	// es
	"Habilitar mensaje del foro de profesores de titulaci&oacute;n"
#elif L==5	// fr
	"Enable post of forum of teachers of degree"			// Besoin de traduction
#elif L==6	// gn
	"Habilitar mensaje del foro de profesores de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Enable post of forum of teachers of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Enable post of forum of teachers of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enable post of forum of teachers of degree"			// Precisa de traduo
#elif L==10	// tr
	"Enable post of forum of teachers of degree"			// eviri lazim!
#endif
	,
	[ActEnbPstForCtrUsr] =
#if   L==1	// ca
	"Enable post of forum of users of center"		// Necessita traducci
#elif L==2	// de
	"Enable post of forum of users of center"		// Need bersetzung
#elif L==3	// en
	"Enable post of forum of users of center"
#elif L==4	// es
	"Habilitar mensaje del foro de usuarios de centro"
#elif L==5	// fr
	"Enable post of forum of users of center"		// Besoin de traduction
#elif L==6	// gn
	"Habilitar mensaje del foro de usuarios de centro"	// Okoteve traduccin
#elif L==7	// it
	"Enable post of forum of users of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Enable post of forum of users of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enable post of forum of users of center"		// Precisa de traduo
#elif L==10	// tr
	"Enable post of forum of users of center"		// eviri lazim!
#endif
	,
	[ActEnbPstForCtrTch] =
#if   L==1	// ca
	"Enable post of forum of teachers of center"		// Necessita traducci
#elif L==2	// de
	"Enable post of forum of teachers of center"		// Need bersetzung
#elif L==3	// en
	"Enable post of forum of teachers of center"
#elif L==4	// es
	"Habilitar mensaje del foro de profesores de centro"
#elif L==5	// fr
	"Enable post of forum of teachers of center"		// Besoin de traduction
#elif L==6	// gn
	"Habilitar mensaje del foro de profesores de centro"	// Okoteve traduccin
#elif L==7	// it
	"Enable post of forum of teachers of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Enable post of forum of teachers of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enable post of forum of teachers of center"		// Precisa de traduo
#elif L==10	// tr
	"Enable post of forum of teachers of center"		// eviri lazim!
#endif
	,
	[ActEnbPstForInsUsr] =
#if   L==1	// ca
	"Enable post of forum of users of institution"			// Necessita traducci
#elif L==2	// de
	"Enable post of forum of users of institution"			// Need bersetzung
#elif L==3	// en
	"Enable post of forum of users of institution"
#elif L==4	// es
	"Habilitar mensaje del foro de usuarios de instituci&oacute;n"
#elif L==5	// fr
	"Enable post of forum of users of institution"			// Besoin de traduction
#elif L==6	// gn
	"Habilitar mensaje del foro de usuarios de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Enable post of forum of users of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Enable post of forum of users of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enable post of forum of users of institution"			// Precisa de traduo
#elif L==10	// tr
	"Enable post of forum of users of institution"			// eviri lazim!
#endif
	,
	[ActEnbPstForInsTch] =
#if   L==1	// ca
	"Enable post of forum of teachers of institution"			// Necessita traducci
#elif L==2	// de
	"Enable post of forum of teachers of institution"			// Need bersetzung
#elif L==3	// en
	"Enable post of forum of teachers of institution"
#elif L==4	// es
	"Habilitar mensaje del foro de profesores de instituci&oacute;n"
#elif L==5	// fr
	"Enable post of forum of teachers of institution"			// Besoin de traduction
#elif L==6	// gn
	"Habilitar mensaje del foro de profesores de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Enable post of forum of teachers of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Enable post of forum of teachers of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enable post of forum of teachers of institution"			// Precisa de traduo
#elif L==10	// tr
	"Enable post of forum of teachers of institution"			// eviri lazim!
#endif
	,
	[ActEnbPstForGenUsr] =
#if   L==1	// ca
	"Enable post of general forum of users"			// Necessita traducci
#elif L==2	// de
	"Enable post of general forum of users"			// Need bersetzung
#elif L==3	// en
	"Enable post of general forum of users"
#elif L==4	// es
	"Habilitar mensaje del foro de usuarios general"
#elif L==5	// fr
	"Enable post of general forum of users"			// Besoin de traduction
#elif L==6	// gn
	"Habilitar mensaje del foro de usuarios general"	// Okoteve traduccin
#elif L==7	// it
	"Enable post of general forum of users"			// Bisogno di traduzione
#elif L==8	// pl
	"Enable post of general forum of users"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enable post of general forum of users"			// Precisa de traduo
#elif L==10	// tr
	"Enable post of general forum of users"			// eviri lazim!
#endif
	,
	[ActEnbPstForGenTch] =
#if   L==1	// ca
	"Enable post of general forum of teachers"		// Necessita traducci
#elif L==2	// de
	"Enable post of general forum of teachers"		// Need bersetzung
#elif L==3	// en
	"Enable post of general forum of teachers"
#elif L==4	// es
	"Habilitar mensaje del foro de profesores general"
#elif L==5	// fr
	"Enable post of general forum of teachers"		// Besoin de traduction
#elif L==6	// gn
	"Habilitar mensaje del foro de profesores general"	// Okoteve traduccin
#elif L==7	// it
	"Enable post of general forum of teachers"		// Bisogno di traduzione
#elif L==8	// pl
	"Enable post of general forum of teachers"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enable post of general forum of teachers"		// Precisa de traduo
#elif L==10	// tr
	"Enable post of general forum of teachers"		// eviri lazim!
#endif
	,
	[ActEnbPstForSWAUsr] =
#if   L==1	// ca
	"Enable post of forum of users of the platform"			// Necessita traducci
#elif L==2	// de
	"Enable post of forum of users of the platform"			// Need bersetzung
#elif L==3	// en
	"Enable post of forum of users of the platform"
#elif L==4	// es
	"Habilitar mensaje del foro de usuarios de la plataforma"
#elif L==5	// fr
	"Enable post of forum of users of the platform"			// Besoin de traduction
#elif L==6	// gn
	"Habilitar mensaje del foro de usuarios de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Enable post of forum of users of the platform"			// Bisogno di traduzione
#elif L==8	// pl
	"Enable post of forum of users of the platform"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enable post of forum of users of the platform"			// Precisa de traduo
#elif L==10	// tr
	"Enable post of forum of users of the platform"			// eviri lazim!
#endif
	,
	[ActEnbPstForSWATch] =
#if   L==1	// ca
	"Enable post of forum of teachers of the platform"		// Necessita traducci
#elif L==2	// de
	"Enable post of forum of teachers of the platform"		// Need bersetzung
#elif L==3	// en
	"Enable post of forum of teachers of the platform"
#elif L==4	// es
	"Habilitar mensaje del foro de profesores de la plataforma"
#elif L==5	// fr
	"Enable post of forum of teachers of the platform"		// Besoin de traduction
#elif L==6	// gn
	"Habilitar mensaje del foro de profesores de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Enable post of forum of teachers of the platform"		// Bisogno di traduzione
#elif L==8	// pl
	"Enable post of forum of teachers of the platform"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enable post of forum of teachers of the platform"		// Precisa de traduo
#elif L==10	// tr
	"Enable post of forum of teachers of the platform"		// eviri lazim!
#endif
	,
	[ActDisPstForCrsUsr] =
#if   L==1	// ca
	"Disable post of forum of users of course"			// Necessita traducci
#elif L==2	// de
	"Disable post of forum of users of course"			// Need bersetzung
#elif L==3	// en
	"Disable post of forum of users of course"
#elif L==4	// es
	"Inhabilitar mensaje del foro de usuarios de asignatura"
#elif L==5	// fr
	"Disable post of forum of users of course"			// Besoin de traduction
#elif L==6	// gn
	"Inhabilitar mensaje del foro de usuarios de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Disable post of forum of users of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Disable post of forum of users of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Disable post of forum of users of course"			// Precisa de traduo
#elif L==10	// tr
	"Disable post of forum of users of course"			// eviri lazim!
#endif
	,
	[ActDisPstForCrsTch] =
#if   L==1	// ca
	"Disable post of forum of teachers of course"			// Necessita traducci
#elif L==2	// de
	"Disable post of forum of teachers of course"			// Need bersetzung
#elif L==3	// en
	"Disable post of forum of teachers of course"
#elif L==4	// es
	"Inhabilitar mensaje del foro de profesores de asignatura"
#elif L==5	// fr
	"Disable post of forum of teachers of course"			// Besoin de traduction
#elif L==6	// gn
	"Inhabilitar mensaje del foro de profesores de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Disable post of forum of teachers of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Disable post of forum of teachers of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Disable post of forum of teachers of course"			// Precisa de traduo
#elif L==10	// tr
	"Disable post of forum of teachers of course"			// eviri lazim!
#endif
	,
	[ActDisPstForDegUsr] =
#if   L==1	// ca
	"Disable post of forum of users of degree"			// Necessita traducci
#elif L==2	// de
	"Disable post of forum of users of degree"			// Need bersetzung
#elif L==3	// en
	"Disable post of forum of users of degree"
#elif L==4	// es
	"Inhabilitar mensaje del foro de usuarios de titulaci&oacute;n"
#elif L==5	// fr
	"Disable post of forum of users of degree"			// Besoin de traduction
#elif L==6	// gn
	"Inhabilitar mensaje del foro de usuarios de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Disable post of forum of users of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Disable post of forum of users of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Disable post of forum of users of degree"			// Precisa de traduo
#elif L==10	// tr
	"Disable post of forum of users of degree"			// eviri lazim!
#endif
	,
	[ActDisPstForDegTch] =
#if   L==1	// ca
	"Disable post of forum of teachers of degree"				// Necessita traducci
#elif L==2	// de
	"Disable post of forum of teachers of degree"				// Need bersetzung
#elif L==3	// en
	"Disable post of forum of teachers of degree"
#elif L==4	// es
	"Inhabilitar mensaje del foro de profesores de titulaci&oacute;n"
#elif L==5	// fr
	"Disable post of forum of teachers of degree"				// Besoin de traduction
#elif L==6	// gn
	"Inhabilitar mensaje del foro de profesores de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Disable post of forum of teachers of degree"				// Bisogno di traduzione
#elif L==8	// pl
	"Disable post of forum of teachers of degree"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Disable post of forum of teachers of degree"				// Precisa de traduo
#elif L==10	// tr
	"Disable post of forum of teachers of degree"				// eviri lazim!
#endif
	,
	[ActDisPstForCtrUsr] =
#if   L==1	// ca
	"Disable post of forum of users of center"		// Necessita traducci
#elif L==2	// de
	"Disable post of forum of users of center"		// Need bersetzung
#elif L==3	// en
	"Disable post of forum of users of center"
#elif L==4	// es
	"Inhabilitar mensaje del foro de usuarios de centro"
#elif L==5	// fr
	"Disable post of forum of users of center"		// Besoin de traduction
#elif L==6	// gn
	"Inhabilitar mensaje del foro de usuarios de centro"	// Okoteve traduccin
#elif L==7	// it
	"Disable post of forum of users of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Disable post of forum of users of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Disable post of forum of users of center"		// Precisa de traduo
#elif L==10	// tr
	"Disable post of forum of users of center"		// eviri lazim!
#endif
	,
	[ActDisPstForCtrTch] =
#if   L==1	// ca
	"Disable post of forum of teachers of center"		// Necessita traducci
#elif L==2	// de
	"Disable post of forum of teachers of center"		// Need bersetzung
#elif L==3	// en
	"Disable post of forum of teachers of center"
#elif L==4	// es
	"Inhabilitar mensaje del foro de profesores de centro"
#elif L==5	// fr
	"Disable post of forum of teachers of center"		// Besoin de traduction
#elif L==6	// gn
	"Inhabilitar mensaje del foro de profesores de centro"	// Okoteve traduccin
#elif L==7	// it
	"Disable post of forum of teachers of center"		// Bisogno di traduzione
#elif L==8	// pl
	"Disable post of forum of teachers of center"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Disable post of forum of teachers of center"		// Precisa de traduo
#elif L==10	// tr
	"Disable post of forum of teachers of center"		// eviri lazim!
#endif
	,
	[ActDisPstForInsUsr] =
#if   L==1	// ca
	"Disable post of forum of users of institution"				// Necessita traducci
#elif L==2	// de
	"Disable post of forum of users of institution"				// Need bersetzung
#elif L==3	// en
	"Disable post of forum of users of institution"
#elif L==4	// es
	"Inhabilitar mensaje del foro de usuarios de instituci&oacute;n"
#elif L==5	// fr
	"Disable post of forum of users of institution"				// Besoin de traduction
#elif L==6	// gn
	"Inhabilitar mensaje del foro de usuarios de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Disable post of forum of users of institution"				// Bisogno di traduzione
#elif L==8	// pl
	"Disable post of forum of users of institution"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Disable post of forum of users of institution"				// Precisa de traduo
#elif L==10	// tr
	"Disable post of forum of users of institution"				// eviri lazim!
#endif
	,
	[ActDisPstForInsTch] =
#if   L==1	// ca
	"Disable post of forum of teachers of institution"			// Necessita traducci
#elif L==2	// de
	"Disable post of forum of teachers of institution"			// Need bersetzung
#elif L==3	// en
	"Disable post of forum of teachers of institution"
#elif L==4	// es
	"Inhabilitar mensaje del foro de profesofres de instituci&oacute;n"
#elif L==5	// fr
	"Disable post of forum of teachers of institution"			// Besoin de traduction
#elif L==6	// gn
	"Inhabilitar mensaje del foro de profesofres de instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Disable post of forum of teachers of institution"			// Bisogno di traduzione
#elif L==8	// pl
	"Disable post of forum of teachers of institution"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Disable post of forum of teachers of institution"			// Precisa de traduo
#elif L==10	// tr
	"Disable post of forum of teachers of institution"			// eviri lazim!
#endif
	,
	[ActDisPstForGenUsr] =
#if   L==1	// ca
	"Disable post of general forum of users"		// Necessita traducci
#elif L==2	// de
	"Disable post of general forum of users"		// Need bersetzung
#elif L==3	// en
	"Disable post of general forum of users"
#elif L==4	// es
	"Inhabilitar mensaje del foro de usuarios general"
#elif L==5	// fr
	"Disable post of general forum of users"		// Besoin de traduction
#elif L==6	// gn
	"Inhabilitar mensaje del foro de usuarios general"	// Okoteve traduccin
#elif L==7	// it
	"Disable post of general forum of users"		// Bisogno di traduzione
#elif L==8	// pl
	"Disable post of general forum of users"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Disable post of general forum of users"		// Precisa de traduo
#elif L==10	// tr
	"Disable post of general forum of users"		// eviri lazim!
#endif
	,
	[ActDisPstForGenTch] =
#if   L==1	// ca
	"Disable post of general forum of teachers"		// Necessita traducci
#elif L==2	// de
	"Disable post of general forum of teachers"		// Need bersetzung
#elif L==3	// en
	"Disable post of general forum of teachers"
#elif L==4	// es
	"Inhabilitar mensaje del foro de profesores general"
#elif L==5	// fr
	"Disable post of general forum of teachers"		// Besoin de traduction
#elif L==6	// gn
	"Inhabilitar mensaje del foro de profesores general"	// Okoteve traduccin
#elif L==7	// it
	"Disable post of general forum of teachers"		// Bisogno di traduzione
#elif L==8	// pl
	"Disable post of general forum of teachers"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Disable post of general forum of teachers"		// Precisa de traduo
#elif L==10	// tr
	"Disable post of general forum of teachers"		// eviri lazim!
#endif
	,
	[ActDisPstForSWAUsr] =
#if   L==1	// ca
	"Disable post of forum of users of the platform"		// Necessita traducci
#elif L==2	// de
	"Disable post of forum of users of the platform"		// Need bersetzung
#elif L==3	// en
	"Disable post of forum of users of the platform"
#elif L==4	// es
	"Inhabilitar mensaje del foro de usuarios de la plataforma"
#elif L==5	// fr
	"Disable post of forum of users of the platform"		// Besoin de traduction
#elif L==6	// gn
	"Inhabilitar mensaje del foro de usuarios de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Disable post of forum of users of the platform"		// Bisogno di traduzione
#elif L==8	// pl
	"Disable post of forum of users of the platform"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Disable post of forum of users of the platform"		// Precisa de traduo
#elif L==10	// tr
	"Disable post of forum of users of the platform"		// eviri lazim!
#endif
	,
	[ActDisPstForSWATch] =
#if   L==1	// ca
	"Disable post of forum of teachers of the platform"		// Necessita traducci
#elif L==2	// de
	"Disable post of forum of teachers of the platform"		// Need bersetzung
#elif L==3	// en
	"Disable post of forum of teachers of the platform"
#elif L==4	// es
	"Inhabilitar mensaje del foro de profesores de la plataforma"
#elif L==5	// fr
	"Disable post of forum of teachers of the platform"		// Besoin de traduction
#elif L==6	// gn
	"Inhabilitar mensaje del foro de profesores de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Disable post of forum of teachers of the platform"		// Bisogno di traduzione
#elif L==8	// pl
	"Disable post of forum of teachers of the platform"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Disable post of forum of teachers of the platform"		// Precisa de traduo
#elif L==10	// tr
	"Disable post of forum of teachers of the platform"		// eviri lazim!
#endif
	,
	[ActReqLnkForCrsUsr] =
#if   L==1	// ca
	"Copy link to thread of forum of users of course"			// Necessita traducci
#elif L==2	// de
	"Copy link to thread of forum of users of course"			// Need bersetzung
#elif L==3	// en
	"Copy link to thread of forum of users of course"
#elif L==4	// es
	"Copiar enlace a discusi&oacute;n del foro de usuarios de asignatura"
#elif L==5	// fr
	"Copy link to thread of forum of users of course"			// Besoin de traduction
#elif L==6	// gn
	"Copiar enlace a discusi&oacute;n del foro de usuarios de asignatura"	// Okoteve traduccin
#elif L==7	// it
	"Copy link to thread of forum of users of course"			// Bisogno di traduzione
#elif L==8	// pl
	"Copy link to thread of forum of users of course"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Copy link to thread of forum of users of course"			// Precisa de traduo
#elif L==10	// tr
	"Copy link to thread of forum of users of course"			// eviri lazim!
#endif
	,
	[ActSeeChtRms] =
#if   L==1	// ca
	"See the chat rooms"	// Necessita traducci
#elif L==2	// de
	"See the chat rooms"	// Need bersetzung
#elif L==3	// en
	"See the chat rooms"
#elif L==4	// es
	"Ver las salas de chat"
#elif L==5	// fr
	"See the chat rooms"	// Besoin de traduction
#elif L==6	// gn
	"Ver las salas de chat"	// Okoteve traduccin
#elif L==7	// it
	"See the chat rooms"	// Bisogno di traduzione
#elif L==8	// pl
	"See the chat rooms"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the chat rooms"	// Precisa de traduo
#elif L==10	// tr
	"See the chat rooms"	// eviri lazim!
#endif
	,
	[ActCht] =
#if   L==1	// ca
	"Enter in a chat room to chat"			// Necessita traducci
#elif L==2	// de
	"Enter in a chat room to chat"			// Need bersetzung
#elif L==3	// en
	"Enter in a chat room to chat"
#elif L==4	// es
	"Entrar en una sala de chat para chatear"
#elif L==5	// fr
	"Enter in a chat room to chat"			// Besoin de traduction
#elif L==6	// gn
	"Entrar en una sala de chat para chatear"	// Okoteve traduccin
#elif L==7	// it
	"Enter in a chat room to chat"			// Bisogno di traduzione
#elif L==8	// pl
	"Enter in a chat room to chat"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Enter in a chat room to chat"			// Precisa de traduo
#elif L==10	// tr
	"Enter in a chat room to chat"			// eviri lazim!
#endif
	,
	[ActSeeRcvMsg] =
#if   L==1	// ca
	"Show the messages received"	// Necessita traducci
#elif L==2	// de
	"Show the messages received"	// Need bersetzung
#elif L==3	// en
	"Show the messages received"
#elif L==4	// es
	"Ver mensajes recibidos"
#elif L==5	// fr
	"Show the messages received"	// Besoin de traduction
#elif L==6	// gn
	"Ver mensajes recibidos"	// Okoteve traduccin
#elif L==7	// it
	"Show the messages received"	// Bisogno di traduzione
#elif L==8	// pl
	"Show the messages received"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show the messages received"	// Precisa de traduo
#elif L==10	// tr
	"Show the messages received"	// eviri lazim!
#endif
	,
	[ActReqMsgUsr] =
#if   L==1	// ca
	"Write message"		// Necessita traducci
#elif L==2	// de
	"Write message"		// Need bersetzung
#elif L==3	// en
	"Write message"
#elif L==4	// es
	"Redactar mensaje"
#elif L==5	// fr
	"Write message"		// Besoin de traduction
#elif L==6	// gn
	"Redactar mensaje"	// Okoteve traduccin
#elif L==7	// it
	"Write message"		// Bisogno di traduzione
#elif L==8	// pl
	"Write message"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Write message"		// Precisa de traduo
#elif L==10	// tr
	"Write message"		// eviri lazim!
#endif
	,
	[ActSeeSntMsg] =
#if   L==1	// ca
	"See messages sent"	// Necessita traducci
#elif L==2	// de
	"See messages sent"	// Need bersetzung
#elif L==3	// en
	"See messages sent"
#elif L==4	// es
	"Ver mensajes enviados"
#elif L==5	// fr
	"See messages sent"	// Besoin de traduction
#elif L==6	// gn
	"Ver mensajes enviados"	// Okoteve traduccin
#elif L==7	// it
	"See messages sent"	// Bisogno di traduzione
#elif L==8	// pl
	"See messages sent"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See messages sent"	// Precisa de traduo
#elif L==10	// tr
	"See messages sent"	// eviri lazim!
#endif
	,
	[ActRcvMsgUsr] =
#if   L==1	// ca
	"Send message"		// Necessita traducci
#elif L==2	// de
	"Send message"		// Need bersetzung
#elif L==3	// en
	"Send message"
#elif L==4	// es
	"Enviar mensaje"
#elif L==5	// fr
	"Send message"		// Besoin de traduction
#elif L==6	// gn
	"Enviar mensaje"	// Okoteve traduccin
#elif L==7	// it
	"Send message"		// Bisogno di traduzione
#elif L==8	// pl
	"Send message"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send message"		// Precisa de traduo
#elif L==10	// tr
	"Send message"		// eviri lazim!
#endif
	,
	[ActReqDelAllSntMsg] =
#if   L==1	// ca
	"Request removal of all messages sent"				// Necessita traducci
#elif L==2	// de
	"Request removal of all messages sent"				// Need bersetzung
#elif L==3	// en
	"Request removal of all messages sent"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de todos los mensajes enviados"
#elif L==5	// fr
	"Request removal of all messages sent"				// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de todos los mensajes enviados"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of all messages sent"				// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of all messages sent"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of all messages sent"				// Precisa de traduo
#elif L==10	// tr
	"Request removal of all messages sent"				// eviri lazim!
#endif
	,
	[ActReqDelAllRcvMsg] =
#if   L==1	// ca
	"Request removal of all messages received"			// Necessita traducci
#elif L==2	// de
	"Request removal of all messages received"			// Need bersetzung
#elif L==3	// en
	"Request removal of all messages received"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de todos los mensajes recibidos"
#elif L==5	// fr
	"Request removal of all messages received"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de todos los mensajes recibidos"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of all messages received"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of all messages received"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of all messages received"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of all messages received"			// eviri lazim!
#endif
	,
	[ActDelAllSntMsg] =
#if   L==1	// ca
	"Remove all messages sent"		// Necessita traducci
#elif L==2	// de
	"Remove all messages sent"		// Need bersetzung
#elif L==3	// en
	"Remove all messages sent"
#elif L==4	// es
	"Eliminar todos los mensajes enviados"
#elif L==5	// fr
	"Remove all messages sent"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar todos los mensajes enviados"	// Okoteve traduccin
#elif L==7	// it
	"Remove all messages sent"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove all messages sent"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove all messages sent"		// Precisa de traduo
#elif L==10	// tr
	"Remove all messages sent"		// eviri lazim!
#endif
	,
	[ActDelAllRcvMsg] =
#if   L==1	// ca
	"Remove all messages received"		// Necessita traducci
#elif L==2	// de
	"Remove all messages received"		// Need bersetzung
#elif L==3	// en
	"Remove all messages received"
#elif L==4	// es
	"Eliminar todos los mensajes recibidos"
#elif L==5	// fr
	"Remove all messages received"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar todos los mensajes recibidos"	// Okoteve traduccin
#elif L==7	// it
	"Remove all messages received"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove all messages received"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove all messages received"		// Precisa de traduo
#elif L==10	// tr
	"Remove all messages received"		// eviri lazim!
#endif
	,
	[ActDelSntMsg] =
#if   L==1	// ca
	"Remove message sent"		// Necessita traducci
#elif L==2	// de
	"Remove message sent"		// Need bersetzung
#elif L==3	// en
	"Remove message sent"
#elif L==4	// es
	"Eliminar mensaje enviado"
#elif L==5	// fr
	"Remove message sent"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar mensaje enviado"	// Okoteve traduccin
#elif L==7	// it
	"Remove message sent"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove message sent"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove message sent"		// Precisa de traduo
#elif L==10	// tr
	"Remove message sent"		// eviri lazim!
#endif
	,
	[ActDelRcvMsg] =
#if   L==1	// ca
	"Remove message received"	// Necessita traducci
#elif L==2	// de
	"Remove message received"	// Need bersetzung
#elif L==3	// en
	"Remove message received"
#elif L==4	// es
	"Eliminar mensaje recibido"
#elif L==5	// fr
	"Remove message received"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar mensaje recibido"	// Okoteve traduccin
#elif L==7	// it
	"Remove message received"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove message received"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove message received"	// Precisa de traduo
#elif L==10	// tr
	"Remove message received"	// eviri lazim!
#endif
	,
	[ActExpSntMsg] =
#if   L==1	// ca
	"See (expand) sent message"		// Necessita traducci
#elif L==2	// de
	"See (expand) sent message"		// Need bersetzung
#elif L==3	// en
	"See (expand) sent message"
#elif L==4	// es
	"Ver (expandir) un mensaje enviado"
#elif L==5	// fr
	"See (expand) sent message"		// Besoin de traduction
#elif L==6	// gn
	"Ver (expandir) un mensaje enviado"	// Okoteve traduccin
#elif L==7	// it
	"See (expand) sent message"		// Bisogno di traduzione
#elif L==8	// pl
	"See (expand) sent message"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See (expand) sent message"		// Precisa de traduo
#elif L==10	// tr
	"See (expand) sent message"		// eviri lazim!
#endif
	,
	[ActExpRcvMsg] =
#if   L==1	// ca
	"See (expand) received message"		// Necessita traducci
#elif L==2	// de
	"See (expand) received message"		// Need bersetzung
#elif L==3	// en
	"See (expand) received message"
#elif L==4	// es
	"Ver (expandir) mensaje recibido"
#elif L==5	// fr
	"See (expand) received message"		// Besoin de traduction
#elif L==6	// gn
	"Ver (expandir) mensaje recibido"	// Okoteve traduccin
#elif L==7	// it
	"See (expand) received message"		// Bisogno di traduzione
#elif L==8	// pl
	"See (expand) received message"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See (expand) received message"		// Precisa de traduo
#elif L==10	// tr
	"See (expand) received message"		// eviri lazim!
#endif
	,
	[ActConSntMsg] =
#if   L==1	// ca
	"Hide (contract) sent message"		// Necessita traducci
#elif L==2	// de
	"Hide (contract) sent message"		// Need bersetzung
#elif L==3	// en
	"Hide (contract) sent message"
#elif L==4	// es
	"Ocultar (contraer) mensaje enviado"
#elif L==5	// fr
	"Hide (contract) sent message"		// Besoin de traduction
#elif L==6	// gn
	"Ocultar (contraer) mensaje enviado"	// Okoteve traduccin
#elif L==7	// it
	"Hide (contract) sent message"		// Bisogno di traduzione
#elif L==8	// pl
	"Hide (contract) sent message"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide (contract) sent message"		// Precisa de traduo
#elif L==10	// tr
	"Hide (contract) sent message"		// eviri lazim!
#endif
	,
	[ActConRcvMsg] =
#if   L==1	// ca
	"Hide (contract) received message"		// Necessita traducci
#elif L==2	// de
	"Hide (contract) received message"		// Need bersetzung
#elif L==3	// en
	"Hide (contract) received message"
#elif L==4	// es
	"Ocultar (contraer) un mensaje recibido"
#elif L==5	// fr
	"Hide (contract) received message"		// Besoin de traduction
#elif L==6	// gn
	"Ocultar (contraer) un mensaje recibido"	// Okoteve traduccin
#elif L==7	// it
	"Hide (contract) received message"		// Bisogno di traduzione
#elif L==8	// pl
	"Hide (contract) received message"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide (contract) received message"		// Precisa de traduo
#elif L==10	// tr
	"Hide (contract) received message"		// eviri lazim!
#endif
	,
	[ActLstBanUsr] =
#if   L==1	// ca
	"List banned users"		// Necessita traducci
#elif L==2	// de
	"List banned users"		// Need bersetzung
#elif L==3	// en
	"List banned users"
#elif L==4	// es
	"Listar usuarios baneados"
#elif L==5	// fr
	"List banned users"		// Besoin de traduction
#elif L==6	// gn
	"Listar usuarios baneados"	// Okoteve traduccin
#elif L==7	// it
	"List banned users"		// Bisogno di traduzione
#elif L==8	// pl
	"List banned users"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List banned users"		// Precisa de traduo
#elif L==10	// tr
	"List banned users"		// eviri lazim!
#endif
	,
	[ActBanUsrMsg] =
#if   L==1	// ca
	"Ban sender of message when showing received messages"		// Necessita traducci
#elif L==2	// de
	"Ban sender of message when showing received messages"		// Need bersetzung
#elif L==3	// en
	"Ban sender of message when showing received messages"
#elif L==4	// es
	"Banear emisor de mensaje al mostrar mensajes recibidos"
#elif L==5	// fr
	"Ban sender of message when showing received messages"		// Besoin de traduction
#elif L==6	// gn
	"Banear emisor de mensaje al mostrar mensajes recibidos"	// Okoteve traduccin
#elif L==7	// it
	"Ban sender of message when showing received messages"		// Bisogno di traduzione
#elif L==8	// pl
	"Ban sender of message when showing received messages"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Ban sender of message when showing received messages"		// Precisa de traduo
#elif L==10	// tr
	"Ban sender of message when showing received messages"		// eviri lazim!
#endif
	,
	[ActUnbUsrMsg] =
#if   L==1	// ca
	"Unban sender of message when showing received messages"	// Necessita traducci
#elif L==2	// de
	"Unban sender of message when showing received messages"	// Need bersetzung
#elif L==3	// en
	"Unban sender of message when showing received messages"
#elif L==4	// es
	"Permitir emisor de mensaje al mostrar mensajes recibidos"
#elif L==5	// fr
	"Unban sender of message when showing received messages"	// Besoin de traduction
#elif L==6	// gn
	"Permitir emisor de mensaje al mostrar mensajes recibidos"	// Okoteve traduccin
#elif L==7	// it
	"Unban sender of message when showing received messages"	// Bisogno di traduzione
#elif L==8	// pl
	"Unban sender of message when showing received messages"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unban sender of message when showing received messages"	// Precisa de traduo
#elif L==10	// tr
	"Unban sender of message when showing received messages"	// eviri lazim!
#endif
	,
	[ActUnbUsrLst] =
#if   L==1	// ca
	"Unban a user when listing banned users"		// Necessita traducci
#elif L==2	// de
	"Unban a user when listing banned users"		// Need bersetzung
#elif L==3	// en
	"Unban a user when listing banned users"
#elif L==4	// es
	"Permitir un usuario al listar los usuarios baneados"
#elif L==5	// fr
	"Unban a user when listing banned users"		// Besoin de traduction
#elif L==6	// gn
	"Permitir un usuario al listar los usuarios baneados"	// Okoteve traduccin
#elif L==7	// it
	"Unban a user when listing banned users"		// Bisogno di traduzione
#elif L==8	// pl
	"Unban a user when listing banned users"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unban a user when listing banned users"		// Precisa de traduo
#elif L==10	// tr
	"Unban a user when listing banned users"		// eviri lazim!
#endif
	,
	[ActReqMaiUsr] =
#if   L==1	// ca
	"Select users to send an email to them"		// Necessita traducci
#elif L==2	// de
	"Select users to send an email to them"		// Need bersetzung
#elif L==3	// en
	"Select users to send an email to them"
#elif L==4	// es
	"Seleccionar usuarios para enviarles un correo"
#elif L==5	// fr
	"Select users to send an email to them"		// Besoin de traduction
#elif L==6	// gn
	"Seleccionar usuarios para enviarles un correo"	// Okoteve traduccin
#elif L==7	// it
	"Select users to send an email to them"		// Bisogno di traduzione
#elif L==8	// pl
	"Select users to send an email to them"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Select users to send an email to them"		// Precisa de traduo
#elif L==10	// tr
	"Select users to send an email to them"		// eviri lazim!
#endif
	,
	[ActMaiUsr] =
#if   L==1	// ca
	"See email addresses to send an email"	// Necessita traducci
#elif L==2	// de
	"See email addresses to send an email"	// Need bersetzung
#elif L==3	// en
	"See email addresses to send an email"
#elif L==4	// es
	"Ver direcciones para enviar un correo"
#elif L==5	// fr
	"See email addresses to send an email"	// Besoin de traduction
#elif L==6	// gn
	"Ver direcciones para enviar un correo"	// Okoteve traduccin
#elif L==7	// it
	"See email addresses to send an email"	// Bisogno di traduzione
#elif L==8	// pl
	"See email addresses to send an email"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See email addresses to send an email"	// Precisa de traduo
#elif L==10	// tr
	"See email addresses to send an email"	// eviri lazim!
#endif
	,
	[ActReqUseGbl] =
#if   L==1	// ca
	"Request seeing use of the platform"	// Necessita traducci
#elif L==2	// de
	"Request seeing use of the platform"	// Need bersetzung
#elif L==3	// en
	"Request seeing use of the platform"
#elif L==4	// es
	"Solicitar ver uso de la plataforma"
#elif L==5	// fr
	"Request seeing use of the platform"	// Besoin de traduction
#elif L==6	// gn
	"Solicitar ver uso de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"Request seeing use of the platform"	// Bisogno di traduzione
#elif L==8	// pl
	"Request seeing use of the platform"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request seeing use of the platform"	// Precisa de traduo
#elif L==10	// tr
	"Request seeing use of the platform"	// eviri lazim!
#endif
	,
	[ActSeeUseGbl] =
#if   L==1	// ca
	"See platform usage statistics"				// Necessita traducci
#elif L==2	// de
	"See platform usage statistics"				// Need bersetzung
#elif L==3	// en
	"See platform usage statistics"
#elif L==4	// es
	"Ver estad&iacute;stica de uso de la plataforma"
#elif L==5	// fr
	"See platform usage statistics"				// Besoin de traduction
#elif L==6	// gn
	"Ver estad&iacute;stica de uso de la plataforma"	// Okoteve traduccin
#elif L==7	// it
	"See platform usage statistics"				// Bisogno di traduzione
#elif L==8	// pl
	"See platform usage statistics"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See platform usage statistics"				// Precisa de traduo
#elif L==10	// tr
	"See platform usage statistics"				// eviri lazim!
#endif
	,
	[ActSeePhoDeg] =
#if   L==1	// ca
	"See a class photo with average photos of students of each degree"			// Necessita traducci
#elif L==2	// de
	"See a class photo with average photos of students of each degree"			// Need bersetzung
#elif L==3	// en
	"See a class photo with average photos of students of each degree"
#elif L==4	// es
	"Ver una foto de clase con fotos promedio de estudiantes de cada titulaci&oacute;n"
#elif L==5	// fr
	"See a class photo with average photos of students of each degree"			// Besoin de traduction
#elif L==6	// gn
	"Ver una foto de clase con fotos promedio de estudiantes de cada titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See a class photo with average photos of students of each degree"			// Bisogno di traduzione
#elif L==8	// pl
	"See a class photo with average photos of students of each degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See a class photo with average photos of students of each degree"			// Precisa de traduo
#elif L==10	// tr
	"See a class photo with average photos of students of each degree"			// eviri lazim!
#endif
	,
	[ActPrnPhoDeg] =
#if   L==1	// ca
	"See print view of class photo with average photos of students of each degree"					// Necessita traducci
#elif L==2	// de
	"See print view of class photo with average photos of students of each degree"					// Need bersetzung
#elif L==3	// en
	"See print view of class photo with average photos of students of each degree"
#elif L==4	// es
	"Ver vista de impresi&oacute;n de foto de clase con fotos promedio de estudiantes de cada titulaci&oacute;n"
#elif L==5	// fr
	"See print view of class photo with average photos of students of each degree"					// Besoin de traduction
#elif L==6	// gn
	"Ver vista de impresi&oacute;n de foto de clase con fotos promedio de estudiantes de cada titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"See print view of class photo with average photos of students of each degree"					// Bisogno di traduzione
#elif L==8	// pl
	"See print view of class photo with average photos of students of each degree"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See print view of class photo with average photos of students of each degree"					// Precisa de traduo
#elif L==10	// tr
	"See print view of class photo with average photos of students of each degree"					// eviri lazim!
#endif
	,
	[ActCalPhoDeg] =
#if   L==1	// ca
	"Compute average photos of students of degree"			// Necessita traducci
#elif L==2	// de
	"Compute average photos of students of degree"			// Need bersetzung
#elif L==3	// en
	"Compute average photos of students of degree"
#elif L==4	// es
	"Calcular fotos promedio de estudiantes de titulaci&oacute;n"
#elif L==5	// fr
	"Compute average photos of students of degree"			// Besoin de traduction
#elif L==6	// gn
	"Calcular fotos promedio de estudiantes de titulaci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Compute average photos of students of degree"			// Bisogno di traduzione
#elif L==8	// pl
	"Compute average photos of students of degree"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Compute average photos of students of degree"			// Precisa de traduo
#elif L==10	// tr
	"Compute average photos of students of degree"			// eviri lazim!
#endif
	,
	[ActReqStaCrs] =
#if   L==1	// ca
	"Request statistics of courses"			// Necessita traducci
#elif L==2	// de
	"Request statistics of courses"			// Need bersetzung
#elif L==3	// en
	"Request statistics of courses"
#elif L==4	// es
	"Solicitar estad&iacute;sticas de asignaturas"
#elif L==5	// fr
	"Request statistics of courses"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar estad&iacute;sticas de asignaturas"	// Okoteve traduccin
#elif L==7	// it
	"Request statistics of courses"			// Bisogno di traduzione
#elif L==8	// pl
	"Request statistics of courses"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request statistics of courses"			// Precisa de traduo
#elif L==10	// tr
	"Request statistics of courses"			// eviri lazim!
#endif
	,
	[ActSeeAllStaCrs] =
#if   L==1	// ca
	"See statistics of courses"			// Necessita traducci
#elif L==2	// de
	"See statistics of courses"			// Need bersetzung
#elif L==3	// en
	"See statistics of courses"
#elif L==4	// es
	"Ver estad&iacute;sticas de asignaturas"
#elif L==5	// fr
	"See statistics of courses"			// Besoin de traduction
#elif L==6	// gn
	"Ver estad&iacute;sticas de asignaturas"	// Okoteve traduccin
#elif L==7	// it
	"See statistics of courses"			// Bisogno di traduzione
#elif L==8	// pl
	"See statistics of courses"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See statistics of courses"			// Precisa de traduo
#elif L==10	// tr
	"See statistics of courses"			// eviri lazim!
#endif
	,
	[ActSeeAllSvy] =
#if   L==1	// ca
	"See surveys"	// Necessita traducci
#elif L==2	// de
	"See surveys"	// Need bersetzung
#elif L==3	// en
	"See surveys"
#elif L==4	// es
	"Ver encuestas"
#elif L==5	// fr
	"See surveys"	// Besoin de traduction
#elif L==6	// gn
	"Ver encuestas"	// Okoteve traduccin
#elif L==7	// it
	"See surveys"	// Bisogno di traduzione
#elif L==8	// pl
	"See surveys"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See surveys"	// Precisa de traduo
#elif L==10	// tr
	"See surveys"	// eviri lazim!
#endif
	,
	[ActSeeOneSvy] =
#if   L==1	// ca
	"Show survey"		// Necessita traducci
#elif L==2	// de
	"Show survey"		// Need bersetzung
#elif L==3	// en
	"Show survey"
#elif L==4	// es
	"Mostrar encuesta"
#elif L==5	// fr
	"Show survey"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Show survey"		// Bisogno di traduzione
#elif L==8	// pl
	"Show survey"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Show survey"		// Precisa de traduo
#elif L==10	// tr
	"Show survey"		// eviri lazim!
#endif
	,
	[ActAnsSvy] =
#if   L==1	// ca
	"Answer survey"		// Necessita traducci
#elif L==2	// de
	"Answer survey"		// Need bersetzung
#elif L==3	// en
	"Answer survey"
#elif L==4	// es
	"Responder encuesta"
#elif L==5	// fr
	"Answer survey"		// Besoin de traduction
#elif L==6	// gn
	"Responder encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Answer survey"		// Bisogno di traduzione
#elif L==8	// pl
	"Answer survey"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Answer survey"		// Precisa de traduo
#elif L==10	// tr
	"Answer survey"		// eviri lazim!
#endif
	,
	[ActFrmNewSvy] =
#if   L==1	// ca
	"Edit new survey"	// Necessita traducci
#elif L==2	// de
	"Edit new survey"	// Need bersetzung
#elif L==3	// en
	"Edit new survey"
#elif L==4	// es
	"Editar nueva encuesta"
#elif L==5	// fr
	"Edit new survey"	// Besoin de traduction
#elif L==6	// gn
	"Editar nueva encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Edit new survey"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit new survey"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new survey"	// Precisa de traduo
#elif L==10	// tr
	"Edit new survey"	// eviri lazim!
#endif
	,
	[ActEdiOneSvy] =
#if   L==1	// ca
	"Edit survey"		// Necessita traducci
#elif L==2	// de
	"Edit survey"		// Need bersetzung
#elif L==3	// en
	"Edit survey"
#elif L==4	// es
	"Editar encuesta"
#elif L==5	// fr
	"Edit survey"		// Besoin de traduction
#elif L==6	// gn
	"Editar encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Edit survey"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit survey"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit survey"		// Precisa de traduo
#elif L==10	// tr
	"Edit survey"		// eviri lazim!
#endif
	,
	[ActNewSvy] =
#if   L==1	// ca
	"Crear enquesta"
#elif L==2	// de
	"Umfrage erstellen"
#elif L==3	// en
	"Create survey"
#elif L==4	// es
	"Crear encuesta"
#elif L==5	// fr
	"Cr&eacute;er sondage"
#elif L==6	// gn
	"Omohe&ntilde;&oacute;i encuesta"
#elif L==7	// it
	"Creare sondaggio"
#elif L==8	// pl
	"Utw&oacute;rz ankiety"
#elif L==9	// pt
	"Criar inqu&eacute;rito"
#elif L==10	// tr
	"Anket olu&scedil;tur"
#endif
	,
	[ActChgSvy] =
#if   L==1	// ca
	"Change survey"		// Necessita traducci
#elif L==2	// de
	"Change survey"		// Need bersetzung
#elif L==3	// en
	"Change survey"
#elif L==4	// es
	"Cambiar encuesta"
#elif L==5	// fr
	"Change survey"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Change survey"		// Bisogno di traduzione
#elif L==8	// pl
	"Change survey"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change survey"		// Precisa de traduo
#elif L==10	// tr
	"Change survey"		// eviri lazim!
#endif
	,
	[ActReqRemSvy] =
#if   L==1	// ca
	"Request removal of survey"			// Necessita traducci
#elif L==2	// de
	"Request removal of survey"			// Need bersetzung
#elif L==3	// en
	"Request removal of survey"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de encuesta"
#elif L==5	// fr
	"Request removal of survey"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of survey"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of survey"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of survey"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of survey"			// eviri lazim!
#endif
	,
	[ActRemSvy] =
#if   L==1	// ca
	"Eliminar enquesta"
#elif L==2	// de
	"Umfrage entfernen"
#elif L==3	// en
	"Remove survey"
#elif L==4	// es
	"Eliminar encuesta"
#elif L==5	// fr
	"Supprimer sondage"
#elif L==6	// gn
	"Eliminar encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Rimuovere sondaggio"
#elif L==8	// pl
	"Usu&nacute; badania"
#elif L==9	// pt
	"Remover inqu&eacute;rito"
#elif L==10	// tr
	"Anketi kald&inodot;r"
#endif
	,
	[ActReqRstSvy] =
#if   L==1	// ca
	"Request reset of answers of survey"			// Necessita traducci
#elif L==2	// de
	"Request reset of answers of survey"			// Need bersetzung
#elif L==3	// en
	"Request reset of answers of survey"
#elif L==4	// es
	"Solicitar puesta a cero de preguntas de encuesta"
#elif L==5	// fr
	"Request reset of answers of survey"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar puesta a cero de preguntas de encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Request reset of answers of survey"			// Bisogno di traduzione
#elif L==8	// pl
	"Request reset of answers of survey"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request reset of answers of survey"			// Precisa de traduo
#elif L==10	// tr
	"Request reset of answers of survey"			// eviri lazim!
#endif
	,
	[ActRstSvy] =
#if   L==1	// ca
	"Reset answers of survey"		// Necessita traducci
#elif L==2	// de
	"Reset answers of survey"		// Need bersetzung
#elif L==3	// en
	"Reset answers of survey"
#elif L==4	// es
	"Poner a cero respuestas de encuesta"
#elif L==5	// fr
	"Reset answers of survey"		// Besoin de traduction
#elif L==6	// gn
	"Poner a cero respuestas de encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Reset answers of survey"		// Bisogno di traduzione
#elif L==8	// pl
	"Reset answers of survey"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Reset answers of survey"		// Precisa de traduo
#elif L==10	// tr
	"Reset answers of survey"		// eviri lazim!
#endif
	,
	[ActHidSvy] =
#if   L==1	// ca
	"Hide survey"		// Necessita traducci
#elif L==2	// de
	"Hide survey"		// Need bersetzung
#elif L==3	// en
	"Hide survey"
#elif L==4	// es
	"Ocultar encuesta"
#elif L==5	// fr
	"Hide survey"		// Besoin de traduction
#elif L==6	// gn
	"Ocultar encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Hide survey"		// Bisogno di traduzione
#elif L==8	// pl
	"Hide survey"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide survey"		// Precisa de traduo
#elif L==10	// tr
	"Hide survey"		// eviri lazim!
#endif
	,
	[ActUnhSvy] =
#if   L==1	// ca
	"Unhide survey"		// Necessita traducci
#elif L==2	// de
	"Unhide survey"		// Need bersetzung
#elif L==3	// en
	"Unhide survey"
#elif L==4	// es
	"Mostrar encuesta"
#elif L==5	// fr
	"Unhide survey"		// Besoin de traduction
#elif L==6	// gn
	"Mostrar encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Unhide survey"		// Bisogno di traduzione
#elif L==8	// pl
	"Unhide survey"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide survey"		// Precisa de traduo
#elif L==10	// tr
	"Unhide survey"		// eviri lazim!
#endif
	,
	[ActReqLnkSvy] =
#if   L==1	// ca
	"Get link to survey"		// Necessita traducci
#elif L==2	// de
	"Copy link to survey"		// Need bersetzung
#elif L==3	// en
	"Copy link to survey"
#elif L==4	// es
	"Copiar enlace a encuesta"
#elif L==5	// fr
	"Copy link to survey"		// Besoin de traduction
#elif L==6	// gn
	"Copiar enlace a encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Copy link to survey"		// Bisogno di traduzione
#elif L==8	// pl
	"Copy link to survey"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Copy link to survey"		// Precisa de traduo
#elif L==10	// tr
	"Copy link to survey"		// eviri lazim!
#endif
	,
	[ActEdiOneSvyQst] =
#if   L==1	// ca
	"Edit new survey question"		// Necessita traducci
#elif L==2	// de
	"Edit new survey question"		// Need bersetzung
#elif L==3	// en
	"Edit new survey question"
#elif L==4	// es
	"Editar nueva pregunta de encuesta"
#elif L==5	// fr
	"Edit new survey question"		// Besoin de traduction
#elif L==6	// gn
	"Editar nueva pregunta de encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Edit new survey question"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit new survey question"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new survey question"		// Precisa de traduo
#elif L==10	// tr
	"Edit new survey question"		// eviri lazim!
#endif
	,
	[ActNewSvyQst] =
#if   L==1	// ca
	"Create survey question"	// Necessita traducci
#elif L==2	// de
	"Create survey question"	// Need bersetzung
#elif L==3	// en
	"Create survey question"
#elif L==4	// es
	"Crear pregunta de encuesta"
#elif L==5	// fr
	"Create survey question"	// Besoin de traduction
#elif L==6	// gn
	"Crear pregunta de encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Create survey question"	// Bisogno di traduzione
#elif L==8	// pl
	"Create survey question"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create survey question"	// Precisa de traduo
#elif L==10	// tr
	"Create survey question"	// eviri lazim!
#endif
	,
	[ActChgSvyQst] =
#if   L==1	// ca
	"Change survey question"	// Necessita traducci
#elif L==2	// de
	"Change survey question"	// Need bersetzung
#elif L==3	// en
	"Change survey question"
#elif L==4	// es
	"Cambiar pregunta de encuesta"
#elif L==5	// fr
	"Change survey question"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar pregunta de encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Change survey question"	// Bisogno di traduzione
#elif L==8	// pl
	"Change survey question"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change survey question"	// Precisa de traduo
#elif L==10	// tr
	"Change survey question"	// eviri lazim!
#endif
	,
	[ActReqRemSvyQst] =
#if   L==1	// ca
	"Request removal of survey question"			// Necessita traducci
#elif L==2	// de
	"Request removal of survey question"			// Need bersetzung
#elif L==3	// en
	"Request removal of survey question"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de pregunta de encuesta"
#elif L==5	// fr
	"Request removal of survey question"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de pregunta de encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of survey question"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of survey question"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of survey question"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of survey question"			// eviri lazim!
#endif
	,
	[ActRemSvyQst] =
#if   L==1	// ca
	"Confirm removal of survey question"			// Necessita traducci
#elif L==2	// de
	"Confirm removal of survey question"			// Need bersetzung
#elif L==3	// en
	"Confirm removal of survey question"
#elif L==4	// es
	"Confirmar eliminaci&oacute;n de pregunta de encuesta"
#elif L==5	// fr
	"Confirm removal of survey question"			// Besoin de traduction
#elif L==6	// gn
	"Confirmar eliminaci&oacute;n de pregunta de encuesta"	// Okoteve traduccin
#elif L==7	// it
	"Confirm removal of survey question"			// Bisogno di traduzione
#elif L==8	// pl
	"Confirm removal of survey question"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Confirm removal of survey question"			// Precisa de traduo
#elif L==10	// tr
	"Confirm removal of survey question"			// eviri lazim!
#endif
	,
	[ActReqAccGbl] =
#if   L==1	// ca
	"Request query of clicks to the complete platform"	// Necessita traducci
#elif L==2	// de
	"Request query of clicks to the complete platform"	// Need bersetzung
#elif L==3	// en
	"Request query of clicks to the complete platform"
#elif L==4	// es
	"Solicitar consulta de clics a la plataforma completa"
#elif L==5	// fr
	"Request query of clicks to the complete platform"	// Besoin de traduction
#elif L==6	// gn
	"Solicitar consulta de clics a la plataforma completa"	// Okoteve traduccin
#elif L==7	// it
	"Request query of clicks to the complete platform"	// Bisogno di traduzione
#elif L==8	// pl
	"Request query of clicks to the complete platform"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request query of clicks to the complete platform"	// Precisa de traduo
#elif L==10	// tr
	"Request query of clicks to the complete platform"	// eviri lazim!
#endif
	,
	[ActSeeAccGbl] =
#if   L==1	// ca
	"Query clicks to the complete platform"		// Necessita traducci
#elif L==2	// de
	"Query clicks to the complete platform"		// Need bersetzung
#elif L==3	// en
	"Query clicks to the complete platform"
#elif L==4	// es
	"Consultar clics a la plataforma completa"
#elif L==5	// fr
	"Query clicks to the complete platform"		// Besoin de traduction
#elif L==6	// gn
	"Consultar clics a la plataforma completa"	// Okoteve traduccin
#elif L==7	// it
	"Query clicks to the complete platform"		// Bisogno di traduzione
#elif L==8	// pl
	"Query clicks to the complete platform"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Query clicks to the complete platform"		// Precisa de traduo
#elif L==10	// tr
	"Query clicks to the complete platform"		// eviri lazim!
#endif
	,
	[ActReqAccCrs] =
#if   L==1	// ca
	"Request query of clicks in the current course"		// Necessita traducci
#elif L==2	// de
	"Request query of clicks in the current course"		// Need bersetzung
#elif L==3	// en
	"Request query of clicks in the current course"
#elif L==4	// es
	"Solicitar consulta de clics en la asignatura actual"
#elif L==5	// fr
	"Request query of clicks in the current course"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar consulta de clics en la asignatura actual"	// Okoteve traduccin
#elif L==7	// it
	"Request query of clicks in the current course"		// Bisogno di traduzione
#elif L==8	// pl
	"Request query of clicks in the current course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request query of clicks in the current course"		// Precisa de traduo
#elif L==10	// tr
	"Request query of clicks in the current course"		// eviri lazim!
#endif
	,
	[ActSeeAccCrs] =
#if   L==1	// ca
	"Query clicks in the current course"		// Necessita traducci
#elif L==2	// de
	"Query clicks in the current course"		// Need bersetzung
#elif L==3	// en
	"Query clicks in the current course"
#elif L==4	// es
	"Consultar clics en la asignatura actual"
#elif L==5	// fr
	"Query clicks in the current course"		// Besoin de traduction
#elif L==6	// gn
	"Consultar clics en la asignatura actual"	// Okoteve traduccin
#elif L==7	// it
	"Query clicks in the current course"		// Bisogno di traduzione
#elif L==8	// pl
	"Query clicks in the current course"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Query clicks in the current course"		// Precisa de traduo
#elif L==10	// tr
	"Query clicks in the current course"		// eviri lazim!
#endif
	,
	[ActLstClk] =
#if   L==1	// ca
	"List the last clicks"			// Necessita traducci
#elif L==2	// de
	"List the last clicks"			// Need bersetzung
#elif L==3	// en
	"List the last clicks"
#elif L==4	// es
	"Listar los &uacute;ltimos clics"
#elif L==5	// fr
	"List the last clicks"			// Besoin de traduction
#elif L==6	// gn
	"Listar los &uacute;ltimos clics"	// Okoteve traduccin
#elif L==7	// it
	"List the last clicks"			// Bisogno di traduzione
#elif L==8	// pl
	"List the last clicks"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"List the last clicks"			// Precisa de traduo
#elif L==10	// tr
	"List the last clicks"			// eviri lazim!
#endif
	,
	[ActRefLstClk] =
#if   L==1	// ca
	"Refresh the last clicks in real time"			// Necessita traducci
#elif L==2	// de
	"Refresh the last clicks in real time"			// Need bersetzung
#elif L==3	// en
	"Refresh the last clicks in real time"
#elif L==4	// es
	"Refrescar los &uacute;ltimos clics en tiempo real"
#elif L==5	// fr
	"Refresh the last clicks in real time"			// Besoin de traduction
#elif L==6	// gn
	"Refrescar los &uacute;ltimos clics en tiempo real"	// Okoteve traduccin
#elif L==7	// it
	"Refresh the last clicks in real time"			// Bisogno di traduzione
#elif L==8	// pl
	"Refresh the last clicks in real time"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Refresh the last clicks in real time"			// Precisa de traduo
#elif L==10	// tr
	"Refresh the last clicks in real time"			// eviri lazim!
#endif
	,
	[ActReqMyUsgRep] =
#if   L==1	// ca
	"Request my usage report"	// Necessita traducci
#elif L==2	// de
	"Request my usage report"	// Need bersetzung
#elif L==3	// en
	"Request my usage report"
#elif L==4	// es
	"Solicitar mi informe de uso"
#elif L==5	// fr
	"Request my usage report"	// Besoin de traduction
#elif L==6	// gn
	"Solicitar mi informe de uso"	// Okoteve traduccin
#elif L==7	// it
	"Request my usage report"	// Bisogno di traduzione
#elif L==8	// pl
	"Request my usage report"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request my usage report"	// Precisa de traduo
#elif L==10	// tr
	"Request my usage report"	// eviri lazim!
#endif
	,
	[ActSeeMyUsgRep] =
#if   L==1	// ca
	"See my usage report"	// Necessita traducci
#elif L==2	// de
	"See my usage report"	// Need bersetzung
#elif L==3	// en
	"See my usage report"
#elif L==4	// es
	"Ver mi informe de uso"
#elif L==5	// fr
	"See my usage report"	// Besoin de traduction
#elif L==6	// gn
	"Ver mi informe de uso"	// Okoteve traduccin
#elif L==7	// it
	"See my usage report"	// Bisogno di traduzione
#elif L==8	// pl
	"See my usage report"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See my usage report"	// Precisa de traduo
#elif L==10	// tr
	"See my usage report"	// eviri lazim!
#endif
	,
	[ActMFUAct] =
#if   L==1	// ca
	"See most frequently used actions"		// Necessita traducci
#elif L==2	// de
	"See most frequently used actions"		// Need bersetzung
#elif L==3	// en
	"See most frequently used actions"
#elif L==4	// es
	"Ver acciones m&aacute;s frecuentemente usadas"
#elif L==5	// fr
	"See most frequently used actions"		// Besoin de traduction
#elif L==6	// gn
	"Ver acciones m&aacute;s frecuentemente usadas"	// Okoteve traduccin
#elif L==7	// it
	"See most frequently used actions"		// Bisogno di traduzione
#elif L==8	// pl
	"See most frequently used actions"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See most frequently used actions"		// Precisa de traduo
#elif L==10	// tr
	"See most frequently used actions"		// eviri lazim!
#endif
	,
	[ActFrmRolSes] =
#if   L==1	// ca
	"See form to log out and to change the current role"			// Necessita traducci
#elif L==2	// de
	"See form to log out and to change the current role"			// Need bersetzung
#elif L==3	// en
	"See form to log out and to change the current role"
#elif L==4	// es
	"Ver formulario para cerrar sesi&oacute;n y para cambiar el rol"
#elif L==5	// fr
	"See form to log out and to change the current role"			// Besoin de traduction
#elif L==6	// gn
	"Ver formulario para cerrar sesi&oacute;n y para cambiar el rol"	// Okoteve traduccin
#elif L==7	// it
	"See form to log out and to change the current role"			// Bisogno di traduzione
#elif L==8	// pl
	"See form to log out and to change the current role"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See form to log out and to change the current role"			// Precisa de traduo
#elif L==10	// tr
	"See form to log out and to change the current role"			// eviri lazim!
#endif
	,
	[ActChgMyRol] =
#if   L==1	// ca
	"Change user's role"		// Necessita traducci
#elif L==2	// de
	"Change user's role"		// Need bersetzung
#elif L==3	// en
	"Change user's role"
#elif L==4	// es
	"Cambiar rol de usuario"
#elif L==5	// fr
	"Change user's role"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar rol de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Change user's role"		// Bisogno di traduzione
#elif L==8	// pl
	"Change user's role"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change user's role"		// Precisa de traduo
#elif L==10	// tr
	"Change user's role"		// eviri lazim!
#endif
	,
	[ActMyCrs] =
#if   L==1	// ca
	"Select one of my courses"		// Necessita traducci
#elif L==2	// de
	"Select one of my courses"		// Need bersetzung
#elif L==3	// en
	"Select one of my courses"
#elif L==4	// es
	"Seleccionar una de mis asignaturas"
#elif L==5	// fr
	"Select one of my courses"		// Besoin de traduction
#elif L==6	// gn
	"Seleccionar una de mis asignaturas"	// Okoteve traduccin
#elif L==7	// it
	"Select one of my courses"		// Bisogno di traduzione
#elif L==8	// pl
	"Select one of my courses"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Select one of my courses"		// Precisa de traduo
#elif L==10	// tr
	"Select one of my courses"		// eviri lazim!
#endif
	,
	[ActSeeMyTT] =
#if   L==1	// ca
	"See the timetable of all my courses"		// Necessita traducci
#elif L==2	// de
	"See the timetable of all my courses"		// Need bersetzung
#elif L==3	// en
	"See the timetable of all my courses"
#elif L==4	// es
	"Ver el horario de todas mis asignaturas"
#elif L==5	// fr
	"See the timetable of all my courses"		// Besoin de traduction
#elif L==6	// gn
	"Ver el horario de todas mis asignaturas"	// Okoteve traduccin
#elif L==7	// it
	"See the timetable of all my courses"		// Bisogno di traduzione
#elif L==8	// pl
	"See the timetable of all my courses"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the timetable of all my courses"		// Precisa de traduo
#elif L==10	// tr
	"See the timetable of all my courses"		// eviri lazim!
#endif
	,
	[ActPrnMyTT] =
#if   L==1	// ca
	"See the print view of the timetable of all my courses"			// Necessita traducci
#elif L==2	// de
	"See the print view of the timetable of all my courses"			// Need bersetzung
#elif L==3	// en
	"See the print view of the timetable of all my courses"
#elif L==4	// es
	"Ver la vista de impresi&oacute;n del horario de todas mis asignaturas"
#elif L==5	// fr
	"See the print view of the timetable of all my courses"			// Besoin de traduction
#elif L==6	// gn
	"Ver la vista de impresi&oacute;n del horario de todas mis asignaturas"	// Okoteve traduccin
#elif L==7	// it
	"See the print view of the timetable of all my courses"			// Bisogno di traduzione
#elif L==8	// pl
	"See the print view of the timetable of all my courses"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See the print view of the timetable of all my courses"			// Precisa de traduo
#elif L==10	// tr
	"See the print view of the timetable of all my courses"			// eviri lazim!
#endif
	,
	[ActEdiTut] =
#if   L==1	// ca
	"Edit my office timetable"		// Necessita traducci
#elif L==2	// de
	"Edit my office timetable"		// Need bersetzung
#elif L==3	// en
	"Edit my office timetable"
#elif L==4	// es
	"Editar mi horario de tutor&iacute;as"
#elif L==5	// fr
	"Edit my office timetable"		// Besoin de traduction
#elif L==6	// gn
	"Editar mi horario de tutor&iacute;as"	// Okoteve traduccin
#elif L==7	// it
	"Edit my office timetable"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit my office timetable"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit my office timetable"		// Precisa de traduo
#elif L==10	// tr
	"Edit my office timetable"		// eviri lazim!
#endif
	,
	[ActChgTut] =
#if   L==1	// ca
	"Change my office timetable"		// Necessita traducci
#elif L==2	// de
	"Change my office timetable"		// Need bersetzung
#elif L==3	// en
	"Change my office timetable"
#elif L==4	// es
	"Cambiar mi horario de tutor&iacute;as"
#elif L==5	// fr
	"Change my office timetable"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar mi horario de tutor&iacute;as"	// Okoteve traduccin
#elif L==7	// it
	"Change my office timetable"		// Bisogno di traduzione
#elif L==8	// pl
	"Change my office timetable"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change my office timetable"		// Precisa de traduo
#elif L==10	// tr
	"Change my office timetable"		// eviri lazim!
#endif
	,
	[ActChgMyTT1stDay] =
#if   L==1	// ca
	"Change first day of week and show office timetable"					// Necessita traducci
#elif L==2	// de
	"Change first day of week and show office timetable"					// Need bersetzung
#elif L==3	// en
	"Change first day of week and show office timetable"
#elif L==4	// es
	"Cambiar primer d&iacute;a de la semana y mostrar el horario de tutor&iacute;as"
#elif L==5	// fr
	"Change first day of week and show office timetable"					// Besoin de traduction
#elif L==6	// gn
	"Cambiar primer d&iacute;a de la semana y mostrar el horario de tutor&iacute;as"	// Okoteve traduccin
#elif L==7	// it
	"Change first day of week and show office timetable"					// Bisogno di traduzione
#elif L==8	// pl
	"Change first day of week and show office timetable"					// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change first day of week and show office timetable"					// Precisa de traduo
#elif L==10	// tr
	"Change first day of week and show office timetable"					// eviri lazim!
#endif
	,
	[ActSeeMyAgd] =
#if   L==1	// ca
	"See my full agenda (personal organizer)"	// Necessita traducci
#elif L==2	// de
	"See my full agenda (personal organizer)"	// Need bersetzung
#elif L==3	// en
	"See my full agenda (personal organizer)"
#elif L==4	// es
	"Ver mi agenda completa (organizador personal)"
#elif L==5	// fr
	"See my full agenda (personal organizer)"	// Besoin de traduction
#elif L==6	// gn
	"Ver mi agenda completa (organizador personal)"	// Okoteve traduccin
#elif L==7	// it
	"See my full agenda (personal organizer)"	// Bisogno di traduzione
#elif L==8	// pl
	"See my full agenda (personal organizer)"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See my full agenda (personal organizer)"	// Precisa de traduo
#elif L==10	// tr
	"See my full agenda (personal organizer)"	// eviri lazim!
#endif
	,
	[ActFrmNewEvtMyAgd] =
#if   L==1	// ca
	"Edit new event in my agenda"		// Necessita traducci
#elif L==2	// de
	"Edit new event in my agenda"		// Need bersetzung
#elif L==3	// en
	"Edit new event in my agenda"
#elif L==4	// es
	"Editar nuevo evento en mi agenda"
#elif L==5	// fr
	"Edit new event in my agenda"		// Besoin de traduction
#elif L==6	// gn
	"Editar nuevo evento en mi agenda"	// Okoteve traduccin
#elif L==7	// it
	"Edit new event in my agenda"		// Bisogno di traduzione
#elif L==8	// pl
	"Edit new event in my agenda"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new event in my agenda"		// Precisa de traduo
#elif L==10	// tr
	"Edit new event in my agenda"		// eviri lazim!
#endif
	,
	[ActEdiOneEvtMyAgd] =
#if   L==1	// ca
	"Edit one event from my agenda"	// Necessita traducci
#elif L==2	// de
	"Edit one event from my agenda"	// Need bersetzung
#elif L==3	// en
	"Edit one event from my agenda"
#elif L==4	// es
	"Editar evento de mi agenda"
#elif L==5	// fr
	"Edit one event from my agenda"	// Besoin de traduction
#elif L==6	// gn
	"Editar evento de mi agenda"	// Okoteve traduccin
#elif L==7	// it
	"Edit one event from my agenda"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit one event from my agenda"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit one event from my agenda"	// Precisa de traduo
#elif L==10	// tr
	"Edit one event from my agenda"	// eviri lazim!
#endif
	,
	[ActNewEvtMyAgd] =
#if   L==1	// ca
	"Crear esdeveniment a agenda"
#elif L==2	// de
	"Kalenderereignis erstellen"
#elif L==3	// en
	"Create event in agenda"
#elif L==4	// es
	"Crear evento en agenda"
#elif L==5	// fr
	"Cr&eacute;er un &eacute;v&eacute;nement dans l'agenda"
#elif L==6	// gn
	"Omohe&ntilde;&oacute;i evento agenda-pe"
#elif L==7	// it
	"Creare evento in agenda"
#elif L==8	// pl
	"Utw&oacute;rz wydarzenie w agend&aogon;"
#elif L==9	// pt
	"Criar evento na agenda"
#elif L==10	// tr
	"Ajandada etkinlik olu&scedil;tur"
#endif
	,
	[ActChgEvtMyAgd] =
#if   L==1	// ca
	"Change event from my agenda"		// Necessita traducci
#elif L==2	// de
	"Change event from my agenda"		// Need bersetzung
#elif L==3	// en
	"Change event from my agenda"
#elif L==4	// es
	"Cambiar datos de evento de mi agenda"
#elif L==5	// fr
	"Change event from my agenda"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar datos de evento de mi agenda"	// Okoteve traduccin
#elif L==7	// it
	"Change event from my agenda"		// Bisogno di traduzione
#elif L==8	// pl
	"Change event from my agenda"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change event from my agenda"		// Precisa de traduo
#elif L==10	// tr
	"Change event from my agenda"		// eviri lazim!
#endif
	,
	[ActReqRemEvtMyAgd] =
#if   L==1	// ca
	"Request removal of event from my agenda"			// Necessita traducci
#elif L==2	// de
	"Request removal of event from my agenda"			// Need bersetzung
#elif L==3	// en
	"Request removal of event from my agenda"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de un evento de mi agenda"
#elif L==5	// fr
	"Request removal of event from my agenda"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de un evento de mi agenda"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of event from my agenda"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of event from my agenda"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of event from my agenda"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of event from my agenda"			// eviri lazim!
#endif
	,
	[ActRemEvtMyAgd] =
#if   L==1	// ca
	"Remove event from my agenda"	// Necessita traducci
#elif L==2	// de
	"Remove event from my agenda"	// Need bersetzung
#elif L==3	// en
	"Remove event from my agenda"
#elif L==4	// es
	"Eliminar evento de mi agenda"
#elif L==5	// fr
	"Remove event from my agenda"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar evento de mi agenda"	// Okoteve traduccin
#elif L==7	// it
	"Remove event from my agenda"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove event from my agenda"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove event from my agenda"	// Precisa de traduo
#elif L==10	// tr
	"Remove event from my agenda"	// eviri lazim!
#endif
	,
	[ActHidEvtMyAgd] =
#if   L==1	// ca
	"Hide event from my agenda"		// Necessita traducci
#elif L==2	// de
	"Hide event from my agenda"		// Need bersetzung
#elif L==3	// en
	"Hide event from my agenda"
#elif L==4	// es
	"Ocultar un evento de mi agenda"
#elif L==5	// fr
	"Hide event from my agenda"		// Besoin de traduction
#elif L==6	// gn
	"Ocultar un evento de mi agenda"	// Okoteve traduccin
#elif L==7	// it
	"Hide event from my agenda"		// Bisogno di traduzione
#elif L==8	// pl
	"Hide event from my agenda"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Hide event from my agenda"		// Precisa de traduo
#elif L==10	// tr
	"Hide event from my agenda"		// eviri lazim!
#endif
	,
	[ActUnhEvtMyAgd] =
#if   L==1	// ca
	"Unhide event from my agenda"	// Necessita traducci
#elif L==2	// de
	"Unhide event from my agenda"	// Need bersetzung
#elif L==3	// en
	"Unhide event from my agenda"
#elif L==4	// es
	"Mostrar evento de mi agenda"
#elif L==5	// fr
	"Unhide event from my agenda"	// Besoin de traduction
#elif L==6	// gn
	"Mostrar evento de mi agenda"	// Okoteve traduccin
#elif L==7	// it
	"Unhide event from my agenda"	// Bisogno di traduzione
#elif L==8	// pl
	"Unhide event from my agenda"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Unhide event from my agenda"	// Precisa de traduo
#elif L==10	// tr
	"Unhide event from my agenda"	// eviri lazim!
#endif
	,
	[ActPrvEvtMyAgd] =
#if   L==1	// ca
	"Make private an event from my agenda"	// Necessita traducci
#elif L==2	// de
	"Make private an event from my agenda"	// Need bersetzung
#elif L==3	// en
	"Make private an event from my agenda"
#elif L==4	// es
	"Hacer privado un evento de mi agenda"
#elif L==5	// fr
	"Make private an event from my agenda"	// Besoin de traduction
#elif L==6	// gn
	"Hacer privado un evento de mi agenda"	// Okoteve traduccin
#elif L==7	// it
	"Make private an event from my agenda"	// Bisogno di traduzione
#elif L==8	// pl
	"Make private an event from my agenda"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Make private an event from my agenda"	// Precisa de traduo
#elif L==10	// tr
	"Make private an event from my agenda"	// eviri lazim!
#endif
	,
	[ActPubEvtMyAgd] =
#if   L==1	// ca
	"Make public an event from my agenda"		// Necessita traducci
#elif L==2	// de
	"Make public an event from my agenda"		// Need bersetzung
#elif L==3	// en
	"Make public an event from my agenda"
#elif L==4	// es
	"Hacer p&uacute;blico un evento de mi agenda"
#elif L==5	// fr
	"Make public an event from my agenda"		// Besoin de traduction
#elif L==6	// gn
	"Hacer p&uacute;blico un evento de mi agenda"	// Okoteve traduccin
#elif L==7	// it
	"Make public an event from my agenda"		// Bisogno di traduzione
#elif L==8	// pl
	"Make public an event from my agenda"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Make public an event from my agenda"		// Precisa de traduo
#elif L==10	// tr
	"Make public an event from my agenda"		// eviri lazim!
#endif
	,
	[ActPrnAgdQR] =
#if   L==1	// ca
	"See agenda QR code ready to print"			// Necessita traducci
#elif L==2	// de
	"See agenda QR code ready to print"			// Need bersetzung
#elif L==3	// en
	"See agenda QR code ready to print"
#elif L==4	// es
	"Ver c&oacute;digo QR de agenda listo para imprimir"
#elif L==5	// fr
	"See agenda QR code ready to print"			// Besoin de traduction
#elif L==6	// gn
	"Ver c&oacute;digo QR de agenda listo para imprimir"	// Okoteve traduccin
#elif L==7	// it
	"See agenda QR code ready to print"			// Bisogno di traduzione
#elif L==8	// pl
	"See agenda QR code ready to print"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See agenda QR code ready to print"			// Precisa de traduo
#elif L==10	// tr
	"See agenda QR code ready to print"			// eviri lazim!
#endif
	,
	[ActFrmMyAcc] =
#if   L==1	// ca
	"See form to create or change my account"	// Necessita traducci
#elif L==2	// de
	"See form to create or change my account"	// Need bersetzung
#elif L==3	// en
	"See form to create or change my account"
#elif L==4	// es
	"Ver formulario para crear o cambiar mi cuenta"
#elif L==5	// fr
	"See form to create or change my account"	// Besoin de traduction
#elif L==6	// gn
	"Ver formulario para crear o cambiar mi cuenta"	// Okoteve traduccin
#elif L==7	// it
	"See form to create or change my account"	// Bisogno di traduzione
#elif L==8	// pl
	"See form to create or change my account"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See form to create or change my account"	// Precisa de traduo
#elif L==10	// tr
	"See form to create or change my account"	// eviri lazim!
#endif
	,
	[ActChkUsrAcc] =
#if   L==1	// ca
	"Check if already exists a new account without password associated to a ID"		// Necessita traducci
#elif L==2	// de
	"Check if already exists a new account without password associated to a ID"		// Need bersetzung
#elif L==3	// en
	"Check if already exists a new account without password associated to a ID"
#elif L==4	// es
	"Comprobar si ya existe una nueva cuenta sin contrase&ntilde;a asociada a un ID"
#elif L==5	// fr
	"Check if already exists a new account without password associated to a ID"		// Besoin de traduction
#elif L==6	// gn
	"Comprobar si ya existe una nueva cuenta sin contrase&ntilde;a asociada a un ID"	// Okoteve traduccin
#elif L==7	// it
	"Check if already exists a new account without password associated to a ID"		// Bisogno di traduzione
#elif L==8	// pl
	"Check if already exists a new account without password associated to a ID"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Check if already exists a new account without password associated to a ID"		// Precisa de traduo
#elif L==10	// tr
	"Check if already exists a new account without password associated to a ID"		// eviri lazim!
#endif
	,
	[ActCreMyAcc] =
#if   L==1	// ca
	"Edit new user account"	// Necessita traducci
#elif L==2	// de
	"Edit new user account"	// Need bersetzung
#elif L==3	// en
	"Edit new user account"
#elif L==4	// es
	"Editar nueva cuenta"
#elif L==5	// fr
	"Edit new user account"	// Besoin de traduction
#elif L==6	// gn
	"Editar nueva cuenta"	// Okoteve traduccin
#elif L==7	// it
	"Edit new user account"	// Bisogno di traduzione
#elif L==8	// pl
	"Edit new user account"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Edit new user account"	// Precisa de traduo
#elif L==10	// tr
	"Edit new user account"	// eviri lazim!
#endif
	,
	[ActCreUsrAcc] =
#if   L==1	// ca
	"Crea compte"
#elif L==2	// de
	"Benutzerkonto anlegen"
#elif L==3	// en
	"Create account"
#elif L==4	// es
	"Crear cuenta"
#elif L==5	// fr
	"Cr&eacute;er compte"
#elif L==6	// gn
	"Ojapo cuenta"
#elif L==7	// it
	"Creare un account"
#elif L==8	// pl
	"Za&lstrok;&oacute;&zdot; konto"
#elif L==9	// pt
	"Criar conta"
#elif L==10	// tr
	"Hesab&inodot; olu&scedil;tur"
#endif
	,
	[ActRemMyID] =
#if   L==1	// ca
	"Remove my user's ID"		// Necessita traducci
#elif L==2	// de
	"Remove my user's ID"		// Need bersetzung
#elif L==3	// en
	"Remove my user's ID"
#elif L==4	// es
	"Eliminar mi ID de usuario"
#elif L==5	// fr
	"Remove my user's ID"		// Besoin de traduction
#elif L==6	// gn
	"Eliminar mi ID de usuario"	// Okoteve traduccin
#elif L==7	// it
	"Remove my user's ID"		// Bisogno di traduzione
#elif L==8	// pl
	"Remove my user's ID"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove my user's ID"		// Precisa de traduo
#elif L==10	// tr
	"Remove my user's ID"		// eviri lazim!
#endif
	,
	[ActChgMyID] =
#if   L==1	// ca
	"Create new user's ID for me"			// Necessita traducci
#elif L==2	// de
	"Create new user's ID for me"			// Need bersetzung
#elif L==3	// en
	"Create new user's ID for me"
#elif L==4	// es
	"Crear nuevo ID de usuario para m&iacute;"
#elif L==5	// fr
	"Create new user's ID for me"			// Besoin de traduction
#elif L==6	// gn
	"Crear nuevo ID de usuario para m&iacute;"	// Okoteve traduccin
#elif L==7	// it
	"Create new user's ID for me"			// Bisogno di traduzione
#elif L==8	// pl
	"Create new user's ID for me"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Create new user's ID for me"			// Precisa de traduo
#elif L==10	// tr
	"Create new user's ID for me"			// eviri lazim!
#endif
	,
	[ActRemMyNck] =
#if   L==1	// ca
	"Remove my old nickname"	// Necessita traducci
#elif L==2	// de
	"Remove my old nickname"	// Need bersetzung
#elif L==3	// en
	"Remove my old nickname"
#elif L==4	// es
	"Eliminar mi antiguo apodo"
#elif L==5	// fr
	"Remove my old nickname"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar mi antiguo apodo"	// Okoteve traduccin
#elif L==7	// it
	"Remove my old nickname"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove my old nickname"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove my old nickname"	// Precisa de traduo
#elif L==10	// tr
	"Remove my old nickname"	// eviri lazim!
#endif
	,
	[ActChgMyNck] =
#if   L==1	// ca
	"Change my nickname"	// Necessita traducci
#elif L==2	// de
	"Change my nickname"	// Need bersetzung
#elif L==3	// en
	"Change my nickname"
#elif L==4	// es
	"Cambiar mi apodo"
#elif L==5	// fr
	"Change my nickname"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar mi apodo"	// Okoteve traduccin
#elif L==7	// it
	"Change my nickname"	// Bisogno di traduzione
#elif L==8	// pl
	"Change my nickname"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change my nickname"	// Precisa de traduo
#elif L==10	// tr
	"Change my nickname"	// eviri lazim!
#endif
	,
	[ActRemMyMai] =
#if   L==1	// ca
	"Remove old email"				// Necessita traducci
#elif L==2	// de
	"Remove old email"				// Need bersetzung
#elif L==3	// en
	"Remove old email"
#elif L==4	// es
	"Eliminar antigua direcci&oacute;n de correo"
#elif L==5	// fr
	"Remove old email"				// Besoin de traduction
#elif L==6	// gn
	"Eliminar antigua direcci&oacute;n de correo"	// Okoteve traduccin
#elif L==7	// it
	"Remove old email"				// Bisogno di traduzione
#elif L==8	// pl
	"Remove old email"				// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove old email"				// Precisa de traduo
#elif L==10	// tr
	"Remove old email"				// eviri lazim!
#endif
	,
	[ActChgMyMai] =
#if   L==1	// ca
	"Change my email address"		// Necessita traducci
#elif L==2	// de
	"Change my email address"		// Need bersetzung
#elif L==3	// en
	"Change my email address"
#elif L==4	// es
	"Cambiar mi direcci&oacute;n de correo"
#elif L==5	// fr
	"Change my email address"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar mi direcci&oacute;n de correo"	// Okoteve traduccin
#elif L==7	// it
	"Change my email address"		// Bisogno di traduzione
#elif L==8	// pl
	"Change my email address"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change my email address"		// Precisa de traduo
#elif L==10	// tr
	"Change my email address"		// eviri lazim!
#endif
	,
	[ActCnfMai] =
#if   L==1	// ca
	"Confirm email address"			// Necessita traducci
#elif L==2	// de
	"Confirm email address"			// Need bersetzung
#elif L==3	// en
	"Confirm email address"
#elif L==4	// es
	"Confirmar direcci&oacute;n de correo"
#elif L==5	// fr
	"Confirm email address"			// Besoin de traduction
#elif L==6	// gn
	"Confirmar direcci&oacute;n de correo"	// Okoteve traduccin
#elif L==7	// it
	"Confirm email address"			// Bisogno di traduzione
#elif L==8	// pl
	"Confirm email address"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Confirm email address"			// Precisa de traduo
#elif L==10	// tr
	"Confirm email address"			// eviri lazim!
#endif
	,
	[ActChgMyPwd] =
#if   L==1	// ca
	"Change my password"		// Necessita traducci
#elif L==2	// de
	"Change my password"		// Need bersetzung
#elif L==3	// en
	"Change my password"
#elif L==4	// es
	"Cambiar mi contrase&ntilde;a"
#elif L==5	// fr
	"Change my password"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar mi contrase&ntilde;a"	// Okoteve traduccin
#elif L==7	// it
	"Change my password"		// Bisogno di traduzione
#elif L==8	// pl
	"Change my password"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change my password"		// Precisa de traduo
#elif L==10	// tr
	"Change my password"		// eviri lazim!
#endif
	,
	[ActReqRemMyAcc] =
#if   L==1	// ca
	"Request removal of my account"			// Necessita traducci
#elif L==2	// de
	"Request removal of my account"			// Need bersetzung
#elif L==3	// en
	"Request removal of my account"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de mi cuenta"
#elif L==5	// fr
	"Request removal of my account"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de mi cuenta"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of my account"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of my account"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of my account"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of my account"			// eviri lazim!
#endif
	,
	[ActRemMyAcc] =
#if   L==1	// ca
	"Remove my account"	// Necessita traducci
#elif L==2	// de
	"Remove my account"	// Need bersetzung
#elif L==3	// en
	"Remove my account"
#elif L==4	// es
	"Eliminar mi cuenta"
#elif L==5	// fr
	"Remove my account"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar mi cuenta"	// Okoteve traduccin
#elif L==7	// it
	"Remove my account"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove my account"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove my account"	// Precisa de traduo
#elif L==10	// tr
	"Remove my account"	// eviri lazim!
#endif
	,
	[ActPrnUsrQR] =
#if   L==1	// ca
	"See my QR code ready to print"			// Necessita traducci
#elif L==2	// de
	"See my QR code ready to print"			// Need bersetzung
#elif L==3	// en
	"See my QR code ready to print"
#elif L==4	// es
	"Ver mi c&oacute;digo QR listo para imprimir"
#elif L==5	// fr
	"See my QR code ready to print"			// Besoin de traduction
#elif L==6	// gn
	"Ver mi c&oacute;digo QR listo para imprimir"	// Okoteve traduccin
#elif L==7	// it
	"See my QR code ready to print"			// Bisogno di traduzione
#elif L==8	// pl
	"See my QR code ready to print"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See my QR code ready to print"			// Precisa de traduo
#elif L==10	// tr
	"See my QR code ready to print"			// eviri lazim!
#endif
	,
	[ActReqEdiRecSha] =
#if   L==1	// ca
	"Request edition of the record with the personal data of the user"		// Necessita traducci
#elif L==2	// de
	"Request edition of the record with the personal data of the user"		// Need bersetzung
#elif L==3	// en
	"Request edition of the record with the personal data of the user"
#elif L==4	// es
	"Solicitar edici&oacute;n de la ficha con los datos personales del usuario"
#elif L==5	// fr
	"Request edition of the record with the personal data of the user"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar edici&oacute;n de la ficha con los datos personales del usuario"	// Okoteve traduccin
#elif L==7	// it
	"Request edition of the record with the personal data of the user"		// Bisogno di traduzione
#elif L==8	// pl
	"Request edition of the record with the personal data of the user"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request edition of the record with the personal data of the user"		// Precisa de traduo
#elif L==10	// tr
	"Request edition of the record with the personal data of the user"		// eviri lazim!
#endif
	,
	[ActChgMyData] =
#if   L==1	// ca
	"Update my personal data"		// Necessita traducci
#elif L==2	// de
	"Update my personal data"		// Need bersetzung
#elif L==3	// en
	"Update my personal data"
#elif L==4	// es
	"Actualizar mis datos personales"
#elif L==5	// fr
	"Update my personal data"		// Besoin de traduction
#elif L==6	// gn
	"Actualizar mis datos personales"	// Okoteve traduccin
#elif L==7	// it
	"Update my personal data"		// Bisogno di traduzione
#elif L==8	// pl
	"Update my personal data"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Update my personal data"		// Precisa de traduo
#elif L==10	// tr
	"Update my personal data"		// eviri lazim!
#endif
	,
	[ActReqMyPho] =
#if   L==1	// ca
	"Request sending of my photo"		// Necessita traducci
#elif L==2	// de
	"Request sending of my photo"		// Need bersetzung
#elif L==3	// en
	"Request sending of my photo"
#elif L==4	// es
	"Solicitar el env&iacute;o de mi foto"
#elif L==5	// fr
	"Request sending of my photo"		// Besoin de traduction
#elif L==6	// gn
	"Solicitar el env&iacute;o de mi foto"	// Okoteve traduccin
#elif L==7	// it
	"Request sending of my photo"		// Bisogno di traduzione
#elif L==8	// pl
	"Request sending of my photo"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request sending of my photo"		// Precisa de traduo
#elif L==10	// tr
	"Request sending of my photo"		// eviri lazim!
#endif
	,
	[ActDetMyPho] =
#if   L==1	// ca
	"Send my photo and detect faces on it"		// Necessita traducci
#elif L==2	// de
	"Send my photo and detect faces on it"		// Need bersetzung
#elif L==3	// en
	"Send my photo and detect faces on it"
#elif L==4	// es
	"Enviar mi foto y detectar rostros en ella"
#elif L==5	// fr
	"Send my photo and detect faces on it"		// Besoin de traduction
#elif L==6	// gn
	"Enviar mi foto y detectar rostros en ella"	// Okoteve traduccin
#elif L==7	// it
	"Send my photo and detect faces on it"		// Bisogno di traduzione
#elif L==8	// pl
	"Send my photo and detect faces on it"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Send my photo and detect faces on it"		// Precisa de traduo
#elif L==10	// tr
	"Send my photo and detect faces on it"		// eviri lazim!
#endif
	,
	[ActUpdMyPho] =
#if   L==1	// ca
	"Update my photo"	// Necessita traducci
#elif L==2	// de
	"Update my photo"	// Need bersetzung
#elif L==3	// en
	"Update my photo"
#elif L==4	// es
	"Actualizar mi foto"
#elif L==5	// fr
	"Update my photo"	// Besoin de traduction
#elif L==6	// gn
	"Actualizar mi foto"	// Okoteve traduccin
#elif L==7	// it
	"Update my photo"	// Bisogno di traduzione
#elif L==8	// pl
	"Update my photo"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Update my photo"	// Precisa de traduo
#elif L==10	// tr
	"Update my photo"	// eviri lazim!
#endif
	,
	[ActReqRemMyPho] =
#if   L==1	// ca
	"Request removal of my photo"			// Necessita traducci
#elif L==2	// de
	"Request removal of my photo"			// Need bersetzung
#elif L==3	// en
	"Request removal of my photo"
#elif L==4	// es
	"Solicitar eliminaci&oacute;n de mi foto"
#elif L==5	// fr
	"Request removal of my photo"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar eliminaci&oacute;n de mi foto"	// Okoteve traduccin
#elif L==7	// it
	"Request removal of my photo"			// Bisogno di traduzione
#elif L==8	// pl
	"Request removal of my photo"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request removal of my photo"			// Precisa de traduo
#elif L==10	// tr
	"Request removal of my photo"			// eviri lazim!
#endif
	,
	[ActRemMyPho] =
#if   L==1	// ca
	"Remove my photo"	// Necessita traducci
#elif L==2	// de
	"Remove my photo"	// Need bersetzung
#elif L==3	// en
	"Remove my photo"
#elif L==4	// es
	"Eliminar mi foto"
#elif L==5	// fr
	"Remove my photo"	// Besoin de traduction
#elif L==6	// gn
	"Eliminar mi foto"	// Okoteve traduccin
#elif L==7	// it
	"Remove my photo"	// Bisogno di traduzione
#elif L==8	// pl
	"Remove my photo"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Remove my photo"	// Precisa de traduo
#elif L==10	// tr
	"Remove my photo"	// eviri lazim!
#endif
	,
	[ActChgCtyMyIns] =
#if   L==1	// ca
	"Change country of my institution"		// Necessita traducci
#elif L==2	// de
	"Change country of my institution"		// Need bersetzung
#elif L==3	// en
	"Change country of my institution"
#elif L==4	// es
	"Cambiar pa&iacute;s de mi instituci&oacute;n"
#elif L==5	// fr
	"Change country of my institution"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar pa&iacute;s de mi instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change country of my institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Change country of my institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change country of my institution"		// Precisa de traduo
#elif L==10	// tr
	"Change country of my institution"		// eviri lazim!
#endif
	,
	[ActChgMyIns] =
#if   L==1	// ca
	"Change my institution"		// Necessita traducci
#elif L==2	// de
	"Change my institution"		// Need bersetzung
#elif L==3	// en
	"Change my institution"
#elif L==4	// es
	"Cambiar mi instituci&oacute;n"
#elif L==5	// fr
	"Change my institution"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar mi instituci&oacute;n"	// Okoteve traduccin
#elif L==7	// it
	"Change my institution"		// Bisogno di traduzione
#elif L==8	// pl
	"Change my institution"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change my institution"		// Precisa de traduo
#elif L==10	// tr
	"Change my institution"		// eviri lazim!
#endif
	,
	[ActChgMyCtr] =
#if   L==1	// ca
	"Change my center"	// Necessita traducci
#elif L==2	// de
	"Change my center"	// Need bersetzung
#elif L==3	// en
	"Change my center"
#elif L==4	// es
	"Cambiar mi centro"
#elif L==5	// fr
	"Change my center"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar mi centro"	// Okoteve traduccin
#elif L==7	// it
	"Change my center"	// Bisogno di traduzione
#elif L==8	// pl
	"Change my center"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change my center"	// Precisa de traduo
#elif L==10	// tr
	"Change my center"	// eviri lazim!
#endif
	,
	[ActChgMyDpt] =
#if   L==1	// ca
	"Change my department"		// Necessita traducci
#elif L==2	// de
	"Change my department"		// Need bersetzung
#elif L==3	// en
	"Change my department"
#elif L==4	// es
	"Cambiar mi departamento"
#elif L==5	// fr
	"Change my department"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar mi departamento"	// Okoteve traduccin
#elif L==7	// it
	"Change my department"		// Bisogno di traduzione
#elif L==8	// pl
	"Change my department"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change my department"		// Precisa de traduo
#elif L==10	// tr
	"Change my department"		// eviri lazim!
#endif
	,
	[ActChgMyOff] =
#if   L==1	// ca
	"Change my office"	// Necessita traducci
#elif L==2	// de
	"Change my office"	// Need bersetzung
#elif L==3	// en
	"Change my office"
#elif L==4	// es
	"Cambiar mi despacho"
#elif L==5	// fr
	"Change my office"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar mi despacho"	// Okoteve traduccin
#elif L==7	// it
	"Change my office"	// Bisogno di traduzione
#elif L==8	// pl
	"Change my office"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change my office"	// Precisa de traduo
#elif L==10	// tr
	"Change my office"	// eviri lazim!
#endif
	,
	[ActChgMyOffPho] =
#if   L==1	// ca
	"Change my office phone"			// Necessita traducci
#elif L==2	// de
	"Change my office phone"			// Need bersetzung
#elif L==3	// en
	"Change my office phone"
#elif L==4	// es
	"Cambiar tel&eacute;fono de mi despacho"
#elif L==5	// fr
	"Change my office phone"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar tel&eacute;fono de mi despacho"	// Okoteve traduccin
#elif L==7	// it
	"Change my office phone"			// Bisogno di traduzione
#elif L==8	// pl
	"Change my office phone"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change my office phone"			// Precisa de traduo
#elif L==10	// tr
	"Change my office phone"			// eviri lazim!
#endif
	,
	[ActReqEdiMyNet] =
#if   L==1	// ca
	"Request edition of my social networks"			// Necessita traducci
#elif L==2	// de
	"Request edition of my social networks"			// Need bersetzung
#elif L==3	// en
	"Request edition of my social networks"
#elif L==4	// es
	"Solicitar edici&oacute;n de mis redes sociales"
#elif L==5	// fr
	"Request edition of my social networks"			// Besoin de traduction
#elif L==6	// gn
	"Solicitar edici&oacute;n de mis redes sociales"	// Okoteve traduccin
#elif L==7	// it
	"Request edition of my social networks"			// Bisogno di traduzione
#elif L==8	// pl
	"Request edition of my social networks"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request edition of my social networks"			// Precisa de traduo
#elif L==10	// tr
	"Request edition of my social networks"			// eviri lazim!
#endif
	,
	[ActChgMyNet] =
#if   L==1	// ca
	"Change my web and social networks"	// Necessita traducci
#elif L==2	// de
	"Change my web and social networks"	// Need bersetzung
#elif L==3	// en
	"Change my web and social networks"
#elif L==4	// es
	"Cambiar mi web y mis redes sociales"
#elif L==5	// fr
	"Change my web and social networks"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar mi web y mis redes sociales"	// Okoteve traduccin
#elif L==7	// it
	"Change my web and social networks"	// Bisogno di traduzione
#elif L==8	// pl
	"Change my web and social networks"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change my web and social networks"	// Precisa de traduo
#elif L==10	// tr
	"Change my web and social networks"	// eviri lazim!
#endif
	,
	[ActReqEdiSet] =
#if   L==1	// ca
	"See forms to edit settings"		// Necessita traducci
#elif L==2	// de
	"See forms to edit settings"		// Need bersetzung
#elif L==3	// en
	"See forms to edit settings"
#elif L==4	// es
	"Ver formularios para editar ajustes"
#elif L==5	// fr
	"See forms to edit settings"		// Besoin de traduction
#elif L==6	// gn
	"Ver formularios para editar ajustes"	// Okoteve traduccin
#elif L==7	// it
	"See forms to edit settings"		// Bisogno di traduzione
#elif L==8	// pl
	"See forms to edit settings"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"See forms to edit settings"		// Precisa de traduo
#elif L==10	// tr
	"See forms to edit settings"		// eviri lazim!
#endif
	,
	[ActChgThe] =
#if   L==1	// ca
	"Change theme"		// Necessita traducci
#elif L==2	// de
	"Change theme"		// Need bersetzung
#elif L==3	// en
	"Change theme"
#elif L==4	// es
	"Cambiar tema"
#elif L==5	// fr
	"Change theme"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar tema"		// Okoteve traduccin
#elif L==7	// it
	"Change theme"		// Bisogno di traduzione
#elif L==8	// pl
	"Change theme"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change theme"		// Precisa de traduo
#elif L==10	// tr
	"Change theme"		// eviri lazim!
#endif
	,
	[ActReqChgLan] =
#if   L==1	// ca
	"Request change of language"	// Necessita traducci
#elif L==2	// de
	"Request change of language"	// Need bersetzung
#elif L==3	// en
	"Request change of language"
#elif L==4	// es
	"Solicitar cambio de idioma"
#elif L==5	// fr
	"Request change of language"	// Besoin de traduction
#elif L==6	// gn
	"Solicitar cambio de idioma"	// Okoteve traduccin
#elif L==7	// it
	"Request change of language"	// Bisogno di traduzione
#elif L==8	// pl
	"Request change of language"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Request change of language"	// Precisa de traduo
#elif L==10	// tr
	"Request change of language"	// eviri lazim!
#endif
	,
	[ActChgLan] =
#if   L==1	// ca
	"Change language"	// Necessita traducci
#elif L==2	// de
	"Change language"	// Need bersetzung
#elif L==3	// en
	"Change language"
#elif L==4	// es
	"Cambiar idioma"
#elif L==5	// fr
	"Change language"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar idioma"	// Okoteve traduccin
#elif L==7	// it
	"Change language"	// Bisogno di traduzione
#elif L==8	// pl
	"Change language"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change language"	// Precisa de traduo
#elif L==10	// tr
	"Change language"	// eviri lazim!
#endif
	,
	[ActChg1stDay] =
#if   L==1	// ca
	"Change first day of the week"			// Necessita traducci
#elif L==2	// de
	"Change first day of the week"			// Need bersetzung
#elif L==3	// en
	"Change first day of the week"
#elif L==4	// es
	"Cambiar primer d&iacute;a de la semana"
#elif L==5	// fr
	"Change first day of the week"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar primer d&iacute;a de la semana"	// Okoteve traduccin
#elif L==7	// it
	"Change first day of the week"			// Bisogno di traduzione
#elif L==8	// pl
	"Change first day of the week"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change first day of the week"			// Precisa de traduo
#elif L==10	// tr
	"Change first day of the week"			// eviri lazim!
#endif
	,
	[ActChgDatFmt] =
#if   L==1	// ca
	"Change date format"		// Necessita traducci
#elif L==2	// de
	"Change date format"		// Need bersetzung
#elif L==3	// en
	"Change date format"
#elif L==4	// es
	"Cambiar formato de fechas"
#elif L==5	// fr
	"Change date format"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar formato de fechas"	// Okoteve traduccin
#elif L==7	// it
	"Change date format"		// Bisogno di traduzione
#elif L==8	// pl
	"Change date format"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change date format"		// Precisa de traduo
#elif L==10	// tr
	"Change date format"		// eviri lazim!
#endif
	,
	[ActChgCol] =
#if   L==1	// ca
	"Change side columns"		// Necessita traducci
#elif L==2	// de
	"Change side columns"		// Need bersetzung
#elif L==3	// en
	"Change side columns"
#elif L==4	// es
	"Cambiar columnas laterales"
#elif L==5	// fr
	"Change side columns"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar columnas laterales"	// Okoteve traduccin
#elif L==7	// it
	"Change side columns"		// Bisogno di traduzione
#elif L==8	// pl
	"Change side columns"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change side columns"		// Precisa de traduo
#elif L==10	// tr
	"Change side columns"		// eviri lazim!
#endif
	,
	[ActChgIco] =
#if   L==1	// ca
	"Change icon set"		// Necessita traducci
#elif L==2	// de
	"Change icon set"		// Need bersetzung
#elif L==3	// en
	"Change icon set"
#elif L==4	// es
	"Cambiar conjunto de iconos"
#elif L==5	// fr
	"Change icon set"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar conjunto de iconos"	// Okoteve traduccin
#elif L==7	// it
	"Change icon set"		// Bisogno di traduzione
#elif L==8	// pl
	"Change icon set"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change icon set"		// Precisa de traduo
#elif L==10	// tr
	"Change icon set"		// eviri lazim!
#endif
	,
	[ActChgMnu] =
#if   L==1	// ca
	"Change menu"		// Necessita traducci
#elif L==2	// de
	"Change menu"		// Need bersetzung
#elif L==3	// en
	"Change menu"
#elif L==4	// es
	"Cambiar men&uacute;"
#elif L==5	// fr
	"Change menu"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar men&uacute;"	// Okoteve traduccin
#elif L==7	// it
	"Change menu"		// Bisogno di traduzione
#elif L==8	// pl
	"Change menu"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change menu"		// Precisa de traduo
#elif L==10	// tr
	"Change menu"		// eviri lazim!
#endif
	,
	[ActChgUsrPho] =
#if   L==1	// ca
	"Change user photo shape"		// Necessita traducci
#elif L==2	// de
	"Change user photo shape"		// Need bersetzung
#elif L==3	// en
	"Change user photo shape"
#elif L==4	// es
	"Cambiar forma de fotos de usuarios"
#elif L==5	// fr
	"Change user photo shape"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar forma de fotos de usuarios"	// Okoteve traduccin
#elif L==7	// it
	"Change user photo shape"		// Bisogno di traduzione
#elif L==8	// pl
	"Change user photo shape"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change user photo shape"		// Precisa de traduo
#elif L==10	// tr
	"Change user photo shape"		// eviri lazim!
#endif
	,
	[ActChgPriPho] =
#if   L==1	// ca
	"Change privacy of my photo"		// Necessita traducci
#elif L==2	// de
	"Change privacy of my photo"		// Need bersetzung
#elif L==3	// en
	"Change privacy of my photo"
#elif L==4	// es
	"Cambiar privacidad de mi foto"
#elif L==5	// fr
	"Change privacy of my photo"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar privacidad de mi foto"		// Okoteve traduccin
#elif L==7	// it
	"Change privacy of my photo"		// Bisogno di traduzione
#elif L==8	// pl
	"Change privacy of my photo"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change privacy of my photo"		// Precisa de traduo
#elif L==10	// tr
	"Change privacy of my photo"		// eviri lazim!
#endif
	,
	[ActChgBasPriPrf] =
#if   L==1	// ca
	"Change privacy of my basic public profile"			// Necessita traducci
#elif L==2	// de
	"Change privacy of my basic public profile"			// Need bersetzung
#elif L==3	// en
	"Change privacy of my basic public profile"
#elif L==4	// es
	"Cambiar privacidad de mi perfil de usuario b&aacute;sico"
#elif L==5	// fr
	"Change privacy of my basic public profile"			// Besoin de traduction
#elif L==6	// gn
	"Cambiar privacidad de mi perfil de usuario b&aacute;sico"	// Okoteve traduccin
#elif L==7	// it
	"Change privacy of my basic public profile"			// Bisogno di traduzione
#elif L==8	// pl
	"Change privacy of my basic public profile"			// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change privacy of my basic public profile"			// Precisa de traduo
#elif L==10	// tr
	"Change privacy of my basic public profile"			// eviri lazim!
#endif
	,
	[ActChgExtPriPrf] =
#if   L==1	// ca
	"Change privacy of my extended public profile"		// Necessita traducci
#elif L==2	// de
	"Change privacy of my extended public profile"		// Need bersetzung
#elif L==3	// en
	"Change privacy of my extended public profile"
#elif L==4	// es
	"Cambiar privacidad de mi perfil de usuario extendido"
#elif L==5	// fr
	"Change privacy of my extended public profile"		// Besoin de traduction
#elif L==6	// gn
	"Cambiar privacidad de mi perfil de usuario extendido"	// Okoteve traduccin
#elif L==7	// it
	"Change privacy of my extended public profile"		// Bisogno di traduzione
#elif L==8	// pl
	"Change privacy of my extended public profile"		// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change privacy of my extended public profile"		// Precisa de traduo
#elif L==10	// tr
	"Change privacy of my extended public profile"		// eviri lazim!
#endif
	,
	[ActChgCooPrf] =
#if   L==1	// ca
	"Change setting about third party cookies"	// Necessita traducci
#elif L==2	// de
	"Change setting about third party cookies"	// Need bersetzung
#elif L==3	// en
	"Change setting about third party cookies"
#elif L==4	// es
	"Cambiar ajuste sobre cookies de terceros"
#elif L==5	// fr
	"Change setting about third party cookies"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar ajuste sobre cookies de terceros"	// Okoteve traduccin
#elif L==7	// it
	"Change setting about third party cookies"	// Bisogno di traduzione
#elif L==8	// pl
	"Change setting about third party cookies"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change setting about third party cookies"	// Precisa de traduo
#elif L==10	// tr
	"Change setting about third party cookies"	// eviri lazim!
#endif
	,
	[ActChgNtfPrf] =
#if   L==1	// ca
	"Change whether to notify by email"	// Necessita traducci
#elif L==2	// de
	"Change whether to notify by email"	// Need bersetzung
#elif L==3	// en
	"Change whether to notify by email"
#elif L==4	// es
	"Cambiar si notificar por correo"
#elif L==5	// fr
	"Change whether to notify by email"	// Besoin de traduction
#elif L==6	// gn
	"Cambiar si notificar por correo"	// Okoteve traduccin
#elif L==7	// it
	"Change whether to notify by email"	// Bisogno di traduzione
#elif L==8	// pl
	"Change whether to notify by email"	// Potrzebujesz tlumaczenie
#elif L==9	// pt
	"Change whether to notify by email"	// Precisa de traduo
#elif L==10	// tr
	"Change whether to notify by email"	// eviri lazim!
#endif
	};
